% phonenumbers package: phonenumbers-DE.def
% Module for German telephone numbers
% Author: K. Wehr
% Version: 2.6
% Date: 2025-05-06
\clist_const:Nn \c_phone_DE_ortsvorwahlen_clist {0201,
0202,
0203,
02041,
02043,
02045,
02051,
02052,
02053,
02054,
02056,
02058,
02064,
02065,
02066,
0208,
0209,
02102,
02103,
02104,
0211,
0212,
02129,
02131,
02132,
02133,
02137,
0214,
02150,
02151,
02152,
02153,
02154,
02156,
02157,
02158,
02159,
02161,
02162,
02163,
02164,
02165,
02166,
02171,
02173,
02174,
02175,
02181,
02182,
02183,
02191,
02192,
02193,
02195,
02196,
02202,
02203,
02204,
02205,
02206,
02207,
02208,
0221,
02222,
02223,
02224,
02225,
02226,
02227,
02228,
02232,
02233,
02234,
02235,
02236,
02237,
02238,
02241,
02242,
02243,
02244,
02245,
02246,
02247,
02248,
02251,
02252,
02253,
02254,
02255,
02256,
02257,
02261,
02262,
02263,
02264,
02265,
02266,
02267,
02268,
02269,
02271,
02272,
02273,
02274,
02275,
0228,
02291,
02292,
02293,
02294,
02295,
02296,
02297,
02301,
02302,
02303,
02304,
02305,
02306,
02307,
02308,
02309,
0231,
02323,
02324,
02325,
02327,
02330,
02331,
02332,
02333,
02334,
02335,
02336,
02337,
02338,
02339,
0234,
02351,
02352,
02353,
02354,
02355,
02357,
02358,
02359,
02360,
02361,
02362,
02363,
02364,
02365,
02366,
02367,
02368,
02369,
02371,
02372,
02373,
02374,
02375,
02377,
02378,
02379,
02381,
02382,
02383,
02384,
02385,
02387,
02388,
02389,
02391,
02392,
02393,
02394,
02395,
02401,
02402,
02403,
02404,
02405,
02406,
02407,
02408,
02409,
0241,
02421,
02422,
02423,
02424,
02425,
02426,
02427,
02428,
02429,
02431,
02432,
02433,
02434,
02435,
02436,
02440,
02441,
02443,
02444,
02445,
02446,
02447,
02448,
02449,
02451,
02452,
02453,
02454,
02455,
02456,
02461,
02462,
02463,
02464,
02465,
02471,
02472,
02473,
02474,
02482,
02484,
02485,
02486,
02501,
02502,
02504,
02505,
02506,
02507,
02508,
02509,
0251,
02520,
02521,
02522,
02523,
02524,
02525,
02526,
02527,
02528,
02529,
02532,
02533,
02534,
02535,
02536,
02538,
02541,
02542,
02543,
02545,
02546,
02547,
02548,
02551,
02552,
02553,
02554,
02555,
02556,
02557,
02558,
02561,
02562,
02563,
02564,
02565,
02566,
02567,
02568,
02571,
02572,
02573,
02574,
02575,
02581,
02582,
02583,
02584,
02585,
02586,
02587,
02588,
02590,
02591,
02592,
02593,
02594,
02595,
02596,
02597,
02598,
02599,
02601,
02602,
02603,
02604,
02605,
02606,
02607,
02608,
0261,
02620,
02621,
02622,
02623,
02624,
02625,
02626,
02627,
02628,
02630,
02631,
02632,
02633,
02634,
02635,
02636,
02637,
02638,
02639,
02641,
02642,
02643,
02644,
02645,
02646,
02647,
02651,
02652,
02653,
02654,
02655,
02656,
02657,
02661,
02662,
02663,
02664,
02666,
02667,
02671,
02672,
02673,
02674,
02675,
02676,
02677,
02678,
02680,
02681,
02682,
02683,
02684,
02685,
02686,
02687,
02688,
02689,
02691,
02692,
02693,
02694,
02695,
02696,
02697,
0271,
02721,
02722,
02723,
02724,
02725,
02732,
02733,
02734,
02735,
02736,
02737,
02738,
02739,
02741,
02742,
02743,
02744,
02745,
02747,
02750,
02751,
02752,
02753,
02754,
02755,
02758,
02759,
02761,
02762,
02763,
02764,
02770,
02771,
02772,
02773,
02774,
02775,
02776,
02777,
02778,
02779,
02801,
02802,
02803,
02804,
0281,
02821,
02822,
02823,
02824,
02825,
02826,
02827,
02828,
02831,
02832,
02833,
02834,
02835,
02836,
02837,
02838,
02839,
02841,
02842,
02843,
02844,
02845,
02850,
02851,
02852,
02853,
02855,
02856,
02857,
02858,
02859,
02861,
02862,
02863,
02864,
02865,
02866,
02867,
02871,
02872,
02873,
02874,
02902,
02903,
02904,
02905,
0291,
02921,
02922,
02923,
02924,
02925,
02927,
02928,
02931,
02932,
02933,
02934,
02935,
02937,
02938,
02941,
02942,
02943,
02944,
02945,
02947,
02948,
02951,
02952,
02953,
02954,
02955,
02957,
02958,
02961,
02962,
02963,
02964,
02971,
02972,
02973,
02974,
02975,
02977,
02981,
02982,
02983,
02984,
02985,
02991,
02992,
02993,
02994,
030,
03301,
03302,
03303,
03304,
033051,
033053,
033054,
033055,
033056,
03306,
03307,
033080,
033082,
033083,
033084,
033085,
033086,
033087,
033088,
033089,
033093,
033094,
0331,
033200,
033201,
033202,
033203,
033204,
033205,
033206,
033207,
033208,
033209,
03321,
03322,
033230,
033231,
033232,
033233,
033234,
033235,
033237,
033238,
033239,
03327,
03328,
03329,
03331,
03332,
033331,
033332,
033333,
033334,
033335,
033336,
033337,
033338,
03334,
03335,
033361,
033362,
033363,
033364,
033365,
033366,
033367,
033368,
033369,
03337,
03338,
033393,
033394,
033395,
033396,
033397,
033398,
03341,
03342,
033432,
033433,
033434,
033435,
033436,
033437,
033438,
033439,
03344,
033451,
033452,
033454,
033456,
033457,
033458,
03346,
033470,
033472,
033473,
033474,
033475,
033476,
033477,
033478,
033479,
0335,
033601,
033602,
033603,
033604,
033605,
033606,
033607,
033608,
033609,
03361,
03362,
033631,
033632,
033633,
033634,
033635,
033636,
033637,
033638,
03364,
033652,
033653,
033654,
033655,
033656,
033657,
03366,
033671,
033672,
033673,
033674,
033675,
033676,
033677,
033678,
033679,
033701,
033702,
033703,
033704,
033708,
03371,
03372,
033731,
033732,
033733,
033734,
033741,
033742,
033743,
033744,
033745,
033746,
033747,
033748,
03375,
033760,
033762,
033763,
033764,
033765,
033766,
033767,
033768,
033769,
03377,
03378,
03379,
03381,
03382,
033830,
033831,
033832,
033833,
033834,
033835,
033836,
033837,
033838,
033839,
033841,
033843,
033844,
033845,
033846,
033847,
033848,
033849,
03385,
03386,
033870,
033872,
033873,
033874,
033875,
033876,
033877,
033878,
03391,
033920,
033921,
033922,
033923,
033924,
033925,
033926,
033928,
033929,
033931,
033932,
033933,
03394,
03395,
033962,
033963,
033964,
033965,
033966,
033967,
033968,
033969,
033970,
033971,
033972,
033973,
033974,
033975,
033976,
033977,
033978,
033979,
033981,
033982,
033983,
033984,
033986,
033989,
0340,
0341,
034202,
034203,
034204,
034205,
034206,
034207,
034208,
03421,
034221,
034222,
034223,
034224,
03423,
034241,
034242,
034243,
034244,
03425,
034261,
034262,
034263,
034291,
034292,
034293,
034294,
034295,
034296,
034297,
034298,
034299,
03431,
034321,
034322,
034324,
034325,
034327,
034328,
03433,
034341,
034342,
034343,
034344,
034345,
034346,
034347,
034348,
03435,
034361,
034362,
034363,
034364,
03437,
034381,
034382,
034383,
034384,
034385,
034386,
03441,
034422,
034423,
034424,
034425,
034426,
03443,
034441,
034443,
034444,
034445,
034446,
03445,
034461,
034462,
034463,
034464,
034465,
034466,
034467,
03447,
03448,
034491,
034492,
034493,
034494,
034495,
034496,
034497,
034498,
0345,
034600,
034601,
034602,
034603,
034604,
034605,
034606,
034607,
034609,
03461,
03462,
034632,
034633,
034635,
034636,
034637,
034638,
034639,
03464,
034651,
034652,
034653,
034654,
034656,
034658,
034659,
03466,
034671,
034672,
034673,
034691,
034692,
03471,
034721,
034722,
03473,
034741,
034742,
034743,
034745,
034746,
03475,
03476,
034771,
034772,
034773,
034774,
034775,
034776,
034779,
034781,
034782,
034783,
034785,
034901,
034903,
034904,
034905,
034906,
034907,
034909,
03491,
034920,
034921,
034922,
034923,
034924,
034925,
034926,
034927,
034928,
034929,
03493,
03494,
034953,
034954,
034955,
034956,
03496,
034973,
034975,
034976,
034977,
034978,
034979,
03501,
035020,
035021,
035022,
035023,
035024,
035025,
035026,
035027,
035028,
035032,
035033,
03504,
035052,
035053,
035054,
035055,
035056,
035057,
035058,
0351,
035200,
035201,
035202,
035203,
035204,
035205,
035206,
035207,
035208,
035209,
03521,
03522,
03523,
035240,
035241,
035242,
035243,
035244,
035245,
035246,
035247,
035248,
035249,
03525,
035263,
035264,
035265,
035266,
035267,
035268,
03528,
03529,
03531,
035322,
035323,
035324,
035325,
035326,
035327,
035329,
03533,
035341,
035342,
035343,
03535,
035361,
035362,
035363,
035364,
035365,
03537,
035383,
035384,
035385,
035386,
035387,
035388,
035389,
03541,
03542,
035433,
035434,
035435,
035436,
035439,
03544,
035451,
035452,
035453,
035454,
035455,
035456,
03546,
035471,
035472,
035473,
035474,
035475,
035476,
035477,
035478,
0355,
035600,
035601,
035602,
035603,
035604,
035605,
035606,
035607,
035608,
035609,
03561,
03562,
03563,
03564,
035691,
035692,
035693,
035694,
035695,
035696,
035697,
035698,
03571,
035722,
035723,
035724,
035725,
035726,
035727,
035728,
03573,
03574,
035751,
035752,
035753,
035754,
035755,
035756,
03576,
035771,
035772,
035773,
035774,
035775,
03578,
035792,
035793,
035795,
035796,
035797,
03581,
035820,
035822,
035823,
035825,
035826,
035827,
035828,
035829,
03583,
035841,
035842,
035843,
035844,
03585,
03586,
035872,
035873,
035874,
035875,
035876,
035877,
03588,
035891,
035892,
035893,
035894,
035895,
03591,
03592,
035930,
035931,
035932,
035933,
035934,
035935,
035936,
035937,
035938,
035939,
03594,
035951,
035952,
035953,
035954,
035955,
03596,
035971,
035973,
035974,
035975,
03601,
036020,
036021,
036022,
036023,
036024,
036025,
036026,
036027,
036028,
036029,
03603,
036041,
036042,
036043,
03605,
03606,
036071,
036072,
036074,
036075,
036076,
036077,
036081,
036082,
036083,
036084,
036085,
036087,
0361,
036200,
036201,
036202,
036203,
036204,
036205,
036206,
036207,
036208,
036209,
03621,
03622,
03623,
03624,
036252,
036253,
036254,
036255,
036256,
036257,
036258,
036259,
03628,
03629,
03631,
03632,
036330,
036331,
036332,
036333,
036334,
036335,
036336,
036337,
036338,
03634,
03635,
03636,
036370,
036371,
036372,
036373,
036374,
036375,
036376,
036377,
036378,
036379,
03641,
036421,
036422,
036423,
036424,
036425,
036426,
036427,
036428,
03643,
03644,
036450,
036451,
036452,
036453,
036454,
036458,
036459,
036461,
036462,
036463,
036464,
036465,
03647,
036481,
036482,
036483,
036484,
0365,
036601,
036602,
036603,
036604,
036605,
036606,
036607,
036608,
03661,
036621,
036622,
036623,
036624,
036625,
036626,
036628,
03663,
036640,
036642,
036643,
036644,
036645,
036646,
036647,
036648,
036649,
036651,
036652,
036653,
036691,
036692,
036693,
036694,
036695,
036701,
036702,
036703,
036704,
036705,
03671,
03672,
036730,
036731,
036732,
036733,
036734,
036735,
036736,
036737,
036738,
036739,
036741,
036742,
036743,
036744,
03675,
036761,
036762,
036764,
036766,
03677,
036781,
036782,
036783,
036784,
036785,
03679,
03681,
03682,
03683,
036840,
036841,
036842,
036843,
036844,
036845,
036846,
036847,
036848,
036849,
03685,
03686,
036870,
036871,
036873,
036874,
036875,
036878,
03691,
036920,
036921,
036922,
036923,
036924,
036925,
036926,
036927,
036928,
036929,
03693,
036940,
036941,
036943,
036944,
036945,
036946,
036947,
036948,
036949,
03695,
036961,
036962,
036963,
036964,
036965,
036966,
036967,
036968,
036969,
0371,
037200,
037202,
037203,
037204,
037206,
037207,
037208,
037209,
03721,
03722,
03723,
03724,
03725,
03726,
03727,
037291,
037292,
037293,
037294,
037295,
037296,
037297,
037298,
03731,
037320,
037321,
037322,
037323,
037324,
037325,
037326,
037327,
037328,
037329,
03733,
037341,
037342,
037343,
037344,
037346,
037347,
037348,
037349,
03735,
037360,
037361,
037362,
037363,
037364,
037365,
037366,
037367,
037368,
037369,
03737,
037381,
037382,
037383,
037384,
03741,
037421,
037422,
037423,
037430,
037431,
037432,
037433,
037434,
037435,
037436,
037437,
037438,
037439,
03744,
03745,
037462,
037463,
037464,
037465,
037467,
037468,
0375,
037600,
037601,
037602,
037603,
037604,
037605,
037606,
037607,
037608,
037609,
03761,
03762,
03763,
03764,
03765,
03771,
03772,
03773,
03774,
037752,
037754,
037755,
037756,
037757,
0381,
038201,
038202,
038203,
038204,
038205,
038206,
038207,
038208,
038209,
03821,
038220,
038221,
038222,
038223,
038224,
038225,
038226,
038227,
038228,
038229,
038231,
038232,
038233,
038234,
038292,
038293,
038294,
038295,
038296,
038297,
038300,
038301,
038302,
038303,
038304,
038305,
038306,
038307,
038308,
038309,
03831,
038320,
038321,
038322,
038323,
038324,
038325,
038326,
038327,
038328,
038331,
038332,
038333,
038334,
03834,
038351,
038352,
038353,
038354,
038355,
038356,
03836,
038370,
038371,
038372,
038373,
038374,
038375,
038376,
038377,
038378,
038379,
03838,
038391,
038392,
038393,
03841,
038422,
038423,
038424,
038425,
038426,
038427,
038428,
038429,
03843,
03844,
038450,
038451,
038452,
038453,
038454,
038455,
038456,
038457,
038458,
038459,
038461,
038462,
038464,
038466,
03847,
038481,
038482,
038483,
038484,
038485,
038486,
038488,
0385,
03860,
03861,
03863,
03865,
03866,
03867,
03868,
03869,
03871,
038720,
038721,
038722,
038723,
038724,
038725,
038726,
038727,
038728,
038729,
038731,
038732,
038733,
038735,
038736,
038737,
038738,
03874,
038750,
038751,
038752,
038753,
038754,
038755,
038756,
038757,
038758,
038759,
03876,
03877,
038780,
038781,
038782,
038783,
038784,
038785,
038787,
038788,
038789,
038791,
038792,
038793,
038794,
038796,
038797,
03881,
038821,
038822,
038823,
038824,
038825,
038826,
038827,
038828,
03883,
038841,
038842,
038843,
038844,
038845,
038847,
038848,
038850,
038851,
038852,
038853,
038854,
038855,
038856,
038858,
038859,
03886,
038871,
038872,
038873,
038874,
038875,
038876,
039000,
039001,
039002,
039003,
039004,
039005,
039006,
039007,
039008,
039009,
03901,
03902,
039030,
039031,
039032,
039033,
039034,
039035,
039036,
039037,
039038,
039039,
03904,
039050,
039051,
039052,
039053,
039054,
039055,
039056,
039057,
039058,
039059,
039061,
039062,
03907,
039080,
039081,
039082,
039083,
039084,
039085,
039086,
039087,
039088,
039089,
03909,
0391,
039200,
039201,
039202,
039203,
039204,
039205,
039206,
039207,
039208,
039209,
03921,
039221,
039222,
039223,
039224,
039225,
039226,
03923,
039241,
039242,
039243,
039244,
039245,
039246,
039247,
039248,
03925,
039262,
039263,
039264,
039265,
039266,
039267,
039268,
03928,
039291,
039292,
039293,
039294,
039295,
039296,
039297,
039298,
03931,
039320,
039321,
039322,
039323,
039324,
039325,
039327,
039328,
039329,
03933,
039341,
039342,
039343,
039344,
039345,
039346,
039347,
039348,
039349,
03935,
039361,
039362,
039363,
039364,
039365,
039366,
03937,
039382,
039383,
039384,
039386,
039387,
039388,
039389,
039390,
039391,
039392,
039393,
039394,
039395,
039396,
039397,
039398,
039399,
039400,
039401,
039402,
039403,
039404,
039405,
039406,
039407,
039408,
039409,
03941,
039421,
039422,
039423,
039424,
039425,
039426,
039427,
039428,
03943,
03944,
039451,
039452,
039453,
039454,
039455,
039456,
039457,
039458,
039459,
03946,
03947,
039481,
039482,
039483,
039484,
039485,
039487,
039488,
039489,
03949,
0395,
039600,
039601,
039602,
039603,
039604,
039605,
039606,
039607,
039608,
03961,
03962,
03963,
03964,
03965,
03966,
03967,
03968,
03969,
03971,
039721,
039722,
039723,
039724,
039726,
039727,
039728,
03973,
039740,
039741,
039742,
039743,
039744,
039745,
039746,
039747,
039748,
039749,
039751,
039752,
039753,
039754,
03976,
039771,
039772,
039773,
039774,
039775,
039776,
039777,
039778,
039779,
03981,
039820,
039821,
039822,
039823,
039824,
039825,
039826,
039827,
039828,
039829,
039831,
039832,
039833,
03984,
039851,
039852,
039853,
039854,
039855,
039856,
039857,
039858,
039859,
039861,
039862,
039863,
03987,
039881,
039882,
039883,
039884,
039885,
039886,
039887,
039888,
039889,
03991,
039921,
039922,
039923,
039924,
039925,
039926,
039927,
039928,
039929,
039931,
039932,
039933,
039934,
03994,
039951,
039952,
039953,
039954,
039955,
039956,
039957,
039959,
03996,
039971,
039972,
039973,
039975,
039976,
039977,
039978,
03998,
039991,
039992,
039993,
039994,
039995,
039996,
039997,
039998,
039999,
040,
04101,
04102,
04103,
04104,
04105,
04106,
04107,
04108,
04109,
04120,
04121,
04122,
04123,
04124,
04125,
04126,
04127,
04128,
04129,
04131,
04132,
04133,
04134,
04135,
04136,
04137,
04138,
04139,
04140,
04141,
04142,
04143,
04144,
04146,
04148,
04149,
04151,
04152,
04153,
04154,
04155,
04156,
04158,
04159,
04161,
04162,
04163,
04164,
04165,
04166,
04167,
04168,
04169,
04171,
04172,
04173,
04174,
04175,
04176,
04177,
04178,
04179,
04180,
04181,
04182,
04183,
04184,
04185,
04186,
04187,
04188,
04189,
04191,
04192,
04193,
04194,
04195,
04202,
04203,
04204,
04205,
04206,
04207,
04208,
04209,
0421,
04221,
04222,
04223,
04224,
04230,
04231,
04232,
04233,
04234,
04235,
04236,
04237,
04238,
04239,
04240,
04241,
04242,
04243,
04244,
04245,
04246,
04247,
04248,
04249,
04251,
04252,
04253,
04254,
04255,
04256,
04257,
04258,
04260,
04261,
04262,
04263,
04264,
04265,
04266,
04267,
04268,
04269,
04271,
04272,
04273,
04274,
04275,
04276,
04277,
04281,
04282,
04283,
04284,
04285,
04286,
04287,
04288,
04289,
04292,
04293,
04294,
04295,
04296,
04297,
04298,
04302,
04303,
04305,
04307,
04308,
0431,
04320,
04321,
04322,
04323,
04324,
04326,
04327,
04328,
04329,
04330,
04331,
04332,
04333,
04334,
04335,
04336,
04337,
04338,
04339,
04340,
04342,
04343,
04344,
04346,
04347,
04348,
04349,
04351,
04352,
04353,
04354,
04355,
04356,
04357,
04358,
04361,
04362,
04363,
04364,
04365,
04366,
04367,
04371,
04372,
04381,
04382,
04383,
04384,
04385,
04392,
04393,
04394,
04401,
04402,
04403,
04404,
04405,
04406,
04407,
04408,
04409,
0441,
04421,
04422,
04423,
04425,
04426,
04431,
04432,
04433,
04434,
04435,
04441,
04442,
04443,
04444,
04445,
04446,
04447,
04451,
04452,
04453,
04454,
04455,
04456,
04458,
04461,
04462,
04463,
04464,
04465,
04466,
04467,
04468,
04469,
04471,
04472,
04473,
04474,
04475,
04477,
04478,
04479,
04480,
04481,
04482,
04483,
04484,
04485,
04486,
04487,
04488,
04489,
04491,
04492,
04493,
04494,
04495,
04496,
04497,
04498,
04499,
04501,
04502,
04503,
04504,
04505,
04506,
04508,
04509,
0451,
04521,
04522,
04523,
04524,
04525,
04526,
04527,
04528,
04529,
04531,
04532,
04533,
04534,
04535,
04536,
04537,
04539,
04541,
04542,
04543,
04544,
04545,
04546,
04547,
04550,
04551,
04552,
04553,
04554,
04555,
04556,
04557,
04558,
04559,
04561,
04562,
04563,
04564,
04602,
04603,
04604,
04605,
04606,
04607,
04608,
04609,
0461,
04621,
04622,
04623,
04624,
04625,
04626,
04627,
04630,
04631,
04632,
04633,
04634,
04635,
04636,
04637,
04638,
04639,
04641,
04642,
04643,
04644,
04646,
04651,
04661,
04662,
04663,
04664,
04665,
04666,
04667,
04668,
04671,
04672,
04673,
04674,
04681,
04682,
04683,
04684,
04702,
04703,
04704,
04705,
04706,
04707,
04708,
0471,
04721,
04722,
04723,
04724,
04725,
04731,
04732,
04733,
04734,
04735,
04736,
04737,
04740,
04741,
04742,
04743,
04744,
04745,
04746,
04747,
04748,
04749,
04751,
04752,
04753,
04754,
04755,
04756,
04757,
04758,
04761,
04762,
04763,
04764,
04765,
04766,
04767,
04768,
04769,
04770,
04771,
04772,
04773,
04774,
04775,
04776,
04777,
04778,
04779,
04791,
04792,
04793,
04794,
04795,
04796,
04802,
04803,
04804,
04805,
04806,
0481,
04821,
04822,
04823,
04824,
04825,
04826,
04827,
04828,
04829,
04830,
04832,
04833,
04834,
04835,
04836,
04837,
04838,
04839,
04841,
04842,
04843,
04844,
04845,
04846,
04847,
04848,
04849,
04851,
04852,
04853,
04854,
04855,
04856,
04857,
04858,
04859,
04861,
04862,
04863,
04864,
04865,
04871,
04872,
04873,
04874,
04875,
04876,
04877,
04881,
04882,
04883,
04884,
04885,
04892,
04893,
04902,
04903,
0491,
04920,
04921,
04922,
04923,
04924,
04925,
04926,
04927,
04928,
04929,
04931,
04932,
04933,
04934,
04935,
04936,
04938,
04939,
04941,
04942,
04943,
04944,
04945,
04946,
04947,
04948,
04950,
04951,
04952,
04953,
04954,
04955,
04956,
04957,
04958,
04959,
04961,
04962,
04963,
04964,
04965,
04966,
04967,
04968,
04971,
04972,
04973,
04974,
04975,
04976,
04977,
05021,
05022,
05023,
05024,
05025,
05026,
05027,
05028,
05031,
05032,
05033,
05034,
05035,
05036,
05037,
05041,
05042,
05043,
05044,
05045,
05051,
05052,
05053,
05054,
05055,
05056,
05060,
05062,
05063,
05064,
05065,
05066,
05067,
05068,
05069,
05071,
05072,
05073,
05074,
05082,
05083,
05084,
05085,
05086,
05101,
05102,
05103,
05105,
05108,
05109,
0511,
05121,
05123,
05126,
05127,
05128,
05129,
05130,
05131,
05132,
05135,
05136,
05137,
05138,
05139,
05141,
05142,
05143,
05144,
05145,
05146,
05147,
05148,
05149,
05151,
05152,
05153,
05154,
05155,
05156,
05157,
05158,
05159,
05161,
05162,
05163,
05164,
05165,
05166,
05167,
05168,
05171,
05172,
05173,
05174,
05175,
05176,
05177,
05181,
05182,
05183,
05184,
05185,
05186,
05187,
05190,
05191,
05192,
05193,
05194,
05195,
05196,
05197,
05198,
05199,
05201,
05202,
05203,
05204,
05205,
05206,
05207,
05208,
05209,
0521,
05221,
05222,
05223,
05224,
05225,
05226,
05228,
05231,
05232,
05233,
05234,
05235,
05236,
05237,
05238,
05241,
05242,
05244,
05245,
05246,
05247,
05248,
05250,
05251,
05252,
05253,
05254,
05255,
05257,
05258,
05259,
05261,
05262,
05263,
05264,
05265,
05266,
05271,
05272,
05273,
05274,
05275,
05276,
05277,
05278,
05281,
05282,
05283,
05284,
05285,
05286,
05292,
05293,
05294,
05295,
05300,
05301,
05302,
05303,
05304,
05305,
05306,
05307,
05308,
05309,
0531,
05320,
05321,
05322,
05323,
05324,
05325,
05326,
05327,
05328,
05329,
05331,
05332,
05333,
05334,
05335,
05336,
05337,
05339,
05341,
05344,
05345,
05346,
05347,
05351,
05352,
05353,
05354,
05355,
05356,
05357,
05358,
05361,
05362,
05363,
05364,
05365,
05366,
05367,
05368,
05371,
05372,
05373,
05374,
05375,
05376,
05377,
05378,
05379,
05381,
05382,
05383,
05384,
05401,
05402,
05403,
05404,
05405,
05406,
05407,
05409,
0541,
05421,
05422,
05423,
05424,
05425,
05426,
05427,
05428,
05429,
05431,
05432,
05433,
05434,
05435,
05436,
05437,
05438,
05439,
05441,
05442,
05443,
05444,
05445,
05446,
05447,
05448,
05451,
05452,
05453,
05454,
05455,
05456,
05457,
05458,
05459,
05461,
05462,
05464,
05465,
05466,
05467,
05468,
05471,
05472,
05473,
05474,
05475,
05476,
05481,
05482,
05483,
05484,
05485,
05491,
05492,
05493,
05494,
05495,
05502,
05503,
05504,
05505,
05506,
05507,
05508,
05509,
0551,
05520,
05521,
05522,
05523,
05524,
05525,
05527,
05528,
05529,
05531,
05532,
05533,
05534,
05535,
05536,
05541,
05542,
05543,
05544,
05545,
05546,
05551,
05552,
05553,
05554,
05555,
05556,
05561,
05562,
05563,
05564,
05565,
05571,
05572,
05573,
05574,
05582,
05583,
05584,
05585,
05586,
05592,
05593,
05594,
05601,
05602,
05603,
05604,
05605,
05606,
05607,
05608,
05609,
0561,
05621,
05622,
05623,
05624,
05625,
05626,
05631,
05632,
05633,
05634,
05635,
05636,
05641,
05642,
05643,
05644,
05645,
05646,
05647,
05648,
05650,
05651,
05652,
05653,
05654,
05655,
05656,
05657,
05658,
05659,
05661,
05662,
05663,
05664,
05665,
05671,
05672,
05673,
05674,
05675,
05676,
05677,
05681,
05682,
05683,
05684,
05685,
05686,
05691,
05692,
05693,
05694,
05695,
05696,
05702,
05703,
05704,
05705,
05706,
05707,
0571,
05721,
05722,
05723,
05724,
05725,
05726,
05731,
05732,
05733,
05734,
05741,
05742,
05743,
05744,
05745,
05746,
05751,
05752,
05753,
05754,
05755,
05761,
05763,
05764,
05765,
05766,
05767,
05768,
05769,
05771,
05772,
05773,
05774,
05775,
05776,
05777,
05802,
05803,
05804,
05805,
05806,
05807,
05808,
0581,
05820,
05821,
05822,
05823,
05824,
05825,
05826,
05827,
05828,
05829,
05831,
05832,
05833,
05834,
05835,
05836,
05837,
05838,
05839,
05840,
05841,
05842,
05843,
05844,
05845,
05846,
05848,
05849,
05850,
05851,
05852,
05853,
05854,
05855,
05857,
05858,
05859,
05861,
05862,
05863,
05864,
05865,
05872,
05873,
05874,
05875,
05882,
05883,
05901,
05902,
05903,
05904,
05905,
05906,
05907,
05908,
05909,
0591,
05921,
05922,
05923,
05924,
05925,
05926,
05931,
05932,
05933,
05934,
05935,
05936,
05937,
05939,
05941,
05942,
05943,
05944,
05945,
05946,
05947,
05948,
05951,
05952,
05953,
05954,
05955,
05956,
05957,
05961,
05962,
05963,
05964,
05965,
05966,
05971,
05973,
05975,
05976,
05977,
05978,
06002,
06003,
06004,
06007,
06008,
06020,
06021,
06022,
06023,
06024,
06026,
06027,
06028,
06029,
06031,
06032,
06033,
06034,
06035,
06036,
06039,
06041,
06042,
06043,
06044,
06045,
06046,
06047,
06048,
06049,
06050,
06051,
06052,
06053,
06054,
06055,
06056,
06057,
06058,
06059,
06061,
06062,
06063,
06066,
06068,
06071,
06073,
06074,
06078,
06081,
06082,
06083,
06084,
06085,
06086,
06087,
06092,
06093,
06094,
06095,
06096,
06101,
06102,
06103,
06104,
06105,
06106,
06107,
06108,
06109,
0611,
06120,
06122,
06123,
06124,
06126,
06127,
06128,
06129,
06130,
06131,
06132,
06133,
06134,
06135,
06136,
06138,
06139,
06142,
06144,
06145,
06146,
06147,
06150,
06151,
06152,
06154,
06155,
06157,
06158,
06159,
06161,
06162,
06163,
06164,
06165,
06166,
06167,
06171,
06172,
06173,
06174,
06175,
06181,
06182,
06183,
06184,
06185,
06186,
06187,
06188,
06190,
06192,
06195,
06196,
06198,
06201,
06202,
06203,
06204,
06205,
06206,
06207,
06209,
0621,
06220,
06221,
06222,
06223,
06224,
06226,
06227,
06228,
06229,
06231,
06232,
06233,
06234,
06235,
06236,
06237,
06238,
06239,
06241,
06242,
06243,
06244,
06245,
06246,
06247,
06249,
06251,
06252,
06253,
06254,
06255,
06256,
06257,
06258,
06261,
06262,
06263,
06264,
06265,
06266,
06267,
06268,
06269,
06271,
06272,
06274,
06275,
06276,
06281,
06282,
06283,
06284,
06285,
06286,
06287,
06291,
06292,
06293,
06294,
06295,
06296,
06297,
06298,
06301,
06302,
06303,
06304,
06305,
06306,
06307,
06308,
0631,
06321,
06322,
06323,
06324,
06325,
06326,
06327,
06328,
06329,
06331,
06332,
06333,
06334,
06335,
06336,
06337,
06338,
06339,
06340,
06341,
06342,
06343,
06344,
06345,
06346,
06347,
06348,
06349,
06351,
06352,
06353,
06355,
06356,
06357,
06358,
06359,
06361,
06362,
06363,
06364,
06371,
06372,
06373,
06374,
06375,
06381,
06382,
06383,
06384,
06385,
06386,
06387,
06391,
06392,
06393,
06394,
06395,
06396,
06397,
06398,
06400,
06401,
06402,
06403,
06404,
06405,
06406,
06407,
06408,
06409,
0641,
06420,
06421,
06422,
06423,
06424,
06425,
06426,
06427,
06428,
06429,
06430,
06431,
06432,
06433,
06434,
06435,
06436,
06438,
06439,
06440,
06441,
06442,
06443,
06444,
06445,
06446,
06447,
06449,
06451,
06452,
06453,
06454,
06455,
06456,
06457,
06458,
06461,
06462,
06464,
06465,
06466,
06467,
06468,
06471,
06472,
06473,
06474,
06475,
06476,
06477,
06478,
06479,
06482,
06483,
06484,
06485,
06486,
06500,
06501,
06502,
06503,
06504,
06505,
06506,
06507,
06508,
06509,
0651,
06522,
06523,
06524,
06525,
06526,
06527,
06531,
06532,
06533,
06534,
06535,
06536,
06541,
06542,
06543,
06544,
06545,
06550,
06551,
06552,
06553,
06554,
06555,
06556,
06557,
06558,
06559,
06561,
06562,
06563,
06564,
06565,
06566,
06567,
06568,
06569,
06571,
06572,
06573,
06574,
06575,
06578,
06580,
06581,
06582,
06583,
06584,
06585,
06586,
06587,
06588,
06589,
06591,
06592,
06593,
06594,
06595,
06596,
06597,
06599,
0661,
06620,
06621,
06622,
06623,
06624,
06625,
06626,
06627,
06628,
06629,
06630,
06631,
06633,
06634,
06635,
06636,
06637,
06638,
06639,
06641,
06642,
06643,
06644,
06645,
06646,
06647,
06648,
06650,
06651,
06652,
06653,
06654,
06655,
06656,
06657,
06658,
06659,
06660,
06661,
06663,
06664,
06665,
06666,
06667,
06668,
06669,
06670,
06672,
06673,
06674,
06675,
06676,
06677,
06678,
06681,
06682,
06683,
06684,
06691,
06692,
06693,
06694,
06695,
06696,
06697,
06698,
06701,
06703,
06704,
06706,
06707,
06708,
06709,
0671,
06721,
06722,
06723,
06724,
06725,
06726,
06727,
06728,
06731,
06732,
06733,
06734,
06735,
06736,
06737,
06741,
06742,
06743,
06744,
06745,
06746,
06747,
06751,
06752,
06753,
06754,
06755,
06756,
06757,
06758,
06761,
06762,
06763,
06764,
06765,
06766,
06771,
06772,
06773,
06774,
06775,
06776,
06781,
06782,
06783,
06784,
06785,
06786,
06787,
06788,
06789,
06802,
06803,
06804,
06805,
06806,
06809,
0681,
06821,
06824,
06825,
06826,
06827,
06831,
06832,
06833,
06834,
06835,
06836,
06837,
06838,
06841,
06842,
06843,
06844,
06848,
06849,
06851,
06852,
06853,
06854,
06855,
06856,
06857,
06858,
06861,
06864,
06865,
06866,
06867,
06868,
06869,
06871,
06872,
06873,
06874,
06875,
06876,
06881,
06887,
06888,
06893,
06894,
06897,
06898,
069,
07021,
07022,
07023,
07024,
07025,
07026,
07031,
07032,
07033,
07034,
07041,
07042,
07043,
07044,
07045,
07046,
07051,
07052,
07053,
07054,
07055,
07056,
07062,
07063,
07066,
07071,
07072,
07073,
07081,
07082,
07083,
07084,
07085,
0711,
07121,
07122,
07123,
07124,
07125,
07126,
07127,
07128,
07129,
07130,
07131,
07132,
07133,
07134,
07135,
07136,
07138,
07139,
07141,
07142,
07143,
07144,
07145,
07146,
07147,
07148,
07150,
07151,
07152,
07153,
07154,
07156,
07157,
07158,
07159,
07161,
07162,
07163,
07164,
07165,
07166,
07171,
07172,
07173,
07174,
07175,
07176,
07181,
07182,
07183,
07184,
07191,
07192,
07193,
07194,
07195,
07202,
07203,
07204,
0721,
07220,
07221,
07222,
07223,
07224,
07225,
07226,
07227,
07228,
07229,
07231,
07232,
07233,
07234,
07235,
07236,
07237,
07240,
07242,
07243,
07244,
07245,
07246,
07247,
07248,
07249,
07250,
07251,
07252,
07253,
07254,
07255,
07256,
07257,
07258,
07259,
07260,
07261,
07262,
07263,
07264,
07265,
07266,
07267,
07268,
07269,
07271,
07272,
07273,
07274,
07275,
07276,
07277,
07300,
07302,
07303,
07304,
07305,
07306,
07307,
07308,
07309,
0731,
07321,
07322,
07323,
07324,
07325,
07326,
07327,
07328,
07329,
07331,
07332,
07333,
07334,
07335,
07336,
07337,
07340,
07343,
07344,
07345,
07346,
07347,
07348,
07351,
07352,
07353,
07354,
07355,
07356,
07357,
07358,
07361,
07362,
07363,
07364,
07365,
07366,
07367,
07371,
07373,
07374,
07375,
07376,
07381,
07382,
07383,
07384,
07385,
07386,
07387,
07388,
07389,
07391,
07392,
07393,
07394,
07395,
07402,
07403,
07404,
0741,
07420,
07422,
07423,
07424,
07425,
07426,
07427,
07428,
07429,
07431,
07432,
07433,
07434,
07435,
07436,
07440,
07441,
07442,
07443,
07444,
07445,
07446,
07447,
07448,
07449,
07451,
07452,
07453,
07454,
07455,
07456,
07457,
07458,
07459,
07461,
07462,
07463,
07464,
07465,
07466,
07467,
07471,
07472,
07473,
07474,
07475,
07476,
07477,
07478,
07482,
07483,
07484,
07485,
07486,
07502,
07503,
07504,
07505,
07506,
0751,
07520,
07522,
07524,
07525,
07527,
07528,
07529,
07531,
07532,
07533,
07534,
07541,
07542,
07543,
07544,
07545,
07546,
07551,
07552,
07553,
07554,
07555,
07556,
07557,
07558,
07561,
07562,
07563,
07564,
07565,
07566,
07567,
07568,
07569,
07570,
07571,
07572,
07573,
07574,
07575,
07576,
07577,
07578,
07579,
07581,
07582,
07583,
07584,
07585,
07586,
07587,
07602,
0761,
07620,
07621,
07622,
07623,
07624,
07625,
07626,
07627,
07628,
07629,
07631,
07632,
07633,
07634,
07635,
07636,
07641,
07642,
07643,
07644,
07645,
07646,
07651,
07652,
07653,
07654,
07655,
07656,
07657,
07660,
07661,
07662,
07663,
07664,
07665,
07666,
07667,
07668,
07669,
07671,
07672,
07673,
07674,
07675,
07676,
07681,
07682,
07683,
07684,
07685,
07702,
07703,
07704,
07705,
07706,
07707,
07708,
07709,
0771,
07720,
07721,
07722,
07723,
07724,
07725,
07726,
07727,
07728,
07729,
07731,
07732,
07733,
07734,
07735,
07736,
07738,
07739,
07741,
07742,
07743,
07744,
07745,
07746,
07747,
07748,
07751,
07753,
07754,
07755,
07761,
07762,
07763,
07764,
07765,
07771,
07773,
07774,
07775,
07777,
07802,
07803,
07804,
07805,
07806,
07807,
07808,
0781,
07821,
07822,
07823,
07824,
07825,
07826,
07831,
07832,
07833,
07834,
07835,
07836,
07837,
07838,
07839,
07841,
07842,
07843,
07844,
07851,
07852,
07853,
07854,
07903,
07904,
07905,
07906,
07907,
0791,
07930,
07931,
07932,
07933,
07934,
07935,
07936,
07937,
07938,
07939,
07940,
07941,
07942,
07943,
07944,
07945,
07946,
07947,
07948,
07949,
07950,
07951,
07952,
07953,
07954,
07955,
07957,
07958,
07959,
07961,
07962,
07963,
07964,
07965,
07966,
07967,
07971,
07972,
07973,
07974,
07975,
07976,
07977,
08020,
08021,
08022,
08023,
08024,
08025,
08026,
08027,
08028,
08029,
08031,
08032,
08033,
08034,
08035,
08036,
08038,
08039,
08041,
08042,
08043,
08045,
08046,
08051,
08052,
08053,
08054,
08055,
08056,
08057,
08061,
08062,
08063,
08064,
08065,
08066,
08067,
08071,
08072,
08073,
08074,
08075,
08076,
08081,
08082,
08083,
08084,
08085,
08086,
08091,
08092,
08093,
08094,
08095,
08102,
08104,
08105,
08106,
0811,
08121,
08122,
08123,
08124,
08131,
08133,
08134,
08135,
08136,
08137,
08138,
08139,
08141,
08142,
08143,
08144,
08145,
08146,
08151,
08152,
08153,
08157,
08158,
08161,
08165,
08166,
08167,
08168,
08170,
08171,
08176,
08177,
08178,
08179,
08191,
08192,
08193,
08194,
08195,
08196,
08202,
08203,
08204,
08205,
08206,
08207,
08208,
0821,
08221,
08222,
08223,
08224,
08225,
08226,
08230,
08231,
08232,
08233,
08234,
08236,
08237,
08238,
08239,
08241,
08243,
08245,
08246,
08247,
08248,
08249,
08250,
08251,
08252,
08253,
08254,
08257,
08258,
08259,
08261,
08262,
08263,
08265,
08266,
08267,
08268,
08269,
08271,
08272,
08273,
08274,
08276,
08281,
08282,
08283,
08284,
08285,
08291,
08292,
08293,
08294,
08295,
08296,
08302,
08303,
08304,
08306,
0831,
08320,
08321,
08322,
08323,
08324,
08325,
08326,
08327,
08328,
08330,
08331,
08332,
08333,
08334,
08335,
08336,
08337,
08338,
08340,
08341,
08342,
08343,
08344,
08345,
08346,
08347,
08348,
08349,
08361,
08362,
08363,
08364,
08365,
08366,
08367,
08368,
08369,
08370,
08372,
08373,
08374,
08375,
08376,
08377,
08378,
08379,
08380,
08381,
08382,
08383,
08384,
08385,
08386,
08387,
08388,
08389,
08392,
08393,
08394,
08395,
08402,
08403,
08404,
08405,
08406,
08407,
0841,
08421,
08422,
08423,
08424,
08426,
08427,
08431,
08432,
08433,
08434,
08435,
08441,
08442,
08443,
08444,
08445,
08446,
08450,
08452,
08453,
08454,
08456,
08457,
08458,
08459,
08460,
08461,
08462,
08463,
08464,
08465,
08466,
08467,
08468,
08469,
08501,
08502,
08503,
08504,
08505,
08506,
08507,
08509,
0851,
08531,
08532,
08533,
08534,
08535,
08536,
08537,
08538,
08541,
08542,
08543,
08544,
08545,
08546,
08547,
08548,
08549,
08550,
08551,
08552,
08553,
08554,
08555,
08556,
08557,
08558,
08561,
08562,
08563,
08564,
08565,
08571,
08572,
08573,
08574,
08581,
08582,
08583,
08584,
08585,
08586,
08591,
08592,
08593,
0861,
08621,
08622,
08623,
08624,
08628,
08629,
08630,
08631,
08633,
08634,
08635,
08636,
08637,
08638,
08639,
08640,
08641,
08642,
08649,
08650,
08651,
08652,
08654,
08656,
08657,
08661,
08662,
08663,
08664,
08665,
08666,
08667,
08669,
08670,
08671,
08677,
08678,
08679,
08681,
08682,
08683,
08684,
08685,
08686,
08687,
08702,
08703,
08704,
08705,
08706,
08707,
08708,
08709,
0871,
08721,
08722,
08723,
08724,
08725,
08726,
08727,
08728,
08731,
08732,
08733,
08734,
08735,
08741,
08742,
08743,
08744,
08745,
08751,
08752,
08753,
08754,
08756,
08761,
08762,
08764,
08765,
08766,
08771,
08772,
08773,
08774,
08781,
08782,
08783,
08784,
08785,
08801,
08802,
08803,
08805,
08806,
08807,
08808,
08809,
0881,
08821,
08822,
08823,
08824,
08825,
08841,
08845,
08846,
08847,
08851,
08856,
08857,
08858,
08860,
08861,
08862,
08867,
08868,
08869,
089,
0906,
09070,
09071,
09072,
09073,
09074,
09075,
09076,
09077,
09078,
09080,
09081,
09082,
09083,
09084,
09085,
09086,
09087,
09088,
09089,
09090,
09091,
09092,
09093,
09094,
09097,
09099,
09101,
09102,
09103,
09104,
09105,
09106,
09107,
0911,
09120,
09122,
09123,
09126,
09127,
09128,
09129,
09131,
09132,
09133,
09134,
09135,
09141,
09142,
09143,
09144,
09145,
09146,
09147,
09148,
09149,
09151,
09152,
09153,
09154,
09155,
09156,
09157,
09158,
09161,
09162,
09163,
09164,
09165,
09166,
09167,
09170,
09171,
09172,
09173,
09174,
09175,
09176,
09177,
09178,
09179,
09180,
09181,
09182,
09183,
09184,
09185,
09186,
09187,
09188,
09189,
09190,
09191,
09192,
09193,
09194,
09195,
09196,
09197,
09198,
09199,
09201,
09202,
09203,
09204,
09205,
09206,
09207,
09208,
09209,
0921,
09220,
09221,
09222,
09223,
09225,
09227,
09228,
09229,
09231,
09232,
09233,
09234,
09235,
09236,
09238,
09241,
09242,
09243,
09244,
09245,
09246,
09251,
09252,
09253,
09254,
09255,
09256,
09257,
09260,
09261,
09262,
09263,
09264,
09265,
09266,
09267,
09268,
09269,
09270,
09271,
09272,
09273,
09274,
09275,
09276,
09277,
09278,
09279,
09280,
09281,
09282,
09283,
09284,
09285,
09286,
09287,
09288,
09289,
09292,
09293,
09294,
09295,
09302,
09303,
09305,
09306,
09307,
0931,
09321,
09323,
09324,
09325,
09326,
09331,
09332,
09333,
09334,
09335,
09336,
09337,
09338,
09339,
09340,
09341,
09342,
09343,
09344,
09345,
09346,
09347,
09348,
09349,
09350,
09351,
09352,
09353,
09354,
09355,
09356,
09357,
09358,
09359,
09360,
09363,
09364,
09365,
09366,
09367,
09369,
09371,
09372,
09373,
09374,
09375,
09376,
09377,
09378,
09381,
09382,
09383,
09384,
09385,
09386,
09391,
09392,
09393,
09394,
09395,
09396,
09397,
09398,
09401,
09402,
09403,
09404,
09405,
09406,
09407,
09408,
09409,
0941,
09420,
09421,
09422,
09423,
09424,
09426,
09427,
09428,
09429,
09431,
09433,
09434,
09435,
09436,
09438,
09439,
09441,
09442,
09443,
09444,
09445,
09446,
09447,
09448,
09451,
09452,
09453,
09454,
09461,
09462,
09463,
09464,
09465,
09466,
09467,
09468,
09469,
09471,
09472,
09473,
09474,
09480,
09481,
09482,
09484,
09491,
09492,
09493,
09495,
09497,
09498,
09499,
09502,
09503,
09504,
09505,
0951,
09521,
09522,
09523,
09524,
09525,
09526,
09527,
09528,
09529,
09531,
09532,
09533,
09534,
09535,
09536,
09542,
09543,
09544,
09545,
09546,
09547,
09548,
09549,
09551,
09552,
09553,
09554,
09555,
09556,
09560,
09561,
09562,
09563,
09564,
09565,
09566,
09567,
09568,
09569,
09571,
09572,
09573,
09574,
09575,
09576,
09602,
09603,
09604,
09605,
09606,
09607,
09608,
0961,
09621,
09622,
09624,
09625,
09626,
09627,
09628,
09631,
09632,
09633,
09634,
09635,
09636,
09637,
09638,
09639,
09641,
09642,
09643,
09644,
09645,
09646,
09647,
09648,
09651,
09652,
09653,
09654,
09655,
09656,
09657,
09658,
09659,
09661,
09662,
09663,
09664,
09665,
09666,
09671,
09672,
09673,
09674,
09675,
09676,
09677,
09681,
09682,
09683,
09701,
09704,
09708,
0971,
09720,
09721,
09722,
09723,
09724,
09725,
09726,
09727,
09728,
09729,
09732,
09733,
09734,
09735,
09736,
09737,
09738,
09741,
09742,
09744,
09745,
09746,
09747,
09748,
09749,
09761,
09762,
09763,
09764,
09765,
09766,
09771,
09772,
09773,
09774,
09775,
09776,
09777,
09778,
09779,
09802,
09803,
09804,
09805,
0981,
09820,
09822,
09823,
09824,
09825,
09826,
09827,
09828,
09829,
09831,
09832,
09833,
09834,
09835,
09836,
09837,
09841,
09842,
09843,
09844,
09845,
09846,
09847,
09848,
09851,
09852,
09853,
09854,
09855,
09856,
09857,
09861,
09865,
09867,
09868,
09869,
09871,
09872,
09873,
09874,
09875,
09876,
09901,
09903,
09904,
09905,
09906,
09907,
09908,
0991,
09920,
09921,
09922,
09923,
09924,
09925,
09926,
09927,
09928,
09929,
09931,
09932,
09933,
09935,
09936,
09937,
09938,
09941,
09942,
09943,
09944,
09945,
09946,
09947,
09948,
09951,
09952,
09953,
09954,
09955,
09956,
09961,
09962,
09963,
09964,
09965,
09966,
09971,
09972,
09973,
09974,
09975,
09976,
09977,
09978}
\clist_const:Nn \c_phone_DE_sondervorwahlen_clist {01371,
01372,
01373,
01374,
01375,
01376,
01377,
01378,
01379,
015019,
015020,
01511,
01512,
01514,
01515,
01516,
01517,
015180,
015181,
015182,
015183,
015184,
015185,
015186,
015310,
01520,
01521,
01522,
01523,
01525,
01526,
01529,
015510,
015511,
015550,
015551,
015552,
015553,
015554,
015555,
015556,
015557,
015558,
015559,
015560,
015561,
015562,
015563,
015564,
015565,
015566,
015567,
015568,
015569,
015630,
015678,
015679,
015700,
015701,
015702,
015703,
015704,
015705,
015706,
01573,
01575,
01577,
01578,
01579,
015888,
01590,
0160,
0162,
0163,
0164,
0168,
0169,
0170,
0171,
0172,
0173,
0174,
0175,
0176,
0177,
0178,
0179,
01801,
01802,
01803,
01804,
01805,
01806,
01807,
0181,
0182,
0183,
0184,
0185,
0186,
0187,
0188,
0189,
0191,
0192,
0193,
0194,
032,
0700,
0800,
09001,
09003,
09005}
\tl_const:cn {c_phone_DE_ortsname_0201_tl} {Essen}
\tl_const:cn {c_phone_DE_ortsname_0202_tl} {Wuppertal}
\tl_const:cn {c_phone_DE_ortsname_0203_tl} {Duisburg}
\tl_const:cn {c_phone_DE_ortsname_02041_tl} {Bottrop}
\tl_const:cn {c_phone_DE_ortsname_02043_tl} {Gladbeck}
\tl_const:cn {c_phone_DE_ortsname_02045_tl} {Bottrop-Kirchhellen}
\tl_const:cn {c_phone_DE_ortsname_02051_tl} {Velbert}
\tl_const:cn {c_phone_DE_ortsname_02052_tl} {Velbert-Langenberg}
\tl_const:cn {c_phone_DE_ortsname_02053_tl} {Velbert-Neviges}
\tl_const:cn {c_phone_DE_ortsname_02054_tl} {Essen-Kettwig}
\tl_const:cn {c_phone_DE_ortsname_02056_tl} {Heiligenhaus}
\tl_const:cn {c_phone_DE_ortsname_02058_tl} {W\"ulfrath}
\tl_const:cn {c_phone_DE_ortsname_02064_tl} {Dinslaken}
\tl_const:cn {c_phone_DE_ortsname_02065_tl} {Duisburg-Rheinhausen}
\tl_const:cn {c_phone_DE_ortsname_02066_tl} {Duisburg-Homberg}
\tl_const:cn {c_phone_DE_ortsname_0208_tl} {Oberhausen~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_0209_tl} {Gelsenkirchen}
\tl_const:cn {c_phone_DE_ortsname_02102_tl} {Ratingen}
\tl_const:cn {c_phone_DE_ortsname_02103_tl} {Hilden}
\tl_const:cn {c_phone_DE_ortsname_02104_tl} {Mettmann}
\tl_const:cn {c_phone_DE_ortsname_0211_tl} {D\"usseldorf}
\tl_const:cn {c_phone_DE_ortsname_0212_tl} {Solingen}
\tl_const:cn {c_phone_DE_ortsname_02129_tl} {Haan~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02131_tl} {Neuss}
\tl_const:cn {c_phone_DE_ortsname_02132_tl} {Meerbusch-B\"uderich}
\tl_const:cn {c_phone_DE_ortsname_02133_tl} {Dormagen}
\tl_const:cn {c_phone_DE_ortsname_02137_tl} {Neuss-Norf}
\tl_const:cn {c_phone_DE_ortsname_0214_tl} {Leverkusen}
\tl_const:cn {c_phone_DE_ortsname_02150_tl} {Meerbusch-Lank}
\tl_const:cn {c_phone_DE_ortsname_02151_tl} {Krefeld}
\tl_const:cn {c_phone_DE_ortsname_02152_tl} {Kempen}
\tl_const:cn {c_phone_DE_ortsname_02153_tl} {Nettetal-Lobberich}
\tl_const:cn {c_phone_DE_ortsname_02154_tl} {Willich}
\tl_const:cn {c_phone_DE_ortsname_02156_tl} {Willich-Anrath}
\tl_const:cn {c_phone_DE_ortsname_02157_tl} {Nettetal-Kaldenkirchen}
\tl_const:cn {c_phone_DE_ortsname_02158_tl} {Grefrath~bei~Krefeld}
\tl_const:cn {c_phone_DE_ortsname_02159_tl} {Meerbusch-Osterath}
\tl_const:cn {c_phone_DE_ortsname_02161_tl} {M\"onchengladbach}
\tl_const:cn {c_phone_DE_ortsname_02162_tl} {Viersen}
\tl_const:cn {c_phone_DE_ortsname_02163_tl} {Schwalmtal~Niederrhein}
\tl_const:cn {c_phone_DE_ortsname_02164_tl} {J\"uchen-Otzenrath}
\tl_const:cn {c_phone_DE_ortsname_02165_tl} {J\"uchen}
\tl_const:cn {c_phone_DE_ortsname_02166_tl} {M\"onchengladbach-Rheydt}
\tl_const:cn {c_phone_DE_ortsname_02171_tl} {Leverkusen-Opladen}
\tl_const:cn {c_phone_DE_ortsname_02173_tl} {Langenfeld~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02174_tl} {Burscheid~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02175_tl} {Leichlingen~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02181_tl} {Grevenbroich}
\tl_const:cn {c_phone_DE_ortsname_02182_tl} {Grevenbroich-Kapellen}
\tl_const:cn {c_phone_DE_ortsname_02183_tl} {Rommerskirchen}
\tl_const:cn {c_phone_DE_ortsname_02191_tl} {Remscheid}
\tl_const:cn {c_phone_DE_ortsname_02192_tl} {H\"uckeswagen}
\tl_const:cn {c_phone_DE_ortsname_02193_tl} {Dabringhausen}
\tl_const:cn {c_phone_DE_ortsname_02195_tl} {Radevormwald}
\tl_const:cn {c_phone_DE_ortsname_02196_tl} {Wermelskirchen}
\tl_const:cn {c_phone_DE_ortsname_02202_tl} {Bergisch~Gladbach}
\tl_const:cn {c_phone_DE_ortsname_02203_tl} {K\"oln-Porz}
\tl_const:cn {c_phone_DE_ortsname_02204_tl} {Bensberg}
\tl_const:cn {c_phone_DE_ortsname_02205_tl} {R\"osrath}
\tl_const:cn {c_phone_DE_ortsname_02206_tl} {Overath}
\tl_const:cn {c_phone_DE_ortsname_02207_tl} {K\"urten-D\"urscheid}
\tl_const:cn {c_phone_DE_ortsname_02208_tl} {Niederkassel}
\tl_const:cn {c_phone_DE_ortsname_0221_tl} {K\"oln}
\tl_const:cn {c_phone_DE_ortsname_02222_tl} {Bornheim~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02223_tl} {K\"onigswinter}
\tl_const:cn {c_phone_DE_ortsname_02224_tl} {Bad~Honnef}
\tl_const:cn {c_phone_DE_ortsname_02225_tl} {Meckenheim~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02226_tl} {Rheinbach}
\tl_const:cn {c_phone_DE_ortsname_02227_tl} {Bornheim-Merten}
\tl_const:cn {c_phone_DE_ortsname_02228_tl} {Remagen-Rolandseck}
\tl_const:cn {c_phone_DE_ortsname_02232_tl} {Br\"uhl~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02233_tl} {H\"urth~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02234_tl} {Frechen}
\tl_const:cn {c_phone_DE_ortsname_02235_tl} {Erftstadt}
\tl_const:cn {c_phone_DE_ortsname_02236_tl} {Wesseling~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02237_tl} {Kerpen-T\"urnich}
\tl_const:cn {c_phone_DE_ortsname_02238_tl} {Pulheim}
\tl_const:cn {c_phone_DE_ortsname_02241_tl} {Siegburg}
\tl_const:cn {c_phone_DE_ortsname_02242_tl} {Hennef~Sieg}
\tl_const:cn {c_phone_DE_ortsname_02243_tl} {Eitorf}
\tl_const:cn {c_phone_DE_ortsname_02244_tl} {K\"onigswinter-Oberpleis}
\tl_const:cn {c_phone_DE_ortsname_02245_tl} {Much}
\tl_const:cn {c_phone_DE_ortsname_02246_tl} {Lohmar~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02247_tl} {Neunkirchen-Seelscheid}
\tl_const:cn {c_phone_DE_ortsname_02248_tl} {Hennef-Uckerath}
\tl_const:cn {c_phone_DE_ortsname_02251_tl} {Euskirchen}
\tl_const:cn {c_phone_DE_ortsname_02252_tl} {Z\"ulpich}
\tl_const:cn {c_phone_DE_ortsname_02253_tl} {Bad~M\"unstereifel}
\tl_const:cn {c_phone_DE_ortsname_02254_tl} {Weilerswist}
\tl_const:cn {c_phone_DE_ortsname_02255_tl} {Euskirchen-Flamersheim}
\tl_const:cn {c_phone_DE_ortsname_02256_tl} {Mechernich-Satzvey}
\tl_const:cn {c_phone_DE_ortsname_02257_tl} {Reckerscheid}
\tl_const:cn {c_phone_DE_ortsname_02261_tl} {Gummersbach}
\tl_const:cn {c_phone_DE_ortsname_02262_tl} {Wiehl}
\tl_const:cn {c_phone_DE_ortsname_02263_tl} {Engelskirchen}
\tl_const:cn {c_phone_DE_ortsname_02264_tl} {Marienheide}
\tl_const:cn {c_phone_DE_ortsname_02265_tl} {Reichshof-Eckenhagen}
\tl_const:cn {c_phone_DE_ortsname_02266_tl} {Lindlar}
\tl_const:cn {c_phone_DE_ortsname_02267_tl} {Wipperf\"urth}
\tl_const:cn {c_phone_DE_ortsname_02268_tl} {K\"urten}
\tl_const:cn {c_phone_DE_ortsname_02269_tl} {Kierspe-R\"onsahl}
\tl_const:cn {c_phone_DE_ortsname_02271_tl} {Bergheim~Erft}
\tl_const:cn {c_phone_DE_ortsname_02272_tl} {Bedburg~Erft}
\tl_const:cn {c_phone_DE_ortsname_02273_tl} {Kerpen-Horrem}
\tl_const:cn {c_phone_DE_ortsname_02274_tl} {Elsdorf~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02275_tl} {Kerpen-Buir}
\tl_const:cn {c_phone_DE_ortsname_0228_tl} {Bonn}
\tl_const:cn {c_phone_DE_ortsname_02291_tl} {Waldbr\"ol}
\tl_const:cn {c_phone_DE_ortsname_02292_tl} {Windeck~Sieg}
\tl_const:cn {c_phone_DE_ortsname_02293_tl} {N\"umbrecht}
\tl_const:cn {c_phone_DE_ortsname_02294_tl} {Morsbach~Sieg}
\tl_const:cn {c_phone_DE_ortsname_02295_tl} {Ruppichteroth}
\tl_const:cn {c_phone_DE_ortsname_02296_tl} {Reichshof-Br\"ucherm\"uhle}
\tl_const:cn {c_phone_DE_ortsname_02297_tl} {Wildbergerh\"utte}
\tl_const:cn {c_phone_DE_ortsname_02301_tl} {Holzwickede}
\tl_const:cn {c_phone_DE_ortsname_02302_tl} {Witten}
\tl_const:cn {c_phone_DE_ortsname_02303_tl} {Unna}
\tl_const:cn {c_phone_DE_ortsname_02304_tl} {Schwerte}
\tl_const:cn {c_phone_DE_ortsname_02305_tl} {Castrop-Rauxel}
\tl_const:cn {c_phone_DE_ortsname_02306_tl} {L\"unen}
\tl_const:cn {c_phone_DE_ortsname_02307_tl} {Kamen}
\tl_const:cn {c_phone_DE_ortsname_02308_tl} {Unna-Hemmerde}
\tl_const:cn {c_phone_DE_ortsname_02309_tl} {Waltrop}
\tl_const:cn {c_phone_DE_ortsname_0231_tl} {Dortmund}
\tl_const:cn {c_phone_DE_ortsname_02323_tl} {Herne}
\tl_const:cn {c_phone_DE_ortsname_02324_tl} {Hattingen~Ruhr}
\tl_const:cn {c_phone_DE_ortsname_02325_tl} {Wanne-Eickel}
\tl_const:cn {c_phone_DE_ortsname_02327_tl} {Bochum-Wattenscheid}
\tl_const:cn {c_phone_DE_ortsname_02330_tl} {Herdecke}
\tl_const:cn {c_phone_DE_ortsname_02331_tl} {Hagen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02332_tl} {Gevelsberg}
\tl_const:cn {c_phone_DE_ortsname_02333_tl} {Ennepetal}
\tl_const:cn {c_phone_DE_ortsname_02334_tl} {Hagen-Hohenlimburg}
\tl_const:cn {c_phone_DE_ortsname_02335_tl} {Wetter~Ruhr}
\tl_const:cn {c_phone_DE_ortsname_02336_tl} {Schwelm}
\tl_const:cn {c_phone_DE_ortsname_02337_tl} {Hagen-Dahl}
\tl_const:cn {c_phone_DE_ortsname_02338_tl} {Breckerfeld}
\tl_const:cn {c_phone_DE_ortsname_02339_tl} {Sprockh\"ovel-Ha\ss linghausen}
\tl_const:cn {c_phone_DE_ortsname_0234_tl} {Bochum}
\tl_const:cn {c_phone_DE_ortsname_02351_tl} {L\"udenscheid}
\tl_const:cn {c_phone_DE_ortsname_02352_tl} {Altena~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02353_tl} {Halver}
\tl_const:cn {c_phone_DE_ortsname_02354_tl} {Meinerzhagen}
\tl_const:cn {c_phone_DE_ortsname_02355_tl} {Schalksm\"uhle}
\tl_const:cn {c_phone_DE_ortsname_02357_tl} {Herscheid~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02358_tl} {Meinerzhagen-Valbert}
\tl_const:cn {c_phone_DE_ortsname_02359_tl} {Kierspe}
\tl_const:cn {c_phone_DE_ortsname_02360_tl} {Haltern-Lippramsdorf}
\tl_const:cn {c_phone_DE_ortsname_02361_tl} {Recklinghausen}
\tl_const:cn {c_phone_DE_ortsname_02362_tl} {Dorsten}
\tl_const:cn {c_phone_DE_ortsname_02363_tl} {Datteln}
\tl_const:cn {c_phone_DE_ortsname_02364_tl} {Haltern~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02365_tl} {Marl}
\tl_const:cn {c_phone_DE_ortsname_02366_tl} {Herten~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02367_tl} {Henrichenburg}
\tl_const:cn {c_phone_DE_ortsname_02368_tl} {Oer-Erkenschwick}
\tl_const:cn {c_phone_DE_ortsname_02369_tl} {Dorsten-Wulfen}
\tl_const:cn {c_phone_DE_ortsname_02371_tl} {Iserlohn}
\tl_const:cn {c_phone_DE_ortsname_02372_tl} {Hemer}
\tl_const:cn {c_phone_DE_ortsname_02373_tl} {Menden~Sauerland}
\tl_const:cn {c_phone_DE_ortsname_02374_tl} {Iserlohn-Letmathe}
\tl_const:cn {c_phone_DE_ortsname_02375_tl} {Balve}
\tl_const:cn {c_phone_DE_ortsname_02377_tl} {Wickede~Ruhr}
\tl_const:cn {c_phone_DE_ortsname_02378_tl} {Fr\"ondenberg-Langschede}
\tl_const:cn {c_phone_DE_ortsname_02379_tl} {Menden-Asbeck}
\tl_const:cn {c_phone_DE_ortsname_02381_tl} {Hamm~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02382_tl} {Ahlen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02383_tl} {B\"onen}
\tl_const:cn {c_phone_DE_ortsname_02384_tl} {Welver}
\tl_const:cn {c_phone_DE_ortsname_02385_tl} {Hamm-Rhynern}
\tl_const:cn {c_phone_DE_ortsname_02387_tl} {Drensteinfurt-Walstedde}
\tl_const:cn {c_phone_DE_ortsname_02388_tl} {Hamm-Uentrop}
\tl_const:cn {c_phone_DE_ortsname_02389_tl} {Werne}
\tl_const:cn {c_phone_DE_ortsname_02391_tl} {Plettenberg}
\tl_const:cn {c_phone_DE_ortsname_02392_tl} {Werdohl}
\tl_const:cn {c_phone_DE_ortsname_02393_tl} {Sundern-Allendorf}
\tl_const:cn {c_phone_DE_ortsname_02394_tl} {Neuenrade-Affeln}
\tl_const:cn {c_phone_DE_ortsname_02395_tl} {Finnentrop-R\"onkhausen}
\tl_const:cn {c_phone_DE_ortsname_02401_tl} {Baesweiler}
\tl_const:cn {c_phone_DE_ortsname_02402_tl} {Stolberg~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02403_tl} {Eschweiler~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02404_tl} {Alsdorf~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02405_tl} {W\"urselen}
\tl_const:cn {c_phone_DE_ortsname_02406_tl} {Herzogenrath}
\tl_const:cn {c_phone_DE_ortsname_02407_tl} {Herzogenrath-Kohlscheid}
\tl_const:cn {c_phone_DE_ortsname_02408_tl} {Aachen-Kornelim\"unster}
\tl_const:cn {c_phone_DE_ortsname_02409_tl} {Stolberg-Gressenich}
\tl_const:cn {c_phone_DE_ortsname_0241_tl} {Aachen}
\tl_const:cn {c_phone_DE_ortsname_02421_tl} {D\"uren}
\tl_const:cn {c_phone_DE_ortsname_02422_tl} {Kreuzau}
\tl_const:cn {c_phone_DE_ortsname_02423_tl} {Langerwehe}
\tl_const:cn {c_phone_DE_ortsname_02424_tl} {Vettwei\ss}
\tl_const:cn {c_phone_DE_ortsname_02425_tl} {Nideggen-Embken}
\tl_const:cn {c_phone_DE_ortsname_02426_tl} {N\"orvenich}
\tl_const:cn {c_phone_DE_ortsname_02427_tl} {Nideggen}
\tl_const:cn {c_phone_DE_ortsname_02428_tl} {Niederzier}
\tl_const:cn {c_phone_DE_ortsname_02429_tl} {H\"urtgenwald}
\tl_const:cn {c_phone_DE_ortsname_02431_tl} {Erkelenz}
\tl_const:cn {c_phone_DE_ortsname_02432_tl} {Wassenberg}
\tl_const:cn {c_phone_DE_ortsname_02433_tl} {H\"uckelhoven}
\tl_const:cn {c_phone_DE_ortsname_02434_tl} {Wegberg}
\tl_const:cn {c_phone_DE_ortsname_02435_tl} {Erkelenz-L\"ovenich}
\tl_const:cn {c_phone_DE_ortsname_02436_tl} {Wegberg-R\"odgen}
\tl_const:cn {c_phone_DE_ortsname_02440_tl} {Nettersheim-Tondorf}
\tl_const:cn {c_phone_DE_ortsname_02441_tl} {Kall}
\tl_const:cn {c_phone_DE_ortsname_02443_tl} {Mechernich}
\tl_const:cn {c_phone_DE_ortsname_02444_tl} {Schleiden-Gem\"und}
\tl_const:cn {c_phone_DE_ortsname_02445_tl} {Schleiden~Eifel}
\tl_const:cn {c_phone_DE_ortsname_02446_tl} {Heimbach~Eifel}
\tl_const:cn {c_phone_DE_ortsname_02447_tl} {Dahlem~bei~Kall}
\tl_const:cn {c_phone_DE_ortsname_02448_tl} {Hellenthal-Rescheid}
\tl_const:cn {c_phone_DE_ortsname_02449_tl} {Blankenheim~Ahr}
\tl_const:cn {c_phone_DE_ortsname_02451_tl} {Geilenkirchen}
\tl_const:cn {c_phone_DE_ortsname_02452_tl} {Heinsberg~Rheinland}
\tl_const:cn {c_phone_DE_ortsname_02453_tl} {Heinsberg-Randerath}
\tl_const:cn {c_phone_DE_ortsname_02454_tl} {Gangelt}
\tl_const:cn {c_phone_DE_ortsname_02455_tl} {Waldfeucht}
\tl_const:cn {c_phone_DE_ortsname_02456_tl} {Selfkant}
\tl_const:cn {c_phone_DE_ortsname_02461_tl} {J\"ulich}
\tl_const:cn {c_phone_DE_ortsname_02462_tl} {Linnich}
\tl_const:cn {c_phone_DE_ortsname_02463_tl} {Titz}
\tl_const:cn {c_phone_DE_ortsname_02464_tl} {Aldenhoven~bei~J\"ulich}
\tl_const:cn {c_phone_DE_ortsname_02465_tl} {Inden}
\tl_const:cn {c_phone_DE_ortsname_02471_tl} {Roetgen~Eifel}
\tl_const:cn {c_phone_DE_ortsname_02472_tl} {Monschau}
\tl_const:cn {c_phone_DE_ortsname_02473_tl} {Simmerath}
\tl_const:cn {c_phone_DE_ortsname_02474_tl} {Nideggen-Schmidt}
\tl_const:cn {c_phone_DE_ortsname_02482_tl} {Hellenthal}
\tl_const:cn {c_phone_DE_ortsname_02484_tl} {Mechernich-Eiserfey}
\tl_const:cn {c_phone_DE_ortsname_02485_tl} {Schleiden-Dreiborn}
\tl_const:cn {c_phone_DE_ortsname_02486_tl} {Nettersheim}
\tl_const:cn {c_phone_DE_ortsname_02501_tl} {M\"unster-Hiltrup}
\tl_const:cn {c_phone_DE_ortsname_02502_tl} {Nottuln}
\tl_const:cn {c_phone_DE_ortsname_02504_tl} {Telgte}
\tl_const:cn {c_phone_DE_ortsname_02505_tl} {Altenberge~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02506_tl} {M\"unster-Wolbeck}
\tl_const:cn {c_phone_DE_ortsname_02507_tl} {Havixbeck}
\tl_const:cn {c_phone_DE_ortsname_02508_tl} {Drensteinfurt}
\tl_const:cn {c_phone_DE_ortsname_02509_tl} {Nottuln-Appelh\"ulsen}
\tl_const:cn {c_phone_DE_ortsname_0251_tl} {M\"unster}
\tl_const:cn {c_phone_DE_ortsname_02520_tl} {Wadersloh-Diestedde}
\tl_const:cn {c_phone_DE_ortsname_02521_tl} {Beckum}
\tl_const:cn {c_phone_DE_ortsname_02522_tl} {Oelde}
\tl_const:cn {c_phone_DE_ortsname_02523_tl} {Wadersloh}
\tl_const:cn {c_phone_DE_ortsname_02524_tl} {Ennigerloh}
\tl_const:cn {c_phone_DE_ortsname_02525_tl} {Beckum-Neubeckum}
\tl_const:cn {c_phone_DE_ortsname_02526_tl} {Sendenhorst}
\tl_const:cn {c_phone_DE_ortsname_02527_tl} {Lippetal-Lippborg}
\tl_const:cn {c_phone_DE_ortsname_02528_tl} {Ennigerloh-Enniger}
\tl_const:cn {c_phone_DE_ortsname_02529_tl} {Oelde-Stromberg}
\tl_const:cn {c_phone_DE_ortsname_02532_tl} {Ostbevern}
\tl_const:cn {c_phone_DE_ortsname_02533_tl} {M\"unster-Nienberge}
\tl_const:cn {c_phone_DE_ortsname_02534_tl} {M\"unster-Roxel}
\tl_const:cn {c_phone_DE_ortsname_02535_tl} {Sendenhorst-Albersloh}
\tl_const:cn {c_phone_DE_ortsname_02536_tl} {M\"unster-Albachten}
\tl_const:cn {c_phone_DE_ortsname_02538_tl} {Drensteinfurt-Rinkerode}
\tl_const:cn {c_phone_DE_ortsname_02541_tl} {Coesfeld}
\tl_const:cn {c_phone_DE_ortsname_02542_tl} {Gescher}
\tl_const:cn {c_phone_DE_ortsname_02543_tl} {Billerbeck~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02545_tl} {Rosendahl-Darfeld}
\tl_const:cn {c_phone_DE_ortsname_02546_tl} {Coesfeld-Lette}
\tl_const:cn {c_phone_DE_ortsname_02547_tl} {Rosendahl-Osterwick}
\tl_const:cn {c_phone_DE_ortsname_02548_tl} {D\"ulmen-Rorup}
\tl_const:cn {c_phone_DE_ortsname_02551_tl} {Steinfurt-Burgsteinfurt}
\tl_const:cn {c_phone_DE_ortsname_02552_tl} {Steinfurt-Borghorst}
\tl_const:cn {c_phone_DE_ortsname_02553_tl} {Ochtrup}
\tl_const:cn {c_phone_DE_ortsname_02554_tl} {Laer~Kreis~Steinfurt}
\tl_const:cn {c_phone_DE_ortsname_02555_tl} {Sch\"oppingen}
\tl_const:cn {c_phone_DE_ortsname_02556_tl} {Metelen}
\tl_const:cn {c_phone_DE_ortsname_02557_tl} {Wettringen~Kreis~Steinfurt}
\tl_const:cn {c_phone_DE_ortsname_02558_tl} {Horstmar}
\tl_const:cn {c_phone_DE_ortsname_02561_tl} {Ahaus}
\tl_const:cn {c_phone_DE_ortsname_02562_tl} {Gronau~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02563_tl} {Stadtlohn}
\tl_const:cn {c_phone_DE_ortsname_02564_tl} {Vreden}
\tl_const:cn {c_phone_DE_ortsname_02565_tl} {Gronau-Epe}
\tl_const:cn {c_phone_DE_ortsname_02566_tl} {Legden}
\tl_const:cn {c_phone_DE_ortsname_02567_tl} {Ahaus-Alst\"atte}
\tl_const:cn {c_phone_DE_ortsname_02568_tl} {Heek}
\tl_const:cn {c_phone_DE_ortsname_02571_tl} {Greven~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02572_tl} {Emsdetten}
\tl_const:cn {c_phone_DE_ortsname_02573_tl} {Nordwalde}
\tl_const:cn {c_phone_DE_ortsname_02574_tl} {Saerbeck}
\tl_const:cn {c_phone_DE_ortsname_02575_tl} {Greven-Reckenfeld}
\tl_const:cn {c_phone_DE_ortsname_02581_tl} {Warendorf}
\tl_const:cn {c_phone_DE_ortsname_02582_tl} {Everswinkel}
\tl_const:cn {c_phone_DE_ortsname_02583_tl} {Sassenberg}
\tl_const:cn {c_phone_DE_ortsname_02584_tl} {Warendorf-Milte}
\tl_const:cn {c_phone_DE_ortsname_02585_tl} {Warendorf-Hoetmar}
\tl_const:cn {c_phone_DE_ortsname_02586_tl} {Beelen}
\tl_const:cn {c_phone_DE_ortsname_02587_tl} {Ennigerloh-Westkirchen}
\tl_const:cn {c_phone_DE_ortsname_02588_tl} {Harsewinkel-Greffen}
\tl_const:cn {c_phone_DE_ortsname_02590_tl} {D\"ulmen-Buldern}
\tl_const:cn {c_phone_DE_ortsname_02591_tl} {L\"udinghausen}
\tl_const:cn {c_phone_DE_ortsname_02592_tl} {Selm}
\tl_const:cn {c_phone_DE_ortsname_02593_tl} {Ascheberg~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02594_tl} {D\"ulmen}
\tl_const:cn {c_phone_DE_ortsname_02595_tl} {Olfen}
\tl_const:cn {c_phone_DE_ortsname_02596_tl} {Nordkirchen}
\tl_const:cn {c_phone_DE_ortsname_02597_tl} {Senden~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02598_tl} {Senden-Ottmarsbocholt}
\tl_const:cn {c_phone_DE_ortsname_02599_tl} {Ascheberg-Herbern}
\tl_const:cn {c_phone_DE_ortsname_02601_tl} {Nauort}
\tl_const:cn {c_phone_DE_ortsname_02602_tl} {Montabaur}
\tl_const:cn {c_phone_DE_ortsname_02603_tl} {Bad~Ems}
\tl_const:cn {c_phone_DE_ortsname_02604_tl} {Nassau~Lahn}
\tl_const:cn {c_phone_DE_ortsname_02605_tl} {L\"of}
\tl_const:cn {c_phone_DE_ortsname_02606_tl} {Winningen~Mosel}
\tl_const:cn {c_phone_DE_ortsname_02607_tl} {Kobern-Gondorf}
\tl_const:cn {c_phone_DE_ortsname_02608_tl} {Welschneudorf}
\tl_const:cn {c_phone_DE_ortsname_0261_tl} {Koblenz~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_02620_tl} {Neuh\"ausel~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02621_tl} {Lahnstein}
\tl_const:cn {c_phone_DE_ortsname_02622_tl} {Bendorf~Rhein}
\tl_const:cn {c_phone_DE_ortsname_02623_tl} {Ransbach-Baumbach}
\tl_const:cn {c_phone_DE_ortsname_02624_tl} {H\"ohr-Grenzhausen}
\tl_const:cn {c_phone_DE_ortsname_02625_tl} {Ochtendung}
\tl_const:cn {c_phone_DE_ortsname_02626_tl} {Selters~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02627_tl} {Braubach}
\tl_const:cn {c_phone_DE_ortsname_02628_tl} {Rhens}
\tl_const:cn {c_phone_DE_ortsname_02630_tl} {M\"ulheim-K\"arlich}
\tl_const:cn {c_phone_DE_ortsname_02631_tl} {Neuwied}
\tl_const:cn {c_phone_DE_ortsname_02632_tl} {Andernach}
\tl_const:cn {c_phone_DE_ortsname_02633_tl} {Brohl-L\"utzing}
\tl_const:cn {c_phone_DE_ortsname_02634_tl} {Rengsdorf}
\tl_const:cn {c_phone_DE_ortsname_02635_tl} {Rheinbrohl}
\tl_const:cn {c_phone_DE_ortsname_02636_tl} {Burgbrohl}
\tl_const:cn {c_phone_DE_ortsname_02637_tl} {Wei\ss enthurm}
\tl_const:cn {c_phone_DE_ortsname_02638_tl} {Waldbreitbach}
\tl_const:cn {c_phone_DE_ortsname_02639_tl} {Anhausen~Kreis~Neuwied}
\tl_const:cn {c_phone_DE_ortsname_02641_tl} {Bad~Neuenahr-Ahrweiler}
\tl_const:cn {c_phone_DE_ortsname_02642_tl} {Remagen}
\tl_const:cn {c_phone_DE_ortsname_02643_tl} {Altenahr}
\tl_const:cn {c_phone_DE_ortsname_02644_tl} {Linz~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_02645_tl} {Vettelscho\ss}
\tl_const:cn {c_phone_DE_ortsname_02646_tl} {K\"onigsfeld~Eifel}
\tl_const:cn {c_phone_DE_ortsname_02647_tl} {Kesseling}
\tl_const:cn {c_phone_DE_ortsname_02651_tl} {Mayen}
\tl_const:cn {c_phone_DE_ortsname_02652_tl} {Mendig}
\tl_const:cn {c_phone_DE_ortsname_02653_tl} {Kaisersesch}
\tl_const:cn {c_phone_DE_ortsname_02654_tl} {Polch}
\tl_const:cn {c_phone_DE_ortsname_02655_tl} {Weibern}
\tl_const:cn {c_phone_DE_ortsname_02656_tl} {Virneburg}
\tl_const:cn {c_phone_DE_ortsname_02657_tl} {Uersfeld}
\tl_const:cn {c_phone_DE_ortsname_02661_tl} {Bad~Marienberg~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02662_tl} {Hachenburg}
\tl_const:cn {c_phone_DE_ortsname_02663_tl} {Westerburg~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02664_tl} {Rennerod}
\tl_const:cn {c_phone_DE_ortsname_02666_tl} {Freilingen~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02667_tl} {Stein-Neukirch}
\tl_const:cn {c_phone_DE_ortsname_02671_tl} {Cochem}
\tl_const:cn {c_phone_DE_ortsname_02672_tl} {Treis-Karden}
\tl_const:cn {c_phone_DE_ortsname_02673_tl} {Ellenz-Poltersdorf}
\tl_const:cn {c_phone_DE_ortsname_02674_tl} {Bad~Bertrich}
\tl_const:cn {c_phone_DE_ortsname_02675_tl} {Ediger-Eller}
\tl_const:cn {c_phone_DE_ortsname_02676_tl} {Ulmen}
\tl_const:cn {c_phone_DE_ortsname_02677_tl} {Lutzerath}
\tl_const:cn {c_phone_DE_ortsname_02678_tl} {B\"uchel~bei~Cochem}
\tl_const:cn {c_phone_DE_ortsname_02680_tl} {M\"undersbach}
\tl_const:cn {c_phone_DE_ortsname_02681_tl} {Altenkirchen~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02682_tl} {Hamm~Sieg}
\tl_const:cn {c_phone_DE_ortsname_02683_tl} {Asbach~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02684_tl} {Puderbach~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02685_tl} {Flammersfeld}
\tl_const:cn {c_phone_DE_ortsname_02686_tl} {Weyerbusch}
\tl_const:cn {c_phone_DE_ortsname_02687_tl} {Horhausen~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_02688_tl} {Kroppach}
\tl_const:cn {c_phone_DE_ortsname_02689_tl} {Dierdorf}
\tl_const:cn {c_phone_DE_ortsname_02691_tl} {Adenau}
\tl_const:cn {c_phone_DE_ortsname_02692_tl} {Kelberg}
\tl_const:cn {c_phone_DE_ortsname_02693_tl} {Antweiler}
\tl_const:cn {c_phone_DE_ortsname_02694_tl} {Wershofen}
\tl_const:cn {c_phone_DE_ortsname_02695_tl} {Insul}
\tl_const:cn {c_phone_DE_ortsname_02696_tl} {Nohn~Eifel}
\tl_const:cn {c_phone_DE_ortsname_02697_tl} {Blankenheim-Ahrh\"utte}
\tl_const:cn {c_phone_DE_ortsname_0271_tl} {Siegen}
\tl_const:cn {c_phone_DE_ortsname_02721_tl} {Lennestadt}
\tl_const:cn {c_phone_DE_ortsname_02722_tl} {Attendorn}
\tl_const:cn {c_phone_DE_ortsname_02723_tl} {Kirchhundem}
\tl_const:cn {c_phone_DE_ortsname_02724_tl} {Finnentrop-Serkenrode}
\tl_const:cn {c_phone_DE_ortsname_02725_tl} {Lennestadt-Oedingen}
\tl_const:cn {c_phone_DE_ortsname_02732_tl} {Kreuztal}
\tl_const:cn {c_phone_DE_ortsname_02733_tl} {Hilchenbach}
\tl_const:cn {c_phone_DE_ortsname_02734_tl} {Freudenberg~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02735_tl} {Neunkirchen~Siegerland}
\tl_const:cn {c_phone_DE_ortsname_02736_tl} {Burbach~Siegerland}
\tl_const:cn {c_phone_DE_ortsname_02737_tl} {Netphen-Deuz}
\tl_const:cn {c_phone_DE_ortsname_02738_tl} {Netphen}
\tl_const:cn {c_phone_DE_ortsname_02739_tl} {Wilnsdorf}
\tl_const:cn {c_phone_DE_ortsname_02741_tl} {Betzdorf}
\tl_const:cn {c_phone_DE_ortsname_02742_tl} {Wissen}
\tl_const:cn {c_phone_DE_ortsname_02743_tl} {Daaden}
\tl_const:cn {c_phone_DE_ortsname_02744_tl} {Herdorf}
\tl_const:cn {c_phone_DE_ortsname_02745_tl} {Brachbach~Sieg}
\tl_const:cn {c_phone_DE_ortsname_02747_tl} {Molzhain}
\tl_const:cn {c_phone_DE_ortsname_02750_tl} {Diedenshausen}
\tl_const:cn {c_phone_DE_ortsname_02751_tl} {Bad~Berleburg}
\tl_const:cn {c_phone_DE_ortsname_02752_tl} {Bad~Laasphe}
\tl_const:cn {c_phone_DE_ortsname_02753_tl} {Erndtebr\"uck}
\tl_const:cn {c_phone_DE_ortsname_02754_tl} {Bad~Laasphe-Feudingen}
\tl_const:cn {c_phone_DE_ortsname_02755_tl} {Bad~Berleburg-Schwarzenau}
\tl_const:cn {c_phone_DE_ortsname_02758_tl} {Bad~Berleburg-Girkhausen}
\tl_const:cn {c_phone_DE_ortsname_02759_tl} {Bad~Berleburg-Aue}
\tl_const:cn {c_phone_DE_ortsname_02761_tl} {Olpe~Biggesee}
\tl_const:cn {c_phone_DE_ortsname_02762_tl} {Wenden~S\"udsauerland}
\tl_const:cn {c_phone_DE_ortsname_02763_tl} {Drolshagen-Bleche}
\tl_const:cn {c_phone_DE_ortsname_02764_tl} {Welschen~Ennest}
\tl_const:cn {c_phone_DE_ortsname_02770_tl} {Eschenburg}
\tl_const:cn {c_phone_DE_ortsname_02771_tl} {Dillenburg}
\tl_const:cn {c_phone_DE_ortsname_02772_tl} {Herborn~Hessen}
\tl_const:cn {c_phone_DE_ortsname_02773_tl} {Haiger}
\tl_const:cn {c_phone_DE_ortsname_02774_tl} {Dietzh\"olztal}
\tl_const:cn {c_phone_DE_ortsname_02775_tl} {Driedorf}
\tl_const:cn {c_phone_DE_ortsname_02776_tl} {Bad~Endbach-Hartenrod}
\tl_const:cn {c_phone_DE_ortsname_02777_tl} {Breitscheid~Hessen}
\tl_const:cn {c_phone_DE_ortsname_02778_tl} {Siegbach}
\tl_const:cn {c_phone_DE_ortsname_02779_tl} {Greifenstein-Beilstein}
\tl_const:cn {c_phone_DE_ortsname_02801_tl} {Xanten}
\tl_const:cn {c_phone_DE_ortsname_02802_tl} {Alpen}
\tl_const:cn {c_phone_DE_ortsname_02803_tl} {Wesel-B\"uderich}
\tl_const:cn {c_phone_DE_ortsname_02804_tl} {Xanten-Marienbaum}
\tl_const:cn {c_phone_DE_ortsname_0281_tl} {Wesel}
\tl_const:cn {c_phone_DE_ortsname_02821_tl} {Kleve~Niederrhein}
\tl_const:cn {c_phone_DE_ortsname_02822_tl} {Emmerich}
\tl_const:cn {c_phone_DE_ortsname_02823_tl} {Goch}
\tl_const:cn {c_phone_DE_ortsname_02824_tl} {Kalkar}
\tl_const:cn {c_phone_DE_ortsname_02825_tl} {Uedem}
\tl_const:cn {c_phone_DE_ortsname_02826_tl} {Kranenburg~Niederrhein}
\tl_const:cn {c_phone_DE_ortsname_02827_tl} {Goch-Hassum}
\tl_const:cn {c_phone_DE_ortsname_02828_tl} {Emmerich-Elten}
\tl_const:cn {c_phone_DE_ortsname_02831_tl} {Geldern}
\tl_const:cn {c_phone_DE_ortsname_02832_tl} {Kevelaer}
\tl_const:cn {c_phone_DE_ortsname_02833_tl} {Kerken}
\tl_const:cn {c_phone_DE_ortsname_02834_tl} {Straelen}
\tl_const:cn {c_phone_DE_ortsname_02835_tl} {Issum}
\tl_const:cn {c_phone_DE_ortsname_02836_tl} {Wachtendonk}
\tl_const:cn {c_phone_DE_ortsname_02837_tl} {Weeze}
\tl_const:cn {c_phone_DE_ortsname_02838_tl} {Sonsbeck}
\tl_const:cn {c_phone_DE_ortsname_02839_tl} {Straelen-Herongen}
\tl_const:cn {c_phone_DE_ortsname_02841_tl} {Moers}
\tl_const:cn {c_phone_DE_ortsname_02842_tl} {Kamp-Lintfort}
\tl_const:cn {c_phone_DE_ortsname_02843_tl} {Rheinberg}
\tl_const:cn {c_phone_DE_ortsname_02844_tl} {Rheinberg-Orsoy}
\tl_const:cn {c_phone_DE_ortsname_02845_tl} {Neukirchen-Vluyn}
\tl_const:cn {c_phone_DE_ortsname_02850_tl} {Rees-Haldern}
\tl_const:cn {c_phone_DE_ortsname_02851_tl} {Rees}
\tl_const:cn {c_phone_DE_ortsname_02852_tl} {Hamminkeln}
\tl_const:cn {c_phone_DE_ortsname_02853_tl} {Schermbeck}
\tl_const:cn {c_phone_DE_ortsname_02855_tl} {Voerde~Niederrhein}
\tl_const:cn {c_phone_DE_ortsname_02856_tl} {Hamminkeln-Br\"unen}
\tl_const:cn {c_phone_DE_ortsname_02857_tl} {Rees-Mehr}
\tl_const:cn {c_phone_DE_ortsname_02858_tl} {H\"unxe}
\tl_const:cn {c_phone_DE_ortsname_02859_tl} {Wesel-Bislich}
\tl_const:cn {c_phone_DE_ortsname_02861_tl} {Borken~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02862_tl} {S\"udlohn}
\tl_const:cn {c_phone_DE_ortsname_02863_tl} {Velen}
\tl_const:cn {c_phone_DE_ortsname_02864_tl} {Reken}
\tl_const:cn {c_phone_DE_ortsname_02865_tl} {Raesfeld}
\tl_const:cn {c_phone_DE_ortsname_02866_tl} {Dorsten-Rhade}
\tl_const:cn {c_phone_DE_ortsname_02867_tl} {Heiden~Kreis~Borken}
\tl_const:cn {c_phone_DE_ortsname_02871_tl} {Bocholt}
\tl_const:cn {c_phone_DE_ortsname_02872_tl} {Rhede~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02873_tl} {Isselburg-Werth}
\tl_const:cn {c_phone_DE_ortsname_02874_tl} {Isselburg}
\tl_const:cn {c_phone_DE_ortsname_02902_tl} {Warstein}
\tl_const:cn {c_phone_DE_ortsname_02903_tl} {Meschede-Freienohl}
\tl_const:cn {c_phone_DE_ortsname_02904_tl} {Bestwig}
\tl_const:cn {c_phone_DE_ortsname_02905_tl} {Bestwig-Ramsbeck}
\tl_const:cn {c_phone_DE_ortsname_0291_tl} {Meschede}
\tl_const:cn {c_phone_DE_ortsname_02921_tl} {Soest}
\tl_const:cn {c_phone_DE_ortsname_02922_tl} {Werl}
\tl_const:cn {c_phone_DE_ortsname_02923_tl} {Lippetal-Herzfeld}
\tl_const:cn {c_phone_DE_ortsname_02924_tl} {M\"ohnesee}
\tl_const:cn {c_phone_DE_ortsname_02925_tl} {Warstein-Allagen}
\tl_const:cn {c_phone_DE_ortsname_02927_tl} {Neuengeseke}
\tl_const:cn {c_phone_DE_ortsname_02928_tl} {Soest-Ost\"onnen}
\tl_const:cn {c_phone_DE_ortsname_02931_tl} {Arnsberg}
\tl_const:cn {c_phone_DE_ortsname_02932_tl} {Neheim-H\"usten}
\tl_const:cn {c_phone_DE_ortsname_02933_tl} {Sundern~Sauerland}
\tl_const:cn {c_phone_DE_ortsname_02934_tl} {Sundern-Altenhellefeld}
\tl_const:cn {c_phone_DE_ortsname_02935_tl} {Sundern-Hachen}
\tl_const:cn {c_phone_DE_ortsname_02937_tl} {Arnsberg-Oeventrop}
\tl_const:cn {c_phone_DE_ortsname_02938_tl} {Ense}
\tl_const:cn {c_phone_DE_ortsname_02941_tl} {Lippstadt}
\tl_const:cn {c_phone_DE_ortsname_02942_tl} {Geseke}
\tl_const:cn {c_phone_DE_ortsname_02943_tl} {Erwitte}
\tl_const:cn {c_phone_DE_ortsname_02944_tl} {Rietberg-Mastholte}
\tl_const:cn {c_phone_DE_ortsname_02945_tl} {Lippstadt-Benninghausen}
\tl_const:cn {c_phone_DE_ortsname_02947_tl} {Anr\"ochte}
\tl_const:cn {c_phone_DE_ortsname_02948_tl} {Lippstadt-Rebbeke}
\tl_const:cn {c_phone_DE_ortsname_02951_tl} {B\"uren}
\tl_const:cn {c_phone_DE_ortsname_02952_tl} {R\"uthen}
\tl_const:cn {c_phone_DE_ortsname_02953_tl} {W\"unnenberg}
\tl_const:cn {c_phone_DE_ortsname_02954_tl} {R\"uthen-Oestereiden}
\tl_const:cn {c_phone_DE_ortsname_02955_tl} {B\"uren-Wewelsburg}
\tl_const:cn {c_phone_DE_ortsname_02957_tl} {W\"unnenberg-Haaren}
\tl_const:cn {c_phone_DE_ortsname_02958_tl} {B\"uren-Harth}
\tl_const:cn {c_phone_DE_ortsname_02961_tl} {Brilon}
\tl_const:cn {c_phone_DE_ortsname_02962_tl} {Olsberg}
\tl_const:cn {c_phone_DE_ortsname_02963_tl} {Brilon-Messinghausen}
\tl_const:cn {c_phone_DE_ortsname_02964_tl} {Brilon-Alme}
\tl_const:cn {c_phone_DE_ortsname_02971_tl} {Schmallenberg-Dorlar}
\tl_const:cn {c_phone_DE_ortsname_02972_tl} {Schmallenberg}
\tl_const:cn {c_phone_DE_ortsname_02973_tl} {Eslohe~Sauerland}
\tl_const:cn {c_phone_DE_ortsname_02974_tl} {Schmallenberg-Fredeburg}
\tl_const:cn {c_phone_DE_ortsname_02975_tl} {Schmallenberg-Oberkirchen}
\tl_const:cn {c_phone_DE_ortsname_02977_tl} {Schmallenberg-B\"odefeld}
\tl_const:cn {c_phone_DE_ortsname_02981_tl} {Winterberg~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_02982_tl} {Medebach}
\tl_const:cn {c_phone_DE_ortsname_02983_tl} {Winterberg-Siedlinghausen}
\tl_const:cn {c_phone_DE_ortsname_02984_tl} {Hallenberg}
\tl_const:cn {c_phone_DE_ortsname_02985_tl} {Winterberg-Niedersfeld}
\tl_const:cn {c_phone_DE_ortsname_02991_tl} {Marsberg-Bredelar}
\tl_const:cn {c_phone_DE_ortsname_02992_tl} {Marsberg}
\tl_const:cn {c_phone_DE_ortsname_02993_tl} {Marsberg-Canstein}
\tl_const:cn {c_phone_DE_ortsname_02994_tl} {Marsberg-Westheim}
\tl_const:cn {c_phone_DE_ortsname_030_tl} {Berlin}
\tl_const:cn {c_phone_DE_ortsname_03301_tl} {Oranienburg}
\tl_const:cn {c_phone_DE_ortsname_03302_tl} {Hennigsdorf}
\tl_const:cn {c_phone_DE_ortsname_03303_tl} {Birkenwerder}
\tl_const:cn {c_phone_DE_ortsname_03304_tl} {Velten}
\tl_const:cn {c_phone_DE_ortsname_033051_tl} {Nassenheide}
\tl_const:cn {c_phone_DE_ortsname_033053_tl} {Zehlendorf~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_033054_tl} {Liebenwalde}
\tl_const:cn {c_phone_DE_ortsname_033055_tl} {Kremmen}
\tl_const:cn {c_phone_DE_ortsname_033056_tl} {M\"uhlenbeck~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_03306_tl} {Gransee}
\tl_const:cn {c_phone_DE_ortsname_03307_tl} {Zehdenick}
\tl_const:cn {c_phone_DE_ortsname_033080_tl} {Marienthal~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_033082_tl} {Menz~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_033083_tl} {Schulzendorf~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_033084_tl} {Gutengermendorf}
\tl_const:cn {c_phone_DE_ortsname_033085_tl} {Seilershof}
\tl_const:cn {c_phone_DE_ortsname_033086_tl} {Grieben~Kreis~Oberhavel}
\tl_const:cn {c_phone_DE_ortsname_033087_tl} {Bredereiche}
\tl_const:cn {c_phone_DE_ortsname_033088_tl} {Falkenthal}
\tl_const:cn {c_phone_DE_ortsname_033089_tl} {Himmelpfort}
\tl_const:cn {c_phone_DE_ortsname_033093_tl} {F\"urstenberg~Havel}
\tl_const:cn {c_phone_DE_ortsname_033094_tl} {L\"owenberg}
\tl_const:cn {c_phone_DE_ortsname_0331_tl} {Potsdam}
\tl_const:cn {c_phone_DE_ortsname_033200_tl} {Bergholz-Rehbr\"ucke}
\tl_const:cn {c_phone_DE_ortsname_033201_tl} {Gro\ss\ Glienicke}
\tl_const:cn {c_phone_DE_ortsname_033202_tl} {T\"oplitz}
\tl_const:cn {c_phone_DE_ortsname_033203_tl} {Kleinmachnow}
\tl_const:cn {c_phone_DE_ortsname_033204_tl} {Beelitz~Mark}
\tl_const:cn {c_phone_DE_ortsname_033205_tl} {Michendorf}
\tl_const:cn {c_phone_DE_ortsname_033206_tl} {Fichtenwalde}
\tl_const:cn {c_phone_DE_ortsname_033207_tl} {Gro\ss\ Kreutz}
\tl_const:cn {c_phone_DE_ortsname_033208_tl} {Fahrland}
\tl_const:cn {c_phone_DE_ortsname_033209_tl} {Caputh}
\tl_const:cn {c_phone_DE_ortsname_03321_tl} {Nauen~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_03322_tl} {Falkensee}
\tl_const:cn {c_phone_DE_ortsname_033230_tl} {B\"ornicke~Kreis~Havelland}
\tl_const:cn {c_phone_DE_ortsname_033231_tl} {Pausin}
\tl_const:cn {c_phone_DE_ortsname_033232_tl} {Brieselang}
\tl_const:cn {c_phone_DE_ortsname_033233_tl} {Ketzin}
\tl_const:cn {c_phone_DE_ortsname_033234_tl} {Wustermark}
\tl_const:cn {c_phone_DE_ortsname_033235_tl} {Friesack}
\tl_const:cn {c_phone_DE_ortsname_033237_tl} {Paulinenaue}
\tl_const:cn {c_phone_DE_ortsname_033238_tl} {Senzke}
\tl_const:cn {c_phone_DE_ortsname_033239_tl} {Gro\ss\ Behnitz}
\tl_const:cn {c_phone_DE_ortsname_03327_tl} {Werder~Havel}
\tl_const:cn {c_phone_DE_ortsname_03328_tl} {Teltow}
\tl_const:cn {c_phone_DE_ortsname_03329_tl} {Stahnsdorf}
\tl_const:cn {c_phone_DE_ortsname_03331_tl} {Angerm\"unde}
\tl_const:cn {c_phone_DE_ortsname_03332_tl} {Schwedt/Oder}
\tl_const:cn {c_phone_DE_ortsname_033331_tl} {Casekow}
\tl_const:cn {c_phone_DE_ortsname_033332_tl} {Gartz~Oder}
\tl_const:cn {c_phone_DE_ortsname_033333_tl} {Tantow}
\tl_const:cn {c_phone_DE_ortsname_033334_tl} {Greiffenberg}
\tl_const:cn {c_phone_DE_ortsname_033335_tl} {Pinnow~Kreis~Uckermark}
\tl_const:cn {c_phone_DE_ortsname_033336_tl} {Passow~Kreis~Uckermark}
\tl_const:cn {c_phone_DE_ortsname_033337_tl} {Altk\"unkendorf}
\tl_const:cn {c_phone_DE_ortsname_033338_tl} {Stolpe/Oder}
\tl_const:cn {c_phone_DE_ortsname_03334_tl} {Eberswalde}
\tl_const:cn {c_phone_DE_ortsname_03335_tl} {Finowfurt}
\tl_const:cn {c_phone_DE_ortsname_033361_tl} {Joachimsthal}
\tl_const:cn {c_phone_DE_ortsname_033362_tl} {Liepe~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033363_tl} {Altenhof~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033364_tl} {Gro\ss-Ziethen~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033365_tl} {L\"udersdorf~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033366_tl} {Chorin}
\tl_const:cn {c_phone_DE_ortsname_033367_tl} {Friedrichswalde~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033368_tl} {Hohensaaten}
\tl_const:cn {c_phone_DE_ortsname_033369_tl} {Oderberg}
\tl_const:cn {c_phone_DE_ortsname_03337_tl} {Biesenthal~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_03338_tl} {Bernau~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033393_tl} {Gro\ss\ Sch\"onebeck~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033394_tl} {Blumberg~Kreis~Barnim}
\tl_const:cn {c_phone_DE_ortsname_033395_tl} {Zerpenschleuse}
\tl_const:cn {c_phone_DE_ortsname_033396_tl} {Klosterfelde}
\tl_const:cn {c_phone_DE_ortsname_033397_tl} {Wandlitz}
\tl_const:cn {c_phone_DE_ortsname_033398_tl} {Werneuchen}
\tl_const:cn {c_phone_DE_ortsname_03341_tl} {Strausberg}
\tl_const:cn {c_phone_DE_ortsname_03342_tl} {Neuenhagen~bei~Berlin}
\tl_const:cn {c_phone_DE_ortsname_033432_tl} {M\"uncheberg}
\tl_const:cn {c_phone_DE_ortsname_033433_tl} {Buckow~M\"arkische~Schweiz}
\tl_const:cn {c_phone_DE_ortsname_033434_tl} {Herzfelde~bei~Strausberg}
\tl_const:cn {c_phone_DE_ortsname_033435_tl} {Rehfelde}
\tl_const:cn {c_phone_DE_ortsname_033436_tl} {Pr\"otzel}
\tl_const:cn {c_phone_DE_ortsname_033437_tl} {Reichenberg~bei~Strausberg}
\tl_const:cn {c_phone_DE_ortsname_033438_tl} {Altlandsberg}
\tl_const:cn {c_phone_DE_ortsname_033439_tl} {Fredersdorf-Vogelsdorf}
\tl_const:cn {c_phone_DE_ortsname_03344_tl} {Bad~Freienwalde}
\tl_const:cn {c_phone_DE_ortsname_033451_tl} {Heckelberg}
\tl_const:cn {c_phone_DE_ortsname_033452_tl} {Neulewin}
\tl_const:cn {c_phone_DE_ortsname_033454_tl} {W\"olsickendorf/Wollenberg}
\tl_const:cn {c_phone_DE_ortsname_033456_tl} {Wriezen}
\tl_const:cn {c_phone_DE_ortsname_033457_tl} {Altreetz}
\tl_const:cn {c_phone_DE_ortsname_033458_tl} {Falkenberg~Mark}
\tl_const:cn {c_phone_DE_ortsname_03346_tl} {Seelow}
\tl_const:cn {c_phone_DE_ortsname_033470_tl} {Lietzen}
\tl_const:cn {c_phone_DE_ortsname_033472_tl} {Golzow~bei~Seelow}
\tl_const:cn {c_phone_DE_ortsname_033473_tl} {Zechin}
\tl_const:cn {c_phone_DE_ortsname_033474_tl} {Neutrebbin}
\tl_const:cn {c_phone_DE_ortsname_033475_tl} {Letschin}
\tl_const:cn {c_phone_DE_ortsname_033476_tl} {Neuhardenberg}
\tl_const:cn {c_phone_DE_ortsname_033477_tl} {Trebnitz~bei~M\"uncheberg}
\tl_const:cn {c_phone_DE_ortsname_033478_tl} {Gro\ss\ Neuendorf}
\tl_const:cn {c_phone_DE_ortsname_033479_tl} {K\"ustrin-Kietz}
\tl_const:cn {c_phone_DE_ortsname_0335_tl} {Frankfurt~(Oder)}
\tl_const:cn {c_phone_DE_ortsname_033601_tl} {Podelzig}
\tl_const:cn {c_phone_DE_ortsname_033602_tl} {Alt~Zeschdorf}
\tl_const:cn {c_phone_DE_ortsname_033603_tl} {Falkenhagen~bei~Seelow}
\tl_const:cn {c_phone_DE_ortsname_033604_tl} {Lebus}
\tl_const:cn {c_phone_DE_ortsname_033605_tl} {Boo\ss en}
\tl_const:cn {c_phone_DE_ortsname_033606_tl} {M\"ullrose}
\tl_const:cn {c_phone_DE_ortsname_033607_tl} {Briesen~Mark}
\tl_const:cn {c_phone_DE_ortsname_033608_tl} {Jacobsdorf~Mark}
\tl_const:cn {c_phone_DE_ortsname_033609_tl} {Brieskow-Finkenheerd}
\tl_const:cn {c_phone_DE_ortsname_03361_tl} {F\"urstenwalde~Spree}
\tl_const:cn {c_phone_DE_ortsname_03362_tl} {Erkner}
\tl_const:cn {c_phone_DE_ortsname_033631_tl} {Bad~Saarow-Pieskow}
\tl_const:cn {c_phone_DE_ortsname_033632_tl} {Hangelsberg}
\tl_const:cn {c_phone_DE_ortsname_033633_tl} {Spreenhagen}
\tl_const:cn {c_phone_DE_ortsname_033634_tl} {Berkenbr\"uck~Kreis~Oder-Spree}
\tl_const:cn {c_phone_DE_ortsname_033635_tl} {Arensdorf~Kreis~Oder-Spree}
\tl_const:cn {c_phone_DE_ortsname_033636_tl} {Steinh\"ofel~Kreis~Oder-Spree}
\tl_const:cn {c_phone_DE_ortsname_033637_tl} {Beerfelde}
\tl_const:cn {c_phone_DE_ortsname_033638_tl} {R\"udersdorf~bei~Berlin}
\tl_const:cn {c_phone_DE_ortsname_03364_tl} {Eisenh\"uttenstadt}
\tl_const:cn {c_phone_DE_ortsname_033652_tl} {Neuzelle}
\tl_const:cn {c_phone_DE_ortsname_033653_tl} {Ziltendorf}
\tl_const:cn {c_phone_DE_ortsname_033654_tl} {F\"unfeichen}
\tl_const:cn {c_phone_DE_ortsname_033655_tl} {Grunow~Kreis~Oder-Spree}
\tl_const:cn {c_phone_DE_ortsname_033656_tl} {Bahro}
\tl_const:cn {c_phone_DE_ortsname_033657_tl} {Steinsdorf~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_03366_tl} {Beeskow}
\tl_const:cn {c_phone_DE_ortsname_033671_tl} {Lieberose}
\tl_const:cn {c_phone_DE_ortsname_033672_tl} {Pfaffendorf~bei~Beeskow}
\tl_const:cn {c_phone_DE_ortsname_033673_tl} {Weichensdorf}
\tl_const:cn {c_phone_DE_ortsname_033674_tl} {Trebatsch}
\tl_const:cn {c_phone_DE_ortsname_033675_tl} {Tauche}
\tl_const:cn {c_phone_DE_ortsname_033676_tl} {Friedland~bei~Beeskow}
\tl_const:cn {c_phone_DE_ortsname_033677_tl} {Glienicke~bei~Beeskow}
\tl_const:cn {c_phone_DE_ortsname_033678_tl} {Storkow~Mark}
\tl_const:cn {c_phone_DE_ortsname_033679_tl} {Wendisch~Rietz}
\tl_const:cn {c_phone_DE_ortsname_033701_tl} {Gro\ss beeren}
\tl_const:cn {c_phone_DE_ortsname_033702_tl} {W\"unsdorf}
\tl_const:cn {c_phone_DE_ortsname_033703_tl} {Sperenberg}
\tl_const:cn {c_phone_DE_ortsname_033704_tl} {Baruth~Mark}
\tl_const:cn {c_phone_DE_ortsname_033708_tl} {Rangsdorf}
\tl_const:cn {c_phone_DE_ortsname_03371_tl} {Luckenwalde}
\tl_const:cn {c_phone_DE_ortsname_03372_tl} {J\"uterbog}
\tl_const:cn {c_phone_DE_ortsname_033731_tl} {Trebbin}
\tl_const:cn {c_phone_DE_ortsname_033732_tl} {Hennickendorf~bei~Luckenwalde}
\tl_const:cn {c_phone_DE_ortsname_033733_tl} {St\"ulpe}
\tl_const:cn {c_phone_DE_ortsname_033734_tl} {Felgentreu}
\tl_const:cn {c_phone_DE_ortsname_033741_tl} {Niederg\"orsdorf}
\tl_const:cn {c_phone_DE_ortsname_033742_tl} {Oehna~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033743_tl} {Bl\"onsdorf}
\tl_const:cn {c_phone_DE_ortsname_033744_tl} {Hohenseefeld}
\tl_const:cn {c_phone_DE_ortsname_033745_tl} {Petkus}
\tl_const:cn {c_phone_DE_ortsname_033746_tl} {Werbig~bei~J\"uterbog}
\tl_const:cn {c_phone_DE_ortsname_033747_tl} {Marzahna}
\tl_const:cn {c_phone_DE_ortsname_033748_tl} {Treuenbrietzen}
\tl_const:cn {c_phone_DE_ortsname_03375_tl} {K\"onigs~Wusterhausen}
\tl_const:cn {c_phone_DE_ortsname_033760_tl} {M\"unchehofe~Kreis~Dahme-Spreewald}
\tl_const:cn {c_phone_DE_ortsname_033762_tl} {Zeuthen}
\tl_const:cn {c_phone_DE_ortsname_033763_tl} {Bestensee}
\tl_const:cn {c_phone_DE_ortsname_033764_tl} {Mittenwalde~Mark}
\tl_const:cn {c_phone_DE_ortsname_033765_tl} {M\"arkisch~Buchholz}
\tl_const:cn {c_phone_DE_ortsname_033766_tl} {Teupitz}
\tl_const:cn {c_phone_DE_ortsname_033767_tl} {Friedersdorf~bei~Berlin}
\tl_const:cn {c_phone_DE_ortsname_033768_tl} {Prieros}
\tl_const:cn {c_phone_DE_ortsname_033769_tl} {T\"opchin}
\tl_const:cn {c_phone_DE_ortsname_03377_tl} {Zossen~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_03378_tl} {Ludwigsfelde}
\tl_const:cn {c_phone_DE_ortsname_03379_tl} {Mahlow}
\tl_const:cn {c_phone_DE_ortsname_03381_tl} {Brandenburg~an~der~Havel}
\tl_const:cn {c_phone_DE_ortsname_03382_tl} {Lehnin}
\tl_const:cn {c_phone_DE_ortsname_033830_tl} {Ziesar}
\tl_const:cn {c_phone_DE_ortsname_033831_tl} {Weseram}
\tl_const:cn {c_phone_DE_ortsname_033832_tl} {Rog\"asen}
\tl_const:cn {c_phone_DE_ortsname_033833_tl} {Wollin~bei~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033834_tl} {Pritzerbe}
\tl_const:cn {c_phone_DE_ortsname_033835_tl} {Golzow~bei~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033836_tl} {Butzow~bei~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033837_tl} {Brielow}
\tl_const:cn {c_phone_DE_ortsname_033838_tl} {P\"awesin}
\tl_const:cn {c_phone_DE_ortsname_033839_tl} {Wusterwitz}
\tl_const:cn {c_phone_DE_ortsname_033841_tl} {Belzig}
\tl_const:cn {c_phone_DE_ortsname_033843_tl} {Niemegk}
\tl_const:cn {c_phone_DE_ortsname_033844_tl} {Br\"uck~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033845_tl} {Borkheide}
\tl_const:cn {c_phone_DE_ortsname_033846_tl} {Dippmannsdorf}
\tl_const:cn {c_phone_DE_ortsname_033847_tl} {G\"orzke}
\tl_const:cn {c_phone_DE_ortsname_033848_tl} {Raben}
\tl_const:cn {c_phone_DE_ortsname_033849_tl} {Wiesenburg~Mark}
\tl_const:cn {c_phone_DE_ortsname_03385_tl} {Rathenow}
\tl_const:cn {c_phone_DE_ortsname_03386_tl} {Premnitz}
\tl_const:cn {c_phone_DE_ortsname_033870_tl} {Zollchow~bei~Rathenow}
\tl_const:cn {c_phone_DE_ortsname_033872_tl} {Hohennauen}
\tl_const:cn {c_phone_DE_ortsname_033873_tl} {Gro\ss wudicke}
\tl_const:cn {c_phone_DE_ortsname_033874_tl} {Stechow~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033875_tl} {Rhinow}
\tl_const:cn {c_phone_DE_ortsname_033876_tl} {Buschow}
\tl_const:cn {c_phone_DE_ortsname_033877_tl} {Nitzahn}
\tl_const:cn {c_phone_DE_ortsname_033878_tl} {Nennhausen}
\tl_const:cn {c_phone_DE_ortsname_03391_tl} {Neuruppin}
\tl_const:cn {c_phone_DE_ortsname_033920_tl} {Walsleben~bei~Neuruppin}
\tl_const:cn {c_phone_DE_ortsname_033921_tl} {Zechlinerh\"utte}
\tl_const:cn {c_phone_DE_ortsname_033922_tl} {Karwesee}
\tl_const:cn {c_phone_DE_ortsname_033923_tl} {Flecken~Zechlin}
\tl_const:cn {c_phone_DE_ortsname_033924_tl} {R\"agelin}
\tl_const:cn {c_phone_DE_ortsname_033925_tl} {Wustrau-Altfriesack}
\tl_const:cn {c_phone_DE_ortsname_033926_tl} {Herzberg~Mark}
\tl_const:cn {c_phone_DE_ortsname_033928_tl} {Wildberg~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033929_tl} {G\"uhlen-Glienicke}
\tl_const:cn {c_phone_DE_ortsname_033931_tl} {Rheinsberg~Mark}
\tl_const:cn {c_phone_DE_ortsname_033932_tl} {Fehrbellin}
\tl_const:cn {c_phone_DE_ortsname_033933_tl} {Lindow~Mark}
\tl_const:cn {c_phone_DE_ortsname_03394_tl} {Wittstock~Dosse}
\tl_const:cn {c_phone_DE_ortsname_03395_tl} {Pritzwalk}
\tl_const:cn {c_phone_DE_ortsname_033962_tl} {Heiligengrabe}
\tl_const:cn {c_phone_DE_ortsname_033963_tl} {Wulfersdorf~bei~Wittstock}
\tl_const:cn {c_phone_DE_ortsname_033964_tl} {Fretzdorf}
\tl_const:cn {c_phone_DE_ortsname_033965_tl} {Herzsprung~bei~Wittstock}
\tl_const:cn {c_phone_DE_ortsname_033966_tl} {Dranse}
\tl_const:cn {c_phone_DE_ortsname_033967_tl} {Freyenstein}
\tl_const:cn {c_phone_DE_ortsname_033968_tl} {Meyenburg~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_033969_tl} {Stepenitz}
\tl_const:cn {c_phone_DE_ortsname_033970_tl} {Neustadt~Dosse}
\tl_const:cn {c_phone_DE_ortsname_033971_tl} {Kyritz~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_033972_tl} {Breddin}
\tl_const:cn {c_phone_DE_ortsname_033973_tl} {Zernitz~bei~Neustadt~Dosse}
\tl_const:cn {c_phone_DE_ortsname_033974_tl} {Dessow}
\tl_const:cn {c_phone_DE_ortsname_033975_tl} {Dannenwalde~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_033976_tl} {Wutike}
\tl_const:cn {c_phone_DE_ortsname_033977_tl} {Gumtow}
\tl_const:cn {c_phone_DE_ortsname_033978_tl} {Segeletz}
\tl_const:cn {c_phone_DE_ortsname_033979_tl} {Wusterhausen~Dosse}
\tl_const:cn {c_phone_DE_ortsname_033981_tl} {Putlitz}
\tl_const:cn {c_phone_DE_ortsname_033982_tl} {Hoppenrade~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_033983_tl} {Gro\ss\ Pankow~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_033984_tl} {Blumenthal~bei~Pritzwalk}
\tl_const:cn {c_phone_DE_ortsname_033986_tl} {Falkenhagen~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_033989_tl} {Sadenbeck}
\tl_const:cn {c_phone_DE_ortsname_0340_tl} {Dessau~Anhalt}
\tl_const:cn {c_phone_DE_ortsname_0341_tl} {Leipzig}
\tl_const:cn {c_phone_DE_ortsname_034202_tl} {Delitzsch}
\tl_const:cn {c_phone_DE_ortsname_034203_tl} {Zwenkau}
\tl_const:cn {c_phone_DE_ortsname_034204_tl} {Schkeuditz}
\tl_const:cn {c_phone_DE_ortsname_034205_tl} {Markranst\"adt}
\tl_const:cn {c_phone_DE_ortsname_034206_tl} {R\"otha}
\tl_const:cn {c_phone_DE_ortsname_034207_tl} {Zwochau}
\tl_const:cn {c_phone_DE_ortsname_034208_tl} {L\"obnitz~bei~Delitzsch}
\tl_const:cn {c_phone_DE_ortsname_03421_tl} {Torgau}
\tl_const:cn {c_phone_DE_ortsname_034221_tl} {Schildau~Gneisenaustadt}
\tl_const:cn {c_phone_DE_ortsname_034222_tl} {Arzberg~bei~Torgau}
\tl_const:cn {c_phone_DE_ortsname_034223_tl} {Dommitzsch}
\tl_const:cn {c_phone_DE_ortsname_034224_tl} {Belgern~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_03423_tl} {Eilenburg}
\tl_const:cn {c_phone_DE_ortsname_034241_tl} {Jesewitz}
\tl_const:cn {c_phone_DE_ortsname_034242_tl} {Hohenprie\ss nitz}
\tl_const:cn {c_phone_DE_ortsname_034243_tl} {Bad~D\"uben}
\tl_const:cn {c_phone_DE_ortsname_034244_tl} {Mockrehna}
\tl_const:cn {c_phone_DE_ortsname_03425_tl} {Wurzen}
\tl_const:cn {c_phone_DE_ortsname_034261_tl} {K\"uhren~bei~Wurzen}
\tl_const:cn {c_phone_DE_ortsname_034262_tl} {Falkenhain~bei~Wurzen}
\tl_const:cn {c_phone_DE_ortsname_034263_tl} {Hohburg}
\tl_const:cn {c_phone_DE_ortsname_034291_tl} {Borsdorf}
\tl_const:cn {c_phone_DE_ortsname_034292_tl} {Brandis~bei~Wurzen}
\tl_const:cn {c_phone_DE_ortsname_034293_tl} {Naunhof~bei~Grimma}
\tl_const:cn {c_phone_DE_ortsname_034294_tl} {Rackwitz}
\tl_const:cn {c_phone_DE_ortsname_034295_tl} {Krensitz}
\tl_const:cn {c_phone_DE_ortsname_034296_tl} {Groitzsch~bei~Pegau}
\tl_const:cn {c_phone_DE_ortsname_034297_tl} {Liebertwolkwitz}
\tl_const:cn {c_phone_DE_ortsname_034298_tl} {Taucha~bei~Leipzig}
\tl_const:cn {c_phone_DE_ortsname_034299_tl} {Gaschwitz}
\tl_const:cn {c_phone_DE_ortsname_03431_tl} {D\"obeln}
\tl_const:cn {c_phone_DE_ortsname_034321_tl} {Leisnig}
\tl_const:cn {c_phone_DE_ortsname_034322_tl} {Ro\ss wein}
\tl_const:cn {c_phone_DE_ortsname_034324_tl} {Ostrau~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_034325_tl} {Mochau-L\"uttewitz}
\tl_const:cn {c_phone_DE_ortsname_034327_tl} {Waldheim~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_034328_tl} {Hartha~bei~D\"obeln}
\tl_const:cn {c_phone_DE_ortsname_03433_tl} {Borna~Stadt}
\tl_const:cn {c_phone_DE_ortsname_034341_tl} {Geithain}
\tl_const:cn {c_phone_DE_ortsname_034342_tl} {Neukieritzsch}
\tl_const:cn {c_phone_DE_ortsname_034343_tl} {Regis-Breitingen}
\tl_const:cn {c_phone_DE_ortsname_034344_tl} {Kohren-Sahlis}
\tl_const:cn {c_phone_DE_ortsname_034345_tl} {Bad~Lausick}
\tl_const:cn {c_phone_DE_ortsname_034346_tl} {Narsdorf}
\tl_const:cn {c_phone_DE_ortsname_034347_tl} {Oelzschau~bei~Borna}
\tl_const:cn {c_phone_DE_ortsname_034348_tl} {Frohburg}
\tl_const:cn {c_phone_DE_ortsname_03435_tl} {Oschatz}
\tl_const:cn {c_phone_DE_ortsname_034361_tl} {Dahlen~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_034362_tl} {M\"ugeln~bei~Oschatz}
\tl_const:cn {c_phone_DE_ortsname_034363_tl} {Cavertitz}
\tl_const:cn {c_phone_DE_ortsname_034364_tl} {Wermsdorf}
\tl_const:cn {c_phone_DE_ortsname_03437_tl} {Grimma}
\tl_const:cn {c_phone_DE_ortsname_034381_tl} {Colditz}
\tl_const:cn {c_phone_DE_ortsname_034382_tl} {Nerchau}
\tl_const:cn {c_phone_DE_ortsname_034383_tl} {Trebsen~Mulde}
\tl_const:cn {c_phone_DE_ortsname_034384_tl} {Gro\ss bothen}
\tl_const:cn {c_phone_DE_ortsname_034385_tl} {Mutzschen}
\tl_const:cn {c_phone_DE_ortsname_034386_tl} {D\"urrweitzschen~bei~Grimma}
\tl_const:cn {c_phone_DE_ortsname_03441_tl} {Zeitz}
\tl_const:cn {c_phone_DE_ortsname_034422_tl} {Osterfeld}
\tl_const:cn {c_phone_DE_ortsname_034423_tl} {Heuckewalde}
\tl_const:cn {c_phone_DE_ortsname_034424_tl} {Reuden~bei~Zeitz}
\tl_const:cn {c_phone_DE_ortsname_034425_tl} {Droy\ss ig}
\tl_const:cn {c_phone_DE_ortsname_034426_tl} {Kayna}
\tl_const:cn {c_phone_DE_ortsname_03443_tl} {Wei\ss enfels~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034441_tl} {Hohenm\"olsen}
\tl_const:cn {c_phone_DE_ortsname_034443_tl} {Teuchern}
\tl_const:cn {c_phone_DE_ortsname_034444_tl} {L\"utzen}
\tl_const:cn {c_phone_DE_ortsname_034445_tl} {St\"o\ss en}
\tl_const:cn {c_phone_DE_ortsname_034446_tl} {Gro\ss korbetha}
\tl_const:cn {c_phone_DE_ortsname_03445_tl} {Naumburg~Saale}
\tl_const:cn {c_phone_DE_ortsname_034461_tl} {Nebra~Unstrut}
\tl_const:cn {c_phone_DE_ortsname_034462_tl} {Laucha~Unstrut}
\tl_const:cn {c_phone_DE_ortsname_034463_tl} {Bad~K\"osen}
\tl_const:cn {c_phone_DE_ortsname_034464_tl} {Freyburg~Unstrut}
\tl_const:cn {c_phone_DE_ortsname_034465_tl} {Bad~Bibra}
\tl_const:cn {c_phone_DE_ortsname_034466_tl} {Janisroda}
\tl_const:cn {c_phone_DE_ortsname_034467_tl} {Eckartsberga}
\tl_const:cn {c_phone_DE_ortsname_03447_tl} {Altenburg~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_03448_tl} {Meuselwitz~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_034491_tl} {Schm\"olln~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_034492_tl} {Lucka}
\tl_const:cn {c_phone_DE_ortsname_034493_tl} {G\"o\ss nitz~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_034494_tl} {Ehrenhain}
\tl_const:cn {c_phone_DE_ortsname_034495_tl} {Dobitschen}
\tl_const:cn {c_phone_DE_ortsname_034496_tl} {N\"obdenitz}
\tl_const:cn {c_phone_DE_ortsname_034497_tl} {Langenleuba-Niederhain}
\tl_const:cn {c_phone_DE_ortsname_034498_tl} {Rositz}
\tl_const:cn {c_phone_DE_ortsname_0345_tl} {Halle~Saale}
\tl_const:cn {c_phone_DE_ortsname_034600_tl} {Ostrau~Saalkreis}
\tl_const:cn {c_phone_DE_ortsname_034601_tl} {Teutschenthal}
\tl_const:cn {c_phone_DE_ortsname_034602_tl} {Landsberg~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034603_tl} {Nauendorf~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034604_tl} {Niemberg}
\tl_const:cn {c_phone_DE_ortsname_034605_tl} {Gr\"obers}
\tl_const:cn {c_phone_DE_ortsname_034606_tl} {Teicha~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034607_tl} {Wettin}
\tl_const:cn {c_phone_DE_ortsname_034609_tl} {Salzm\"unde}
\tl_const:cn {c_phone_DE_ortsname_03461_tl} {Merseburg~Saale}
\tl_const:cn {c_phone_DE_ortsname_03462_tl} {Bad~D\"urrenberg}
\tl_const:cn {c_phone_DE_ortsname_034632_tl} {M\"ucheln~Geiseltal}
\tl_const:cn {c_phone_DE_ortsname_034633_tl} {Braunsbedra}
\tl_const:cn {c_phone_DE_ortsname_034635_tl} {Bad~Lauchst\"adt}
\tl_const:cn {c_phone_DE_ortsname_034636_tl} {Schafst\"adt}
\tl_const:cn {c_phone_DE_ortsname_034637_tl} {Frankleben}
\tl_const:cn {c_phone_DE_ortsname_034638_tl} {Z\"oschen}
\tl_const:cn {c_phone_DE_ortsname_034639_tl} {Wallendorf~Luppe}
\tl_const:cn {c_phone_DE_ortsname_03464_tl} {Sangerhausen}
\tl_const:cn {c_phone_DE_ortsname_034651_tl} {Ro\ss la}
\tl_const:cn {c_phone_DE_ortsname_034652_tl} {Allstedt}
\tl_const:cn {c_phone_DE_ortsname_034653_tl} {Rottleberode}
\tl_const:cn {c_phone_DE_ortsname_034654_tl} {Stolberg~Harz}
\tl_const:cn {c_phone_DE_ortsname_034656_tl} {Wallhausen~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034658_tl} {Hayn~Harz}
\tl_const:cn {c_phone_DE_ortsname_034659_tl} {Blankenheim~bei~Sangerhausen}
\tl_const:cn {c_phone_DE_ortsname_03466_tl} {Artern~Unstrut}
\tl_const:cn {c_phone_DE_ortsname_034671_tl} {Bad~Frankenhausen~Kyffh\"auser}
\tl_const:cn {c_phone_DE_ortsname_034672_tl} {Ro\ss leben}
\tl_const:cn {c_phone_DE_ortsname_034673_tl} {Heldrungen}
\tl_const:cn {c_phone_DE_ortsname_034691_tl} {K\"onnern}
\tl_const:cn {c_phone_DE_ortsname_034692_tl} {Alsleben~Saale}
\tl_const:cn {c_phone_DE_ortsname_03471_tl} {Bernburg~Saale}
\tl_const:cn {c_phone_DE_ortsname_034721_tl} {Nienburg~Saale}
\tl_const:cn {c_phone_DE_ortsname_034722_tl} {Preu\ss litz}
\tl_const:cn {c_phone_DE_ortsname_03473_tl} {Aschersleben~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034741_tl} {Frose}
\tl_const:cn {c_phone_DE_ortsname_034742_tl} {Sylda}
\tl_const:cn {c_phone_DE_ortsname_034743_tl} {Ermsleben}
\tl_const:cn {c_phone_DE_ortsname_034745_tl} {Winningen~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034746_tl} {Giersleben}
\tl_const:cn {c_phone_DE_ortsname_03475_tl} {Lutherstadt~Eisleben}
\tl_const:cn {c_phone_DE_ortsname_03476_tl} {Hettstedt~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034771_tl} {Querfurt}
\tl_const:cn {c_phone_DE_ortsname_034772_tl} {Helbra}
\tl_const:cn {c_phone_DE_ortsname_034773_tl} {Schwittersdorf}
\tl_const:cn {c_phone_DE_ortsname_034774_tl} {R\"oblingen~am~See}
\tl_const:cn {c_phone_DE_ortsname_034775_tl} {Wippra}
\tl_const:cn {c_phone_DE_ortsname_034776_tl} {Rothenschirmbach}
\tl_const:cn {c_phone_DE_ortsname_034779_tl} {Abberode}
\tl_const:cn {c_phone_DE_ortsname_034781_tl} {Greifenhagen}
\tl_const:cn {c_phone_DE_ortsname_034782_tl} {Mansfeld~S\"udharz}
\tl_const:cn {c_phone_DE_ortsname_034783_tl} {Gerbstedt}
\tl_const:cn {c_phone_DE_ortsname_034785_tl} {Sandersleben}
\tl_const:cn {c_phone_DE_ortsname_034901_tl} {Ro\ss lau~Elbe}
\tl_const:cn {c_phone_DE_ortsname_034903_tl} {Coswig~Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034904_tl} {Oranienbaum}
\tl_const:cn {c_phone_DE_ortsname_034905_tl} {W\"orlitz}
\tl_const:cn {c_phone_DE_ortsname_034906_tl} {Raguhn}
\tl_const:cn {c_phone_DE_ortsname_034907_tl} {Jeber-Bergfrieden}
\tl_const:cn {c_phone_DE_ortsname_034909_tl} {Aken~Elbe}
\tl_const:cn {c_phone_DE_ortsname_03491_tl} {Lutherstadt~Wittenberg}
\tl_const:cn {c_phone_DE_ortsname_034920_tl} {Kropst\"adt}
\tl_const:cn {c_phone_DE_ortsname_034921_tl} {Kemberg}
\tl_const:cn {c_phone_DE_ortsname_034922_tl} {M\"uhlanger}
\tl_const:cn {c_phone_DE_ortsname_034923_tl} {Cobbelsdorf}
\tl_const:cn {c_phone_DE_ortsname_034924_tl} {Zahna}
\tl_const:cn {c_phone_DE_ortsname_034925_tl} {Bad~Schmiedeberg}
\tl_const:cn {c_phone_DE_ortsname_034926_tl} {Pretzsch~Elbe}
\tl_const:cn {c_phone_DE_ortsname_034927_tl} {Globig-Bleddin}
\tl_const:cn {c_phone_DE_ortsname_034928_tl} {Seegrehna}
\tl_const:cn {c_phone_DE_ortsname_034929_tl} {Straach}
\tl_const:cn {c_phone_DE_ortsname_03493_tl} {Bitterfeld}
\tl_const:cn {c_phone_DE_ortsname_03494_tl} {Wolfen}
\tl_const:cn {c_phone_DE_ortsname_034953_tl} {Gr\"afenhainichen}
\tl_const:cn {c_phone_DE_ortsname_034954_tl} {Roitzsch~bei~Bitterfeld}
\tl_const:cn {c_phone_DE_ortsname_034955_tl} {Gossa}
\tl_const:cn {c_phone_DE_ortsname_034956_tl} {Z\"orbig}
\tl_const:cn {c_phone_DE_ortsname_03496_tl} {K\"othen~Anhalt}
\tl_const:cn {c_phone_DE_ortsname_034973_tl} {Osternienburg}
\tl_const:cn {c_phone_DE_ortsname_034975_tl} {G\"orzig~Kreis~K\"othen}
\tl_const:cn {c_phone_DE_ortsname_034976_tl} {Gr\"obzig}
\tl_const:cn {c_phone_DE_ortsname_034977_tl} {Quellendorf}
\tl_const:cn {c_phone_DE_ortsname_034978_tl} {Radegast~Kreis~K\"othen}
\tl_const:cn {c_phone_DE_ortsname_034979_tl} {Wulfen~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_03501_tl} {Pirna}
\tl_const:cn {c_phone_DE_ortsname_035020_tl} {Struppen}
\tl_const:cn {c_phone_DE_ortsname_035021_tl} {K\"onigstein~S\"achsische~Schweiz}
\tl_const:cn {c_phone_DE_ortsname_035022_tl} {Bad~Schandau}
\tl_const:cn {c_phone_DE_ortsname_035023_tl} {Bad~Gottleuba}
\tl_const:cn {c_phone_DE_ortsname_035024_tl} {Stadt~Wehlen}
\tl_const:cn {c_phone_DE_ortsname_035025_tl} {Liebstadt}
\tl_const:cn {c_phone_DE_ortsname_035026_tl} {D\"urrr\"ohrsdorf-Dittersbach}
\tl_const:cn {c_phone_DE_ortsname_035027_tl} {Weesenstein}
\tl_const:cn {c_phone_DE_ortsname_035028_tl} {Krippen}
\tl_const:cn {c_phone_DE_ortsname_035032_tl} {Langenhennersdorf}
\tl_const:cn {c_phone_DE_ortsname_035033_tl} {Rosenthal~S\"achsische~Schweiz}
\tl_const:cn {c_phone_DE_ortsname_03504_tl} {Dippoldiswalde}
\tl_const:cn {c_phone_DE_ortsname_035052_tl} {Kipsdorf~Kurort}
\tl_const:cn {c_phone_DE_ortsname_035053_tl} {Glash\"utte~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035054_tl} {Lauenstein~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035055_tl} {H\"ockendorf~bei~Dippoldiswalde}
\tl_const:cn {c_phone_DE_ortsname_035056_tl} {Altenberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035057_tl} {Hermsdorf~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_035058_tl} {Pretzschendorf}
\tl_const:cn {c_phone_DE_ortsname_0351_tl} {Dresden}
\tl_const:cn {c_phone_DE_ortsname_035200_tl} {Arnsdorf~bei~Dresden}
\tl_const:cn {c_phone_DE_ortsname_035201_tl} {Langebr\"uck}
\tl_const:cn {c_phone_DE_ortsname_035202_tl} {Klingenberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035203_tl} {Tharandt}
\tl_const:cn {c_phone_DE_ortsname_035204_tl} {Wilsdruff}
\tl_const:cn {c_phone_DE_ortsname_035205_tl} {Ottendorf-Okrilla}
\tl_const:cn {c_phone_DE_ortsname_035206_tl} {Kreischa~bei~Dresden}
\tl_const:cn {c_phone_DE_ortsname_035207_tl} {Moritzburg}
\tl_const:cn {c_phone_DE_ortsname_035208_tl} {Radeburg}
\tl_const:cn {c_phone_DE_ortsname_035209_tl} {Mohorn}
\tl_const:cn {c_phone_DE_ortsname_03521_tl} {Mei\ss en}
\tl_const:cn {c_phone_DE_ortsname_03522_tl} {Gro\ss enhain~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_03523_tl} {Coswig~bei~Dresden}
\tl_const:cn {c_phone_DE_ortsname_035240_tl} {Tauscha~bei~Gro\ss enhain}
\tl_const:cn {c_phone_DE_ortsname_035241_tl} {Lommatzsch}
\tl_const:cn {c_phone_DE_ortsname_035242_tl} {Nossen}
\tl_const:cn {c_phone_DE_ortsname_035243_tl} {Weinb\"ohla}
\tl_const:cn {c_phone_DE_ortsname_035244_tl} {Kr\"ogis}
\tl_const:cn {c_phone_DE_ortsname_035245_tl} {Burkhardswalde-Munzig}
\tl_const:cn {c_phone_DE_ortsname_035246_tl} {Ziegenhain~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035247_tl} {Zehren~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035248_tl} {Sch\"onfeld~bei~Gro\ss enhain}
\tl_const:cn {c_phone_DE_ortsname_035249_tl} {Ba\ss litz}
\tl_const:cn {c_phone_DE_ortsname_03525_tl} {Riesa}
\tl_const:cn {c_phone_DE_ortsname_035263_tl} {Gr\"oditz~bei~Riesa}
\tl_const:cn {c_phone_DE_ortsname_035264_tl} {Strehla}
\tl_const:cn {c_phone_DE_ortsname_035265_tl} {Glaubitz}
\tl_const:cn {c_phone_DE_ortsname_035266_tl} {Heyda~bei~Riesa}
\tl_const:cn {c_phone_DE_ortsname_035267_tl} {Diesbar-Seu\ss litz}
\tl_const:cn {c_phone_DE_ortsname_035268_tl} {Stauchitz}
\tl_const:cn {c_phone_DE_ortsname_03528_tl} {Radeberg}
\tl_const:cn {c_phone_DE_ortsname_03529_tl} {Heidenau~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_03531_tl} {Finsterwalde}
\tl_const:cn {c_phone_DE_ortsname_035322_tl} {Doberlug-Kirchhain}
\tl_const:cn {c_phone_DE_ortsname_035323_tl} {Sonnewalde}
\tl_const:cn {c_phone_DE_ortsname_035324_tl} {Crinitz}
\tl_const:cn {c_phone_DE_ortsname_035325_tl} {R\"uckersdorf~bei~Finsterwalde}
\tl_const:cn {c_phone_DE_ortsname_035326_tl} {Sch\"onborn~Kreis~Elbe-Elster}
\tl_const:cn {c_phone_DE_ortsname_035327_tl} {Prie\ss en}
\tl_const:cn {c_phone_DE_ortsname_035329_tl} {Dollenchen}
\tl_const:cn {c_phone_DE_ortsname_03533_tl} {Elsterwerda}
\tl_const:cn {c_phone_DE_ortsname_035341_tl} {Bad~Liebenwerda}
\tl_const:cn {c_phone_DE_ortsname_035342_tl} {M\"uhlberg~Elbe}
\tl_const:cn {c_phone_DE_ortsname_035343_tl} {Hirschfeld~bei~Elsterwerda}
\tl_const:cn {c_phone_DE_ortsname_03535_tl} {Herzberg~Elster}
\tl_const:cn {c_phone_DE_ortsname_035361_tl} {Schlieben}
\tl_const:cn {c_phone_DE_ortsname_035362_tl} {Sch\"onewalde~bei~Herzberg}
\tl_const:cn {c_phone_DE_ortsname_035363_tl} {Fermerswalde}
\tl_const:cn {c_phone_DE_ortsname_035364_tl} {Lebusa}
\tl_const:cn {c_phone_DE_ortsname_035365_tl} {Falkenberg~Elster}
\tl_const:cn {c_phone_DE_ortsname_03537_tl} {Jessen~Elster}
\tl_const:cn {c_phone_DE_ortsname_035383_tl} {Elster~Elbe}
\tl_const:cn {c_phone_DE_ortsname_035384_tl} {Steinsdorf~bei~Jessen}
\tl_const:cn {c_phone_DE_ortsname_035385_tl} {Annaburg}
\tl_const:cn {c_phone_DE_ortsname_035386_tl} {Prettin}
\tl_const:cn {c_phone_DE_ortsname_035387_tl} {Seyda}
\tl_const:cn {c_phone_DE_ortsname_035388_tl} {Kl\"oden}
\tl_const:cn {c_phone_DE_ortsname_035389_tl} {Holzdorf~Elster}
\tl_const:cn {c_phone_DE_ortsname_03541_tl} {Calau}
\tl_const:cn {c_phone_DE_ortsname_03542_tl} {L\"ubbenau~Spreewald}
\tl_const:cn {c_phone_DE_ortsname_035433_tl} {Vetschau}
\tl_const:cn {c_phone_DE_ortsname_035434_tl} {Altd\"obern}
\tl_const:cn {c_phone_DE_ortsname_035435_tl} {Gollmitz~bei~Calau}
\tl_const:cn {c_phone_DE_ortsname_035436_tl} {Laasow~bei~Calau}
\tl_const:cn {c_phone_DE_ortsname_035439_tl} {Zinnitz}
\tl_const:cn {c_phone_DE_ortsname_03544_tl} {Luckau~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_035451_tl} {Dahme~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_035452_tl} {Gol\ss en}
\tl_const:cn {c_phone_DE_ortsname_035453_tl} {Drahnsdorf}
\tl_const:cn {c_phone_DE_ortsname_035454_tl} {Uckro}
\tl_const:cn {c_phone_DE_ortsname_035455_tl} {Walddrehna}
\tl_const:cn {c_phone_DE_ortsname_035456_tl} {Terpt}
\tl_const:cn {c_phone_DE_ortsname_03546_tl} {L\"ubben~Spreewald}
\tl_const:cn {c_phone_DE_ortsname_035471_tl} {Birkenhainchen}
\tl_const:cn {c_phone_DE_ortsname_035472_tl} {Schlepzig}
\tl_const:cn {c_phone_DE_ortsname_035473_tl} {Neu~L\"ubbenau}
\tl_const:cn {c_phone_DE_ortsname_035474_tl} {Sch\"onwalde~bei~L\"ubben}
\tl_const:cn {c_phone_DE_ortsname_035475_tl} {Straupitz}
\tl_const:cn {c_phone_DE_ortsname_035476_tl} {Wittmannsdorf-B\"uckchen}
\tl_const:cn {c_phone_DE_ortsname_035477_tl} {Rietzneuendorf-Friedrichshof}
\tl_const:cn {c_phone_DE_ortsname_035478_tl} {Goyatz}
\tl_const:cn {c_phone_DE_ortsname_0355_tl} {Cottbus}
\tl_const:cn {c_phone_DE_ortsname_035600_tl} {D\"obern~Niederlausitz}
\tl_const:cn {c_phone_DE_ortsname_035601_tl} {Peitz}
\tl_const:cn {c_phone_DE_ortsname_035602_tl} {Drebkau}
\tl_const:cn {c_phone_DE_ortsname_035603_tl} {Burg~Spreewald}
\tl_const:cn {c_phone_DE_ortsname_035604_tl} {Krieschow}
\tl_const:cn {c_phone_DE_ortsname_035605_tl} {Komptendorf}
\tl_const:cn {c_phone_DE_ortsname_035606_tl} {Briesen~bei~Cottbus}
\tl_const:cn {c_phone_DE_ortsname_035607_tl} {J\"anschwalde}
\tl_const:cn {c_phone_DE_ortsname_035608_tl} {Gro\ss\ O\ss nig}
\tl_const:cn {c_phone_DE_ortsname_035609_tl} {Drachhausen}
\tl_const:cn {c_phone_DE_ortsname_03561_tl} {Guben}
\tl_const:cn {c_phone_DE_ortsname_03562_tl} {Forst~Lausitz}
\tl_const:cn {c_phone_DE_ortsname_03563_tl} {Spremberg}
\tl_const:cn {c_phone_DE_ortsname_03564_tl} {Schwarze~Pumpe}
\tl_const:cn {c_phone_DE_ortsname_035691_tl} {B\"arenklau~Niederlausitz}
\tl_const:cn {c_phone_DE_ortsname_035692_tl} {Kerkwitz}
\tl_const:cn {c_phone_DE_ortsname_035693_tl} {Lausch\"utz}
\tl_const:cn {c_phone_DE_ortsname_035694_tl} {Gosda~bei~Klinge}
\tl_const:cn {c_phone_DE_ortsname_035695_tl} {Simmersdorf}
\tl_const:cn {c_phone_DE_ortsname_035696_tl} {Briesnig}
\tl_const:cn {c_phone_DE_ortsname_035697_tl} {Bagenz}
\tl_const:cn {c_phone_DE_ortsname_035698_tl} {Hornow}
\tl_const:cn {c_phone_DE_ortsname_03571_tl} {Hoyerswerda}
\tl_const:cn {c_phone_DE_ortsname_035722_tl} {Lauta~bei~Hoyerswerda}
\tl_const:cn {c_phone_DE_ortsname_035723_tl} {Bernsdorf~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035724_tl} {Lohsa}
\tl_const:cn {c_phone_DE_ortsname_035725_tl} {Wittichenau}
\tl_const:cn {c_phone_DE_ortsname_035726_tl} {Gro\ss\ S\"archen}
\tl_const:cn {c_phone_DE_ortsname_035727_tl} {Burghammer}
\tl_const:cn {c_phone_DE_ortsname_035728_tl} {Uhyst~Spree}
\tl_const:cn {c_phone_DE_ortsname_03573_tl} {Senftenberg}
\tl_const:cn {c_phone_DE_ortsname_03574_tl} {Lauchhammer}
\tl_const:cn {c_phone_DE_ortsname_035751_tl} {Welzow}
\tl_const:cn {c_phone_DE_ortsname_035752_tl} {Ruhland}
\tl_const:cn {c_phone_DE_ortsname_035753_tl} {Gro\ss r\"aschen}
\tl_const:cn {c_phone_DE_ortsname_035754_tl} {Klettwitz}
\tl_const:cn {c_phone_DE_ortsname_035755_tl} {Ortrand}
\tl_const:cn {c_phone_DE_ortsname_035756_tl} {Hosena}
\tl_const:cn {c_phone_DE_ortsname_03576_tl} {Wei\ss wasser}
\tl_const:cn {c_phone_DE_ortsname_035771_tl} {Bad~Muskau}
\tl_const:cn {c_phone_DE_ortsname_035772_tl} {Rietschen}
\tl_const:cn {c_phone_DE_ortsname_035773_tl} {Schleife}
\tl_const:cn {c_phone_DE_ortsname_035774_tl} {Boxberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035775_tl} {Pechern}
\tl_const:cn {c_phone_DE_ortsname_03578_tl} {Kamenz}
\tl_const:cn {c_phone_DE_ortsname_035792_tl} {O\ss ling}
\tl_const:cn {c_phone_DE_ortsname_035793_tl} {Elstra}
\tl_const:cn {c_phone_DE_ortsname_035795_tl} {K\"onigsbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_035796_tl} {Panschwitz-Kuckau}
\tl_const:cn {c_phone_DE_ortsname_035797_tl} {Schwepnitz}
\tl_const:cn {c_phone_DE_ortsname_03581_tl} {G\"orlitz}
\tl_const:cn {c_phone_DE_ortsname_035820_tl} {Zodel}
\tl_const:cn {c_phone_DE_ortsname_035822_tl} {Hagenwerder}
\tl_const:cn {c_phone_DE_ortsname_035823_tl} {Ostritz}
\tl_const:cn {c_phone_DE_ortsname_035825_tl} {Kodersdorf}
\tl_const:cn {c_phone_DE_ortsname_035826_tl} {K\"onigshain~bei~G\"orlitz}
\tl_const:cn {c_phone_DE_ortsname_035827_tl} {Nieder~Seifersdorf}
\tl_const:cn {c_phone_DE_ortsname_035828_tl} {Reichenbach~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035829_tl} {Gersdorf~bei~G\"orlitz}
\tl_const:cn {c_phone_DE_ortsname_03583_tl} {Zittau}
\tl_const:cn {c_phone_DE_ortsname_035841_tl} {Gro\ss sch\"onau~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035842_tl} {Oderwitz}
\tl_const:cn {c_phone_DE_ortsname_035843_tl} {Hirschfelde~bei~Zittau}
\tl_const:cn {c_phone_DE_ortsname_035844_tl} {Oybin~Kurort}
\tl_const:cn {c_phone_DE_ortsname_03585_tl} {L\"obau}
\tl_const:cn {c_phone_DE_ortsname_03586_tl} {Neugersdorf~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035872_tl} {Neusalza-Spremberg}
\tl_const:cn {c_phone_DE_ortsname_035873_tl} {Herrnhut}
\tl_const:cn {c_phone_DE_ortsname_035874_tl} {Bernstadt~auf~dem~Eigen}
\tl_const:cn {c_phone_DE_ortsname_035875_tl} {Obercunnersdorf~bei~L\"obau}
\tl_const:cn {c_phone_DE_ortsname_035876_tl} {Wei\ss enberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035877_tl} {Cunewalde}
\tl_const:cn {c_phone_DE_ortsname_03588_tl} {Niesky}
\tl_const:cn {c_phone_DE_ortsname_035891_tl} {Rothenburg~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035892_tl} {Horka~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035893_tl} {M\"ucka}
\tl_const:cn {c_phone_DE_ortsname_035894_tl} {H\"ahnichen}
\tl_const:cn {c_phone_DE_ortsname_035895_tl} {Klitten}
\tl_const:cn {c_phone_DE_ortsname_03591_tl} {Bautzen}
\tl_const:cn {c_phone_DE_ortsname_03592_tl} {Kirschau}
\tl_const:cn {c_phone_DE_ortsname_035930_tl} {Seitschen}
\tl_const:cn {c_phone_DE_ortsname_035931_tl} {K\"onigswartha}
\tl_const:cn {c_phone_DE_ortsname_035932_tl} {Guttau}
\tl_const:cn {c_phone_DE_ortsname_035933_tl} {Neschwitz}
\tl_const:cn {c_phone_DE_ortsname_035934_tl} {Gro\ss dubrau}
\tl_const:cn {c_phone_DE_ortsname_035935_tl} {Kleinwelka}
\tl_const:cn {c_phone_DE_ortsname_035936_tl} {Sohland~Spree}
\tl_const:cn {c_phone_DE_ortsname_035937_tl} {Prischwitz}
\tl_const:cn {c_phone_DE_ortsname_035938_tl} {Gro\ss postwitz~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035939_tl} {Hochkirch}
\tl_const:cn {c_phone_DE_ortsname_03594_tl} {Bischofswerda}
\tl_const:cn {c_phone_DE_ortsname_035951_tl} {Neukirch~Lausitz}
\tl_const:cn {c_phone_DE_ortsname_035952_tl} {Gro\ss r\"ohrsdorf~Oberlausitz}
\tl_const:cn {c_phone_DE_ortsname_035953_tl} {Burkau}
\tl_const:cn {c_phone_DE_ortsname_035954_tl} {Gro\ss harthau}
\tl_const:cn {c_phone_DE_ortsname_035955_tl} {Pulsnitz}
\tl_const:cn {c_phone_DE_ortsname_03596_tl} {Neustadt~in~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_035971_tl} {Sebnitz}
\tl_const:cn {c_phone_DE_ortsname_035973_tl} {Stolpen}
\tl_const:cn {c_phone_DE_ortsname_035974_tl} {Hinterhermsdorf}
\tl_const:cn {c_phone_DE_ortsname_035975_tl} {Hohnstein}
\tl_const:cn {c_phone_DE_ortsname_03601_tl} {M\"uhlhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036020_tl} {Ebeleben}
\tl_const:cn {c_phone_DE_ortsname_036021_tl} {Schlotheim}
\tl_const:cn {c_phone_DE_ortsname_036022_tl} {Gro\ss engottern}
\tl_const:cn {c_phone_DE_ortsname_036023_tl} {Horsmar}
\tl_const:cn {c_phone_DE_ortsname_036024_tl} {Diedorf~bei~M\"uhlhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036025_tl} {K\"orner}
\tl_const:cn {c_phone_DE_ortsname_036026_tl} {Struth~bei~M\"uhlhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036027_tl} {Lengenfeld~unterm~Stein}
\tl_const:cn {c_phone_DE_ortsname_036028_tl} {Kammerforst~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036029_tl} {Menteroda}
\tl_const:cn {c_phone_DE_ortsname_03603_tl} {Bad~Langensalza}
\tl_const:cn {c_phone_DE_ortsname_036041_tl} {Bad~Tennstedt}
\tl_const:cn {c_phone_DE_ortsname_036042_tl} {Tonna}
\tl_const:cn {c_phone_DE_ortsname_036043_tl} {Kirchheilingen}
\tl_const:cn {c_phone_DE_ortsname_03605_tl} {Leinefelde}
\tl_const:cn {c_phone_DE_ortsname_03606_tl} {Heilbad~Heiligenstadt}
\tl_const:cn {c_phone_DE_ortsname_036071_tl} {Teistungen}
\tl_const:cn {c_phone_DE_ortsname_036072_tl} {Wei\ss enborn-L\"uderode}
\tl_const:cn {c_phone_DE_ortsname_036074_tl} {Worbis}
\tl_const:cn {c_phone_DE_ortsname_036075_tl} {Dingelst\"adt~Eichsfeld}
\tl_const:cn {c_phone_DE_ortsname_036076_tl} {Niederorschel}
\tl_const:cn {c_phone_DE_ortsname_036077_tl} {Gro\ss bodungen}
\tl_const:cn {c_phone_DE_ortsname_036081_tl} {Arenshausen}
\tl_const:cn {c_phone_DE_ortsname_036082_tl} {Ershausen}
\tl_const:cn {c_phone_DE_ortsname_036083_tl} {Uder}
\tl_const:cn {c_phone_DE_ortsname_036084_tl} {Heuthen}
\tl_const:cn {c_phone_DE_ortsname_036085_tl} {Reinholterode}
\tl_const:cn {c_phone_DE_ortsname_036087_tl} {W\"ustheuterode}
\tl_const:cn {c_phone_DE_ortsname_0361_tl} {Erfurt}
\tl_const:cn {c_phone_DE_ortsname_036200_tl} {Elxleben~bei~Arnstadt}
\tl_const:cn {c_phone_DE_ortsname_036201_tl} {Walschleben}
\tl_const:cn {c_phone_DE_ortsname_036202_tl} {Neudietendorf}
\tl_const:cn {c_phone_DE_ortsname_036203_tl} {Vieselbach}
\tl_const:cn {c_phone_DE_ortsname_036204_tl} {Stotternheim}
\tl_const:cn {c_phone_DE_ortsname_036205_tl} {Gr\"afenroda}
\tl_const:cn {c_phone_DE_ortsname_036206_tl} {Gro\ss fahner}
\tl_const:cn {c_phone_DE_ortsname_036207_tl} {Plaue~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036208_tl} {Ermstedt}
\tl_const:cn {c_phone_DE_ortsname_036209_tl} {Klettbach}
\tl_const:cn {c_phone_DE_ortsname_03621_tl} {Gotha~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_03622_tl} {Waltershausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_03623_tl} {Friedrichroda}
\tl_const:cn {c_phone_DE_ortsname_03624_tl} {Ohrdruf}
\tl_const:cn {c_phone_DE_ortsname_036252_tl} {Tambach-Dietharz~Th\"uringer~Wald}
\tl_const:cn {c_phone_DE_ortsname_036253_tl} {Georgenthal~Th\"uringer~Wald}
\tl_const:cn {c_phone_DE_ortsname_036254_tl} {Friedrichswerth}
\tl_const:cn {c_phone_DE_ortsname_036255_tl} {Goldbach~bei~Gotha}
\tl_const:cn {c_phone_DE_ortsname_036256_tl} {Wechmar}
\tl_const:cn {c_phone_DE_ortsname_036257_tl} {Luisenthal~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036258_tl} {Friemar}
\tl_const:cn {c_phone_DE_ortsname_036259_tl} {Tabarz~Th\"uringer~Wald}
\tl_const:cn {c_phone_DE_ortsname_03628_tl} {Arnstadt}
\tl_const:cn {c_phone_DE_ortsname_03629_tl} {Stadtilm}
\tl_const:cn {c_phone_DE_ortsname_03631_tl} {Nordhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_03632_tl} {Sondershausen}
\tl_const:cn {c_phone_DE_ortsname_036330_tl} {Gro\ss berndten}
\tl_const:cn {c_phone_DE_ortsname_036331_tl} {Ilfeld}
\tl_const:cn {c_phone_DE_ortsname_036332_tl} {Ellrich}
\tl_const:cn {c_phone_DE_ortsname_036333_tl} {Heringen~Helme}
\tl_const:cn {c_phone_DE_ortsname_036334_tl} {Wolkramshausen}
\tl_const:cn {c_phone_DE_ortsname_036335_tl} {Gro\ss wechsungen}
\tl_const:cn {c_phone_DE_ortsname_036336_tl} {Klettenberg}
\tl_const:cn {c_phone_DE_ortsname_036337_tl} {Schiedungen}
\tl_const:cn {c_phone_DE_ortsname_036338_tl} {Bleicherode}
\tl_const:cn {c_phone_DE_ortsname_03634_tl} {S\"ommerda}
\tl_const:cn {c_phone_DE_ortsname_03635_tl} {K\"olleda}
\tl_const:cn {c_phone_DE_ortsname_03636_tl} {Greu\ss en}
\tl_const:cn {c_phone_DE_ortsname_036370_tl} {Gro\ss enehrich}
\tl_const:cn {c_phone_DE_ortsname_036371_tl} {Schlo\ss vippach}
\tl_const:cn {c_phone_DE_ortsname_036372_tl} {Kleinneuhausen}
\tl_const:cn {c_phone_DE_ortsname_036373_tl} {Buttst\"adt}
\tl_const:cn {c_phone_DE_ortsname_036374_tl} {Wei\ss ensee}
\tl_const:cn {c_phone_DE_ortsname_036375_tl} {Kindelbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_036376_tl} {Strau\ss furt}
\tl_const:cn {c_phone_DE_ortsname_036377_tl} {Rastenberg}
\tl_const:cn {c_phone_DE_ortsname_036378_tl} {Ostramondra}
\tl_const:cn {c_phone_DE_ortsname_036379_tl} {Holzengel}
\tl_const:cn {c_phone_DE_ortsname_03641_tl} {Jena}
\tl_const:cn {c_phone_DE_ortsname_036421_tl} {Camburg}
\tl_const:cn {c_phone_DE_ortsname_036422_tl} {Reinst\"adt~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036423_tl} {Orlam\"unde}
\tl_const:cn {c_phone_DE_ortsname_036424_tl} {Kahla~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036425_tl} {Isserstedt}
\tl_const:cn {c_phone_DE_ortsname_036426_tl} {Ottendorf~bei~Stadtroda}
\tl_const:cn {c_phone_DE_ortsname_036427_tl} {Dornburg~Saale}
\tl_const:cn {c_phone_DE_ortsname_036428_tl} {Stadtroda}
\tl_const:cn {c_phone_DE_ortsname_03643_tl} {Weimar~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_03644_tl} {Apolda}
\tl_const:cn {c_phone_DE_ortsname_036450_tl} {Kranichfeld}
\tl_const:cn {c_phone_DE_ortsname_036451_tl} {Buttelstedt}
\tl_const:cn {c_phone_DE_ortsname_036452_tl} {Berlstedt}
\tl_const:cn {c_phone_DE_ortsname_036453_tl} {Mellingen}
\tl_const:cn {c_phone_DE_ortsname_036454_tl} {Magdala}
\tl_const:cn {c_phone_DE_ortsname_036458_tl} {Bad~Berka}
\tl_const:cn {c_phone_DE_ortsname_036459_tl} {Blankenhain~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036461_tl} {Bad~Sulza}
\tl_const:cn {c_phone_DE_ortsname_036462_tl} {O\ss mannstedt}
\tl_const:cn {c_phone_DE_ortsname_036463_tl} {Gebstedt}
\tl_const:cn {c_phone_DE_ortsname_036464_tl} {Wormstedt}
\tl_const:cn {c_phone_DE_ortsname_036465_tl} {Oberndorf~bei~Apolda}
\tl_const:cn {c_phone_DE_ortsname_03647_tl} {P\"o\ss neck}
\tl_const:cn {c_phone_DE_ortsname_036481_tl} {Neustadt~an~der~Orla}
\tl_const:cn {c_phone_DE_ortsname_036482_tl} {Triptis}
\tl_const:cn {c_phone_DE_ortsname_036483_tl} {Ziegenr\"uck}
\tl_const:cn {c_phone_DE_ortsname_036484_tl} {Knau~bei~P\"o\ss neck}
\tl_const:cn {c_phone_DE_ortsname_0365_tl} {Gera}
\tl_const:cn {c_phone_DE_ortsname_036601_tl} {Hermsdorf~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036602_tl} {Ronneburg~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036603_tl} {Weida}
\tl_const:cn {c_phone_DE_ortsname_036604_tl} {M\"unchenbernsdorf}
\tl_const:cn {c_phone_DE_ortsname_036605_tl} {Bad~K\"ostritz}
\tl_const:cn {c_phone_DE_ortsname_036606_tl} {Kraftsdorf}
\tl_const:cn {c_phone_DE_ortsname_036607_tl} {Niederp\"ollnitz}
\tl_const:cn {c_phone_DE_ortsname_036608_tl} {Seelingst\"adt~bei~Gera}
\tl_const:cn {c_phone_DE_ortsname_03661_tl} {Greiz}
\tl_const:cn {c_phone_DE_ortsname_036621_tl} {Elsterberg~bei~Plauen}
\tl_const:cn {c_phone_DE_ortsname_036622_tl} {Triebes}
\tl_const:cn {c_phone_DE_ortsname_036623_tl} {Berga~Elster}
\tl_const:cn {c_phone_DE_ortsname_036624_tl} {Teichwolframsdorf}
\tl_const:cn {c_phone_DE_ortsname_036625_tl} {Langenwetzendorf}
\tl_const:cn {c_phone_DE_ortsname_036626_tl} {Auma}
\tl_const:cn {c_phone_DE_ortsname_036628_tl} {Zeulenroda}
\tl_const:cn {c_phone_DE_ortsname_03663_tl} {Schleiz}
\tl_const:cn {c_phone_DE_ortsname_036640_tl} {Remptendorf}
\tl_const:cn {c_phone_DE_ortsname_036642_tl} {Harra}
\tl_const:cn {c_phone_DE_ortsname_036643_tl} {Thimmendorf}
\tl_const:cn {c_phone_DE_ortsname_036644_tl} {Hirschberg~Saale}
\tl_const:cn {c_phone_DE_ortsname_036645_tl} {M\"uhltroff}
\tl_const:cn {c_phone_DE_ortsname_036646_tl} {Tanna~bei~Schleiz}
\tl_const:cn {c_phone_DE_ortsname_036647_tl} {Saalburg~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036648_tl} {Dittersdorf~bei~Schleiz}
\tl_const:cn {c_phone_DE_ortsname_036649_tl} {Gefell~bei~Schleiz}
\tl_const:cn {c_phone_DE_ortsname_036651_tl} {Lobenstein}
\tl_const:cn {c_phone_DE_ortsname_036652_tl} {Wurzbach}
\tl_const:cn {c_phone_DE_ortsname_036653_tl} {Lehesten~Th\"uringer~Wald}
\tl_const:cn {c_phone_DE_ortsname_036691_tl} {Eisenberg~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036692_tl} {B\"urgel}
\tl_const:cn {c_phone_DE_ortsname_036693_tl} {Crossen~an~der~Elster}
\tl_const:cn {c_phone_DE_ortsname_036694_tl} {Schk\"olen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036695_tl} {S\"ollmnitz}
\tl_const:cn {c_phone_DE_ortsname_036701_tl} {Lichte}
\tl_const:cn {c_phone_DE_ortsname_036702_tl} {Lauscha}
\tl_const:cn {c_phone_DE_ortsname_036703_tl} {Gr\"afenthal}
\tl_const:cn {c_phone_DE_ortsname_036704_tl} {Steinheid}
\tl_const:cn {c_phone_DE_ortsname_036705_tl} {Oberwei\ss bach~Th\"uringer~Wald}
\tl_const:cn {c_phone_DE_ortsname_03671_tl} {Saalfeld~Saale}
\tl_const:cn {c_phone_DE_ortsname_03672_tl} {Rudolstadt}
\tl_const:cn {c_phone_DE_ortsname_036730_tl} {Sitzendorf}
\tl_const:cn {c_phone_DE_ortsname_036731_tl} {Unterloquitz}
\tl_const:cn {c_phone_DE_ortsname_036732_tl} {K\"onitz}
\tl_const:cn {c_phone_DE_ortsname_036733_tl} {Kaulsdorf}
\tl_const:cn {c_phone_DE_ortsname_036734_tl} {Leutenberg}
\tl_const:cn {c_phone_DE_ortsname_036735_tl} {Probstzella}
\tl_const:cn {c_phone_DE_ortsname_036736_tl} {Arnsgereuth}
\tl_const:cn {c_phone_DE_ortsname_036737_tl} {Drognitz}
\tl_const:cn {c_phone_DE_ortsname_036738_tl} {K\"onigsee}
\tl_const:cn {c_phone_DE_ortsname_036739_tl} {Rottenbach}
\tl_const:cn {c_phone_DE_ortsname_036741_tl} {Bad~Blankenburg}
\tl_const:cn {c_phone_DE_ortsname_036742_tl} {Uhlst\"adt}
\tl_const:cn {c_phone_DE_ortsname_036743_tl} {Teichel}
\tl_const:cn {c_phone_DE_ortsname_036744_tl} {Remda}
\tl_const:cn {c_phone_DE_ortsname_03675_tl} {Sonneberg~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036761_tl} {Heubisch}
\tl_const:cn {c_phone_DE_ortsname_036762_tl} {Steinach~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036764_tl} {Neuhaus-Schierschnitz}
\tl_const:cn {c_phone_DE_ortsname_036766_tl} {Schalkau}
\tl_const:cn {c_phone_DE_ortsname_03677_tl} {Ilmenau~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036781_tl} {Gro\ss breitenbach}
\tl_const:cn {c_phone_DE_ortsname_036782_tl} {Schmiedefeld~am~Rennsteig}
\tl_const:cn {c_phone_DE_ortsname_036783_tl} {Gehren~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036784_tl} {St\"utzerbach}
\tl_const:cn {c_phone_DE_ortsname_036785_tl} {Gr\"afinau-Angstedt}
\tl_const:cn {c_phone_DE_ortsname_03679_tl} {Neuhaus~am~Rennweg}
\tl_const:cn {c_phone_DE_ortsname_03681_tl} {Suhl}
\tl_const:cn {c_phone_DE_ortsname_03682_tl} {Zella-Mehlis}
\tl_const:cn {c_phone_DE_ortsname_03683_tl} {Schmalkalden}
\tl_const:cn {c_phone_DE_ortsname_036840_tl} {Trusetal}
\tl_const:cn {c_phone_DE_ortsname_036841_tl} {Schleusingen}
\tl_const:cn {c_phone_DE_ortsname_036842_tl} {Oberhof~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036843_tl} {Benshausen}
\tl_const:cn {c_phone_DE_ortsname_036844_tl} {Rohr~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036845_tl} {Gehlberg}
\tl_const:cn {c_phone_DE_ortsname_036846_tl} {Suhl-Dietzhausen}
\tl_const:cn {c_phone_DE_ortsname_036847_tl} {Steinbach-Hallenberg}
\tl_const:cn {c_phone_DE_ortsname_036848_tl} {Wernshausen}
\tl_const:cn {c_phone_DE_ortsname_036849_tl} {Kleinschmalkalden}
\tl_const:cn {c_phone_DE_ortsname_03685_tl} {Hildburghausen}
\tl_const:cn {c_phone_DE_ortsname_03686_tl} {Eisfeld}
\tl_const:cn {c_phone_DE_ortsname_036870_tl} {Masserberg}
\tl_const:cn {c_phone_DE_ortsname_036871_tl} {Bad~Colberg-Heldburg}
\tl_const:cn {c_phone_DE_ortsname_036873_tl} {Themar}
\tl_const:cn {c_phone_DE_ortsname_036874_tl} {Sch\"onbrunn~bei~Hildburghausen}
\tl_const:cn {c_phone_DE_ortsname_036875_tl} {Straufhain-Streufdorf}
\tl_const:cn {c_phone_DE_ortsname_036878_tl} {Oberland}
\tl_const:cn {c_phone_DE_ortsname_03691_tl} {Eisenach~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036920_tl} {Gro\ss enlupnitz}
\tl_const:cn {c_phone_DE_ortsname_036921_tl} {Wutha-Farnroda}
\tl_const:cn {c_phone_DE_ortsname_036922_tl} {Gerstungen}
\tl_const:cn {c_phone_DE_ortsname_036923_tl} {Treffurt}
\tl_const:cn {c_phone_DE_ortsname_036924_tl} {Mihla}
\tl_const:cn {c_phone_DE_ortsname_036925_tl} {Marksuhl}
\tl_const:cn {c_phone_DE_ortsname_036926_tl} {Creuzburg}
\tl_const:cn {c_phone_DE_ortsname_036927_tl} {Unterellen}
\tl_const:cn {c_phone_DE_ortsname_036928_tl} {Neuenhof~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036929_tl} {Ruhla}
\tl_const:cn {c_phone_DE_ortsname_03693_tl} {Meiningen}
\tl_const:cn {c_phone_DE_ortsname_036940_tl} {Oepfershausen}
\tl_const:cn {c_phone_DE_ortsname_036941_tl} {Wasungen}
\tl_const:cn {c_phone_DE_ortsname_036943_tl} {Bettenhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036944_tl} {Rentwertshausen}
\tl_const:cn {c_phone_DE_ortsname_036945_tl} {Henneberg}
\tl_const:cn {c_phone_DE_ortsname_036946_tl} {Erbenhausen~Th\"uringen}
\tl_const:cn {c_phone_DE_ortsname_036947_tl} {J\"uchsen}
\tl_const:cn {c_phone_DE_ortsname_036948_tl} {R\"omhild}
\tl_const:cn {c_phone_DE_ortsname_036949_tl} {Oberma\ss feld-Grimmenthal}
\tl_const:cn {c_phone_DE_ortsname_03695_tl} {Bad~Salzungen}
\tl_const:cn {c_phone_DE_ortsname_036961_tl} {Bad~Liebenstein}
\tl_const:cn {c_phone_DE_ortsname_036962_tl} {Vacha}
\tl_const:cn {c_phone_DE_ortsname_036963_tl} {Dorndorf~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_036964_tl} {Dermbach~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_036965_tl} {Stadtlengsfeld}
\tl_const:cn {c_phone_DE_ortsname_036966_tl} {Kaltennordheim}
\tl_const:cn {c_phone_DE_ortsname_036967_tl} {Geisa}
\tl_const:cn {c_phone_DE_ortsname_036968_tl} {Ro\ss dorf~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_036969_tl} {Merkers}
\tl_const:cn {c_phone_DE_ortsname_0371_tl} {Chemnitz~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037200_tl} {Wittgensdorf~bei~Chemnitz}
\tl_const:cn {c_phone_DE_ortsname_037202_tl} {Clau\ss nitz~bei~Chemnitz}
\tl_const:cn {c_phone_DE_ortsname_037203_tl} {Gersdorf~bei~Chemnitz}
\tl_const:cn {c_phone_DE_ortsname_037204_tl} {Lichtenstein~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037206_tl} {Frankenberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037207_tl} {Hainichen~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037208_tl} {Auerswalde}
\tl_const:cn {c_phone_DE_ortsname_037209_tl} {Einsiedel~bei~Chemnitz}
\tl_const:cn {c_phone_DE_ortsname_03721_tl} {Meinersdorf}
\tl_const:cn {c_phone_DE_ortsname_03722_tl} {Limbach-Oberfrohna}
\tl_const:cn {c_phone_DE_ortsname_03723_tl} {Hohenstein-Ernstthal}
\tl_const:cn {c_phone_DE_ortsname_03724_tl} {Burgst\"adt}
\tl_const:cn {c_phone_DE_ortsname_03725_tl} {Zschopau}
\tl_const:cn {c_phone_DE_ortsname_03726_tl} {Fl\"oha}
\tl_const:cn {c_phone_DE_ortsname_03727_tl} {Mittweida}
\tl_const:cn {c_phone_DE_ortsname_037291_tl} {Augustusburg}
\tl_const:cn {c_phone_DE_ortsname_037292_tl} {Oederan}
\tl_const:cn {c_phone_DE_ortsname_037293_tl} {Eppendorf~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037294_tl} {Gr\"unhainichen}
\tl_const:cn {c_phone_DE_ortsname_037295_tl} {Lugau~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037296_tl} {Stollberg~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037297_tl} {Thum~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037298_tl} {Oelsnitz~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_03731_tl} {Freiberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037320_tl} {Mulda~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037321_tl} {Frankenstein~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037322_tl} {Brand-Erbisdorf}
\tl_const:cn {c_phone_DE_ortsname_037323_tl} {Lichtenberg~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037324_tl} {Reinsberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037325_tl} {Niederbobritzsch}
\tl_const:cn {c_phone_DE_ortsname_037326_tl} {Frauenstein~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037327_tl} {Rechenberg-Bienenm\"uhle}
\tl_const:cn {c_phone_DE_ortsname_037328_tl} {Gro\ss schirma}
\tl_const:cn {c_phone_DE_ortsname_037329_tl} {Gro\ss hartmannsdorf}
\tl_const:cn {c_phone_DE_ortsname_03733_tl} {Annaberg-Buchholz}
\tl_const:cn {c_phone_DE_ortsname_037341_tl} {Ehrenfriedersdorf}
\tl_const:cn {c_phone_DE_ortsname_037342_tl} {Cranzahl}
\tl_const:cn {c_phone_DE_ortsname_037343_tl} {J\"ohstadt}
\tl_const:cn {c_phone_DE_ortsname_037344_tl} {Crottendorf~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037346_tl} {Geyer}
\tl_const:cn {c_phone_DE_ortsname_037347_tl} {B\"arenstein~Kreis~Annaberg}
\tl_const:cn {c_phone_DE_ortsname_037348_tl} {Oberwiesenthal~Kurort}
\tl_const:cn {c_phone_DE_ortsname_037349_tl} {Scheibenberg}
\tl_const:cn {c_phone_DE_ortsname_03735_tl} {Marienberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037360_tl} {Olbernhau}
\tl_const:cn {c_phone_DE_ortsname_037361_tl} {Neuhausen~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037362_tl} {Seiffen~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037363_tl} {Z\"oblitz}
\tl_const:cn {c_phone_DE_ortsname_037364_tl} {Reitzenhain~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037365_tl} {Sayda}
\tl_const:cn {c_phone_DE_ortsname_037366_tl} {R\"ubenau}
\tl_const:cn {c_phone_DE_ortsname_037367_tl} {Lengefeld~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037368_tl} {Deutschneudorf}
\tl_const:cn {c_phone_DE_ortsname_037369_tl} {Wolkenstein}
\tl_const:cn {c_phone_DE_ortsname_03737_tl} {Rochlitz}
\tl_const:cn {c_phone_DE_ortsname_037381_tl} {Penig}
\tl_const:cn {c_phone_DE_ortsname_037382_tl} {Geringswalde}
\tl_const:cn {c_phone_DE_ortsname_037383_tl} {Lunzenau}
\tl_const:cn {c_phone_DE_ortsname_037384_tl} {Wechselburg}
\tl_const:cn {c_phone_DE_ortsname_03741_tl} {Plauen}
\tl_const:cn {c_phone_DE_ortsname_037421_tl} {Oelsnitz~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037422_tl} {Markneukirchen}
\tl_const:cn {c_phone_DE_ortsname_037423_tl} {Adorf~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037430_tl} {Eichigt}
\tl_const:cn {c_phone_DE_ortsname_037431_tl} {Mehltheuer~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037432_tl} {Pausa~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037433_tl} {Gutenf\"urst}
\tl_const:cn {c_phone_DE_ortsname_037434_tl} {Bobenneukirchen}
\tl_const:cn {c_phone_DE_ortsname_037435_tl} {Reuth~bei~Plauen}
\tl_const:cn {c_phone_DE_ortsname_037436_tl} {Weischlitz}
\tl_const:cn {c_phone_DE_ortsname_037437_tl} {Bad~Elster}
\tl_const:cn {c_phone_DE_ortsname_037438_tl} {Bad~Brambach}
\tl_const:cn {c_phone_DE_ortsname_037439_tl} {Jocketa}
\tl_const:cn {c_phone_DE_ortsname_03744_tl} {Auerbach~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_03745_tl} {Falkenstein~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037462_tl} {Rothenkirchen~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037463_tl} {Bergen~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037464_tl} {Sch\"oneck~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037465_tl} {Tannenbergsthal~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037467_tl} {Klingenthal~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037468_tl} {Treuen~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_0375_tl} {Zwickau}
\tl_const:cn {c_phone_DE_ortsname_037600_tl} {Neumark~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037601_tl} {M\"ulsen~St.\ Jacob}
\tl_const:cn {c_phone_DE_ortsname_037602_tl} {Kirchberg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037603_tl} {Wildenfels}
\tl_const:cn {c_phone_DE_ortsname_037604_tl} {Mosel}
\tl_const:cn {c_phone_DE_ortsname_037605_tl} {Hartenstein~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037606_tl} {Lengenfeld~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_037607_tl} {Ebersbrunn~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037608_tl} {Waldenburg~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_037609_tl} {Wolkenburg~Mulde}
\tl_const:cn {c_phone_DE_ortsname_03761_tl} {Werdau~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_03762_tl} {Crimmitschau}
\tl_const:cn {c_phone_DE_ortsname_03763_tl} {Glauchau}
\tl_const:cn {c_phone_DE_ortsname_03764_tl} {Meerane}
\tl_const:cn {c_phone_DE_ortsname_03765_tl} {Reichenbach~Vogtland}
\tl_const:cn {c_phone_DE_ortsname_03771_tl} {Aue~Sachsen}
\tl_const:cn {c_phone_DE_ortsname_03772_tl} {Schneeberg~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_03773_tl} {Johanngeorgenstadt}
\tl_const:cn {c_phone_DE_ortsname_03774_tl} {Schwarzenberg}
\tl_const:cn {c_phone_DE_ortsname_037752_tl} {Eibenstock}
\tl_const:cn {c_phone_DE_ortsname_037754_tl} {Zw\"onitz}
\tl_const:cn {c_phone_DE_ortsname_037755_tl} {Sch\"onheide~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037756_tl} {Breitenbrunn~Erzgebirge}
\tl_const:cn {c_phone_DE_ortsname_037757_tl} {Rittersgr\"un}
\tl_const:cn {c_phone_DE_ortsname_0381_tl} {Rostock}
\tl_const:cn {c_phone_DE_ortsname_038201_tl} {Gelbensande}
\tl_const:cn {c_phone_DE_ortsname_038202_tl} {Volkenshagen}
\tl_const:cn {c_phone_DE_ortsname_038203_tl} {Bad~Doberan}
\tl_const:cn {c_phone_DE_ortsname_038204_tl} {Broderstorf}
\tl_const:cn {c_phone_DE_ortsname_038205_tl} {Tessin~bei~Rostock}
\tl_const:cn {c_phone_DE_ortsname_038206_tl} {Seeheilbad~Graal-M\"uritz}
\tl_const:cn {c_phone_DE_ortsname_038207_tl} {St\"abelow}
\tl_const:cn {c_phone_DE_ortsname_038208_tl} {Kavelstorf}
\tl_const:cn {c_phone_DE_ortsname_038209_tl} {Sanitz~bei~Rostock}
\tl_const:cn {c_phone_DE_ortsname_03821_tl} {Ribnitz-Damgarten}
\tl_const:cn {c_phone_DE_ortsname_038220_tl} {Ostseebad~Wustrow}
\tl_const:cn {c_phone_DE_ortsname_038221_tl} {Marlow}
\tl_const:cn {c_phone_DE_ortsname_038222_tl} {Semlow}
\tl_const:cn {c_phone_DE_ortsname_038223_tl} {Saal~Vorpommern}
\tl_const:cn {c_phone_DE_ortsname_038224_tl} {Gresenhorst}
\tl_const:cn {c_phone_DE_ortsname_038225_tl} {Trinwillershagen}
\tl_const:cn {c_phone_DE_ortsname_038226_tl} {Ostseebad~Dierhagen}
\tl_const:cn {c_phone_DE_ortsname_038227_tl} {L\"udershagen~bei~Barth}
\tl_const:cn {c_phone_DE_ortsname_038228_tl} {Dettmannsdorf-K\"olzow}
\tl_const:cn {c_phone_DE_ortsname_038229_tl} {Bad~S\"ulze}
\tl_const:cn {c_phone_DE_ortsname_038231_tl} {Barth}
\tl_const:cn {c_phone_DE_ortsname_038232_tl} {Ostseebad~Zingst}
\tl_const:cn {c_phone_DE_ortsname_038233_tl} {Ostseebad~Prerow}
\tl_const:cn {c_phone_DE_ortsname_038234_tl} {Born~auf~dem~Dar\ss}
\tl_const:cn {c_phone_DE_ortsname_038292_tl} {Kr\"opelin}
\tl_const:cn {c_phone_DE_ortsname_038293_tl} {Ostseebad~K\"uhlungsborn}
\tl_const:cn {c_phone_DE_ortsname_038294_tl} {Neubukow}
\tl_const:cn {c_phone_DE_ortsname_038295_tl} {Satow~bei~Bad~Doberan}
\tl_const:cn {c_phone_DE_ortsname_038296_tl} {Ostseebad~Rerik}
\tl_const:cn {c_phone_DE_ortsname_038297_tl} {Moitin}
\tl_const:cn {c_phone_DE_ortsname_038300_tl} {Insel~Hiddensee}
\tl_const:cn {c_phone_DE_ortsname_038301_tl} {Putbus}
\tl_const:cn {c_phone_DE_ortsname_038302_tl} {Sagard}
\tl_const:cn {c_phone_DE_ortsname_038303_tl} {Ostseebad~Sellin}
\tl_const:cn {c_phone_DE_ortsname_038304_tl} {Garz~R\"ugen}
\tl_const:cn {c_phone_DE_ortsname_038305_tl} {Gingst}
\tl_const:cn {c_phone_DE_ortsname_038306_tl} {Samtens}
\tl_const:cn {c_phone_DE_ortsname_038307_tl} {Poseritz}
\tl_const:cn {c_phone_DE_ortsname_038308_tl} {G\"ohren~R\"ugen}
\tl_const:cn {c_phone_DE_ortsname_038309_tl} {Trent}
\tl_const:cn {c_phone_DE_ortsname_03831_tl} {Stralsund}
\tl_const:cn {c_phone_DE_ortsname_038320_tl} {Tribsees}
\tl_const:cn {c_phone_DE_ortsname_038321_tl} {Martensdorf~bei~Stralsund}
\tl_const:cn {c_phone_DE_ortsname_038322_tl} {Richtenberg}
\tl_const:cn {c_phone_DE_ortsname_038323_tl} {Prohn}
\tl_const:cn {c_phone_DE_ortsname_038324_tl} {Velgast}
\tl_const:cn {c_phone_DE_ortsname_038325_tl} {Rolofshagen}
\tl_const:cn {c_phone_DE_ortsname_038326_tl} {Grimmen}
\tl_const:cn {c_phone_DE_ortsname_038327_tl} {Elmenhorst~Vorpommern}
\tl_const:cn {c_phone_DE_ortsname_038328_tl} {Miltzow}
\tl_const:cn {c_phone_DE_ortsname_038331_tl} {Rakow~Vorpommern}
\tl_const:cn {c_phone_DE_ortsname_038332_tl} {Gro\ss\ Bisdorf}
\tl_const:cn {c_phone_DE_ortsname_038333_tl} {Horst~bei~Grimmen}
\tl_const:cn {c_phone_DE_ortsname_038334_tl} {Grammendorf}
\tl_const:cn {c_phone_DE_ortsname_03834_tl} {Greifswald}
\tl_const:cn {c_phone_DE_ortsname_038351_tl} {Mesekenhagen}
\tl_const:cn {c_phone_DE_ortsname_038352_tl} {Kemnitz~bei~Greifswald}
\tl_const:cn {c_phone_DE_ortsname_038353_tl} {G\"utzkow~bei~Greifswald}
\tl_const:cn {c_phone_DE_ortsname_038354_tl} {Wusterhusen}
\tl_const:cn {c_phone_DE_ortsname_038355_tl} {Z\"ussow}
\tl_const:cn {c_phone_DE_ortsname_038356_tl} {Behrenhoff}
\tl_const:cn {c_phone_DE_ortsname_03836_tl} {Wolgast}
\tl_const:cn {c_phone_DE_ortsname_038370_tl} {Kr\"oslin}
\tl_const:cn {c_phone_DE_ortsname_038371_tl} {Karlshagen}
\tl_const:cn {c_phone_DE_ortsname_038372_tl} {Usedom}
\tl_const:cn {c_phone_DE_ortsname_038373_tl} {Katzow}
\tl_const:cn {c_phone_DE_ortsname_038374_tl} {Lassan~bei~Wolgast}
\tl_const:cn {c_phone_DE_ortsname_038375_tl} {Koserow}
\tl_const:cn {c_phone_DE_ortsname_038376_tl} {Zirchow}
\tl_const:cn {c_phone_DE_ortsname_038377_tl} {Zinnowitz}
\tl_const:cn {c_phone_DE_ortsname_038378_tl} {Seebad~Heringsdorf}
\tl_const:cn {c_phone_DE_ortsname_038379_tl} {Benz~Usedom}
\tl_const:cn {c_phone_DE_ortsname_03838_tl} {Bergen~auf~R\"ugen}
\tl_const:cn {c_phone_DE_ortsname_038391_tl} {Altenkirchen~R\"ugen}
\tl_const:cn {c_phone_DE_ortsname_038392_tl} {Sassnitz}
\tl_const:cn {c_phone_DE_ortsname_038393_tl} {Ostseebad~Binz}
\tl_const:cn {c_phone_DE_ortsname_03841_tl} {Wismar~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038422_tl} {Neukloster}
\tl_const:cn {c_phone_DE_ortsname_038423_tl} {Bad~Kleinen}
\tl_const:cn {c_phone_DE_ortsname_038424_tl} {Bobitz}
\tl_const:cn {c_phone_DE_ortsname_038425_tl} {Kirchdorf~Poel}
\tl_const:cn {c_phone_DE_ortsname_038426_tl} {Neuburg-Steinhausen}
\tl_const:cn {c_phone_DE_ortsname_038427_tl} {Blowatz}
\tl_const:cn {c_phone_DE_ortsname_038428_tl} {Hohenkirchen~bei~Wismar}
\tl_const:cn {c_phone_DE_ortsname_038429_tl} {Glasin}
\tl_const:cn {c_phone_DE_ortsname_03843_tl} {G\"ustrow}
\tl_const:cn {c_phone_DE_ortsname_03844_tl} {Schwaan}
\tl_const:cn {c_phone_DE_ortsname_038450_tl} {Tarnow~bei~B\"utzow}
\tl_const:cn {c_phone_DE_ortsname_038451_tl} {Hoppenrade~bei~G\"ustrow}
\tl_const:cn {c_phone_DE_ortsname_038452_tl} {Lalendorf}
\tl_const:cn {c_phone_DE_ortsname_038453_tl} {Mistorf}
\tl_const:cn {c_phone_DE_ortsname_038454_tl} {Kritzkow}
\tl_const:cn {c_phone_DE_ortsname_038455_tl} {Plaaz}
\tl_const:cn {c_phone_DE_ortsname_038456_tl} {Langhagen~bei~G\"ustrow}
\tl_const:cn {c_phone_DE_ortsname_038457_tl} {Krakow~am~See}
\tl_const:cn {c_phone_DE_ortsname_038458_tl} {Zehna}
\tl_const:cn {c_phone_DE_ortsname_038459_tl} {Laage}
\tl_const:cn {c_phone_DE_ortsname_038461_tl} {B\"utzow}
\tl_const:cn {c_phone_DE_ortsname_038462_tl} {Baumgarten~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038464_tl} {Bernitt}
\tl_const:cn {c_phone_DE_ortsname_038466_tl} {J\"urgenshagen}
\tl_const:cn {c_phone_DE_ortsname_03847_tl} {Sternberg}
\tl_const:cn {c_phone_DE_ortsname_038481_tl} {Witzin}
\tl_const:cn {c_phone_DE_ortsname_038482_tl} {Warin}
\tl_const:cn {c_phone_DE_ortsname_038483_tl} {Br\"uel}
\tl_const:cn {c_phone_DE_ortsname_038484_tl} {Ventschow}
\tl_const:cn {c_phone_DE_ortsname_038485_tl} {Dabel}
\tl_const:cn {c_phone_DE_ortsname_038486_tl} {Gust\"avel}
\tl_const:cn {c_phone_DE_ortsname_038488_tl} {Demen}
\tl_const:cn {c_phone_DE_ortsname_0385_tl} {Schwerin~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_03860_tl} {Raben~Steinfeld}
\tl_const:cn {c_phone_DE_ortsname_03861_tl} {Plate}
\tl_const:cn {c_phone_DE_ortsname_03863_tl} {Crivitz}
\tl_const:cn {c_phone_DE_ortsname_03865_tl} {Holthusen}
\tl_const:cn {c_phone_DE_ortsname_03866_tl} {Cambs}
\tl_const:cn {c_phone_DE_ortsname_03867_tl} {L\"ubstorf}
\tl_const:cn {c_phone_DE_ortsname_03868_tl} {Rastow}
\tl_const:cn {c_phone_DE_ortsname_03869_tl} {D\"ummer}
\tl_const:cn {c_phone_DE_ortsname_03871_tl} {Parchim}
\tl_const:cn {c_phone_DE_ortsname_038720_tl} {Grebbin}
\tl_const:cn {c_phone_DE_ortsname_038721_tl} {Ziegendorf}
\tl_const:cn {c_phone_DE_ortsname_038722_tl} {Raduhn}
\tl_const:cn {c_phone_DE_ortsname_038723_tl} {Kladrum}
\tl_const:cn {c_phone_DE_ortsname_038724_tl} {Siggelkow}
\tl_const:cn {c_phone_DE_ortsname_038725_tl} {Gro\ss\ Godems}
\tl_const:cn {c_phone_DE_ortsname_038726_tl} {Spornitz}
\tl_const:cn {c_phone_DE_ortsname_038727_tl} {Mestlin}
\tl_const:cn {c_phone_DE_ortsname_038728_tl} {Doms\"uhl}
\tl_const:cn {c_phone_DE_ortsname_038729_tl} {Marnitz}
\tl_const:cn {c_phone_DE_ortsname_038731_tl} {L\"ubz}
\tl_const:cn {c_phone_DE_ortsname_038732_tl} {Gallin~bei~L\"ubz}
\tl_const:cn {c_phone_DE_ortsname_038733_tl} {Karbow-Vietl\"ubbe}
\tl_const:cn {c_phone_DE_ortsname_038735_tl} {Plau~am~See}
\tl_const:cn {c_phone_DE_ortsname_038736_tl} {Goldberg~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038737_tl} {Ganzlin}
\tl_const:cn {c_phone_DE_ortsname_038738_tl} {Karow~bei~L\"ubz}
\tl_const:cn {c_phone_DE_ortsname_03874_tl} {Ludwigslust~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038750_tl} {Malli\ss}
\tl_const:cn {c_phone_DE_ortsname_038751_tl} {Picher}
\tl_const:cn {c_phone_DE_ortsname_038752_tl} {Zierzow~bei~Ludwigslust}
\tl_const:cn {c_phone_DE_ortsname_038753_tl} {W\"obbelin}
\tl_const:cn {c_phone_DE_ortsname_038754_tl} {Leussow~bei~Ludwigslust}
\tl_const:cn {c_phone_DE_ortsname_038755_tl} {Eldena}
\tl_const:cn {c_phone_DE_ortsname_038756_tl} {Grabow~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038757_tl} {Neustadt-Glewe}
\tl_const:cn {c_phone_DE_ortsname_038758_tl} {D\"omitz}
\tl_const:cn {c_phone_DE_ortsname_038759_tl} {Tewswoos}
\tl_const:cn {c_phone_DE_ortsname_03876_tl} {Perleberg}
\tl_const:cn {c_phone_DE_ortsname_03877_tl} {Wittenberge}
\tl_const:cn {c_phone_DE_ortsname_038780_tl} {Lanz~Brandenburg}
\tl_const:cn {c_phone_DE_ortsname_038781_tl} {Mellen}
\tl_const:cn {c_phone_DE_ortsname_038782_tl} {Reetz~bei~Perleberg}
\tl_const:cn {c_phone_DE_ortsname_038783_tl} {Dallmin}
\tl_const:cn {c_phone_DE_ortsname_038784_tl} {Kleinow~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_038785_tl} {Berge~bei~Perleberg}
\tl_const:cn {c_phone_DE_ortsname_038787_tl} {Gl\"owen}
\tl_const:cn {c_phone_DE_ortsname_038788_tl} {Gro\ss\ Warnow}
\tl_const:cn {c_phone_DE_ortsname_038789_tl} {Wolfshagen~bei~Perleberg}
\tl_const:cn {c_phone_DE_ortsname_038791_tl} {Bad~Wilsnack}
\tl_const:cn {c_phone_DE_ortsname_038792_tl} {Lenzen~(Elbe)}
\tl_const:cn {c_phone_DE_ortsname_038793_tl} {Dergenthin}
\tl_const:cn {c_phone_DE_ortsname_038794_tl} {Cumlosen}
\tl_const:cn {c_phone_DE_ortsname_038796_tl} {Viesecke}
\tl_const:cn {c_phone_DE_ortsname_038797_tl} {Karst\"adt~Kreis~Prignitz}
\tl_const:cn {c_phone_DE_ortsname_03881_tl} {Grevesm\"uhlen}
\tl_const:cn {c_phone_DE_ortsname_038821_tl} {L\"udersdorf~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038822_tl} {Diedrichshagen~bei~Grevesm\"uhlen}
\tl_const:cn {c_phone_DE_ortsname_038823_tl} {Selmsdorf}
\tl_const:cn {c_phone_DE_ortsname_038824_tl} {Mallentin}
\tl_const:cn {c_phone_DE_ortsname_038825_tl} {Kl\"utz}
\tl_const:cn {c_phone_DE_ortsname_038826_tl} {Dassow}
\tl_const:cn {c_phone_DE_ortsname_038827_tl} {Kalkhorst}
\tl_const:cn {c_phone_DE_ortsname_038828_tl} {Sch\"onberg~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_03883_tl} {Hagenow}
\tl_const:cn {c_phone_DE_ortsname_038841_tl} {Neuhaus~Elbe}
\tl_const:cn {c_phone_DE_ortsname_038842_tl} {L\"uttenmark}
\tl_const:cn {c_phone_DE_ortsname_038843_tl} {Bennin}
\tl_const:cn {c_phone_DE_ortsname_038844_tl} {G\"ulze}
\tl_const:cn {c_phone_DE_ortsname_038845_tl} {Kaar\ss en}
\tl_const:cn {c_phone_DE_ortsname_038847_tl} {Boizenburg~Elbe}
\tl_const:cn {c_phone_DE_ortsname_038848_tl} {Vellahn}
\tl_const:cn {c_phone_DE_ortsname_038850_tl} {Gammelin}
\tl_const:cn {c_phone_DE_ortsname_038851_tl} {Zarrentin~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_038852_tl} {Wittenburg}
\tl_const:cn {c_phone_DE_ortsname_038853_tl} {Dr\"onnewitz~bei~Hagenow}
\tl_const:cn {c_phone_DE_ortsname_038854_tl} {Redefin}
\tl_const:cn {c_phone_DE_ortsname_038855_tl} {L\"ubtheen}
\tl_const:cn {c_phone_DE_ortsname_038856_tl} {Pritzier~bei~Hagenow}
\tl_const:cn {c_phone_DE_ortsname_038858_tl} {Lassahn}
\tl_const:cn {c_phone_DE_ortsname_038859_tl} {Alt~Zachun}
\tl_const:cn {c_phone_DE_ortsname_03886_tl} {Gadebusch}
\tl_const:cn {c_phone_DE_ortsname_038871_tl} {M\"uhlen~Eichsen}
\tl_const:cn {c_phone_DE_ortsname_038872_tl} {Rehna}
\tl_const:cn {c_phone_DE_ortsname_038873_tl} {Carlow}
\tl_const:cn {c_phone_DE_ortsname_038874_tl} {L\"utzow}
\tl_const:cn {c_phone_DE_ortsname_038875_tl} {Schlagsdorf~bei~Gadebusch}
\tl_const:cn {c_phone_DE_ortsname_038876_tl} {Roggendorf}
\tl_const:cn {c_phone_DE_ortsname_039000_tl} {Beetzendorf}
\tl_const:cn {c_phone_DE_ortsname_039001_tl} {Apenburg}
\tl_const:cn {c_phone_DE_ortsname_039002_tl} {Oebisfelde}
\tl_const:cn {c_phone_DE_ortsname_039003_tl} {J\"ubar}
\tl_const:cn {c_phone_DE_ortsname_039004_tl} {K\"ockte~bei~Gardelegen}
\tl_const:cn {c_phone_DE_ortsname_039005_tl} {Kusey}
\tl_const:cn {c_phone_DE_ortsname_039006_tl} {Miesterhorst}
\tl_const:cn {c_phone_DE_ortsname_039007_tl} {Tangeln}
\tl_const:cn {c_phone_DE_ortsname_039008_tl} {Kunrau}
\tl_const:cn {c_phone_DE_ortsname_039009_tl} {Badel}
\tl_const:cn {c_phone_DE_ortsname_03901_tl} {Salzwedel}
\tl_const:cn {c_phone_DE_ortsname_03902_tl} {Diesdorf~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039030_tl} {Brunau}
\tl_const:cn {c_phone_DE_ortsname_039031_tl} {D\"ahre}
\tl_const:cn {c_phone_DE_ortsname_039032_tl} {Mahlsdorf~bei~Salzwedel}
\tl_const:cn {c_phone_DE_ortsname_039033_tl} {Wallstawe}
\tl_const:cn {c_phone_DE_ortsname_039034_tl} {Fleetmark}
\tl_const:cn {c_phone_DE_ortsname_039035_tl} {Kuhfelde}
\tl_const:cn {c_phone_DE_ortsname_039036_tl} {Binde}
\tl_const:cn {c_phone_DE_ortsname_039037_tl} {Pretzier}
\tl_const:cn {c_phone_DE_ortsname_039038_tl} {Henningen}
\tl_const:cn {c_phone_DE_ortsname_039039_tl} {Bonese}
\tl_const:cn {c_phone_DE_ortsname_03904_tl} {Haldensleben}
\tl_const:cn {c_phone_DE_ortsname_039050_tl} {Bartensleben}
\tl_const:cn {c_phone_DE_ortsname_039051_tl} {Calv\"orde}
\tl_const:cn {c_phone_DE_ortsname_039052_tl} {Erxleben~bei~Haldensleben}
\tl_const:cn {c_phone_DE_ortsname_039053_tl} {S\"uplingen}
\tl_const:cn {c_phone_DE_ortsname_039054_tl} {Flechtingen}
\tl_const:cn {c_phone_DE_ortsname_039055_tl} {H\"orsingen}
\tl_const:cn {c_phone_DE_ortsname_039056_tl} {Kl\"uden}
\tl_const:cn {c_phone_DE_ortsname_039057_tl} {R\"atzlingen~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039058_tl} {Uthm\"oden}
\tl_const:cn {c_phone_DE_ortsname_039059_tl} {Wegenstedt}
\tl_const:cn {c_phone_DE_ortsname_039061_tl} {Weferlingen}
\tl_const:cn {c_phone_DE_ortsname_039062_tl} {Bebertal}
\tl_const:cn {c_phone_DE_ortsname_03907_tl} {Gardelegen}
\tl_const:cn {c_phone_DE_ortsname_039080_tl} {Kalbe~Milde}
\tl_const:cn {c_phone_DE_ortsname_039081_tl} {Kakerbeck~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039082_tl} {Mieste}
\tl_const:cn {c_phone_DE_ortsname_039083_tl} {Me\ss dorf}
\tl_const:cn {c_phone_DE_ortsname_039084_tl} {Lindstedt}
\tl_const:cn {c_phone_DE_ortsname_039085_tl} {Zichtau}
\tl_const:cn {c_phone_DE_ortsname_039086_tl} {J\"avenitz}
\tl_const:cn {c_phone_DE_ortsname_039087_tl} {Jerchel~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039088_tl} {Letzlingen}
\tl_const:cn {c_phone_DE_ortsname_039089_tl} {Bismark~Altmark}
\tl_const:cn {c_phone_DE_ortsname_03909_tl} {Kl\"otze~Altmark}
\tl_const:cn {c_phone_DE_ortsname_0391_tl} {Magdeburg}
\tl_const:cn {c_phone_DE_ortsname_039200_tl} {Gommern}
\tl_const:cn {c_phone_DE_ortsname_039201_tl} {Wolmirstedt}
\tl_const:cn {c_phone_DE_ortsname_039202_tl} {Gro\ss\ Ammensleben}
\tl_const:cn {c_phone_DE_ortsname_039203_tl} {Barleben}
\tl_const:cn {c_phone_DE_ortsname_039204_tl} {Niederndodeleben}
\tl_const:cn {c_phone_DE_ortsname_039205_tl} {Langenweddingen}
\tl_const:cn {c_phone_DE_ortsname_039206_tl} {Eichenbarleben}
\tl_const:cn {c_phone_DE_ortsname_039207_tl} {Colbitz}
\tl_const:cn {c_phone_DE_ortsname_039208_tl} {Loitsche}
\tl_const:cn {c_phone_DE_ortsname_039209_tl} {Wanzleben}
\tl_const:cn {c_phone_DE_ortsname_03921_tl} {Burg~bei~Magdeburg}
\tl_const:cn {c_phone_DE_ortsname_039221_tl} {M\"ockern~bei~Magdeburg}
\tl_const:cn {c_phone_DE_ortsname_039222_tl} {M\"oser}
\tl_const:cn {c_phone_DE_ortsname_039223_tl} {Thee\ss en}
\tl_const:cn {c_phone_DE_ortsname_039224_tl} {B\"uden}
\tl_const:cn {c_phone_DE_ortsname_039225_tl} {Altengrabow}
\tl_const:cn {c_phone_DE_ortsname_039226_tl} {Hohenziatz}
\tl_const:cn {c_phone_DE_ortsname_03923_tl} {Zerbst}
\tl_const:cn {c_phone_DE_ortsname_039241_tl} {Leitzkau}
\tl_const:cn {c_phone_DE_ortsname_039242_tl} {Pr\"odel}
\tl_const:cn {c_phone_DE_ortsname_039243_tl} {Nedlitz~bei~Zerbst}
\tl_const:cn {c_phone_DE_ortsname_039244_tl} {Steutz}
\tl_const:cn {c_phone_DE_ortsname_039245_tl} {Loburg}
\tl_const:cn {c_phone_DE_ortsname_039246_tl} {Lindau~Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039247_tl} {G\"utergl\"uck}
\tl_const:cn {c_phone_DE_ortsname_039248_tl} {Dobritz}
\tl_const:cn {c_phone_DE_ortsname_03925_tl} {Sta\ss furt}
\tl_const:cn {c_phone_DE_ortsname_039262_tl} {G\"usten~Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039263_tl} {Unseburg}
\tl_const:cn {c_phone_DE_ortsname_039264_tl} {Kroppenstedt}
\tl_const:cn {c_phone_DE_ortsname_039265_tl} {L\"oderburg}
\tl_const:cn {c_phone_DE_ortsname_039266_tl} {F\"orderstedt}
\tl_const:cn {c_phone_DE_ortsname_039267_tl} {Schneidlingen}
\tl_const:cn {c_phone_DE_ortsname_039268_tl} {Egeln}
\tl_const:cn {c_phone_DE_ortsname_03928_tl} {Sch\"onebeck~Elbe}
\tl_const:cn {c_phone_DE_ortsname_039291_tl} {Calbe~Saale}
\tl_const:cn {c_phone_DE_ortsname_039292_tl} {Biederitz}
\tl_const:cn {c_phone_DE_ortsname_039293_tl} {Dreileben}
\tl_const:cn {c_phone_DE_ortsname_039294_tl} {Gro\ss\ Rosenburg}
\tl_const:cn {c_phone_DE_ortsname_039295_tl} {Zuchau}
\tl_const:cn {c_phone_DE_ortsname_039296_tl} {Welsleben}
\tl_const:cn {c_phone_DE_ortsname_039297_tl} {Eickendorf~Kreis~Sch\"onebeck}
\tl_const:cn {c_phone_DE_ortsname_039298_tl} {Barby~Elbe}
\tl_const:cn {c_phone_DE_ortsname_03931_tl} {Stendal}
\tl_const:cn {c_phone_DE_ortsname_039320_tl} {Schinne}
\tl_const:cn {c_phone_DE_ortsname_039321_tl} {Arneburg}
\tl_const:cn {c_phone_DE_ortsname_039322_tl} {Tangerm\"unde}
\tl_const:cn {c_phone_DE_ortsname_039323_tl} {Sch\"onhausen~Elbe}
\tl_const:cn {c_phone_DE_ortsname_039324_tl} {Kl\"aden~bei~Stendal}
\tl_const:cn {c_phone_DE_ortsname_039325_tl} {Vinzelberg}
\tl_const:cn {c_phone_DE_ortsname_039327_tl} {Klietz}
\tl_const:cn {c_phone_DE_ortsname_039328_tl} {Rochau}
\tl_const:cn {c_phone_DE_ortsname_039329_tl} {M\"oringen}
\tl_const:cn {c_phone_DE_ortsname_03933_tl} {Genthin}
\tl_const:cn {c_phone_DE_ortsname_039341_tl} {Redekin}
\tl_const:cn {c_phone_DE_ortsname_039342_tl} {Gladau}
\tl_const:cn {c_phone_DE_ortsname_039343_tl} {Jerichow}
\tl_const:cn {c_phone_DE_ortsname_039344_tl} {G\"usen}
\tl_const:cn {c_phone_DE_ortsname_039345_tl} {Parchen}
\tl_const:cn {c_phone_DE_ortsname_039346_tl} {Tucheim}
\tl_const:cn {c_phone_DE_ortsname_039347_tl} {Kade}
\tl_const:cn {c_phone_DE_ortsname_039348_tl} {Klitsche}
\tl_const:cn {c_phone_DE_ortsname_039349_tl} {Parey~Elbe}
\tl_const:cn {c_phone_DE_ortsname_03935_tl} {Tangerh\"utte}
\tl_const:cn {c_phone_DE_ortsname_039361_tl} {L\"uderitz}
\tl_const:cn {c_phone_DE_ortsname_039362_tl} {Grieben~bei~Tangerh\"utte}
\tl_const:cn {c_phone_DE_ortsname_039363_tl} {Angern}
\tl_const:cn {c_phone_DE_ortsname_039364_tl} {Dolle}
\tl_const:cn {c_phone_DE_ortsname_039365_tl} {Bellingen~bei~Stendal}
\tl_const:cn {c_phone_DE_ortsname_039366_tl} {Kehnert}
\tl_const:cn {c_phone_DE_ortsname_03937_tl} {Osterburg~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039382_tl} {Kamern}
\tl_const:cn {c_phone_DE_ortsname_039383_tl} {Sandau~Elbe}
\tl_const:cn {c_phone_DE_ortsname_039384_tl} {Arendsee~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039386_tl} {Seehausen~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039387_tl} {Havelberg}
\tl_const:cn {c_phone_DE_ortsname_039388_tl} {Goldbeck~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039389_tl} {Schollene}
\tl_const:cn {c_phone_DE_ortsname_039390_tl} {Iden}
\tl_const:cn {c_phone_DE_ortsname_039391_tl} {L\"uckstedt}
\tl_const:cn {c_phone_DE_ortsname_039392_tl} {R\"onnebeck~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039393_tl} {Werben~Elbe}
\tl_const:cn {c_phone_DE_ortsname_039394_tl} {Hohenberg-Krusemark}
\tl_const:cn {c_phone_DE_ortsname_039395_tl} {Wanzer}
\tl_const:cn {c_phone_DE_ortsname_039396_tl} {Neukirchen~Altmark}
\tl_const:cn {c_phone_DE_ortsname_039397_tl} {Geestgottberg}
\tl_const:cn {c_phone_DE_ortsname_039398_tl} {Gro\ss\ Garz}
\tl_const:cn {c_phone_DE_ortsname_039399_tl} {Kleinau}
\tl_const:cn {c_phone_DE_ortsname_039400_tl} {Wefensleben}
\tl_const:cn {c_phone_DE_ortsname_039401_tl} {Neuwegersleben}
\tl_const:cn {c_phone_DE_ortsname_039402_tl} {V\"olpke}
\tl_const:cn {c_phone_DE_ortsname_039403_tl} {Gr\"oningen~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039404_tl} {Ausleben}
\tl_const:cn {c_phone_DE_ortsname_039405_tl} {H\"otensleben}
\tl_const:cn {c_phone_DE_ortsname_039406_tl} {Harbke}
\tl_const:cn {c_phone_DE_ortsname_039407_tl} {Seehausen~B\"orde}
\tl_const:cn {c_phone_DE_ortsname_039408_tl} {Hadmersleben}
\tl_const:cn {c_phone_DE_ortsname_039409_tl} {Eilsleben}
\tl_const:cn {c_phone_DE_ortsname_03941_tl} {Halberstadt}
\tl_const:cn {c_phone_DE_ortsname_039421_tl} {Osterwieck}
\tl_const:cn {c_phone_DE_ortsname_039422_tl} {Badersleben}
\tl_const:cn {c_phone_DE_ortsname_039423_tl} {Wegeleben}
\tl_const:cn {c_phone_DE_ortsname_039424_tl} {Schwanebeck~Sachsen-Anhalt}
\tl_const:cn {c_phone_DE_ortsname_039425_tl} {Dingelstedt~am~Huy}
\tl_const:cn {c_phone_DE_ortsname_039426_tl} {Hessen}
\tl_const:cn {c_phone_DE_ortsname_039427_tl} {Str\"obeck}
\tl_const:cn {c_phone_DE_ortsname_039428_tl} {Pabstorf}
\tl_const:cn {c_phone_DE_ortsname_03943_tl} {Wernigerode}
\tl_const:cn {c_phone_DE_ortsname_03944_tl} {Blankenburg~Harz}
\tl_const:cn {c_phone_DE_ortsname_039451_tl} {Wasserleben}
\tl_const:cn {c_phone_DE_ortsname_039452_tl} {Ilsenburg}
\tl_const:cn {c_phone_DE_ortsname_039453_tl} {Derenburg}
\tl_const:cn {c_phone_DE_ortsname_039454_tl} {Elbingerode~Harz}
\tl_const:cn {c_phone_DE_ortsname_039455_tl} {Schierke}
\tl_const:cn {c_phone_DE_ortsname_039456_tl} {Altenbrak}
\tl_const:cn {c_phone_DE_ortsname_039457_tl} {Benneckenstein~Harz}
\tl_const:cn {c_phone_DE_ortsname_039458_tl} {Heudeber}
\tl_const:cn {c_phone_DE_ortsname_039459_tl} {Hasselfelde}
\tl_const:cn {c_phone_DE_ortsname_03946_tl} {Quedlinburg}
\tl_const:cn {c_phone_DE_ortsname_03947_tl} {Thale}
\tl_const:cn {c_phone_DE_ortsname_039481_tl} {Hedersleben~bei~Aschersleben}
\tl_const:cn {c_phone_DE_ortsname_039482_tl} {Gatersleben}
\tl_const:cn {c_phone_DE_ortsname_039483_tl} {Ballenstedt}
\tl_const:cn {c_phone_DE_ortsname_039484_tl} {Harzgerode}
\tl_const:cn {c_phone_DE_ortsname_039485_tl} {Gernrode~Harz}
\tl_const:cn {c_phone_DE_ortsname_039487_tl} {Friedrichsbrunn}
\tl_const:cn {c_phone_DE_ortsname_039488_tl} {G\"untersberge}
\tl_const:cn {c_phone_DE_ortsname_039489_tl} {Stra\ss berg~Harz}
\tl_const:cn {c_phone_DE_ortsname_03949_tl} {Oschersleben~Bode}
\tl_const:cn {c_phone_DE_ortsname_0395_tl} {Neubrandenburg}
\tl_const:cn {c_phone_DE_ortsname_039600_tl} {Zwiedorf}
\tl_const:cn {c_phone_DE_ortsname_039601_tl} {Friedland~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_039602_tl} {Kleeth}
\tl_const:cn {c_phone_DE_ortsname_039603_tl} {Burg~Stargard}
\tl_const:cn {c_phone_DE_ortsname_039604_tl} {Wildberg~bei~Altentreptow}
\tl_const:cn {c_phone_DE_ortsname_039605_tl} {Gro\ss\ Nemerow}
\tl_const:cn {c_phone_DE_ortsname_039606_tl} {Glienke}
\tl_const:cn {c_phone_DE_ortsname_039607_tl} {Kotelow}
\tl_const:cn {c_phone_DE_ortsname_039608_tl} {Staven}
\tl_const:cn {c_phone_DE_ortsname_03961_tl} {Altentreptow}
\tl_const:cn {c_phone_DE_ortsname_03962_tl} {Penzlin~bei~Waren}
\tl_const:cn {c_phone_DE_ortsname_03963_tl} {Woldegk}
\tl_const:cn {c_phone_DE_ortsname_03964_tl} {Bredenfelde~bei~Strasburg}
\tl_const:cn {c_phone_DE_ortsname_03965_tl} {Burow~bei~Altentreptow}
\tl_const:cn {c_phone_DE_ortsname_03966_tl} {C\"olpin}
\tl_const:cn {c_phone_DE_ortsname_03967_tl} {Oertzenhof~bei~Strasburg}
\tl_const:cn {c_phone_DE_ortsname_03968_tl} {Sch\"onbeck~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_03969_tl} {Siedenbollentin}
\tl_const:cn {c_phone_DE_ortsname_03971_tl} {Anklam}
\tl_const:cn {c_phone_DE_ortsname_039721_tl} {Liepen~bei~Anklam}
\tl_const:cn {c_phone_DE_ortsname_039722_tl} {Sarnow~bei~Anklam}
\tl_const:cn {c_phone_DE_ortsname_039723_tl} {Krien}
\tl_const:cn {c_phone_DE_ortsname_039724_tl} {Klein~B\"unzow}
\tl_const:cn {c_phone_DE_ortsname_039726_tl} {Ducherow}
\tl_const:cn {c_phone_DE_ortsname_039727_tl} {Spantekow}
\tl_const:cn {c_phone_DE_ortsname_039728_tl} {Medow~bei~Anklam}
\tl_const:cn {c_phone_DE_ortsname_03973_tl} {Pasewalk}
\tl_const:cn {c_phone_DE_ortsname_039740_tl} {Nechlin}
\tl_const:cn {c_phone_DE_ortsname_039741_tl} {Jatznick}
\tl_const:cn {c_phone_DE_ortsname_039742_tl} {Br\"ussow~bei~Pasewalk}
\tl_const:cn {c_phone_DE_ortsname_039743_tl} {Zerrenthin}
\tl_const:cn {c_phone_DE_ortsname_039744_tl} {Rothenklempenow}
\tl_const:cn {c_phone_DE_ortsname_039745_tl} {Hetzdorf~bei~Strasburg}
\tl_const:cn {c_phone_DE_ortsname_039746_tl} {Krackow}
\tl_const:cn {c_phone_DE_ortsname_039747_tl} {Z\"usedom}
\tl_const:cn {c_phone_DE_ortsname_039748_tl} {Viereck}
\tl_const:cn {c_phone_DE_ortsname_039749_tl} {Grambow~bei~Pasewalk}
\tl_const:cn {c_phone_DE_ortsname_039751_tl} {Penkun}
\tl_const:cn {c_phone_DE_ortsname_039752_tl} {Blumenhagen~bei~Strasburg}
\tl_const:cn {c_phone_DE_ortsname_039753_tl} {Strasburg}
\tl_const:cn {c_phone_DE_ortsname_039754_tl} {L\"ocknitz~Vorpommern}
\tl_const:cn {c_phone_DE_ortsname_03976_tl} {Torgelow~bei~Ueckerm\"unde}
\tl_const:cn {c_phone_DE_ortsname_039771_tl} {Ueckerm\"unde}
\tl_const:cn {c_phone_DE_ortsname_039772_tl} {Rothem\"uhl}
\tl_const:cn {c_phone_DE_ortsname_039773_tl} {Altwarp}
\tl_const:cn {c_phone_DE_ortsname_039774_tl} {M\"onkebude}
\tl_const:cn {c_phone_DE_ortsname_039775_tl} {Ahlbeck~bei~Torgelow}
\tl_const:cn {c_phone_DE_ortsname_039776_tl} {Hintersee}
\tl_const:cn {c_phone_DE_ortsname_039777_tl} {Borkenfriede}
\tl_const:cn {c_phone_DE_ortsname_039778_tl} {Ferdinandshof~bei~Torgelow}
\tl_const:cn {c_phone_DE_ortsname_039779_tl} {Eggesin}
\tl_const:cn {c_phone_DE_ortsname_03981_tl} {Neustrelitz}
\tl_const:cn {c_phone_DE_ortsname_039820_tl} {Triepkendorf}
\tl_const:cn {c_phone_DE_ortsname_039821_tl} {Carpin}
\tl_const:cn {c_phone_DE_ortsname_039822_tl} {Kratzeburg}
\tl_const:cn {c_phone_DE_ortsname_039823_tl} {Rechlin}
\tl_const:cn {c_phone_DE_ortsname_039824_tl} {Hohenzieritz}
\tl_const:cn {c_phone_DE_ortsname_039825_tl} {Wokuhl}
\tl_const:cn {c_phone_DE_ortsname_039826_tl} {Blankensee~bei~Neustrelitz}
\tl_const:cn {c_phone_DE_ortsname_039827_tl} {Schwarz~bei~Neustrelitz}
\tl_const:cn {c_phone_DE_ortsname_039828_tl} {Wustrow~Kreis~Mecklenburg-Strelitz}
\tl_const:cn {c_phone_DE_ortsname_039829_tl} {Blankenf\"orde}
\tl_const:cn {c_phone_DE_ortsname_039831_tl} {Feldberg~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_039832_tl} {Wesenberg~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_039833_tl} {Mirow~Kreis~Neustrelitz}
\tl_const:cn {c_phone_DE_ortsname_03984_tl} {Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039851_tl} {G\"oritz~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039852_tl} {Sch\"onermark~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039853_tl} {Holzendorf~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039854_tl} {Kleptow}
\tl_const:cn {c_phone_DE_ortsname_039855_tl} {Parmen-Weggun}
\tl_const:cn {c_phone_DE_ortsname_039856_tl} {Beenz~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039857_tl} {Drense}
\tl_const:cn {c_phone_DE_ortsname_039858_tl} {Bietikow}
\tl_const:cn {c_phone_DE_ortsname_039859_tl} {F\"urstenwerder}
\tl_const:cn {c_phone_DE_ortsname_039861_tl} {Gramzow~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039862_tl} {Schm\"olln~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039863_tl} {Seehausen~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_03987_tl} {Templin}
\tl_const:cn {c_phone_DE_ortsname_039881_tl} {Ringenwalde~bei~Templin}
\tl_const:cn {c_phone_DE_ortsname_039882_tl} {Gollin}
\tl_const:cn {c_phone_DE_ortsname_039883_tl} {Gro\ss\ D\"olln}
\tl_const:cn {c_phone_DE_ortsname_039884_tl} {Ha\ss leben~bei~Prenzlau}
\tl_const:cn {c_phone_DE_ortsname_039885_tl} {Jakobshagen}
\tl_const:cn {c_phone_DE_ortsname_039886_tl} {Milmersdorf}
\tl_const:cn {c_phone_DE_ortsname_039887_tl} {Gerswalde}
\tl_const:cn {c_phone_DE_ortsname_039888_tl} {Lychen}
\tl_const:cn {c_phone_DE_ortsname_039889_tl} {Boitzenburg}
\tl_const:cn {c_phone_DE_ortsname_03991_tl} {Waren~M\"uritz}
\tl_const:cn {c_phone_DE_ortsname_039921_tl} {Ankershagen}
\tl_const:cn {c_phone_DE_ortsname_039922_tl} {Dambeck~bei~R\"obel}
\tl_const:cn {c_phone_DE_ortsname_039923_tl} {Priborn}
\tl_const:cn {c_phone_DE_ortsname_039924_tl} {Stuer}
\tl_const:cn {c_phone_DE_ortsname_039925_tl} {Wredenhagen}
\tl_const:cn {c_phone_DE_ortsname_039926_tl} {Grabowh\"ofe}
\tl_const:cn {c_phone_DE_ortsname_039927_tl} {Nossentiner~H\"utte}
\tl_const:cn {c_phone_DE_ortsname_039928_tl} {M\"ollenhagen}
\tl_const:cn {c_phone_DE_ortsname_039929_tl} {Jabel~bei~Waren}
\tl_const:cn {c_phone_DE_ortsname_039931_tl} {R\"obel~M\"uritz}
\tl_const:cn {c_phone_DE_ortsname_039932_tl} {Malchow~bei~Waren}
\tl_const:cn {c_phone_DE_ortsname_039933_tl} {Vollrathsruhe}
\tl_const:cn {c_phone_DE_ortsname_039934_tl} {Gro\ss\ Plasten}
\tl_const:cn {c_phone_DE_ortsname_03994_tl} {Malchin}
\tl_const:cn {c_phone_DE_ortsname_039951_tl} {Faulenrost}
\tl_const:cn {c_phone_DE_ortsname_039952_tl} {Grammentin}
\tl_const:cn {c_phone_DE_ortsname_039953_tl} {Schwinkendorf}
\tl_const:cn {c_phone_DE_ortsname_039954_tl} {Stavenhagen~Reuterstadt}
\tl_const:cn {c_phone_DE_ortsname_039955_tl} {J\"urgenstorf~Mecklenburg}
\tl_const:cn {c_phone_DE_ortsname_039956_tl} {Neukalen}
\tl_const:cn {c_phone_DE_ortsname_039957_tl} {Gielow}
\tl_const:cn {c_phone_DE_ortsname_039959_tl} {Dargun}
\tl_const:cn {c_phone_DE_ortsname_03996_tl} {Teterow}
\tl_const:cn {c_phone_DE_ortsname_039971_tl} {Gnoien}
\tl_const:cn {c_phone_DE_ortsname_039972_tl} {Walkendorf}
\tl_const:cn {c_phone_DE_ortsname_039973_tl} {Altkalen}
\tl_const:cn {c_phone_DE_ortsname_039975_tl} {Th\"urkow}
\tl_const:cn {c_phone_DE_ortsname_039976_tl} {Gro\ss\ B\"utzin}
\tl_const:cn {c_phone_DE_ortsname_039977_tl} {J\"ordenstorf}
\tl_const:cn {c_phone_DE_ortsname_039978_tl} {Gro\ss\ Roge}
\tl_const:cn {c_phone_DE_ortsname_03998_tl} {Demmin}
\tl_const:cn {c_phone_DE_ortsname_039991_tl} {Daberkow}
\tl_const:cn {c_phone_DE_ortsname_039992_tl} {G\"ormin}
\tl_const:cn {c_phone_DE_ortsname_039993_tl} {Hohenmocker}
\tl_const:cn {c_phone_DE_ortsname_039994_tl} {Metschow}
\tl_const:cn {c_phone_DE_ortsname_039995_tl} {Nossendorf}
\tl_const:cn {c_phone_DE_ortsname_039996_tl} {T\"orpin}
\tl_const:cn {c_phone_DE_ortsname_039997_tl} {Jarmen}
\tl_const:cn {c_phone_DE_ortsname_039998_tl} {Loitz~bei~Demmin}
\tl_const:cn {c_phone_DE_ortsname_039999_tl} {Tutow}
\tl_const:cn {c_phone_DE_ortsname_040_tl} {Hamburg}
\tl_const:cn {c_phone_DE_ortsname_04101_tl} {Pinneberg}
\tl_const:cn {c_phone_DE_ortsname_04102_tl} {Ahrensburg}
\tl_const:cn {c_phone_DE_ortsname_04103_tl} {Wedel}
\tl_const:cn {c_phone_DE_ortsname_04104_tl} {Aum\"uhle~bei~Hamburg}
\tl_const:cn {c_phone_DE_ortsname_04105_tl} {Seevetal}
\tl_const:cn {c_phone_DE_ortsname_04106_tl} {Quickborn~Kreis~Pinneberg}
\tl_const:cn {c_phone_DE_ortsname_04107_tl} {Siek~Kreis~Stormarn}
\tl_const:cn {c_phone_DE_ortsname_04108_tl} {Rosengarten~Kreis~Harburg}
\tl_const:cn {c_phone_DE_ortsname_04109_tl} {Tangstedt~bei~Hamburg}
\tl_const:cn {c_phone_DE_ortsname_04120_tl} {Ellerhoop}
\tl_const:cn {c_phone_DE_ortsname_04121_tl} {Elmshorn}
\tl_const:cn {c_phone_DE_ortsname_04122_tl} {Uetersen}
\tl_const:cn {c_phone_DE_ortsname_04123_tl} {Barmstedt}
\tl_const:cn {c_phone_DE_ortsname_04124_tl} {Gl\"uckstadt}
\tl_const:cn {c_phone_DE_ortsname_04125_tl} {Seesterm\"uhe}
\tl_const:cn {c_phone_DE_ortsname_04126_tl} {Horst~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04127_tl} {Westerhorn}
\tl_const:cn {c_phone_DE_ortsname_04128_tl} {Kollmar}
\tl_const:cn {c_phone_DE_ortsname_04129_tl} {Haseldorf}
\tl_const:cn {c_phone_DE_ortsname_04131_tl} {L\"uneburg}
\tl_const:cn {c_phone_DE_ortsname_04132_tl} {Amelinghausen}
\tl_const:cn {c_phone_DE_ortsname_04133_tl} {Wittorf~Kreis~L\"uneburg}
\tl_const:cn {c_phone_DE_ortsname_04134_tl} {Embsen~Kreis~L\"uneburg}
\tl_const:cn {c_phone_DE_ortsname_04135_tl} {Kirchgellersen}
\tl_const:cn {c_phone_DE_ortsname_04136_tl} {Scharnebeck}
\tl_const:cn {c_phone_DE_ortsname_04137_tl} {Barendorf}
\tl_const:cn {c_phone_DE_ortsname_04138_tl} {Betzendorf~Kreis~L\"uneburg}
\tl_const:cn {c_phone_DE_ortsname_04139_tl} {Hohnstorf~Elbe}
\tl_const:cn {c_phone_DE_ortsname_04140_tl} {Estorf~Kreis~Stade}
\tl_const:cn {c_phone_DE_ortsname_04141_tl} {Stade}
\tl_const:cn {c_phone_DE_ortsname_04142_tl} {Steinkirchen~Kreis~Stade}
\tl_const:cn {c_phone_DE_ortsname_04143_tl} {Drochtersen}
\tl_const:cn {c_phone_DE_ortsname_04144_tl} {Himmelpforten}
\tl_const:cn {c_phone_DE_ortsname_04146_tl} {Stade-B\"utzfleth}
\tl_const:cn {c_phone_DE_ortsname_04148_tl} {Drochtersen-Assel}
\tl_const:cn {c_phone_DE_ortsname_04149_tl} {Fredenbeck}
\tl_const:cn {c_phone_DE_ortsname_04151_tl} {Schwarzenbek}
\tl_const:cn {c_phone_DE_ortsname_04152_tl} {Geesthacht}
\tl_const:cn {c_phone_DE_ortsname_04153_tl} {Lauenburg~Elbe}
\tl_const:cn {c_phone_DE_ortsname_04154_tl} {Trittau}
\tl_const:cn {c_phone_DE_ortsname_04155_tl} {B\"uchen}
\tl_const:cn {c_phone_DE_ortsname_04156_tl} {Talkau}
\tl_const:cn {c_phone_DE_ortsname_04158_tl} {Roseburg}
\tl_const:cn {c_phone_DE_ortsname_04159_tl} {Basthorst}
\tl_const:cn {c_phone_DE_ortsname_04161_tl} {Buxtehude}
\tl_const:cn {c_phone_DE_ortsname_04162_tl} {Jork}
\tl_const:cn {c_phone_DE_ortsname_04163_tl} {Horneburg~Niederelbe}
\tl_const:cn {c_phone_DE_ortsname_04164_tl} {Harsefeld}
\tl_const:cn {c_phone_DE_ortsname_04165_tl} {Hollenstedt~Nordheide}
\tl_const:cn {c_phone_DE_ortsname_04166_tl} {Ahlerstedt}
\tl_const:cn {c_phone_DE_ortsname_04167_tl} {Apensen}
\tl_const:cn {c_phone_DE_ortsname_04168_tl} {Neu~Wulmstorf-Elstorf}
\tl_const:cn {c_phone_DE_ortsname_04169_tl} {Sauensiek}
\tl_const:cn {c_phone_DE_ortsname_04171_tl} {Winsen~Luhe}
\tl_const:cn {c_phone_DE_ortsname_04172_tl} {Salzhausen}
\tl_const:cn {c_phone_DE_ortsname_04173_tl} {Wulfsen}
\tl_const:cn {c_phone_DE_ortsname_04174_tl} {Stelle~Kreis~Harburg}
\tl_const:cn {c_phone_DE_ortsname_04175_tl} {Egestorf~Nordheide}
\tl_const:cn {c_phone_DE_ortsname_04176_tl} {Marschacht}
\tl_const:cn {c_phone_DE_ortsname_04177_tl} {Drage~Elbe}
\tl_const:cn {c_phone_DE_ortsname_04178_tl} {Radbruch}
\tl_const:cn {c_phone_DE_ortsname_04179_tl} {Winsen-T\"onnhausen}
\tl_const:cn {c_phone_DE_ortsname_04180_tl} {K\"onigsmoor}
\tl_const:cn {c_phone_DE_ortsname_04181_tl} {Buchholz~in~der~Nordheide}
\tl_const:cn {c_phone_DE_ortsname_04182_tl} {Tostedt}
\tl_const:cn {c_phone_DE_ortsname_04183_tl} {Jesteburg}
\tl_const:cn {c_phone_DE_ortsname_04184_tl} {Hanstedt~Nordheide}
\tl_const:cn {c_phone_DE_ortsname_04185_tl} {Marxen~Auetal}
\tl_const:cn {c_phone_DE_ortsname_04186_tl} {Buchholz-Trelde}
\tl_const:cn {c_phone_DE_ortsname_04187_tl} {Holm-Seppensen}
\tl_const:cn {c_phone_DE_ortsname_04188_tl} {Welle~Nordheide}
\tl_const:cn {c_phone_DE_ortsname_04189_tl} {Undeloh}
\tl_const:cn {c_phone_DE_ortsname_04191_tl} {Kaltenkirchen~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04192_tl} {Bad~Bramstedt}
\tl_const:cn {c_phone_DE_ortsname_04193_tl} {Henstedt-Ulzburg}
\tl_const:cn {c_phone_DE_ortsname_04194_tl} {Sieversh\"utten}
\tl_const:cn {c_phone_DE_ortsname_04195_tl} {Hartenholm}
\tl_const:cn {c_phone_DE_ortsname_04202_tl} {Achim~bei~Bremen}
\tl_const:cn {c_phone_DE_ortsname_04203_tl} {Weyhe~bei~Bremen}
\tl_const:cn {c_phone_DE_ortsname_04204_tl} {Thedinghausen}
\tl_const:cn {c_phone_DE_ortsname_04205_tl} {Ottersberg}
\tl_const:cn {c_phone_DE_ortsname_04206_tl} {Stuhr-Heiligenrode}
\tl_const:cn {c_phone_DE_ortsname_04207_tl} {Oyten}
\tl_const:cn {c_phone_DE_ortsname_04208_tl} {Grasberg}
\tl_const:cn {c_phone_DE_ortsname_04209_tl} {Schwanewede}
\tl_const:cn {c_phone_DE_ortsname_0421_tl} {Bremen}
\tl_const:cn {c_phone_DE_ortsname_04221_tl} {Delmenhorst}
\tl_const:cn {c_phone_DE_ortsname_04222_tl} {Ganderkesee}
\tl_const:cn {c_phone_DE_ortsname_04223_tl} {Ganderkesee-Bookholzberg}
\tl_const:cn {c_phone_DE_ortsname_04224_tl} {Gro\ss\ Ippener}
\tl_const:cn {c_phone_DE_ortsname_04230_tl} {Verden-Walle}
\tl_const:cn {c_phone_DE_ortsname_04231_tl} {Verden~Aller}
\tl_const:cn {c_phone_DE_ortsname_04232_tl} {Langwedel~Kreis~Verden}
\tl_const:cn {c_phone_DE_ortsname_04233_tl} {Blender}
\tl_const:cn {c_phone_DE_ortsname_04234_tl} {D\"orverden}
\tl_const:cn {c_phone_DE_ortsname_04235_tl} {Langwedel-Etelsen}
\tl_const:cn {c_phone_DE_ortsname_04236_tl} {Kirchlinteln}
\tl_const:cn {c_phone_DE_ortsname_04237_tl} {Bendingbostel}
\tl_const:cn {c_phone_DE_ortsname_04238_tl} {Neddenaverbergen}
\tl_const:cn {c_phone_DE_ortsname_04239_tl} {D\"orverden-Westen}
\tl_const:cn {c_phone_DE_ortsname_04240_tl} {Syke-Heiligenfelde}
\tl_const:cn {c_phone_DE_ortsname_04241_tl} {Bassum}
\tl_const:cn {c_phone_DE_ortsname_04242_tl} {Syke}
\tl_const:cn {c_phone_DE_ortsname_04243_tl} {Twistringen}
\tl_const:cn {c_phone_DE_ortsname_04244_tl} {Harpstedt}
\tl_const:cn {c_phone_DE_ortsname_04245_tl} {Neuenkirchen~bei~Bassum}
\tl_const:cn {c_phone_DE_ortsname_04246_tl} {Twistringen-Heiligenloh}
\tl_const:cn {c_phone_DE_ortsname_04247_tl} {Affinghausen}
\tl_const:cn {c_phone_DE_ortsname_04248_tl} {Bassum-Neubruchhausen}
\tl_const:cn {c_phone_DE_ortsname_04249_tl} {Bassum-Nordwohlde}
\tl_const:cn {c_phone_DE_ortsname_04251_tl} {Hoya}
\tl_const:cn {c_phone_DE_ortsname_04252_tl} {Bruchhausen-Vilsen}
\tl_const:cn {c_phone_DE_ortsname_04253_tl} {Asendorf~Kreis~Diepholz}
\tl_const:cn {c_phone_DE_ortsname_04254_tl} {Eystrup}
\tl_const:cn {c_phone_DE_ortsname_04255_tl} {Martfeld}
\tl_const:cn {c_phone_DE_ortsname_04256_tl} {Hilgermissen}
\tl_const:cn {c_phone_DE_ortsname_04257_tl} {Schweringen}
\tl_const:cn {c_phone_DE_ortsname_04258_tl} {Schwarme}
\tl_const:cn {c_phone_DE_ortsname_04260_tl} {Visselh\"ovede-Wittorf}
\tl_const:cn {c_phone_DE_ortsname_04261_tl} {Rotenburg~W\"umme}
\tl_const:cn {c_phone_DE_ortsname_04262_tl} {Visselh\"ovede}
\tl_const:cn {c_phone_DE_ortsname_04263_tl} {Schee\ss el}
\tl_const:cn {c_phone_DE_ortsname_04264_tl} {Sottrum~Kreis~Rotenburg}
\tl_const:cn {c_phone_DE_ortsname_04265_tl} {Fintel}
\tl_const:cn {c_phone_DE_ortsname_04266_tl} {Brockel}
\tl_const:cn {c_phone_DE_ortsname_04267_tl} {Lauenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_04268_tl} {B\"otersen}
\tl_const:cn {c_phone_DE_ortsname_04269_tl} {Ahausen-Kirchwalsede}
\tl_const:cn {c_phone_DE_ortsname_04271_tl} {Sulingen}
\tl_const:cn {c_phone_DE_ortsname_04272_tl} {Siedenburg}
\tl_const:cn {c_phone_DE_ortsname_04273_tl} {Kirchdorf~bei~Sulingen}
\tl_const:cn {c_phone_DE_ortsname_04274_tl} {Varrel~bei~Sulingen}
\tl_const:cn {c_phone_DE_ortsname_04275_tl} {Ehrenburg}
\tl_const:cn {c_phone_DE_ortsname_04276_tl} {Borstel~bei~Sulingen}
\tl_const:cn {c_phone_DE_ortsname_04277_tl} {Schwaf\"orden}
\tl_const:cn {c_phone_DE_ortsname_04281_tl} {Zeven}
\tl_const:cn {c_phone_DE_ortsname_04282_tl} {Sittensen}
\tl_const:cn {c_phone_DE_ortsname_04283_tl} {Tarmstedt}
\tl_const:cn {c_phone_DE_ortsname_04284_tl} {Selsingen}
\tl_const:cn {c_phone_DE_ortsname_04285_tl} {Rhade~bei~Zeven}
\tl_const:cn {c_phone_DE_ortsname_04286_tl} {Gyhum}
\tl_const:cn {c_phone_DE_ortsname_04287_tl} {Heeslingen-Boitzen}
\tl_const:cn {c_phone_DE_ortsname_04288_tl} {Horstedt~Kreis~Rotenburg}
\tl_const:cn {c_phone_DE_ortsname_04289_tl} {Kirchtimke}
\tl_const:cn {c_phone_DE_ortsname_04292_tl} {Ritterhude}
\tl_const:cn {c_phone_DE_ortsname_04293_tl} {Ottersberg-Fischerhude}
\tl_const:cn {c_phone_DE_ortsname_04294_tl} {Riede~Kreis~Verden}
\tl_const:cn {c_phone_DE_ortsname_04295_tl} {Emtinghausen}
\tl_const:cn {c_phone_DE_ortsname_04296_tl} {Schwanewede-Aschwarden}
\tl_const:cn {c_phone_DE_ortsname_04297_tl} {Ottersberg-Posthausen}
\tl_const:cn {c_phone_DE_ortsname_04298_tl} {Lilienthal}
\tl_const:cn {c_phone_DE_ortsname_04302_tl} {Kirchbarkau}
\tl_const:cn {c_phone_DE_ortsname_04303_tl} {Schlesen}
\tl_const:cn {c_phone_DE_ortsname_04305_tl} {Westensee}
\tl_const:cn {c_phone_DE_ortsname_04307_tl} {Raisdorf}
\tl_const:cn {c_phone_DE_ortsname_04308_tl} {Schwedeneck}
\tl_const:cn {c_phone_DE_ortsname_0431_tl} {Kiel}
\tl_const:cn {c_phone_DE_ortsname_04320_tl} {Heidm\"uhlen}
\tl_const:cn {c_phone_DE_ortsname_04321_tl} {Neum\"unster}
\tl_const:cn {c_phone_DE_ortsname_04322_tl} {Bordesholm}
\tl_const:cn {c_phone_DE_ortsname_04323_tl} {Bornh\"oved}
\tl_const:cn {c_phone_DE_ortsname_04324_tl} {Brokstedt}
\tl_const:cn {c_phone_DE_ortsname_04326_tl} {Wankendorf}
\tl_const:cn {c_phone_DE_ortsname_04327_tl} {Gro\ss enaspe}
\tl_const:cn {c_phone_DE_ortsname_04328_tl} {Rickling}
\tl_const:cn {c_phone_DE_ortsname_04329_tl} {Langwedel~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04330_tl} {Emkendorf}
\tl_const:cn {c_phone_DE_ortsname_04331_tl} {Rendsburg}
\tl_const:cn {c_phone_DE_ortsname_04332_tl} {Hamdorf~bei~Rendsburg}
\tl_const:cn {c_phone_DE_ortsname_04333_tl} {Erfde}
\tl_const:cn {c_phone_DE_ortsname_04334_tl} {Bredenbek~bei~Rendsburg}
\tl_const:cn {c_phone_DE_ortsname_04335_tl} {Hohn~bei~Rendsburg}
\tl_const:cn {c_phone_DE_ortsname_04336_tl} {Owschlag}
\tl_const:cn {c_phone_DE_ortsname_04337_tl} {Jevenstedt}
\tl_const:cn {c_phone_DE_ortsname_04338_tl} {Alt~Duvenstedt}
\tl_const:cn {c_phone_DE_ortsname_04339_tl} {Christiansholm}
\tl_const:cn {c_phone_DE_ortsname_04340_tl} {Achterwehr}
\tl_const:cn {c_phone_DE_ortsname_04342_tl} {Preetz~Kreis~Pl\"on}
\tl_const:cn {c_phone_DE_ortsname_04343_tl} {Laboe}
\tl_const:cn {c_phone_DE_ortsname_04344_tl} {Sch\"onberg~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04346_tl} {Gettorf}
\tl_const:cn {c_phone_DE_ortsname_04347_tl} {Flintbek}
\tl_const:cn {c_phone_DE_ortsname_04348_tl} {Sch\"onkirchen}
\tl_const:cn {c_phone_DE_ortsname_04349_tl} {D\"anischenhagen}
\tl_const:cn {c_phone_DE_ortsname_04351_tl} {Eckernf\"orde}
\tl_const:cn {c_phone_DE_ortsname_04352_tl} {Damp}
\tl_const:cn {c_phone_DE_ortsname_04353_tl} {Ascheffel}
\tl_const:cn {c_phone_DE_ortsname_04354_tl} {Fleckeby}
\tl_const:cn {c_phone_DE_ortsname_04355_tl} {Rieseby}
\tl_const:cn {c_phone_DE_ortsname_04356_tl} {Gro\ss\ Wittensee}
\tl_const:cn {c_phone_DE_ortsname_04357_tl} {Sehestedt~Eider}
\tl_const:cn {c_phone_DE_ortsname_04358_tl} {Loose~bei~Eckernf\"orde}
\tl_const:cn {c_phone_DE_ortsname_04361_tl} {Oldenburg~in~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04362_tl} {Heiligenhafen}
\tl_const:cn {c_phone_DE_ortsname_04363_tl} {Lensahn}
\tl_const:cn {c_phone_DE_ortsname_04364_tl} {Dahme~Kreis~Ostholstein}
\tl_const:cn {c_phone_DE_ortsname_04365_tl} {Heringsdorf~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04366_tl} {Gr\"omitz-Cismar}
\tl_const:cn {c_phone_DE_ortsname_04367_tl} {Gro\ss enbrode}
\tl_const:cn {c_phone_DE_ortsname_04371_tl} {Burg~auf~Fehmarn}
\tl_const:cn {c_phone_DE_ortsname_04372_tl} {Westfehmarn}
\tl_const:cn {c_phone_DE_ortsname_04381_tl} {L\"utjenburg}
\tl_const:cn {c_phone_DE_ortsname_04382_tl} {Wangels}
\tl_const:cn {c_phone_DE_ortsname_04383_tl} {Grebin}
\tl_const:cn {c_phone_DE_ortsname_04384_tl} {Selent}
\tl_const:cn {c_phone_DE_ortsname_04385_tl} {Hohenfelde~bei~Kiel}
\tl_const:cn {c_phone_DE_ortsname_04392_tl} {Nortorf~bei~Neum\"unster}
\tl_const:cn {c_phone_DE_ortsname_04393_tl} {Boostedt}
\tl_const:cn {c_phone_DE_ortsname_04394_tl} {Bokhorst}
\tl_const:cn {c_phone_DE_ortsname_04401_tl} {Brake~Unterweser}
\tl_const:cn {c_phone_DE_ortsname_04402_tl} {Rastede}
\tl_const:cn {c_phone_DE_ortsname_04403_tl} {Bad~Zwischenahn}
\tl_const:cn {c_phone_DE_ortsname_04404_tl} {Elsfleth}
\tl_const:cn {c_phone_DE_ortsname_04405_tl} {Edewecht}
\tl_const:cn {c_phone_DE_ortsname_04406_tl} {Berne}
\tl_const:cn {c_phone_DE_ortsname_04407_tl} {Wardenburg}
\tl_const:cn {c_phone_DE_ortsname_04408_tl} {Hude~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_04409_tl} {Westerstede-Ocholt}
\tl_const:cn {c_phone_DE_ortsname_0441_tl} {Oldenburg~(Oldb)}
\tl_const:cn {c_phone_DE_ortsname_04421_tl} {Wilhelmshaven}
\tl_const:cn {c_phone_DE_ortsname_04422_tl} {Sande~Kreis~Friesland}
\tl_const:cn {c_phone_DE_ortsname_04423_tl} {Fedderwarden}
\tl_const:cn {c_phone_DE_ortsname_04425_tl} {Wangerland-Hooksiel}
\tl_const:cn {c_phone_DE_ortsname_04426_tl} {Wangerland-Horumersiel}
\tl_const:cn {c_phone_DE_ortsname_04431_tl} {Wildeshausen}
\tl_const:cn {c_phone_DE_ortsname_04432_tl} {D\"otlingen-Brettorf}
\tl_const:cn {c_phone_DE_ortsname_04433_tl} {D\"otlingen}
\tl_const:cn {c_phone_DE_ortsname_04434_tl} {Colnrade}
\tl_const:cn {c_phone_DE_ortsname_04435_tl} {Gro\ss enkneten}
\tl_const:cn {c_phone_DE_ortsname_04441_tl} {Vechta}
\tl_const:cn {c_phone_DE_ortsname_04442_tl} {Lohne~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_04443_tl} {Dinklage}
\tl_const:cn {c_phone_DE_ortsname_04444_tl} {Goldenstedt}
\tl_const:cn {c_phone_DE_ortsname_04445_tl} {Visbek~Kreis~Vechta}
\tl_const:cn {c_phone_DE_ortsname_04446_tl} {Bakum~Kreis~Vechta}
\tl_const:cn {c_phone_DE_ortsname_04447_tl} {Vechta-Langf\"orden}
\tl_const:cn {c_phone_DE_ortsname_04451_tl} {Varel~Jadebusen}
\tl_const:cn {c_phone_DE_ortsname_04452_tl} {Zetel-Neuenburg}
\tl_const:cn {c_phone_DE_ortsname_04453_tl} {Zetel}
\tl_const:cn {c_phone_DE_ortsname_04454_tl} {Jade}
\tl_const:cn {c_phone_DE_ortsname_04455_tl} {Jade-Schweiburg}
\tl_const:cn {c_phone_DE_ortsname_04456_tl} {Varel-Altj\"uhrden}
\tl_const:cn {c_phone_DE_ortsname_04458_tl} {Wiefelstede-Spohle}
\tl_const:cn {c_phone_DE_ortsname_04461_tl} {Jever}
\tl_const:cn {c_phone_DE_ortsname_04462_tl} {Wittmund}
\tl_const:cn {c_phone_DE_ortsname_04463_tl} {Wangerland}
\tl_const:cn {c_phone_DE_ortsname_04464_tl} {Wittmund-Carolinensiel}
\tl_const:cn {c_phone_DE_ortsname_04465_tl} {Friedeburg~Ostfriesland}
\tl_const:cn {c_phone_DE_ortsname_04466_tl} {Wittmund-Ardorf}
\tl_const:cn {c_phone_DE_ortsname_04467_tl} {Wittmund-Funnix}
\tl_const:cn {c_phone_DE_ortsname_04468_tl} {Friedeburg-Reepsholt}
\tl_const:cn {c_phone_DE_ortsname_04469_tl} {Wangerooge}
\tl_const:cn {c_phone_DE_ortsname_04471_tl} {Cloppenburg}
\tl_const:cn {c_phone_DE_ortsname_04472_tl} {Lastrup}
\tl_const:cn {c_phone_DE_ortsname_04473_tl} {Emstek}
\tl_const:cn {c_phone_DE_ortsname_04474_tl} {Garrel}
\tl_const:cn {c_phone_DE_ortsname_04475_tl} {Molbergen}
\tl_const:cn {c_phone_DE_ortsname_04477_tl} {Lastrup-Hemmelte}
\tl_const:cn {c_phone_DE_ortsname_04478_tl} {Cappeln~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_04479_tl} {Molbergen-Peheim}
\tl_const:cn {c_phone_DE_ortsname_04480_tl} {Ovelg\"onne-Str\"uckhausen}
\tl_const:cn {c_phone_DE_ortsname_04481_tl} {Hatten-Sandkrug}
\tl_const:cn {c_phone_DE_ortsname_04482_tl} {Hatten}
\tl_const:cn {c_phone_DE_ortsname_04483_tl} {Ovelg\"onne-Gro\ss enmeer}
\tl_const:cn {c_phone_DE_ortsname_04484_tl} {Hude-W\"usting}
\tl_const:cn {c_phone_DE_ortsname_04485_tl} {Elsfleth-Huntorf}
\tl_const:cn {c_phone_DE_ortsname_04486_tl} {Edewecht-Friedrichsfehn}
\tl_const:cn {c_phone_DE_ortsname_04487_tl} {Gro\ss enkneten-Huntlosen}
\tl_const:cn {c_phone_DE_ortsname_04488_tl} {Westerstede}
\tl_const:cn {c_phone_DE_ortsname_04489_tl} {Apen}
\tl_const:cn {c_phone_DE_ortsname_04491_tl} {Friesoythe}
\tl_const:cn {c_phone_DE_ortsname_04492_tl} {Saterland}
\tl_const:cn {c_phone_DE_ortsname_04493_tl} {Friesoythe-Gehlenberg}
\tl_const:cn {c_phone_DE_ortsname_04494_tl} {B\"osel~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_04495_tl} {Friesoythe-Th\"ule}
\tl_const:cn {c_phone_DE_ortsname_04496_tl} {Friesoythe-Markhausen}
\tl_const:cn {c_phone_DE_ortsname_04497_tl} {Bar\ss el-Harkebr\"ugge}
\tl_const:cn {c_phone_DE_ortsname_04498_tl} {Saterland-Ramsloh}
\tl_const:cn {c_phone_DE_ortsname_04499_tl} {Bar\ss el}
\tl_const:cn {c_phone_DE_ortsname_04501_tl} {Kastorf~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04502_tl} {L\"ubeck-Travem\"unde}
\tl_const:cn {c_phone_DE_ortsname_04503_tl} {Timmendorfer~Strand}
\tl_const:cn {c_phone_DE_ortsname_04504_tl} {Ratekau}
\tl_const:cn {c_phone_DE_ortsname_04505_tl} {Stockelsdorf-Curau}
\tl_const:cn {c_phone_DE_ortsname_04506_tl} {Stockelsdorf-Krumbeck}
\tl_const:cn {c_phone_DE_ortsname_04508_tl} {Krummesse}
\tl_const:cn {c_phone_DE_ortsname_04509_tl} {Gro\ss\ Gr\"onau}
\tl_const:cn {c_phone_DE_ortsname_0451_tl} {L\"ubeck}
\tl_const:cn {c_phone_DE_ortsname_04521_tl} {Eutin}
\tl_const:cn {c_phone_DE_ortsname_04522_tl} {Pl\"on}
\tl_const:cn {c_phone_DE_ortsname_04523_tl} {Malente}
\tl_const:cn {c_phone_DE_ortsname_04524_tl} {Scharbeutz-P\"onitz}
\tl_const:cn {c_phone_DE_ortsname_04525_tl} {Ahrensb\"ok}
\tl_const:cn {c_phone_DE_ortsname_04526_tl} {Ascheberg~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04527_tl} {Bosau}
\tl_const:cn {c_phone_DE_ortsname_04528_tl} {Sch\"onwalde~am~Bungsberg}
\tl_const:cn {c_phone_DE_ortsname_04529_tl} {S\"usel-Bujendorf}
\tl_const:cn {c_phone_DE_ortsname_04531_tl} {Bad~Oldesloe}
\tl_const:cn {c_phone_DE_ortsname_04532_tl} {Bargteheide}
\tl_const:cn {c_phone_DE_ortsname_04533_tl} {Reinfeld~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04534_tl} {Steinburg~Kreis~Stormarn}
\tl_const:cn {c_phone_DE_ortsname_04535_tl} {Nahe}
\tl_const:cn {c_phone_DE_ortsname_04536_tl} {Steinhorst~Lauenburg}
\tl_const:cn {c_phone_DE_ortsname_04537_tl} {S\"ulfeld~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04539_tl} {Westerau}
\tl_const:cn {c_phone_DE_ortsname_04541_tl} {Ratzeburg}
\tl_const:cn {c_phone_DE_ortsname_04542_tl} {M\"olln~Lauenburg}
\tl_const:cn {c_phone_DE_ortsname_04543_tl} {Nusse}
\tl_const:cn {c_phone_DE_ortsname_04544_tl} {Berkenthin}
\tl_const:cn {c_phone_DE_ortsname_04545_tl} {Seedorf~Lauenburg}
\tl_const:cn {c_phone_DE_ortsname_04546_tl} {Mustin~Lauenburg}
\tl_const:cn {c_phone_DE_ortsname_04547_tl} {Gudow~Lauenburg}
\tl_const:cn {c_phone_DE_ortsname_04550_tl} {B\"uhnsdorf}
\tl_const:cn {c_phone_DE_ortsname_04551_tl} {Bad~Segeberg}
\tl_const:cn {c_phone_DE_ortsname_04552_tl} {Leezen}
\tl_const:cn {c_phone_DE_ortsname_04553_tl} {Geschendorf}
\tl_const:cn {c_phone_DE_ortsname_04554_tl} {Wahlstedt}
\tl_const:cn {c_phone_DE_ortsname_04555_tl} {Seedorf~bei~Bad~Segeberg}
\tl_const:cn {c_phone_DE_ortsname_04556_tl} {Ahrensb\"ok-Gnissau}
\tl_const:cn {c_phone_DE_ortsname_04557_tl} {Blunk}
\tl_const:cn {c_phone_DE_ortsname_04558_tl} {Todesfelde}
\tl_const:cn {c_phone_DE_ortsname_04559_tl} {Wensin}
\tl_const:cn {c_phone_DE_ortsname_04561_tl} {Neustadt~in~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04562_tl} {Gr\"omitz}
\tl_const:cn {c_phone_DE_ortsname_04563_tl} {Scharbeutz-Haffkrug}
\tl_const:cn {c_phone_DE_ortsname_04564_tl} {Schashagen}
\tl_const:cn {c_phone_DE_ortsname_04602_tl} {Freienwill}
\tl_const:cn {c_phone_DE_ortsname_04603_tl} {Havetoft}
\tl_const:cn {c_phone_DE_ortsname_04604_tl} {Gro\ss enwiehe}
\tl_const:cn {c_phone_DE_ortsname_04605_tl} {Medelby}
\tl_const:cn {c_phone_DE_ortsname_04606_tl} {Wanderup}
\tl_const:cn {c_phone_DE_ortsname_04607_tl} {Janneby}
\tl_const:cn {c_phone_DE_ortsname_04608_tl} {Handewitt}
\tl_const:cn {c_phone_DE_ortsname_04609_tl} {Eggebek}
\tl_const:cn {c_phone_DE_ortsname_0461_tl} {Flensburg}
\tl_const:cn {c_phone_DE_ortsname_04621_tl} {Schleswig}
\tl_const:cn {c_phone_DE_ortsname_04622_tl} {Taarstedt}
\tl_const:cn {c_phone_DE_ortsname_04623_tl} {B\"oklund}
\tl_const:cn {c_phone_DE_ortsname_04624_tl} {Kropp}
\tl_const:cn {c_phone_DE_ortsname_04625_tl} {J\"ubek}
\tl_const:cn {c_phone_DE_ortsname_04626_tl} {Treia}
\tl_const:cn {c_phone_DE_ortsname_04627_tl} {D\"orpstedt}
\tl_const:cn {c_phone_DE_ortsname_04630_tl} {Barderup}
\tl_const:cn {c_phone_DE_ortsname_04631_tl} {Gl\"ucksburg~Ostsee}
\tl_const:cn {c_phone_DE_ortsname_04632_tl} {Steinbergkirche}
\tl_const:cn {c_phone_DE_ortsname_04633_tl} {Satrup}
\tl_const:cn {c_phone_DE_ortsname_04634_tl} {Husby}
\tl_const:cn {c_phone_DE_ortsname_04635_tl} {S\"orup}
\tl_const:cn {c_phone_DE_ortsname_04636_tl} {Langballig}
\tl_const:cn {c_phone_DE_ortsname_04637_tl} {Sterup}
\tl_const:cn {c_phone_DE_ortsname_04638_tl} {Tarp}
\tl_const:cn {c_phone_DE_ortsname_04639_tl} {Schaff\/lund}
\tl_const:cn {c_phone_DE_ortsname_04641_tl} {S\"uderbrarup}
\tl_const:cn {c_phone_DE_ortsname_04642_tl} {Kappeln~Schlei}
\tl_const:cn {c_phone_DE_ortsname_04643_tl} {Gelting~Angeln}
\tl_const:cn {c_phone_DE_ortsname_04644_tl} {Karby}
\tl_const:cn {c_phone_DE_ortsname_04646_tl} {Mohrkirch}
\tl_const:cn {c_phone_DE_ortsname_04651_tl} {Sylt}
\tl_const:cn {c_phone_DE_ortsname_04661_tl} {Nieb\"ull}
\tl_const:cn {c_phone_DE_ortsname_04662_tl} {Leck}
\tl_const:cn {c_phone_DE_ortsname_04663_tl} {S\"uderl\"ugum}
\tl_const:cn {c_phone_DE_ortsname_04664_tl} {Neukirchen~bei~Nieb\"ull}
\tl_const:cn {c_phone_DE_ortsname_04665_tl} {Emmelsb\"ull-Horsb\"ull}
\tl_const:cn {c_phone_DE_ortsname_04666_tl} {Ladelund}
\tl_const:cn {c_phone_DE_ortsname_04667_tl} {Dageb\"ull}
\tl_const:cn {c_phone_DE_ortsname_04668_tl} {Klanxb\"ull}
\tl_const:cn {c_phone_DE_ortsname_04671_tl} {Bredstedt}
\tl_const:cn {c_phone_DE_ortsname_04672_tl} {Langenhorn}
\tl_const:cn {c_phone_DE_ortsname_04673_tl} {Joldelund}
\tl_const:cn {c_phone_DE_ortsname_04674_tl} {Ockholm}
\tl_const:cn {c_phone_DE_ortsname_04681_tl} {Wyk~auf~F\"ohr}
\tl_const:cn {c_phone_DE_ortsname_04682_tl} {Amrum}
\tl_const:cn {c_phone_DE_ortsname_04683_tl} {Oldsum}
\tl_const:cn {c_phone_DE_ortsname_04684_tl} {Langene\ss\ Hallig}
\tl_const:cn {c_phone_DE_ortsname_04702_tl} {Sandstedt}
\tl_const:cn {c_phone_DE_ortsname_04703_tl} {Loxstedt-Donnern}
\tl_const:cn {c_phone_DE_ortsname_04704_tl} {Drangstedt}
\tl_const:cn {c_phone_DE_ortsname_04705_tl} {Wremen}
\tl_const:cn {c_phone_DE_ortsname_04706_tl} {Schiffdorf}
\tl_const:cn {c_phone_DE_ortsname_04707_tl} {Langen-Neuenwalde}
\tl_const:cn {c_phone_DE_ortsname_04708_tl} {Ringstedt}
\tl_const:cn {c_phone_DE_ortsname_0471_tl} {Bremerhaven}
\tl_const:cn {c_phone_DE_ortsname_04721_tl} {Cuxhaven}
\tl_const:cn {c_phone_DE_ortsname_04722_tl} {Cuxhaven-Altenbruch}
\tl_const:cn {c_phone_DE_ortsname_04723_tl} {Cuxhaven-Altenwalde}
\tl_const:cn {c_phone_DE_ortsname_04724_tl} {Cuxhaven-L\"udingworth}
\tl_const:cn {c_phone_DE_ortsname_04725_tl} {Helgoland}
\tl_const:cn {c_phone_DE_ortsname_04731_tl} {Nordenham}
\tl_const:cn {c_phone_DE_ortsname_04732_tl} {Stadland-Rodenkirchen}
\tl_const:cn {c_phone_DE_ortsname_04733_tl} {Butjadingen-Burhave}
\tl_const:cn {c_phone_DE_ortsname_04734_tl} {Stadland-Seefeld}
\tl_const:cn {c_phone_DE_ortsname_04735_tl} {Butjadingen-Stollhamm}
\tl_const:cn {c_phone_DE_ortsname_04736_tl} {Butjadingen-Tossens}
\tl_const:cn {c_phone_DE_ortsname_04737_tl} {Stadland-Schwei}
\tl_const:cn {c_phone_DE_ortsname_04740_tl} {Loxstedt-Dedesdorf}
\tl_const:cn {c_phone_DE_ortsname_04741_tl} {Nordholz~bei~Bremerhaven}
\tl_const:cn {c_phone_DE_ortsname_04742_tl} {Dorum}
\tl_const:cn {c_phone_DE_ortsname_04743_tl} {Langen~bei~Bremerhaven}
\tl_const:cn {c_phone_DE_ortsname_04744_tl} {Loxstedt}
\tl_const:cn {c_phone_DE_ortsname_04745_tl} {Bad~Bederkesa}
\tl_const:cn {c_phone_DE_ortsname_04746_tl} {Hagen~bei~Bremerhaven}
\tl_const:cn {c_phone_DE_ortsname_04747_tl} {Beverstedt}
\tl_const:cn {c_phone_DE_ortsname_04748_tl} {Stubben~bei~Bremerhaven}
\tl_const:cn {c_phone_DE_ortsname_04749_tl} {Schiffdorf-Geestenseth}
\tl_const:cn {c_phone_DE_ortsname_04751_tl} {Otterndorf}
\tl_const:cn {c_phone_DE_ortsname_04752_tl} {Neuhaus~Oste}
\tl_const:cn {c_phone_DE_ortsname_04753_tl} {Balje}
\tl_const:cn {c_phone_DE_ortsname_04754_tl} {B\"ulkau}
\tl_const:cn {c_phone_DE_ortsname_04755_tl} {Ihlienworth}
\tl_const:cn {c_phone_DE_ortsname_04756_tl} {Odisheim}
\tl_const:cn {c_phone_DE_ortsname_04757_tl} {Wanna}
\tl_const:cn {c_phone_DE_ortsname_04758_tl} {Nordleda}
\tl_const:cn {c_phone_DE_ortsname_04761_tl} {Bremerv\"orde}
\tl_const:cn {c_phone_DE_ortsname_04762_tl} {Kutenholz}
\tl_const:cn {c_phone_DE_ortsname_04763_tl} {Gnarrenburg}
\tl_const:cn {c_phone_DE_ortsname_04764_tl} {Gnarrenburg-Klenkendorf}
\tl_const:cn {c_phone_DE_ortsname_04765_tl} {Ebersdorf~bei~Bremerv\"orde}
\tl_const:cn {c_phone_DE_ortsname_04766_tl} {Basdahl}
\tl_const:cn {c_phone_DE_ortsname_04767_tl} {Bremerv\"orde-Bevern}
\tl_const:cn {c_phone_DE_ortsname_04768_tl} {Hipstedt}
\tl_const:cn {c_phone_DE_ortsname_04769_tl} {Bremerv\"orde-Iselersheim}
\tl_const:cn {c_phone_DE_ortsname_04770_tl} {Wischhafen}
\tl_const:cn {c_phone_DE_ortsname_04771_tl} {Hemmoor}
\tl_const:cn {c_phone_DE_ortsname_04772_tl} {Oberndorf~Oste}
\tl_const:cn {c_phone_DE_ortsname_04773_tl} {Lamstedt}
\tl_const:cn {c_phone_DE_ortsname_04774_tl} {Hechthausen}
\tl_const:cn {c_phone_DE_ortsname_04775_tl} {Gro\ss enw\"orden}
\tl_const:cn {c_phone_DE_ortsname_04776_tl} {Osten-Altendorf}
\tl_const:cn {c_phone_DE_ortsname_04777_tl} {Cadenberge}
\tl_const:cn {c_phone_DE_ortsname_04778_tl} {Wingst}
\tl_const:cn {c_phone_DE_ortsname_04779_tl} {Freiburg~Elbe}
\tl_const:cn {c_phone_DE_ortsname_04791_tl} {Osterholz-Scharmbeck}
\tl_const:cn {c_phone_DE_ortsname_04792_tl} {Worpswede}
\tl_const:cn {c_phone_DE_ortsname_04793_tl} {Hambergen}
\tl_const:cn {c_phone_DE_ortsname_04794_tl} {Worpswede-Ostersode}
\tl_const:cn {c_phone_DE_ortsname_04795_tl} {Garlstedt}
\tl_const:cn {c_phone_DE_ortsname_04796_tl} {Teufelsmoor}
\tl_const:cn {c_phone_DE_ortsname_04802_tl} {Wrohm}
\tl_const:cn {c_phone_DE_ortsname_04803_tl} {Pahlen}
\tl_const:cn {c_phone_DE_ortsname_04804_tl} {Nordhastedt}
\tl_const:cn {c_phone_DE_ortsname_04805_tl} {Schafstedt}
\tl_const:cn {c_phone_DE_ortsname_04806_tl} {Sarzb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_0481_tl} {Heide~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04821_tl} {Itzehoe}
\tl_const:cn {c_phone_DE_ortsname_04822_tl} {Kellinghusen}
\tl_const:cn {c_phone_DE_ortsname_04823_tl} {Wilster}
\tl_const:cn {c_phone_DE_ortsname_04824_tl} {Krempe}
\tl_const:cn {c_phone_DE_ortsname_04825_tl} {Burg~Dithmarschen}
\tl_const:cn {c_phone_DE_ortsname_04826_tl} {Hohenlockstedt}
\tl_const:cn {c_phone_DE_ortsname_04827_tl} {Wacken}
\tl_const:cn {c_phone_DE_ortsname_04828_tl} {L\"agerdorf}
\tl_const:cn {c_phone_DE_ortsname_04829_tl} {Wewelsfleth}
\tl_const:cn {c_phone_DE_ortsname_04830_tl} {S\"uderhastedt}
\tl_const:cn {c_phone_DE_ortsname_04832_tl} {Meldorf}
\tl_const:cn {c_phone_DE_ortsname_04833_tl} {Wesselburen}
\tl_const:cn {c_phone_DE_ortsname_04834_tl} {B\"usum}
\tl_const:cn {c_phone_DE_ortsname_04835_tl} {Albersdorf~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04836_tl} {Hennstedt~Dithmarschen}
\tl_const:cn {c_phone_DE_ortsname_04837_tl} {Neuenkirchen~Dithmarschen}
\tl_const:cn {c_phone_DE_ortsname_04838_tl} {Tellingstedt}
\tl_const:cn {c_phone_DE_ortsname_04839_tl} {W\"ohrden~Dithmarschen}
\tl_const:cn {c_phone_DE_ortsname_04841_tl} {Husum~Nordsee}
\tl_const:cn {c_phone_DE_ortsname_04842_tl} {Nordstrand}
\tl_const:cn {c_phone_DE_ortsname_04843_tl} {Vi\"ol}
\tl_const:cn {c_phone_DE_ortsname_04844_tl} {Pellworm}
\tl_const:cn {c_phone_DE_ortsname_04845_tl} {Ostenfeld~Husum}
\tl_const:cn {c_phone_DE_ortsname_04846_tl} {Hattstedt}
\tl_const:cn {c_phone_DE_ortsname_04847_tl} {Oster-Ohrstedt}
\tl_const:cn {c_phone_DE_ortsname_04848_tl} {Rantrum}
\tl_const:cn {c_phone_DE_ortsname_04849_tl} {Hooge}
\tl_const:cn {c_phone_DE_ortsname_04851_tl} {Marne}
\tl_const:cn {c_phone_DE_ortsname_04852_tl} {Brunsb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_04853_tl} {Sankt~Michaelisdonn}
\tl_const:cn {c_phone_DE_ortsname_04854_tl} {Friedrichskoog}
\tl_const:cn {c_phone_DE_ortsname_04855_tl} {Eddelak}
\tl_const:cn {c_phone_DE_ortsname_04856_tl} {Kronprinzenkoog}
\tl_const:cn {c_phone_DE_ortsname_04857_tl} {Barlt}
\tl_const:cn {c_phone_DE_ortsname_04858_tl} {Sankt~Margarethen~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04859_tl} {Windbergen}
\tl_const:cn {c_phone_DE_ortsname_04861_tl} {T\"onning}
\tl_const:cn {c_phone_DE_ortsname_04862_tl} {Garding}
\tl_const:cn {c_phone_DE_ortsname_04863_tl} {Sankt~Peter-Ording}
\tl_const:cn {c_phone_DE_ortsname_04864_tl} {Oldenswort}
\tl_const:cn {c_phone_DE_ortsname_04865_tl} {Osterhever}
\tl_const:cn {c_phone_DE_ortsname_04871_tl} {Hohenwestedt}
\tl_const:cn {c_phone_DE_ortsname_04872_tl} {Hanerau-Hademarschen}
\tl_const:cn {c_phone_DE_ortsname_04873_tl} {Aukrug}
\tl_const:cn {c_phone_DE_ortsname_04874_tl} {Todenb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_04875_tl} {Stafstedt}
\tl_const:cn {c_phone_DE_ortsname_04876_tl} {Reher~Holstein}
\tl_const:cn {c_phone_DE_ortsname_04877_tl} {Hennstedt~bei~Itzehoe}
\tl_const:cn {c_phone_DE_ortsname_04881_tl} {Friedrichstadt}
\tl_const:cn {c_phone_DE_ortsname_04882_tl} {Lunden}
\tl_const:cn {c_phone_DE_ortsname_04883_tl} {S\"uderstapel}
\tl_const:cn {c_phone_DE_ortsname_04884_tl} {Schwabstedt}
\tl_const:cn {c_phone_DE_ortsname_04885_tl} {Bergenhusen}
\tl_const:cn {c_phone_DE_ortsname_04892_tl} {Schenefeld~Mittelholstein}
\tl_const:cn {c_phone_DE_ortsname_04893_tl} {Hohenaspe}
\tl_const:cn {c_phone_DE_ortsname_04902_tl} {Jemgum-Ditzum}
\tl_const:cn {c_phone_DE_ortsname_04903_tl} {Wymeer}
\tl_const:cn {c_phone_DE_ortsname_0491_tl} {Leer~Ostfriesland}
\tl_const:cn {c_phone_DE_ortsname_04920_tl} {Wirdum}
\tl_const:cn {c_phone_DE_ortsname_04921_tl} {Emden~Stadt}
\tl_const:cn {c_phone_DE_ortsname_04922_tl} {Borkum}
\tl_const:cn {c_phone_DE_ortsname_04923_tl} {Krummh\"orn-Pewsum}
\tl_const:cn {c_phone_DE_ortsname_04924_tl} {Moormerland-Oldersum}
\tl_const:cn {c_phone_DE_ortsname_04925_tl} {Hinte}
\tl_const:cn {c_phone_DE_ortsname_04926_tl} {Krummh\"orn-Greetsiel}
\tl_const:cn {c_phone_DE_ortsname_04927_tl} {Krummh\"orn-Loquard}
\tl_const:cn {c_phone_DE_ortsname_04928_tl} {Ihlow-Riepe}
\tl_const:cn {c_phone_DE_ortsname_04929_tl} {Ihlow~Kreis~Aurich}
\tl_const:cn {c_phone_DE_ortsname_04931_tl} {Norden}
\tl_const:cn {c_phone_DE_ortsname_04932_tl} {Norderney}
\tl_const:cn {c_phone_DE_ortsname_04933_tl} {Dornum~Ostfriesland}
\tl_const:cn {c_phone_DE_ortsname_04934_tl} {Marienhafe}
\tl_const:cn {c_phone_DE_ortsname_04935_tl} {Juist}
\tl_const:cn {c_phone_DE_ortsname_04936_tl} {Gro\ss heide}
\tl_const:cn {c_phone_DE_ortsname_04938_tl} {Hagermarsch}
\tl_const:cn {c_phone_DE_ortsname_04939_tl} {Baltrum}
\tl_const:cn {c_phone_DE_ortsname_04941_tl} {Aurich}
\tl_const:cn {c_phone_DE_ortsname_04942_tl} {S\"udbrookmerland}
\tl_const:cn {c_phone_DE_ortsname_04943_tl} {Gro\ss efehn}
\tl_const:cn {c_phone_DE_ortsname_04944_tl} {Wiesmoor}
\tl_const:cn {c_phone_DE_ortsname_04945_tl} {Gro\ss efehn-Timmel}
\tl_const:cn {c_phone_DE_ortsname_04946_tl} {Gro\ss efehn-Bagband}
\tl_const:cn {c_phone_DE_ortsname_04947_tl} {Aurich-Ogenbargen}
\tl_const:cn {c_phone_DE_ortsname_04948_tl} {Wiesmoor-Marcardsmoor}
\tl_const:cn {c_phone_DE_ortsname_04950_tl} {Holtland}
\tl_const:cn {c_phone_DE_ortsname_04951_tl} {Weener}
\tl_const:cn {c_phone_DE_ortsname_04952_tl} {Rhauderfehn}
\tl_const:cn {c_phone_DE_ortsname_04953_tl} {Bunde}
\tl_const:cn {c_phone_DE_ortsname_04954_tl} {Moormerland}
\tl_const:cn {c_phone_DE_ortsname_04955_tl} {Westoverledingen}
\tl_const:cn {c_phone_DE_ortsname_04956_tl} {Uplengen}
\tl_const:cn {c_phone_DE_ortsname_04957_tl} {Detern}
\tl_const:cn {c_phone_DE_ortsname_04958_tl} {Jemgum}
\tl_const:cn {c_phone_DE_ortsname_04959_tl} {Dollart}
\tl_const:cn {c_phone_DE_ortsname_04961_tl} {Papenburg}
\tl_const:cn {c_phone_DE_ortsname_04962_tl} {Papenburg-Aschendorf}
\tl_const:cn {c_phone_DE_ortsname_04963_tl} {D\"orpen}
\tl_const:cn {c_phone_DE_ortsname_04964_tl} {Rhede~Ems}
\tl_const:cn {c_phone_DE_ortsname_04965_tl} {Surwold}
\tl_const:cn {c_phone_DE_ortsname_04966_tl} {Neub\"orger}
\tl_const:cn {c_phone_DE_ortsname_04967_tl} {Rhauderfehn-Burlage}
\tl_const:cn {c_phone_DE_ortsname_04968_tl} {Neulehe}
\tl_const:cn {c_phone_DE_ortsname_04971_tl} {Esens}
\tl_const:cn {c_phone_DE_ortsname_04972_tl} {Langeoog}
\tl_const:cn {c_phone_DE_ortsname_04973_tl} {Wittmund-Burhafe}
\tl_const:cn {c_phone_DE_ortsname_04974_tl} {Neuharlingersiel}
\tl_const:cn {c_phone_DE_ortsname_04975_tl} {Westerholt~Ostfriesland}
\tl_const:cn {c_phone_DE_ortsname_04976_tl} {Spiekeroog}
\tl_const:cn {c_phone_DE_ortsname_04977_tl} {Blomberg~Ostfriesland}
\tl_const:cn {c_phone_DE_ortsname_05021_tl} {Nienburg~Weser}
\tl_const:cn {c_phone_DE_ortsname_05022_tl} {Wietzen}
\tl_const:cn {c_phone_DE_ortsname_05023_tl} {Liebenau~Kreis~Nienburg~Weser}
\tl_const:cn {c_phone_DE_ortsname_05024_tl} {Rohrsen~Kreis~Nienburg~Weser}
\tl_const:cn {c_phone_DE_ortsname_05025_tl} {Estorf~Weser}
\tl_const:cn {c_phone_DE_ortsname_05026_tl} {Steimbke}
\tl_const:cn {c_phone_DE_ortsname_05027_tl} {Linsburg}
\tl_const:cn {c_phone_DE_ortsname_05028_tl} {Pennigsehl}
\tl_const:cn {c_phone_DE_ortsname_05031_tl} {Wunstorf}
\tl_const:cn {c_phone_DE_ortsname_05032_tl} {Neustadt~am~R\"ubenberge}
\tl_const:cn {c_phone_DE_ortsname_05033_tl} {Wunstorf-Gro\ss enheidorn}
\tl_const:cn {c_phone_DE_ortsname_05034_tl} {Neustadt-Hagen}
\tl_const:cn {c_phone_DE_ortsname_05035_tl} {Gro\ss\ Munzel}
\tl_const:cn {c_phone_DE_ortsname_05036_tl} {Neustadt-Schneeren}
\tl_const:cn {c_phone_DE_ortsname_05037_tl} {Bad~Rehburg}
\tl_const:cn {c_phone_DE_ortsname_05041_tl} {Springe~Deister}
\tl_const:cn {c_phone_DE_ortsname_05042_tl} {Bad~M\"under~am~Deister}
\tl_const:cn {c_phone_DE_ortsname_05043_tl} {Lauenau}
\tl_const:cn {c_phone_DE_ortsname_05044_tl} {Springe-Eldagsen}
\tl_const:cn {c_phone_DE_ortsname_05045_tl} {Springe-Bennigsen}
\tl_const:cn {c_phone_DE_ortsname_05051_tl} {Bergen~Kreis~Celle}
\tl_const:cn {c_phone_DE_ortsname_05052_tl} {Hermannsburg}
\tl_const:cn {c_phone_DE_ortsname_05053_tl} {Fa\ss berg-M\"uden}
\tl_const:cn {c_phone_DE_ortsname_05054_tl} {Bergen-S\"ulze}
\tl_const:cn {c_phone_DE_ortsname_05055_tl} {Fa\ss berg}
\tl_const:cn {c_phone_DE_ortsname_05056_tl} {Winsen-Mei\ss endorf}
\tl_const:cn {c_phone_DE_ortsname_05060_tl} {Bodenburg}
\tl_const:cn {c_phone_DE_ortsname_05062_tl} {Holle~bei~Hildesheim}
\tl_const:cn {c_phone_DE_ortsname_05063_tl} {Bad~Salzdetfurth}
\tl_const:cn {c_phone_DE_ortsname_05064_tl} {Gro\ss\ D\"ungen}
\tl_const:cn {c_phone_DE_ortsname_05065_tl} {Sibbesse}
\tl_const:cn {c_phone_DE_ortsname_05066_tl} {Sarstedt}
\tl_const:cn {c_phone_DE_ortsname_05067_tl} {Bockenem}
\tl_const:cn {c_phone_DE_ortsname_05068_tl} {Elze~Leine}
\tl_const:cn {c_phone_DE_ortsname_05069_tl} {Nordstemmen}
\tl_const:cn {c_phone_DE_ortsname_05071_tl} {Schwarmstedt}
\tl_const:cn {c_phone_DE_ortsname_05072_tl} {Neustadt-Mandelsloh}
\tl_const:cn {c_phone_DE_ortsname_05073_tl} {Neustadt-Esperke}
\tl_const:cn {c_phone_DE_ortsname_05074_tl} {Rodewald}
\tl_const:cn {c_phone_DE_ortsname_05082_tl} {Langlingen}
\tl_const:cn {c_phone_DE_ortsname_05083_tl} {Hohne~bei~Celle}
\tl_const:cn {c_phone_DE_ortsname_05084_tl} {Hamb\"uhren}
\tl_const:cn {c_phone_DE_ortsname_05085_tl} {Burgdorf-Ehlershausen}
\tl_const:cn {c_phone_DE_ortsname_05086_tl} {Celle-Scheuen}
\tl_const:cn {c_phone_DE_ortsname_05101_tl} {Pattensen}
\tl_const:cn {c_phone_DE_ortsname_05102_tl} {Laatzen}
\tl_const:cn {c_phone_DE_ortsname_05103_tl} {Wennigsen~Deister}
\tl_const:cn {c_phone_DE_ortsname_05105_tl} {Barsinghausen}
\tl_const:cn {c_phone_DE_ortsname_05108_tl} {Gehrden~Hannover}
\tl_const:cn {c_phone_DE_ortsname_05109_tl} {Ronnenberg}
\tl_const:cn {c_phone_DE_ortsname_0511_tl} {Hannover}
\tl_const:cn {c_phone_DE_ortsname_05121_tl} {Hildesheim}
\tl_const:cn {c_phone_DE_ortsname_05123_tl} {Schellerten}
\tl_const:cn {c_phone_DE_ortsname_05126_tl} {Algermissen}
\tl_const:cn {c_phone_DE_ortsname_05127_tl} {Harsum}
\tl_const:cn {c_phone_DE_ortsname_05128_tl} {Hohenhameln}
\tl_const:cn {c_phone_DE_ortsname_05129_tl} {S\"ohlde}
\tl_const:cn {c_phone_DE_ortsname_05130_tl} {Wedemark}
\tl_const:cn {c_phone_DE_ortsname_05131_tl} {Garbsen}
\tl_const:cn {c_phone_DE_ortsname_05132_tl} {Lehrte}
\tl_const:cn {c_phone_DE_ortsname_05135_tl} {Burgwedel-Fuhrberg}
\tl_const:cn {c_phone_DE_ortsname_05136_tl} {Burgdorf~Kreis~Hannover}
\tl_const:cn {c_phone_DE_ortsname_05137_tl} {Seelze}
\tl_const:cn {c_phone_DE_ortsname_05138_tl} {Sehnde}
\tl_const:cn {c_phone_DE_ortsname_05139_tl} {Burgwedel}
\tl_const:cn {c_phone_DE_ortsname_05141_tl} {Celle}
\tl_const:cn {c_phone_DE_ortsname_05142_tl} {Eschede}
\tl_const:cn {c_phone_DE_ortsname_05143_tl} {Winsen~Aller}
\tl_const:cn {c_phone_DE_ortsname_05144_tl} {Wathlingen}
\tl_const:cn {c_phone_DE_ortsname_05145_tl} {Beedenbostel}
\tl_const:cn {c_phone_DE_ortsname_05146_tl} {Wietze}
\tl_const:cn {c_phone_DE_ortsname_05147_tl} {Uetze-H\"anigsen}
\tl_const:cn {c_phone_DE_ortsname_05148_tl} {Steinhorst~Niedersachsen}
\tl_const:cn {c_phone_DE_ortsname_05149_tl} {Wienhausen}
\tl_const:cn {c_phone_DE_ortsname_05151_tl} {Hameln}
\tl_const:cn {c_phone_DE_ortsname_05152_tl} {Hessisch~Oldendorf}
\tl_const:cn {c_phone_DE_ortsname_05153_tl} {Salzhemmendorf}
\tl_const:cn {c_phone_DE_ortsname_05154_tl} {Aerzen}
\tl_const:cn {c_phone_DE_ortsname_05155_tl} {Emmerthal}
\tl_const:cn {c_phone_DE_ortsname_05156_tl} {Coppenbr\"ugge}
\tl_const:cn {c_phone_DE_ortsname_05157_tl} {Emmerthal-B\"orry}
\tl_const:cn {c_phone_DE_ortsname_05158_tl} {Hemeringen}
\tl_const:cn {c_phone_DE_ortsname_05159_tl} {Coppenbr\"ugge-Bisperode}
\tl_const:cn {c_phone_DE_ortsname_05161_tl} {Walsrode}
\tl_const:cn {c_phone_DE_ortsname_05162_tl} {Fallingbostel}
\tl_const:cn {c_phone_DE_ortsname_05163_tl} {Fallingbostel-Dorfmark}
\tl_const:cn {c_phone_DE_ortsname_05164_tl} {Hodenhagen}
\tl_const:cn {c_phone_DE_ortsname_05165_tl} {Rethem~Aller}
\tl_const:cn {c_phone_DE_ortsname_05166_tl} {Walsrode-Kirchboitzen}
\tl_const:cn {c_phone_DE_ortsname_05167_tl} {Walsrode-Westenholz}
\tl_const:cn {c_phone_DE_ortsname_05168_tl} {Walsrode-Stellichte}
\tl_const:cn {c_phone_DE_ortsname_05171_tl} {Peine}
\tl_const:cn {c_phone_DE_ortsname_05172_tl} {Ilsede}
\tl_const:cn {c_phone_DE_ortsname_05173_tl} {Uetze}
\tl_const:cn {c_phone_DE_ortsname_05174_tl} {Lahstedt}
\tl_const:cn {c_phone_DE_ortsname_05175_tl} {Lehrte-Arpke}
\tl_const:cn {c_phone_DE_ortsname_05176_tl} {Edemissen}
\tl_const:cn {c_phone_DE_ortsname_05177_tl} {Edemissen-Abbensen}
\tl_const:cn {c_phone_DE_ortsname_05181_tl} {Alfeld~Leine}
\tl_const:cn {c_phone_DE_ortsname_05182_tl} {Gronau~Leine}
\tl_const:cn {c_phone_DE_ortsname_05183_tl} {Lamspringe}
\tl_const:cn {c_phone_DE_ortsname_05184_tl} {Freden~Leine}
\tl_const:cn {c_phone_DE_ortsname_05185_tl} {Duingen}
\tl_const:cn {c_phone_DE_ortsname_05186_tl} {Salzhemmendorf-Wallensen}
\tl_const:cn {c_phone_DE_ortsname_05187_tl} {Delligsen}
\tl_const:cn {c_phone_DE_ortsname_05190_tl} {Soltau-Emmingen}
\tl_const:cn {c_phone_DE_ortsname_05191_tl} {Soltau}
\tl_const:cn {c_phone_DE_ortsname_05192_tl} {Munster}
\tl_const:cn {c_phone_DE_ortsname_05193_tl} {Schneverdingen}
\tl_const:cn {c_phone_DE_ortsname_05194_tl} {Bispingen}
\tl_const:cn {c_phone_DE_ortsname_05195_tl} {Neuenkirchen~bei~Soltau}
\tl_const:cn {c_phone_DE_ortsname_05196_tl} {Wietzendorf}
\tl_const:cn {c_phone_DE_ortsname_05197_tl} {Soltau-Frielingen}
\tl_const:cn {c_phone_DE_ortsname_05198_tl} {Schneverdingen-Wintermoor}
\tl_const:cn {c_phone_DE_ortsname_05199_tl} {Schneverdingen-Heber}
\tl_const:cn {c_phone_DE_ortsname_05201_tl} {Halle~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05202_tl} {Oerlinghausen}
\tl_const:cn {c_phone_DE_ortsname_05203_tl} {Werther~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05204_tl} {Steinhagen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05205_tl} {Bielefeld-Sennestadt}
\tl_const:cn {c_phone_DE_ortsname_05206_tl} {Bielefeld-J\"ollenbeck}
\tl_const:cn {c_phone_DE_ortsname_05207_tl} {Schlo\ss\ Holte-Stukenbrock}
\tl_const:cn {c_phone_DE_ortsname_05208_tl} {Leopoldsh\"ohe}
\tl_const:cn {c_phone_DE_ortsname_05209_tl} {G\"utersloh-Friedrichsdorf}
\tl_const:cn {c_phone_DE_ortsname_0521_tl} {Bielefeld}
\tl_const:cn {c_phone_DE_ortsname_05221_tl} {Herford}
\tl_const:cn {c_phone_DE_ortsname_05222_tl} {Bad~Salzuflen}
\tl_const:cn {c_phone_DE_ortsname_05223_tl} {B\"unde}
\tl_const:cn {c_phone_DE_ortsname_05224_tl} {Enger~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05225_tl} {Spenge}
\tl_const:cn {c_phone_DE_ortsname_05226_tl} {Bruchm\"uhlen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05228_tl} {Vlotho-Exter}
\tl_const:cn {c_phone_DE_ortsname_05231_tl} {Detmold}
\tl_const:cn {c_phone_DE_ortsname_05232_tl} {Lage~Lippe}
\tl_const:cn {c_phone_DE_ortsname_05233_tl} {Steinheim~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05234_tl} {Horn-Bad~Meinberg}
\tl_const:cn {c_phone_DE_ortsname_05235_tl} {Blomberg~Lippe}
\tl_const:cn {c_phone_DE_ortsname_05236_tl} {Blomberg-Gro\ss enmarpe}
\tl_const:cn {c_phone_DE_ortsname_05237_tl} {Augustdorf}
\tl_const:cn {c_phone_DE_ortsname_05238_tl} {Nieheim-Himmighausen}
\tl_const:cn {c_phone_DE_ortsname_05241_tl} {G\"utersloh}
\tl_const:cn {c_phone_DE_ortsname_05242_tl} {Rheda-Wiedenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05244_tl} {Rietberg}
\tl_const:cn {c_phone_DE_ortsname_05245_tl} {Herzebrock-Clarholz}
\tl_const:cn {c_phone_DE_ortsname_05246_tl} {Verl}
\tl_const:cn {c_phone_DE_ortsname_05247_tl} {Harsewinkel}
\tl_const:cn {c_phone_DE_ortsname_05248_tl} {Langenberg~Kreis~G\"utersloh}
\tl_const:cn {c_phone_DE_ortsname_05250_tl} {Delbr\"uck~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05251_tl} {Paderborn}
\tl_const:cn {c_phone_DE_ortsname_05252_tl} {Bad~Lippspringe}
\tl_const:cn {c_phone_DE_ortsname_05253_tl} {Bad~Driburg}
\tl_const:cn {c_phone_DE_ortsname_05254_tl} {Paderborn-Schlo\ss\ Neuhaus}
\tl_const:cn {c_phone_DE_ortsname_05255_tl} {Altenbeken}
\tl_const:cn {c_phone_DE_ortsname_05257_tl} {H\"ovelhof}
\tl_const:cn {c_phone_DE_ortsname_05258_tl} {Salzkotten}
\tl_const:cn {c_phone_DE_ortsname_05259_tl} {Bad~Driburg-Neuenheerse}
\tl_const:cn {c_phone_DE_ortsname_05261_tl} {Lemgo}
\tl_const:cn {c_phone_DE_ortsname_05262_tl} {Extertal}
\tl_const:cn {c_phone_DE_ortsname_05263_tl} {Barntrup}
\tl_const:cn {c_phone_DE_ortsname_05264_tl} {Kalletal}
\tl_const:cn {c_phone_DE_ortsname_05265_tl} {D\"orentrup}
\tl_const:cn {c_phone_DE_ortsname_05266_tl} {Lemgo-Kirchheide}
\tl_const:cn {c_phone_DE_ortsname_05271_tl} {H\"oxter}
\tl_const:cn {c_phone_DE_ortsname_05272_tl} {Brakel~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05273_tl} {Beverungen}
\tl_const:cn {c_phone_DE_ortsname_05274_tl} {Nieheim}
\tl_const:cn {c_phone_DE_ortsname_05275_tl} {H\"oxter-Ottbergen}
\tl_const:cn {c_phone_DE_ortsname_05276_tl} {Marienm\"unster}
\tl_const:cn {c_phone_DE_ortsname_05277_tl} {H\"oxter-F\"urstenau}
\tl_const:cn {c_phone_DE_ortsname_05278_tl} {H\"oxter-Ovenhausen}
\tl_const:cn {c_phone_DE_ortsname_05281_tl} {Bad~Pyrmont}
\tl_const:cn {c_phone_DE_ortsname_05282_tl} {Schieder-Schwalenberg}
\tl_const:cn {c_phone_DE_ortsname_05283_tl} {L\"ugde-Rischenau}
\tl_const:cn {c_phone_DE_ortsname_05284_tl} {Schwalenberg}
\tl_const:cn {c_phone_DE_ortsname_05285_tl} {Bad~Pyrmont-Kleinenberg}
\tl_const:cn {c_phone_DE_ortsname_05286_tl} {Ottenstein~Niedersachsen}
\tl_const:cn {c_phone_DE_ortsname_05292_tl} {Lichtenau-Atteln}
\tl_const:cn {c_phone_DE_ortsname_05293_tl} {Paderborn-Dahl}
\tl_const:cn {c_phone_DE_ortsname_05294_tl} {H\"ovelhof-Espeln}
\tl_const:cn {c_phone_DE_ortsname_05295_tl} {Lichtenau~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05300_tl} {Salzgitter-\"Ufingen}
\tl_const:cn {c_phone_DE_ortsname_05301_tl} {Lehre-Essenrode}
\tl_const:cn {c_phone_DE_ortsname_05302_tl} {Vechelde}
\tl_const:cn {c_phone_DE_ortsname_05303_tl} {Wendeburg}
\tl_const:cn {c_phone_DE_ortsname_05304_tl} {Meine}
\tl_const:cn {c_phone_DE_ortsname_05305_tl} {Sickte}
\tl_const:cn {c_phone_DE_ortsname_05306_tl} {Cremlingen}
\tl_const:cn {c_phone_DE_ortsname_05307_tl} {Braunschweig-Wenden}
\tl_const:cn {c_phone_DE_ortsname_05308_tl} {Lehre}
\tl_const:cn {c_phone_DE_ortsname_05309_tl} {Lehre-Wendhausen}
\tl_const:cn {c_phone_DE_ortsname_0531_tl} {Braunschweig}
\tl_const:cn {c_phone_DE_ortsname_05320_tl} {Torfhaus}
\tl_const:cn {c_phone_DE_ortsname_05321_tl} {Goslar}
\tl_const:cn {c_phone_DE_ortsname_05322_tl} {Bad~Harzburg}
\tl_const:cn {c_phone_DE_ortsname_05323_tl} {Clausthal-Zellerfeld}
\tl_const:cn {c_phone_DE_ortsname_05324_tl} {Vienenburg}
\tl_const:cn {c_phone_DE_ortsname_05325_tl} {Goslar-Hahnenklee}
\tl_const:cn {c_phone_DE_ortsname_05326_tl} {Langelsheim}
\tl_const:cn {c_phone_DE_ortsname_05327_tl} {Bad~Grund~Harz}
\tl_const:cn {c_phone_DE_ortsname_05328_tl} {Altenau~Harz}
\tl_const:cn {c_phone_DE_ortsname_05329_tl} {Schulenberg~im~Oberharz}
\tl_const:cn {c_phone_DE_ortsname_05331_tl} {Wolfenb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_05332_tl} {Sch\"oppenstedt}
\tl_const:cn {c_phone_DE_ortsname_05333_tl} {Dettum}
\tl_const:cn {c_phone_DE_ortsname_05334_tl} {Hornburg~Kreis~Wolfenb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_05335_tl} {Schladen}
\tl_const:cn {c_phone_DE_ortsname_05336_tl} {Semmenstedt}
\tl_const:cn {c_phone_DE_ortsname_05337_tl} {Kissenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05339_tl} {Gielde}
\tl_const:cn {c_phone_DE_ortsname_05341_tl} {Salzgitter}
\tl_const:cn {c_phone_DE_ortsname_05344_tl} {Lengede}
\tl_const:cn {c_phone_DE_ortsname_05345_tl} {Baddeckenstedt}
\tl_const:cn {c_phone_DE_ortsname_05346_tl} {Liebenburg}
\tl_const:cn {c_phone_DE_ortsname_05347_tl} {Burgdorf~bei~Salzgitter}
\tl_const:cn {c_phone_DE_ortsname_05351_tl} {Helmstedt}
\tl_const:cn {c_phone_DE_ortsname_05352_tl} {Sch\"oningen}
\tl_const:cn {c_phone_DE_ortsname_05353_tl} {K\"onigslutter~am~Elm}
\tl_const:cn {c_phone_DE_ortsname_05354_tl} {Jerxheim}
\tl_const:cn {c_phone_DE_ortsname_05355_tl} {Frellstedt}
\tl_const:cn {c_phone_DE_ortsname_05356_tl} {Helmstedt-Barmke}
\tl_const:cn {c_phone_DE_ortsname_05357_tl} {Grasleben}
\tl_const:cn {c_phone_DE_ortsname_05358_tl} {Bahrdorf-Mackendorf}
\tl_const:cn {c_phone_DE_ortsname_05361_tl} {Wolfsburg}
\tl_const:cn {c_phone_DE_ortsname_05362_tl} {Wolfsburg-Fallersleben}
\tl_const:cn {c_phone_DE_ortsname_05363_tl} {Wolfsburg-Vorsfelde}
\tl_const:cn {c_phone_DE_ortsname_05364_tl} {Velpke}
\tl_const:cn {c_phone_DE_ortsname_05365_tl} {Wolfsburg-Neindorf}
\tl_const:cn {c_phone_DE_ortsname_05366_tl} {Jembke}
\tl_const:cn {c_phone_DE_ortsname_05367_tl} {R\"uhen}
\tl_const:cn {c_phone_DE_ortsname_05368_tl} {Parsau}
\tl_const:cn {c_phone_DE_ortsname_05371_tl} {Gifhorn}
\tl_const:cn {c_phone_DE_ortsname_05372_tl} {Meinersen}
\tl_const:cn {c_phone_DE_ortsname_05373_tl} {Hillerse~Kreis~Gifhorn}
\tl_const:cn {c_phone_DE_ortsname_05374_tl} {Isenb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_05375_tl} {M\"uden~Aller}
\tl_const:cn {c_phone_DE_ortsname_05376_tl} {Wesendorf~Kreis~Gifhorn}
\tl_const:cn {c_phone_DE_ortsname_05377_tl} {Ehra-Lessien}
\tl_const:cn {c_phone_DE_ortsname_05378_tl} {Sassenburg-Platendorf}
\tl_const:cn {c_phone_DE_ortsname_05379_tl} {Sassenburg-Gru\ss endorf}
\tl_const:cn {c_phone_DE_ortsname_05381_tl} {Seesen}
\tl_const:cn {c_phone_DE_ortsname_05382_tl} {Bad~Gandersheim}
\tl_const:cn {c_phone_DE_ortsname_05383_tl} {Lutter~am~Barenberge}
\tl_const:cn {c_phone_DE_ortsname_05384_tl} {Seesen-Gro\ss\ Rh\"uden}
\tl_const:cn {c_phone_DE_ortsname_05401_tl} {Georgsmarienh\"utte}
\tl_const:cn {c_phone_DE_ortsname_05402_tl} {Bissendorf~Kreis~Osnabr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05403_tl} {Bad~Iburg}
\tl_const:cn {c_phone_DE_ortsname_05404_tl} {Westerkappeln}
\tl_const:cn {c_phone_DE_ortsname_05405_tl} {Hasbergen~Kreis~Osnabr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05406_tl} {Belm}
\tl_const:cn {c_phone_DE_ortsname_05407_tl} {Wallenhorst}
\tl_const:cn {c_phone_DE_ortsname_05409_tl} {Hilter~am~Teutoburger~Wald}
\tl_const:cn {c_phone_DE_ortsname_0541_tl} {Osnabr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05421_tl} {Dissen~am~Teutoburger~Wald}
\tl_const:cn {c_phone_DE_ortsname_05422_tl} {Melle}
\tl_const:cn {c_phone_DE_ortsname_05423_tl} {Versmold}
\tl_const:cn {c_phone_DE_ortsname_05424_tl} {Bad~Rothenfelde}
\tl_const:cn {c_phone_DE_ortsname_05425_tl} {Borgholzhausen}
\tl_const:cn {c_phone_DE_ortsname_05426_tl} {Glandorf}
\tl_const:cn {c_phone_DE_ortsname_05427_tl} {Melle-Buer}
\tl_const:cn {c_phone_DE_ortsname_05428_tl} {Melle-Neuenkirchen}
\tl_const:cn {c_phone_DE_ortsname_05429_tl} {Melle-Wellingholzhausen}
\tl_const:cn {c_phone_DE_ortsname_05431_tl} {Quakenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05432_tl} {L\"oningen}
\tl_const:cn {c_phone_DE_ortsname_05433_tl} {Badbergen}
\tl_const:cn {c_phone_DE_ortsname_05434_tl} {Essen~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_05435_tl} {Berge~bei~Quakenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05436_tl} {Nortrup}
\tl_const:cn {c_phone_DE_ortsname_05437_tl} {Menslage}
\tl_const:cn {c_phone_DE_ortsname_05438_tl} {Bakum-L\"usche}
\tl_const:cn {c_phone_DE_ortsname_05439_tl} {Bersenbr\"uck}
\tl_const:cn {c_phone_DE_ortsname_05441_tl} {Diepholz}
\tl_const:cn {c_phone_DE_ortsname_05442_tl} {Barnstorf~Kreis~Diepholz}
\tl_const:cn {c_phone_DE_ortsname_05443_tl} {Lemf\"orde}
\tl_const:cn {c_phone_DE_ortsname_05444_tl} {Wagenfeld}
\tl_const:cn {c_phone_DE_ortsname_05445_tl} {Drebber}
\tl_const:cn {c_phone_DE_ortsname_05446_tl} {Rehden}
\tl_const:cn {c_phone_DE_ortsname_05447_tl} {Lembruch}
\tl_const:cn {c_phone_DE_ortsname_05448_tl} {Barver}
\tl_const:cn {c_phone_DE_ortsname_05451_tl} {Ibbenb\"uren}
\tl_const:cn {c_phone_DE_ortsname_05452_tl} {Mettingen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05453_tl} {Recke}
\tl_const:cn {c_phone_DE_ortsname_05454_tl} {H\"orstel-Riesenbeck}
\tl_const:cn {c_phone_DE_ortsname_05455_tl} {Tecklenburg-Brochterbeck}
\tl_const:cn {c_phone_DE_ortsname_05456_tl} {Westerkappeln-Velpe}
\tl_const:cn {c_phone_DE_ortsname_05457_tl} {Hopsten-Schale}
\tl_const:cn {c_phone_DE_ortsname_05458_tl} {Hopsten}
\tl_const:cn {c_phone_DE_ortsname_05459_tl} {H\"orstel}
\tl_const:cn {c_phone_DE_ortsname_05461_tl} {Bramsche~Hase}
\tl_const:cn {c_phone_DE_ortsname_05462_tl} {Ankum}
\tl_const:cn {c_phone_DE_ortsname_05464_tl} {Alfhausen}
\tl_const:cn {c_phone_DE_ortsname_05465_tl} {Neuenkirchen~bei~Bramsche}
\tl_const:cn {c_phone_DE_ortsname_05466_tl} {Merzen}
\tl_const:cn {c_phone_DE_ortsname_05467_tl} {Voltlage}
\tl_const:cn {c_phone_DE_ortsname_05468_tl} {Bramsche-Engter}
\tl_const:cn {c_phone_DE_ortsname_05471_tl} {Bohmte}
\tl_const:cn {c_phone_DE_ortsname_05472_tl} {Bad~Essen}
\tl_const:cn {c_phone_DE_ortsname_05473_tl} {Ostercappeln}
\tl_const:cn {c_phone_DE_ortsname_05474_tl} {Stemwede-Dielingen}
\tl_const:cn {c_phone_DE_ortsname_05475_tl} {Bohmte-Hunteburg}
\tl_const:cn {c_phone_DE_ortsname_05476_tl} {Ostercappeln-Venne}
\tl_const:cn {c_phone_DE_ortsname_05481_tl} {Lengerich~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05482_tl} {Tecklenburg}
\tl_const:cn {c_phone_DE_ortsname_05483_tl} {Lienen}
\tl_const:cn {c_phone_DE_ortsname_05484_tl} {Lienen-Kattenvenne}
\tl_const:cn {c_phone_DE_ortsname_05485_tl} {Ladbergen}
\tl_const:cn {c_phone_DE_ortsname_05491_tl} {Damme~D\"ummer}
\tl_const:cn {c_phone_DE_ortsname_05492_tl} {Steinfeld~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_05493_tl} {Neuenkirchen~Kreis~Vechta}
\tl_const:cn {c_phone_DE_ortsname_05494_tl} {Holdorf~Niedersachsen}
\tl_const:cn {c_phone_DE_ortsname_05495_tl} {V\"orden~Kreis~Vechta}
\tl_const:cn {c_phone_DE_ortsname_05502_tl} {Dransfeld}
\tl_const:cn {c_phone_DE_ortsname_05503_tl} {N\"orten-Hardenberg}
\tl_const:cn {c_phone_DE_ortsname_05504_tl} {Friedland~Kreis~G\"ottingen}
\tl_const:cn {c_phone_DE_ortsname_05505_tl} {Hardegsen}
\tl_const:cn {c_phone_DE_ortsname_05506_tl} {Adelebsen}
\tl_const:cn {c_phone_DE_ortsname_05507_tl} {Eberg\"otzen}
\tl_const:cn {c_phone_DE_ortsname_05508_tl} {Gleichen-Rittmarshausen}
\tl_const:cn {c_phone_DE_ortsname_05509_tl} {Rosdorf~Kreis~G\"ottingen}
\tl_const:cn {c_phone_DE_ortsname_0551_tl} {G\"ottingen}
\tl_const:cn {c_phone_DE_ortsname_05520_tl} {Braunlage}
\tl_const:cn {c_phone_DE_ortsname_05521_tl} {Herzberg~am~Harz}
\tl_const:cn {c_phone_DE_ortsname_05522_tl} {Osterode~am~Harz}
\tl_const:cn {c_phone_DE_ortsname_05523_tl} {Bad~Sachsa}
\tl_const:cn {c_phone_DE_ortsname_05524_tl} {Bad~Lauterberg~im~Harz}
\tl_const:cn {c_phone_DE_ortsname_05525_tl} {Walkenried}
\tl_const:cn {c_phone_DE_ortsname_05527_tl} {Duderstadt}
\tl_const:cn {c_phone_DE_ortsname_05528_tl} {Gieboldehausen}
\tl_const:cn {c_phone_DE_ortsname_05529_tl} {Rhumspringe}
\tl_const:cn {c_phone_DE_ortsname_05531_tl} {Holzminden}
\tl_const:cn {c_phone_DE_ortsname_05532_tl} {Stadtoldendorf}
\tl_const:cn {c_phone_DE_ortsname_05533_tl} {Bodenwerder}
\tl_const:cn {c_phone_DE_ortsname_05534_tl} {Eschershausen~an~der~Lenne}
\tl_const:cn {c_phone_DE_ortsname_05535_tl} {Polle}
\tl_const:cn {c_phone_DE_ortsname_05536_tl} {Holzminden-Neuhaus}
\tl_const:cn {c_phone_DE_ortsname_05541_tl} {Hann.\ M\"unden}
\tl_const:cn {c_phone_DE_ortsname_05542_tl} {Witzenhausen}
\tl_const:cn {c_phone_DE_ortsname_05543_tl} {Staufenberg~Niedersachsen}
\tl_const:cn {c_phone_DE_ortsname_05544_tl} {Reinhardshagen}
\tl_const:cn {c_phone_DE_ortsname_05545_tl} {Hedem\"unden}
\tl_const:cn {c_phone_DE_ortsname_05546_tl} {Scheden}
\tl_const:cn {c_phone_DE_ortsname_05551_tl} {Northeim}
\tl_const:cn {c_phone_DE_ortsname_05552_tl} {Katlenburg}
\tl_const:cn {c_phone_DE_ortsname_05553_tl} {Kalefeld}
\tl_const:cn {c_phone_DE_ortsname_05554_tl} {Moringen}
\tl_const:cn {c_phone_DE_ortsname_05555_tl} {Moringen-Fredelsloh}
\tl_const:cn {c_phone_DE_ortsname_05556_tl} {Lindau~Harz}
\tl_const:cn {c_phone_DE_ortsname_05561_tl} {Einbeck}
\tl_const:cn {c_phone_DE_ortsname_05562_tl} {Dassel-Markoldendorf}
\tl_const:cn {c_phone_DE_ortsname_05563_tl} {Kreiensen}
\tl_const:cn {c_phone_DE_ortsname_05564_tl} {Dassel}
\tl_const:cn {c_phone_DE_ortsname_05565_tl} {Einbeck-Wenzen}
\tl_const:cn {c_phone_DE_ortsname_05571_tl} {Uslar}
\tl_const:cn {c_phone_DE_ortsname_05572_tl} {Bodenfelde}
\tl_const:cn {c_phone_DE_ortsname_05573_tl} {Uslar-Volpriehausen}
\tl_const:cn {c_phone_DE_ortsname_05574_tl} {Oberweser}
\tl_const:cn {c_phone_DE_ortsname_05582_tl} {Sankt~Andreasberg}
\tl_const:cn {c_phone_DE_ortsname_05583_tl} {Braunlage-Hohegei\ss}
\tl_const:cn {c_phone_DE_ortsname_05584_tl} {Hattorf~am~Harz}
\tl_const:cn {c_phone_DE_ortsname_05585_tl} {Herzberg-Sieber}
\tl_const:cn {c_phone_DE_ortsname_05586_tl} {Wieda}
\tl_const:cn {c_phone_DE_ortsname_05592_tl} {Gleichen-Bremke}
\tl_const:cn {c_phone_DE_ortsname_05593_tl} {Bovenden-Lenglern}
\tl_const:cn {c_phone_DE_ortsname_05594_tl} {Bovenden-Reyershausen}
\tl_const:cn {c_phone_DE_ortsname_05601_tl} {Schauenburg}
\tl_const:cn {c_phone_DE_ortsname_05602_tl} {Hessisch~Lichtenau}
\tl_const:cn {c_phone_DE_ortsname_05603_tl} {Gudensberg}
\tl_const:cn {c_phone_DE_ortsname_05604_tl} {Gro\ss almerode}
\tl_const:cn {c_phone_DE_ortsname_05605_tl} {Kaufungen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05606_tl} {Zierenberg}
\tl_const:cn {c_phone_DE_ortsname_05607_tl} {Fuldatal}
\tl_const:cn {c_phone_DE_ortsname_05608_tl} {S\"ohrewald}
\tl_const:cn {c_phone_DE_ortsname_05609_tl} {Ahnatal}
\tl_const:cn {c_phone_DE_ortsname_0561_tl} {Kassel}
\tl_const:cn {c_phone_DE_ortsname_05621_tl} {Bad~Wildungen}
\tl_const:cn {c_phone_DE_ortsname_05622_tl} {Fritzlar}
\tl_const:cn {c_phone_DE_ortsname_05623_tl} {Edertal}
\tl_const:cn {c_phone_DE_ortsname_05624_tl} {Bad~Emstal}
\tl_const:cn {c_phone_DE_ortsname_05625_tl} {Naumburg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05626_tl} {Bad~Zwesten}
\tl_const:cn {c_phone_DE_ortsname_05631_tl} {Korbach}
\tl_const:cn {c_phone_DE_ortsname_05632_tl} {Willingen~Upland}
\tl_const:cn {c_phone_DE_ortsname_05633_tl} {Diemelsee}
\tl_const:cn {c_phone_DE_ortsname_05634_tl} {Waldeck-Sachsenhausen}
\tl_const:cn {c_phone_DE_ortsname_05635_tl} {V\"ohl}
\tl_const:cn {c_phone_DE_ortsname_05636_tl} {Lichtenfels-Goddelsheim}
\tl_const:cn {c_phone_DE_ortsname_05641_tl} {Warburg}
\tl_const:cn {c_phone_DE_ortsname_05642_tl} {Warburg-Scherfede}
\tl_const:cn {c_phone_DE_ortsname_05643_tl} {Borgentreich}
\tl_const:cn {c_phone_DE_ortsname_05644_tl} {Willebadessen-Peckelsheim}
\tl_const:cn {c_phone_DE_ortsname_05645_tl} {Borgentreich-Borgholz}
\tl_const:cn {c_phone_DE_ortsname_05646_tl} {Willebadessen}
\tl_const:cn {c_phone_DE_ortsname_05647_tl} {Lichtenau-Kleinenberg}
\tl_const:cn {c_phone_DE_ortsname_05648_tl} {Brakel-Gehrden}
\tl_const:cn {c_phone_DE_ortsname_05650_tl} {Cornberg}
\tl_const:cn {c_phone_DE_ortsname_05651_tl} {Eschwege}
\tl_const:cn {c_phone_DE_ortsname_05652_tl} {Bad~Sooden-Allendorf}
\tl_const:cn {c_phone_DE_ortsname_05653_tl} {Sontra}
\tl_const:cn {c_phone_DE_ortsname_05654_tl} {Herleshausen}
\tl_const:cn {c_phone_DE_ortsname_05655_tl} {Wanfried}
\tl_const:cn {c_phone_DE_ortsname_05656_tl} {Waldkappel}
\tl_const:cn {c_phone_DE_ortsname_05657_tl} {Mei\ss ner}
\tl_const:cn {c_phone_DE_ortsname_05658_tl} {Wehretal}
\tl_const:cn {c_phone_DE_ortsname_05659_tl} {Ringgau}
\tl_const:cn {c_phone_DE_ortsname_05661_tl} {Melsungen}
\tl_const:cn {c_phone_DE_ortsname_05662_tl} {Felsberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05663_tl} {Spangenberg}
\tl_const:cn {c_phone_DE_ortsname_05664_tl} {Morschen}
\tl_const:cn {c_phone_DE_ortsname_05665_tl} {Guxhagen}
\tl_const:cn {c_phone_DE_ortsname_05671_tl} {Hofgeismar}
\tl_const:cn {c_phone_DE_ortsname_05672_tl} {Bad~Karlshafen}
\tl_const:cn {c_phone_DE_ortsname_05673_tl} {Immenhausen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05674_tl} {Grebenstein}
\tl_const:cn {c_phone_DE_ortsname_05675_tl} {Trendelburg}
\tl_const:cn {c_phone_DE_ortsname_05676_tl} {Liebenau~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05677_tl} {Calden-Westuffeln}
\tl_const:cn {c_phone_DE_ortsname_05681_tl} {Homberg~Efze}
\tl_const:cn {c_phone_DE_ortsname_05682_tl} {Borken~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05683_tl} {Wabern~Hessen}
\tl_const:cn {c_phone_DE_ortsname_05684_tl} {Frielendorf}
\tl_const:cn {c_phone_DE_ortsname_05685_tl} {Kn\"ullwald}
\tl_const:cn {c_phone_DE_ortsname_05686_tl} {Schwarzenborn~Kn\"ull}
\tl_const:cn {c_phone_DE_ortsname_05691_tl} {Bad~Arolsen}
\tl_const:cn {c_phone_DE_ortsname_05692_tl} {Wolfhagen}
\tl_const:cn {c_phone_DE_ortsname_05693_tl} {Volkmarsen}
\tl_const:cn {c_phone_DE_ortsname_05694_tl} {Diemelstadt}
\tl_const:cn {c_phone_DE_ortsname_05695_tl} {Twistetal}
\tl_const:cn {c_phone_DE_ortsname_05696_tl} {Bad~Arolsen-Landau}
\tl_const:cn {c_phone_DE_ortsname_05702_tl} {Petershagen-Lahde}
\tl_const:cn {c_phone_DE_ortsname_05703_tl} {Hille}
\tl_const:cn {c_phone_DE_ortsname_05704_tl} {Petershagen-Friedewalde}
\tl_const:cn {c_phone_DE_ortsname_05705_tl} {Petershagen-Windheim}
\tl_const:cn {c_phone_DE_ortsname_05706_tl} {Porta~Westfalica}
\tl_const:cn {c_phone_DE_ortsname_05707_tl} {Petershagen~Weser}
\tl_const:cn {c_phone_DE_ortsname_0571_tl} {Minden~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05721_tl} {Stadthagen}
\tl_const:cn {c_phone_DE_ortsname_05722_tl} {B\"uckeburg}
\tl_const:cn {c_phone_DE_ortsname_05723_tl} {Bad~Nenndorf}
\tl_const:cn {c_phone_DE_ortsname_05724_tl} {Obernkirchen}
\tl_const:cn {c_phone_DE_ortsname_05725_tl} {Lindhorst~bei~Stadthagen}
\tl_const:cn {c_phone_DE_ortsname_05726_tl} {Wiedensahl}
\tl_const:cn {c_phone_DE_ortsname_05731_tl} {Bad~Oeynhausen}
\tl_const:cn {c_phone_DE_ortsname_05732_tl} {L\"ohne}
\tl_const:cn {c_phone_DE_ortsname_05733_tl} {Vlotho}
\tl_const:cn {c_phone_DE_ortsname_05734_tl} {Bergkirchen~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05741_tl} {L\"ubbecke}
\tl_const:cn {c_phone_DE_ortsname_05742_tl} {Preu\ss isch~Oldendorf}
\tl_const:cn {c_phone_DE_ortsname_05743_tl} {Espelkamp-Gestringen}
\tl_const:cn {c_phone_DE_ortsname_05744_tl} {H\"ullhorst}
\tl_const:cn {c_phone_DE_ortsname_05745_tl} {Stemwede-Levern}
\tl_const:cn {c_phone_DE_ortsname_05746_tl} {R\"odinghausen}
\tl_const:cn {c_phone_DE_ortsname_05751_tl} {Rinteln}
\tl_const:cn {c_phone_DE_ortsname_05752_tl} {Auetal-Hattendorf}
\tl_const:cn {c_phone_DE_ortsname_05753_tl} {Auetal-Bernsen}
\tl_const:cn {c_phone_DE_ortsname_05754_tl} {Extertal-Bremke}
\tl_const:cn {c_phone_DE_ortsname_05755_tl} {Kalletal-Varenholz}
\tl_const:cn {c_phone_DE_ortsname_05761_tl} {Stolzenau}
\tl_const:cn {c_phone_DE_ortsname_05763_tl} {Uchte}
\tl_const:cn {c_phone_DE_ortsname_05764_tl} {Steyerberg}
\tl_const:cn {c_phone_DE_ortsname_05765_tl} {Raddestorf}
\tl_const:cn {c_phone_DE_ortsname_05766_tl} {Rehburg-Loccum}
\tl_const:cn {c_phone_DE_ortsname_05767_tl} {Warmsen}
\tl_const:cn {c_phone_DE_ortsname_05768_tl} {Petershagen-Heimsen}
\tl_const:cn {c_phone_DE_ortsname_05769_tl} {Steyerberg-Voigtei}
\tl_const:cn {c_phone_DE_ortsname_05771_tl} {Rahden~Westfalen}
\tl_const:cn {c_phone_DE_ortsname_05772_tl} {Espelkamp}
\tl_const:cn {c_phone_DE_ortsname_05773_tl} {Stemwede-Wehdem}
\tl_const:cn {c_phone_DE_ortsname_05774_tl} {Wagenfeld-Str\"ohen}
\tl_const:cn {c_phone_DE_ortsname_05775_tl} {Diepenau}
\tl_const:cn {c_phone_DE_ortsname_05776_tl} {Preu\ss isch~Str\"ohen}
\tl_const:cn {c_phone_DE_ortsname_05777_tl} {Diepenau-Essern}
\tl_const:cn {c_phone_DE_ortsname_05802_tl} {Wrestedt}
\tl_const:cn {c_phone_DE_ortsname_05803_tl} {Rosche}
\tl_const:cn {c_phone_DE_ortsname_05804_tl} {R\"atzlingen~Kreis~Uelzen}
\tl_const:cn {c_phone_DE_ortsname_05805_tl} {Oetzen}
\tl_const:cn {c_phone_DE_ortsname_05806_tl} {Barum~bei~Bad~Bevensen}
\tl_const:cn {c_phone_DE_ortsname_05807_tl} {Altenmedingen}
\tl_const:cn {c_phone_DE_ortsname_05808_tl} {Gerdau}
\tl_const:cn {c_phone_DE_ortsname_0581_tl} {Uelzen}
\tl_const:cn {c_phone_DE_ortsname_05820_tl} {Suhlendorf}
\tl_const:cn {c_phone_DE_ortsname_05821_tl} {Bad~Bevensen}
\tl_const:cn {c_phone_DE_ortsname_05822_tl} {Ebstorf}
\tl_const:cn {c_phone_DE_ortsname_05823_tl} {Bienenb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_05824_tl} {Bad~Bodenteich}
\tl_const:cn {c_phone_DE_ortsname_05825_tl} {Wieren}
\tl_const:cn {c_phone_DE_ortsname_05826_tl} {Suderburg}
\tl_const:cn {c_phone_DE_ortsname_05827_tl} {Unterl\"u\ss}
\tl_const:cn {c_phone_DE_ortsname_05828_tl} {Himbergen}
\tl_const:cn {c_phone_DE_ortsname_05829_tl} {Wriedel}
\tl_const:cn {c_phone_DE_ortsname_05831_tl} {Wittingen}
\tl_const:cn {c_phone_DE_ortsname_05832_tl} {Hankensb\"uttel}
\tl_const:cn {c_phone_DE_ortsname_05833_tl} {Brome}
\tl_const:cn {c_phone_DE_ortsname_05834_tl} {Wittingen-Knesebeck}
\tl_const:cn {c_phone_DE_ortsname_05835_tl} {Wahrenholz}
\tl_const:cn {c_phone_DE_ortsname_05836_tl} {Wittingen-Radenbeck}
\tl_const:cn {c_phone_DE_ortsname_05837_tl} {Sprakensehl}
\tl_const:cn {c_phone_DE_ortsname_05838_tl} {Gro\ss\ Oesingen}
\tl_const:cn {c_phone_DE_ortsname_05839_tl} {Wittingen-Ohrdorf}
\tl_const:cn {c_phone_DE_ortsname_05840_tl} {Schnackenburg}
\tl_const:cn {c_phone_DE_ortsname_05841_tl} {L\"uchow~Wendland}
\tl_const:cn {c_phone_DE_ortsname_05842_tl} {Schnega}
\tl_const:cn {c_phone_DE_ortsname_05843_tl} {Wustrow~Wendland}
\tl_const:cn {c_phone_DE_ortsname_05844_tl} {Clenze}
\tl_const:cn {c_phone_DE_ortsname_05845_tl} {Bergen~Dumme}
\tl_const:cn {c_phone_DE_ortsname_05846_tl} {Gartow~Niedersachsen}
\tl_const:cn {c_phone_DE_ortsname_05848_tl} {Trebel}
\tl_const:cn {c_phone_DE_ortsname_05849_tl} {Waddeweitz}
\tl_const:cn {c_phone_DE_ortsname_05850_tl} {Neetze}
\tl_const:cn {c_phone_DE_ortsname_05851_tl} {Dahlenburg}
\tl_const:cn {c_phone_DE_ortsname_05852_tl} {Bleckede}
\tl_const:cn {c_phone_DE_ortsname_05853_tl} {Neu~Darchau}
\tl_const:cn {c_phone_DE_ortsname_05854_tl} {Bleckede-Barskamp}
\tl_const:cn {c_phone_DE_ortsname_05855_tl} {Nahrendorf}
\tl_const:cn {c_phone_DE_ortsname_05857_tl} {Bleckede-Brackede}
\tl_const:cn {c_phone_DE_ortsname_05858_tl} {Hitzacker-Wietzetze}
\tl_const:cn {c_phone_DE_ortsname_05859_tl} {Thomasburg}
\tl_const:cn {c_phone_DE_ortsname_05861_tl} {Dannenberg~Elbe}
\tl_const:cn {c_phone_DE_ortsname_05862_tl} {Hitzacker~Elbe}
\tl_const:cn {c_phone_DE_ortsname_05863_tl} {Zernien}
\tl_const:cn {c_phone_DE_ortsname_05864_tl} {Jameln}
\tl_const:cn {c_phone_DE_ortsname_05865_tl} {Gusborn}
\tl_const:cn {c_phone_DE_ortsname_05872_tl} {Stoetze}
\tl_const:cn {c_phone_DE_ortsname_05873_tl} {Eimke}
\tl_const:cn {c_phone_DE_ortsname_05874_tl} {Soltendieck}
\tl_const:cn {c_phone_DE_ortsname_05875_tl} {Emmendorf}
\tl_const:cn {c_phone_DE_ortsname_05882_tl} {Gorleben}
\tl_const:cn {c_phone_DE_ortsname_05883_tl} {Lemgow}
\tl_const:cn {c_phone_DE_ortsname_05901_tl} {F\"urstenau~bei~Bramsche}
\tl_const:cn {c_phone_DE_ortsname_05902_tl} {Freren}
\tl_const:cn {c_phone_DE_ortsname_05903_tl} {Emsb\"uren}
\tl_const:cn {c_phone_DE_ortsname_05904_tl} {Lengerich~Emsland}
\tl_const:cn {c_phone_DE_ortsname_05905_tl} {Beesten}
\tl_const:cn {c_phone_DE_ortsname_05906_tl} {L\"unne}
\tl_const:cn {c_phone_DE_ortsname_05907_tl} {Geeste}
\tl_const:cn {c_phone_DE_ortsname_05908_tl} {Wietmarschen-Lohne}
\tl_const:cn {c_phone_DE_ortsname_05909_tl} {Wettrup}
\tl_const:cn {c_phone_DE_ortsname_0591_tl} {Lingen~(Ems)}
\tl_const:cn {c_phone_DE_ortsname_05921_tl} {Nordhorn}
\tl_const:cn {c_phone_DE_ortsname_05922_tl} {Bad~Bentheim}
\tl_const:cn {c_phone_DE_ortsname_05923_tl} {Sch\"uttorf}
\tl_const:cn {c_phone_DE_ortsname_05924_tl} {Bad~Bentheim-Gildehaus}
\tl_const:cn {c_phone_DE_ortsname_05925_tl} {Wietmarschen}
\tl_const:cn {c_phone_DE_ortsname_05926_tl} {Engden}
\tl_const:cn {c_phone_DE_ortsname_05931_tl} {Meppen}
\tl_const:cn {c_phone_DE_ortsname_05932_tl} {Haren~Ems}
\tl_const:cn {c_phone_DE_ortsname_05933_tl} {Lathen}
\tl_const:cn {c_phone_DE_ortsname_05934_tl} {Haren-R\"utenbrock}
\tl_const:cn {c_phone_DE_ortsname_05935_tl} {Twist-Sch\"oninghsdorf}
\tl_const:cn {c_phone_DE_ortsname_05936_tl} {Twist}
\tl_const:cn {c_phone_DE_ortsname_05937_tl} {Geeste-Gro\ss\ Hesepe}
\tl_const:cn {c_phone_DE_ortsname_05939_tl} {Sustrum}
\tl_const:cn {c_phone_DE_ortsname_05941_tl} {Neuenhaus~Dinkel}
\tl_const:cn {c_phone_DE_ortsname_05942_tl} {Uelsen}
\tl_const:cn {c_phone_DE_ortsname_05943_tl} {Emlichheim}
\tl_const:cn {c_phone_DE_ortsname_05944_tl} {Hoogstede}
\tl_const:cn {c_phone_DE_ortsname_05945_tl} {Wilsum}
\tl_const:cn {c_phone_DE_ortsname_05946_tl} {Georgsdorf}
\tl_const:cn {c_phone_DE_ortsname_05947_tl} {Laar~Vechte}
\tl_const:cn {c_phone_DE_ortsname_05948_tl} {Itterbeck}
\tl_const:cn {c_phone_DE_ortsname_05951_tl} {Werlte}
\tl_const:cn {c_phone_DE_ortsname_05952_tl} {S\"ogel}
\tl_const:cn {c_phone_DE_ortsname_05953_tl} {B\"orger}
\tl_const:cn {c_phone_DE_ortsname_05954_tl} {Lorup}
\tl_const:cn {c_phone_DE_ortsname_05955_tl} {Esterwegen}
\tl_const:cn {c_phone_DE_ortsname_05956_tl} {Rastdorf}
\tl_const:cn {c_phone_DE_ortsname_05957_tl} {Lindern~Oldenburg}
\tl_const:cn {c_phone_DE_ortsname_05961_tl} {Hasel\"unne}
\tl_const:cn {c_phone_DE_ortsname_05962_tl} {Herzlake}
\tl_const:cn {c_phone_DE_ortsname_05963_tl} {Bawinkel}
\tl_const:cn {c_phone_DE_ortsname_05964_tl} {L\"ahden}
\tl_const:cn {c_phone_DE_ortsname_05965_tl} {Klein~Ber\ss en}
\tl_const:cn {c_phone_DE_ortsname_05966_tl} {Meppen-Apeldorn}
\tl_const:cn {c_phone_DE_ortsname_05971_tl} {Rheine}
\tl_const:cn {c_phone_DE_ortsname_05973_tl} {Neuenkirchen~Kreis~Steinfurt}
\tl_const:cn {c_phone_DE_ortsname_05975_tl} {Rheine-Mesum}
\tl_const:cn {c_phone_DE_ortsname_05976_tl} {Salzbergen}
\tl_const:cn {c_phone_DE_ortsname_05977_tl} {Spelle}
\tl_const:cn {c_phone_DE_ortsname_05978_tl} {H\"orstel-Dreierwalde}
\tl_const:cn {c_phone_DE_ortsname_06002_tl} {Ober-M\"orlen}
\tl_const:cn {c_phone_DE_ortsname_06003_tl} {Rosbach~vor~der~H\"ohe}
\tl_const:cn {c_phone_DE_ortsname_06004_tl} {Lich-Eberstadt}
\tl_const:cn {c_phone_DE_ortsname_06007_tl} {Rosbach-Rodheim}
\tl_const:cn {c_phone_DE_ortsname_06008_tl} {Echzell}
\tl_const:cn {c_phone_DE_ortsname_06020_tl} {Heigenbr\"ucken}
\tl_const:cn {c_phone_DE_ortsname_06021_tl} {Aschaffenburg}
\tl_const:cn {c_phone_DE_ortsname_06022_tl} {Obernburg~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06023_tl} {Alzenau~in~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_06024_tl} {Sch\"ollkrippen}
\tl_const:cn {c_phone_DE_ortsname_06026_tl} {Gro\ss ostheim}
\tl_const:cn {c_phone_DE_ortsname_06027_tl} {Stockstadt~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06028_tl} {Sulzbach~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06029_tl} {M\"ombris}
\tl_const:cn {c_phone_DE_ortsname_06031_tl} {Friedberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06032_tl} {Bad~Nauheim}
\tl_const:cn {c_phone_DE_ortsname_06033_tl} {Butzbach}
\tl_const:cn {c_phone_DE_ortsname_06034_tl} {W\"ollstadt}
\tl_const:cn {c_phone_DE_ortsname_06035_tl} {Reichelsheim~Wetterau}
\tl_const:cn {c_phone_DE_ortsname_06036_tl} {W\"olfersheim}
\tl_const:cn {c_phone_DE_ortsname_06039_tl} {Karben}
\tl_const:cn {c_phone_DE_ortsname_06041_tl} {Glauburg}
\tl_const:cn {c_phone_DE_ortsname_06042_tl} {B\"udingen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06043_tl} {Nidda}
\tl_const:cn {c_phone_DE_ortsname_06044_tl} {Schotten~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06045_tl} {Gedern}
\tl_const:cn {c_phone_DE_ortsname_06046_tl} {Ortenberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06047_tl} {Altenstadt~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06048_tl} {B\"udingen-Eckartshausen}
\tl_const:cn {c_phone_DE_ortsname_06049_tl} {Kefenrod}
\tl_const:cn {c_phone_DE_ortsname_06050_tl} {Biebergem\"und}
\tl_const:cn {c_phone_DE_ortsname_06051_tl} {Gelnhausen}
\tl_const:cn {c_phone_DE_ortsname_06052_tl} {Bad~Orb}
\tl_const:cn {c_phone_DE_ortsname_06053_tl} {W\"achtersbach}
\tl_const:cn {c_phone_DE_ortsname_06054_tl} {Birstein}
\tl_const:cn {c_phone_DE_ortsname_06055_tl} {Freigericht}
\tl_const:cn {c_phone_DE_ortsname_06056_tl} {Bad~Soden-Salm\"unster}
\tl_const:cn {c_phone_DE_ortsname_06057_tl} {Fl\"orsbachtal}
\tl_const:cn {c_phone_DE_ortsname_06058_tl} {Gr\"undau}
\tl_const:cn {c_phone_DE_ortsname_06059_tl} {Jossgrund}
\tl_const:cn {c_phone_DE_ortsname_06061_tl} {Michelstadt}
\tl_const:cn {c_phone_DE_ortsname_06062_tl} {Erbach~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06063_tl} {Bad~K\"onig}
\tl_const:cn {c_phone_DE_ortsname_06066_tl} {Michelstadt-Vielbrunn}
\tl_const:cn {c_phone_DE_ortsname_06068_tl} {Beerfelden}
\tl_const:cn {c_phone_DE_ortsname_06071_tl} {Dieburg}
\tl_const:cn {c_phone_DE_ortsname_06073_tl} {Babenhausen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06074_tl} {R\"odermark}
\tl_const:cn {c_phone_DE_ortsname_06078_tl} {Gro\ss-Umstadt}
\tl_const:cn {c_phone_DE_ortsname_06081_tl} {Usingen}
\tl_const:cn {c_phone_DE_ortsname_06082_tl} {Niederreifenberg}
\tl_const:cn {c_phone_DE_ortsname_06083_tl} {Weilrod}
\tl_const:cn {c_phone_DE_ortsname_06084_tl} {Schmitten~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06085_tl} {Waldsolms}
\tl_const:cn {c_phone_DE_ortsname_06086_tl} {Gr\"avenwiesbach}
\tl_const:cn {c_phone_DE_ortsname_06087_tl} {Waldems}
\tl_const:cn {c_phone_DE_ortsname_06092_tl} {Heimbuchenthal}
\tl_const:cn {c_phone_DE_ortsname_06093_tl} {Laufach}
\tl_const:cn {c_phone_DE_ortsname_06094_tl} {Weibersbrunn}
\tl_const:cn {c_phone_DE_ortsname_06095_tl} {Bessenbach}
\tl_const:cn {c_phone_DE_ortsname_06096_tl} {Wiesen~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_06101_tl} {Bad~Vilbel}
\tl_const:cn {c_phone_DE_ortsname_06102_tl} {Neu-Isenburg}
\tl_const:cn {c_phone_DE_ortsname_06103_tl} {Langen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06104_tl} {Heusenstamm}
\tl_const:cn {c_phone_DE_ortsname_06105_tl} {M\"orfelden-Walldorf}
\tl_const:cn {c_phone_DE_ortsname_06106_tl} {Rodgau}
\tl_const:cn {c_phone_DE_ortsname_06107_tl} {Kelsterbach}
\tl_const:cn {c_phone_DE_ortsname_06108_tl} {M\"uhlheim~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06109_tl} {Frankfurt-Bergen-Enkheim}
\tl_const:cn {c_phone_DE_ortsname_0611_tl} {Wiesbaden}
\tl_const:cn {c_phone_DE_ortsname_06120_tl} {Aarbergen}
\tl_const:cn {c_phone_DE_ortsname_06122_tl} {Hofheim-Wallau}
\tl_const:cn {c_phone_DE_ortsname_06123_tl} {Eltville~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_06124_tl} {Bad~Schwalbach}
\tl_const:cn {c_phone_DE_ortsname_06126_tl} {Idstein}
\tl_const:cn {c_phone_DE_ortsname_06127_tl} {Niedernhausen~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06128_tl} {Taunusstein}
\tl_const:cn {c_phone_DE_ortsname_06129_tl} {Schlangenbad}
\tl_const:cn {c_phone_DE_ortsname_06130_tl} {Schwabenheim~an~der~Selz}
\tl_const:cn {c_phone_DE_ortsname_06131_tl} {Mainz}
\tl_const:cn {c_phone_DE_ortsname_06132_tl} {Ingelheim~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_06133_tl} {Oppenheim}
\tl_const:cn {c_phone_DE_ortsname_06134_tl} {Mainz-Kastel}
\tl_const:cn {c_phone_DE_ortsname_06135_tl} {Bodenheim~Rhein}
\tl_const:cn {c_phone_DE_ortsname_06136_tl} {Nieder-Olm}
\tl_const:cn {c_phone_DE_ortsname_06138_tl} {Mommenheim}
\tl_const:cn {c_phone_DE_ortsname_06139_tl} {Budenheim}
\tl_const:cn {c_phone_DE_ortsname_06142_tl} {R\"usselsheim}
\tl_const:cn {c_phone_DE_ortsname_06144_tl} {Bischofsheim~bei~R\"usselsheim}
\tl_const:cn {c_phone_DE_ortsname_06145_tl} {Fl\"orsheim~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06146_tl} {Hochheim~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06147_tl} {Trebur}
\tl_const:cn {c_phone_DE_ortsname_06150_tl} {Weiterstadt}
\tl_const:cn {c_phone_DE_ortsname_06151_tl} {Darmstadt}
\tl_const:cn {c_phone_DE_ortsname_06152_tl} {Gro\ss-Gerau}
\tl_const:cn {c_phone_DE_ortsname_06154_tl} {Ober-Ramstadt}
\tl_const:cn {c_phone_DE_ortsname_06155_tl} {Griesheim~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06157_tl} {Pfungstadt}
\tl_const:cn {c_phone_DE_ortsname_06158_tl} {Riedstadt}
\tl_const:cn {c_phone_DE_ortsname_06159_tl} {Messel}
\tl_const:cn {c_phone_DE_ortsname_06161_tl} {Brensbach}
\tl_const:cn {c_phone_DE_ortsname_06162_tl} {Reinheim~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06163_tl} {H\"ochst~im~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06164_tl} {Reichelsheim~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06165_tl} {Breuberg}
\tl_const:cn {c_phone_DE_ortsname_06166_tl} {Fischbachtal}
\tl_const:cn {c_phone_DE_ortsname_06167_tl} {Modautal}
\tl_const:cn {c_phone_DE_ortsname_06171_tl} {Oberursel~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06172_tl} {Bad~Homburg~vor~der~H\"ohe}
\tl_const:cn {c_phone_DE_ortsname_06173_tl} {Kronberg~im~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06174_tl} {K\"onigstein~im~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06175_tl} {Friedrichsdorf~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06181_tl} {Hanau}
\tl_const:cn {c_phone_DE_ortsname_06182_tl} {Seligenstadt}
\tl_const:cn {c_phone_DE_ortsname_06183_tl} {Erlensee}
\tl_const:cn {c_phone_DE_ortsname_06184_tl} {Langenselbold}
\tl_const:cn {c_phone_DE_ortsname_06185_tl} {Hammersbach~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06186_tl} {Gro\ss krotzenburg}
\tl_const:cn {c_phone_DE_ortsname_06187_tl} {Sch\"oneck}
\tl_const:cn {c_phone_DE_ortsname_06188_tl} {Kahl~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06190_tl} {Hattersheim~am~Main}
\tl_const:cn {c_phone_DE_ortsname_06192_tl} {Hofheim~am~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06195_tl} {Kelkheim~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06196_tl} {Bad~Soden~am~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06198_tl} {Eppstein}
\tl_const:cn {c_phone_DE_ortsname_06201_tl} {Weinheim~Bergstra\ss e}
\tl_const:cn {c_phone_DE_ortsname_06202_tl} {Schwetzingen}
\tl_const:cn {c_phone_DE_ortsname_06203_tl} {Ladenburg}
\tl_const:cn {c_phone_DE_ortsname_06204_tl} {Viernheim}
\tl_const:cn {c_phone_DE_ortsname_06205_tl} {Hockenheim}
\tl_const:cn {c_phone_DE_ortsname_06206_tl} {Lampertheim}
\tl_const:cn {c_phone_DE_ortsname_06207_tl} {Wald-Michelbach}
\tl_const:cn {c_phone_DE_ortsname_06209_tl} {M\"orlenbach}
\tl_const:cn {c_phone_DE_ortsname_0621_tl} {Mannheim}
\tl_const:cn {c_phone_DE_ortsname_06220_tl} {Wilhelmsfeld}
\tl_const:cn {c_phone_DE_ortsname_06221_tl} {Heidelberg}
\tl_const:cn {c_phone_DE_ortsname_06222_tl} {Wiesloch}
\tl_const:cn {c_phone_DE_ortsname_06223_tl} {Neckargem\"und}
\tl_const:cn {c_phone_DE_ortsname_06224_tl} {Sandhausen~Baden}
\tl_const:cn {c_phone_DE_ortsname_06226_tl} {Meckesheim}
\tl_const:cn {c_phone_DE_ortsname_06227_tl} {Walldorf~Baden}
\tl_const:cn {c_phone_DE_ortsname_06228_tl} {Sch\"onau~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06229_tl} {Neckarsteinach}
\tl_const:cn {c_phone_DE_ortsname_06231_tl} {Hochdorf-Assenheim}
\tl_const:cn {c_phone_DE_ortsname_06232_tl} {Speyer}
\tl_const:cn {c_phone_DE_ortsname_06233_tl} {Frankenthal~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06234_tl} {Mutterstadt}
\tl_const:cn {c_phone_DE_ortsname_06235_tl} {Schifferstadt}
\tl_const:cn {c_phone_DE_ortsname_06236_tl} {Neuhofen~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06237_tl} {Maxdorf}
\tl_const:cn {c_phone_DE_ortsname_06238_tl} {Dirmstein}
\tl_const:cn {c_phone_DE_ortsname_06239_tl} {Bobenheim-Roxheim}
\tl_const:cn {c_phone_DE_ortsname_06241_tl} {Worms}
\tl_const:cn {c_phone_DE_ortsname_06242_tl} {Osthofen}
\tl_const:cn {c_phone_DE_ortsname_06243_tl} {Monsheim}
\tl_const:cn {c_phone_DE_ortsname_06244_tl} {Westhofen~Rheinhessen}
\tl_const:cn {c_phone_DE_ortsname_06245_tl} {Biblis}
\tl_const:cn {c_phone_DE_ortsname_06246_tl} {Eich~Rheinhessen}
\tl_const:cn {c_phone_DE_ortsname_06247_tl} {Worms-Pfeddersheim}
\tl_const:cn {c_phone_DE_ortsname_06249_tl} {Guntersblum}
\tl_const:cn {c_phone_DE_ortsname_06251_tl} {Bensheim}
\tl_const:cn {c_phone_DE_ortsname_06252_tl} {Heppenheim~Bergstra\ss e}
\tl_const:cn {c_phone_DE_ortsname_06253_tl} {F\"urth~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06254_tl} {Lautertal~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06255_tl} {Lindenfels}
\tl_const:cn {c_phone_DE_ortsname_06256_tl} {Lampertheim-H\"uttenfeld}
\tl_const:cn {c_phone_DE_ortsname_06257_tl} {Seeheim-Jugenheim}
\tl_const:cn {c_phone_DE_ortsname_06258_tl} {Gernsheim}
\tl_const:cn {c_phone_DE_ortsname_06261_tl} {Mosbach~Baden}
\tl_const:cn {c_phone_DE_ortsname_06262_tl} {Aglasterhausen}
\tl_const:cn {c_phone_DE_ortsname_06263_tl} {Neckargerach}
\tl_const:cn {c_phone_DE_ortsname_06264_tl} {Neudenau}
\tl_const:cn {c_phone_DE_ortsname_06265_tl} {Billigheim~Baden}
\tl_const:cn {c_phone_DE_ortsname_06266_tl} {Ha\ss mersheim}
\tl_const:cn {c_phone_DE_ortsname_06267_tl} {Fahrenbach~Baden}
\tl_const:cn {c_phone_DE_ortsname_06268_tl} {H\"uffenhardt}
\tl_const:cn {c_phone_DE_ortsname_06269_tl} {Gundelsheim~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_06271_tl} {Eberbach~Baden}
\tl_const:cn {c_phone_DE_ortsname_06272_tl} {Hirschhorn~Neckar}
\tl_const:cn {c_phone_DE_ortsname_06274_tl} {Waldbrunn~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06275_tl} {Rothenberg~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06276_tl} {Hesseneck}
\tl_const:cn {c_phone_DE_ortsname_06281_tl} {Buchen~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06282_tl} {Walld\"urn}
\tl_const:cn {c_phone_DE_ortsname_06283_tl} {Hardheim~Odenwald}
\tl_const:cn {c_phone_DE_ortsname_06284_tl} {Mudau}
\tl_const:cn {c_phone_DE_ortsname_06285_tl} {Walld\"urn-Altheim}
\tl_const:cn {c_phone_DE_ortsname_06286_tl} {Walld\"urn-Rippberg}
\tl_const:cn {c_phone_DE_ortsname_06287_tl} {Limbach~Baden}
\tl_const:cn {c_phone_DE_ortsname_06291_tl} {Adelsheim}
\tl_const:cn {c_phone_DE_ortsname_06292_tl} {Seckach}
\tl_const:cn {c_phone_DE_ortsname_06293_tl} {Schefflenz}
\tl_const:cn {c_phone_DE_ortsname_06294_tl} {Krautheim~Jagst}
\tl_const:cn {c_phone_DE_ortsname_06295_tl} {Rosenberg~Baden}
\tl_const:cn {c_phone_DE_ortsname_06296_tl} {Ahorn~Baden}
\tl_const:cn {c_phone_DE_ortsname_06297_tl} {Ravenstein~Baden}
\tl_const:cn {c_phone_DE_ortsname_06298_tl} {M\"ockm\"uhl}
\tl_const:cn {c_phone_DE_ortsname_06301_tl} {Otterbach~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06302_tl} {Winnweiler}
\tl_const:cn {c_phone_DE_ortsname_06303_tl} {Enkenbach-Alsenborn}
\tl_const:cn {c_phone_DE_ortsname_06304_tl} {Wolfstein~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06305_tl} {Hochspeyer}
\tl_const:cn {c_phone_DE_ortsname_06306_tl} {Trippstadt}
\tl_const:cn {c_phone_DE_ortsname_06307_tl} {Schopp}
\tl_const:cn {c_phone_DE_ortsname_06308_tl} {Olsbr\"ucken}
\tl_const:cn {c_phone_DE_ortsname_0631_tl} {Kaiserslautern}
\tl_const:cn {c_phone_DE_ortsname_06321_tl} {Neustadt~an~der~Weinstra\ss e}
\tl_const:cn {c_phone_DE_ortsname_06322_tl} {Bad~D\"urkheim}
\tl_const:cn {c_phone_DE_ortsname_06323_tl} {Edenkoben}
\tl_const:cn {c_phone_DE_ortsname_06324_tl} {Ha\ss loch}
\tl_const:cn {c_phone_DE_ortsname_06325_tl} {Lambrecht~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06326_tl} {Deidesheim}
\tl_const:cn {c_phone_DE_ortsname_06327_tl} {Neustadt-Lachen}
\tl_const:cn {c_phone_DE_ortsname_06328_tl} {Elmstein}
\tl_const:cn {c_phone_DE_ortsname_06329_tl} {Weidenthal~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06331_tl} {Pirmasens}
\tl_const:cn {c_phone_DE_ortsname_06332_tl} {Zweibr\"ucken}
\tl_const:cn {c_phone_DE_ortsname_06333_tl} {Waldfischbach-Burgalben}
\tl_const:cn {c_phone_DE_ortsname_06334_tl} {Thaleischweiler-Fr\"oschen}
\tl_const:cn {c_phone_DE_ortsname_06335_tl} {Trulben}
\tl_const:cn {c_phone_DE_ortsname_06336_tl} {Dellfeld}
\tl_const:cn {c_phone_DE_ortsname_06337_tl} {Gro\ss bundenbach}
\tl_const:cn {c_phone_DE_ortsname_06338_tl} {Hornbach~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06339_tl} {Gro\ss steinhausen}
\tl_const:cn {c_phone_DE_ortsname_06340_tl} {W\"orth-Schaidt}
\tl_const:cn {c_phone_DE_ortsname_06341_tl} {Landau~in~der~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06342_tl} {Schweigen-Rechtenbach}
\tl_const:cn {c_phone_DE_ortsname_06343_tl} {Bad~Bergzabern}
\tl_const:cn {c_phone_DE_ortsname_06344_tl} {Schwegenheim}
\tl_const:cn {c_phone_DE_ortsname_06345_tl} {Albersweiler}
\tl_const:cn {c_phone_DE_ortsname_06346_tl} {Annweiler~am~Trifels}
\tl_const:cn {c_phone_DE_ortsname_06347_tl} {Hochstadt~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06348_tl} {Offenbach~an~der~Queich}
\tl_const:cn {c_phone_DE_ortsname_06349_tl} {Billigheim-Ingenheim}
\tl_const:cn {c_phone_DE_ortsname_06351_tl} {Eisenberg~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06352_tl} {Kirchheimbolanden}
\tl_const:cn {c_phone_DE_ortsname_06353_tl} {Freinsheim}
\tl_const:cn {c_phone_DE_ortsname_06355_tl} {Albisheim~Pfrimm}
\tl_const:cn {c_phone_DE_ortsname_06356_tl} {Carlsberg~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06357_tl} {Standenb\"uhl}
\tl_const:cn {c_phone_DE_ortsname_06358_tl} {Kriegsfeld}
\tl_const:cn {c_phone_DE_ortsname_06359_tl} {Gr\"unstadt}
\tl_const:cn {c_phone_DE_ortsname_06361_tl} {Rockenhausen}
\tl_const:cn {c_phone_DE_ortsname_06362_tl} {Alsenz}
\tl_const:cn {c_phone_DE_ortsname_06363_tl} {Niederkirchen}
\tl_const:cn {c_phone_DE_ortsname_06364_tl} {Nu\ss bach~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06371_tl} {Landstuhl}
\tl_const:cn {c_phone_DE_ortsname_06372_tl} {Bruchm\"uhlbach-Miesau}
\tl_const:cn {c_phone_DE_ortsname_06373_tl} {Sch\"onenberg-K\"ubelberg}
\tl_const:cn {c_phone_DE_ortsname_06374_tl} {Weilerbach}
\tl_const:cn {c_phone_DE_ortsname_06375_tl} {Wallhalben}
\tl_const:cn {c_phone_DE_ortsname_06381_tl} {Kusel}
\tl_const:cn {c_phone_DE_ortsname_06382_tl} {Lauterecken}
\tl_const:cn {c_phone_DE_ortsname_06383_tl} {Glan-M\"unchweiler}
\tl_const:cn {c_phone_DE_ortsname_06384_tl} {Konken}
\tl_const:cn {c_phone_DE_ortsname_06385_tl} {Reichenbach-Steegen}
\tl_const:cn {c_phone_DE_ortsname_06386_tl} {Altenkirchen~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06387_tl} {Sankt~Julian}
\tl_const:cn {c_phone_DE_ortsname_06391_tl} {Dahn}
\tl_const:cn {c_phone_DE_ortsname_06392_tl} {Hauenstein~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06393_tl} {Fischbach~bei~Dahn}
\tl_const:cn {c_phone_DE_ortsname_06394_tl} {Bundenthal}
\tl_const:cn {c_phone_DE_ortsname_06395_tl} {M\"unchweiler~an~der~Rodalb}
\tl_const:cn {c_phone_DE_ortsname_06396_tl} {Hinterweidenthal}
\tl_const:cn {c_phone_DE_ortsname_06397_tl} {Leimen~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_06398_tl} {Vorderweidenthal}
\tl_const:cn {c_phone_DE_ortsname_06400_tl} {M\"ucke}
\tl_const:cn {c_phone_DE_ortsname_06401_tl} {Gr\"unberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06402_tl} {Hungen}
\tl_const:cn {c_phone_DE_ortsname_06403_tl} {Linden~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06404_tl} {Lich~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06405_tl} {Laubach~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06406_tl} {Lollar}
\tl_const:cn {c_phone_DE_ortsname_06407_tl} {Rabenau~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06408_tl} {Buseck}
\tl_const:cn {c_phone_DE_ortsname_06409_tl} {Biebertal}
\tl_const:cn {c_phone_DE_ortsname_0641_tl} {Gie\ss en}
\tl_const:cn {c_phone_DE_ortsname_06420_tl} {Lahntal}
\tl_const:cn {c_phone_DE_ortsname_06421_tl} {Marburg}
\tl_const:cn {c_phone_DE_ortsname_06422_tl} {Kirchhain}
\tl_const:cn {c_phone_DE_ortsname_06423_tl} {Wetter~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06424_tl} {Ebsdorfergrund}
\tl_const:cn {c_phone_DE_ortsname_06425_tl} {Rauschenberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06426_tl} {Fronhausen}
\tl_const:cn {c_phone_DE_ortsname_06427_tl} {C\"olbe-Sch\"onstadt}
\tl_const:cn {c_phone_DE_ortsname_06428_tl} {Stadtallendorf}
\tl_const:cn {c_phone_DE_ortsname_06429_tl} {Schweinsberg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06430_tl} {Hahnst\"atten}
\tl_const:cn {c_phone_DE_ortsname_06431_tl} {Limburg~an~der~Lahn}
\tl_const:cn {c_phone_DE_ortsname_06432_tl} {Diez}
\tl_const:cn {c_phone_DE_ortsname_06433_tl} {Hadamar}
\tl_const:cn {c_phone_DE_ortsname_06434_tl} {Bad~Camberg}
\tl_const:cn {c_phone_DE_ortsname_06435_tl} {Wallmerod}
\tl_const:cn {c_phone_DE_ortsname_06436_tl} {Dornburg~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06438_tl} {H\"unfelden}
\tl_const:cn {c_phone_DE_ortsname_06439_tl} {Holzappel}
\tl_const:cn {c_phone_DE_ortsname_06440_tl} {K\"olschhausen}
\tl_const:cn {c_phone_DE_ortsname_06441_tl} {Wetzlar}
\tl_const:cn {c_phone_DE_ortsname_06442_tl} {Braunfels}
\tl_const:cn {c_phone_DE_ortsname_06443_tl} {Ehringshausen~Dill}
\tl_const:cn {c_phone_DE_ortsname_06444_tl} {Bischoffen}
\tl_const:cn {c_phone_DE_ortsname_06445_tl} {Sch\"offengrund}
\tl_const:cn {c_phone_DE_ortsname_06446_tl} {Hohenahr}
\tl_const:cn {c_phone_DE_ortsname_06447_tl} {Langg\"ons-Niederkleen}
\tl_const:cn {c_phone_DE_ortsname_06449_tl} {Ehringshausen-Katzenfurt}
\tl_const:cn {c_phone_DE_ortsname_06451_tl} {Frankenberg~Eder}
\tl_const:cn {c_phone_DE_ortsname_06452_tl} {Battenberg~Eder}
\tl_const:cn {c_phone_DE_ortsname_06453_tl} {Gem\"unden~Wohra}
\tl_const:cn {c_phone_DE_ortsname_06454_tl} {Lichtenfels-Sachsenberg}
\tl_const:cn {c_phone_DE_ortsname_06455_tl} {Frankenau~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06456_tl} {Haina~Kloster}
\tl_const:cn {c_phone_DE_ortsname_06457_tl} {Burgwald~Eder}
\tl_const:cn {c_phone_DE_ortsname_06458_tl} {Rosenthal~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06461_tl} {Biedenkopf}
\tl_const:cn {c_phone_DE_ortsname_06462_tl} {Gladenbach}
\tl_const:cn {c_phone_DE_ortsname_06464_tl} {Angelburg}
\tl_const:cn {c_phone_DE_ortsname_06465_tl} {Breidenbach~bei~Biedenkopf}
\tl_const:cn {c_phone_DE_ortsname_06466_tl} {Dautphetal-Friedensdorf}
\tl_const:cn {c_phone_DE_ortsname_06467_tl} {Hatzfeld~Eder}
\tl_const:cn {c_phone_DE_ortsname_06468_tl} {Dautphetal-Mornshausen}
\tl_const:cn {c_phone_DE_ortsname_06471_tl} {Weilburg}
\tl_const:cn {c_phone_DE_ortsname_06472_tl} {Weilm\"unster}
\tl_const:cn {c_phone_DE_ortsname_06473_tl} {Leun}
\tl_const:cn {c_phone_DE_ortsname_06474_tl} {Villmar-Aumenau}
\tl_const:cn {c_phone_DE_ortsname_06475_tl} {Weilm\"unster-Wolfenhausen}
\tl_const:cn {c_phone_DE_ortsname_06476_tl} {Mengerskirchen}
\tl_const:cn {c_phone_DE_ortsname_06477_tl} {Greifenstein-Nenderoth}
\tl_const:cn {c_phone_DE_ortsname_06478_tl} {Greifenstein-Ulm}
\tl_const:cn {c_phone_DE_ortsname_06479_tl} {Waldbrunn~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_06482_tl} {Runkel}
\tl_const:cn {c_phone_DE_ortsname_06483_tl} {Selters~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06484_tl} {Beselich}
\tl_const:cn {c_phone_DE_ortsname_06485_tl} {Nentershausen~Westerwald}
\tl_const:cn {c_phone_DE_ortsname_06486_tl} {Katzenelnbogen}
\tl_const:cn {c_phone_DE_ortsname_06500_tl} {Waldrach}
\tl_const:cn {c_phone_DE_ortsname_06501_tl} {Konz}
\tl_const:cn {c_phone_DE_ortsname_06502_tl} {Schweich}
\tl_const:cn {c_phone_DE_ortsname_06503_tl} {Hermeskeil}
\tl_const:cn {c_phone_DE_ortsname_06504_tl} {Thalfang}
\tl_const:cn {c_phone_DE_ortsname_06505_tl} {Kordel}
\tl_const:cn {c_phone_DE_ortsname_06506_tl} {Welschbillig}
\tl_const:cn {c_phone_DE_ortsname_06507_tl} {Neumagen-Dhron}
\tl_const:cn {c_phone_DE_ortsname_06508_tl} {Hetzerath~Mosel}
\tl_const:cn {c_phone_DE_ortsname_06509_tl} {B\"udlich}
\tl_const:cn {c_phone_DE_ortsname_0651_tl} {Trier}
\tl_const:cn {c_phone_DE_ortsname_06522_tl} {Mettendorf}
\tl_const:cn {c_phone_DE_ortsname_06523_tl} {Holsthum}
\tl_const:cn {c_phone_DE_ortsname_06524_tl} {Rodershausen}
\tl_const:cn {c_phone_DE_ortsname_06525_tl} {Irrel}
\tl_const:cn {c_phone_DE_ortsname_06526_tl} {Bollendorf}
\tl_const:cn {c_phone_DE_ortsname_06527_tl} {Oberweis}
\tl_const:cn {c_phone_DE_ortsname_06531_tl} {Bernkastel-Kues}
\tl_const:cn {c_phone_DE_ortsname_06532_tl} {Zeltingen-Rachtig}
\tl_const:cn {c_phone_DE_ortsname_06533_tl} {Morbach~Hunsr\"uck}
\tl_const:cn {c_phone_DE_ortsname_06534_tl} {M\"ulheim~Mosel}
\tl_const:cn {c_phone_DE_ortsname_06535_tl} {Osann-Monzel}
\tl_const:cn {c_phone_DE_ortsname_06536_tl} {Kleinich}
\tl_const:cn {c_phone_DE_ortsname_06541_tl} {Traben-Trarbach}
\tl_const:cn {c_phone_DE_ortsname_06542_tl} {Bullay}
\tl_const:cn {c_phone_DE_ortsname_06543_tl} {B\"uchenbeuren}
\tl_const:cn {c_phone_DE_ortsname_06544_tl} {Rhaunen}
\tl_const:cn {c_phone_DE_ortsname_06545_tl} {Blankenrath}
\tl_const:cn {c_phone_DE_ortsname_06550_tl} {Irrhausen}
\tl_const:cn {c_phone_DE_ortsname_06551_tl} {Pr\"um}
\tl_const:cn {c_phone_DE_ortsname_06552_tl} {Olzheim}
\tl_const:cn {c_phone_DE_ortsname_06553_tl} {Sch\"onecken}
\tl_const:cn {c_phone_DE_ortsname_06554_tl} {Waxweiler}
\tl_const:cn {c_phone_DE_ortsname_06555_tl} {Bleialf}
\tl_const:cn {c_phone_DE_ortsname_06556_tl} {Pronsfeld}
\tl_const:cn {c_phone_DE_ortsname_06557_tl} {Hallschlag}
\tl_const:cn {c_phone_DE_ortsname_06558_tl} {B\"udesheim~Eifel}
\tl_const:cn {c_phone_DE_ortsname_06559_tl} {Leidenborn}
\tl_const:cn {c_phone_DE_ortsname_06561_tl} {Bitburg}
\tl_const:cn {c_phone_DE_ortsname_06562_tl} {Speicher}
\tl_const:cn {c_phone_DE_ortsname_06563_tl} {Kyllburg}
\tl_const:cn {c_phone_DE_ortsname_06564_tl} {Neuerburg~Eifel}
\tl_const:cn {c_phone_DE_ortsname_06565_tl} {Dudeldorf}
\tl_const:cn {c_phone_DE_ortsname_06566_tl} {K\"orperich}
\tl_const:cn {c_phone_DE_ortsname_06567_tl} {Oberkail}
\tl_const:cn {c_phone_DE_ortsname_06568_tl} {Wolsfeld}
\tl_const:cn {c_phone_DE_ortsname_06569_tl} {Bickendorf}
\tl_const:cn {c_phone_DE_ortsname_06571_tl} {Wittlich}
\tl_const:cn {c_phone_DE_ortsname_06572_tl} {Manderscheid~Eifel}
\tl_const:cn {c_phone_DE_ortsname_06573_tl} {Gillenfeld}
\tl_const:cn {c_phone_DE_ortsname_06574_tl} {Hasborn}
\tl_const:cn {c_phone_DE_ortsname_06575_tl} {Landscheid}
\tl_const:cn {c_phone_DE_ortsname_06578_tl} {Salmtal}
\tl_const:cn {c_phone_DE_ortsname_06580_tl} {Zemmer}
\tl_const:cn {c_phone_DE_ortsname_06581_tl} {Saarburg}
\tl_const:cn {c_phone_DE_ortsname_06582_tl} {Freudenburg}
\tl_const:cn {c_phone_DE_ortsname_06583_tl} {Palzem}
\tl_const:cn {c_phone_DE_ortsname_06584_tl} {Wellen~Mosel}
\tl_const:cn {c_phone_DE_ortsname_06585_tl} {Ralingen}
\tl_const:cn {c_phone_DE_ortsname_06586_tl} {Beuren~Hochwald}
\tl_const:cn {c_phone_DE_ortsname_06587_tl} {Zerf}
\tl_const:cn {c_phone_DE_ortsname_06588_tl} {Pluwig}
\tl_const:cn {c_phone_DE_ortsname_06589_tl} {Kell~am~See}
\tl_const:cn {c_phone_DE_ortsname_06591_tl} {Gerolstein}
\tl_const:cn {c_phone_DE_ortsname_06592_tl} {Daun}
\tl_const:cn {c_phone_DE_ortsname_06593_tl} {Hillesheim~Eifel}
\tl_const:cn {c_phone_DE_ortsname_06594_tl} {Birresborn}
\tl_const:cn {c_phone_DE_ortsname_06595_tl} {Dockweiler}
\tl_const:cn {c_phone_DE_ortsname_06596_tl} {\"Udersdorf}
\tl_const:cn {c_phone_DE_ortsname_06597_tl} {J\"unkerath}
\tl_const:cn {c_phone_DE_ortsname_06599_tl} {Weidenbach~bei~Gerolstein}
\tl_const:cn {c_phone_DE_ortsname_0661_tl} {Fulda}
\tl_const:cn {c_phone_DE_ortsname_06620_tl} {Philippsthal~Werra}
\tl_const:cn {c_phone_DE_ortsname_06621_tl} {Bad~Hersfeld}
\tl_const:cn {c_phone_DE_ortsname_06622_tl} {Bebra}
\tl_const:cn {c_phone_DE_ortsname_06623_tl} {Rotenburg~an~der~Fulda}
\tl_const:cn {c_phone_DE_ortsname_06624_tl} {Heringen~Werra}
\tl_const:cn {c_phone_DE_ortsname_06625_tl} {Niederaula}
\tl_const:cn {c_phone_DE_ortsname_06626_tl} {Wildeck-Obersuhl}
\tl_const:cn {c_phone_DE_ortsname_06627_tl} {Nentershausen~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06628_tl} {Oberaula}
\tl_const:cn {c_phone_DE_ortsname_06629_tl} {Schenklengsfeld}
\tl_const:cn {c_phone_DE_ortsname_06630_tl} {Schwalmtal-Storndorf}
\tl_const:cn {c_phone_DE_ortsname_06631_tl} {Alsfeld}
\tl_const:cn {c_phone_DE_ortsname_06633_tl} {Homberg~Ohm}
\tl_const:cn {c_phone_DE_ortsname_06634_tl} {Gem\"unden~Felda}
\tl_const:cn {c_phone_DE_ortsname_06635_tl} {Kirtorf}
\tl_const:cn {c_phone_DE_ortsname_06636_tl} {Romrod}
\tl_const:cn {c_phone_DE_ortsname_06637_tl} {Feldatal}
\tl_const:cn {c_phone_DE_ortsname_06638_tl} {Schwalmtal-Renzendorf}
\tl_const:cn {c_phone_DE_ortsname_06639_tl} {Ottrau}
\tl_const:cn {c_phone_DE_ortsname_06641_tl} {Lauterbach~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06642_tl} {Schlitz}
\tl_const:cn {c_phone_DE_ortsname_06643_tl} {Herbstein}
\tl_const:cn {c_phone_DE_ortsname_06644_tl} {Grebenhain}
\tl_const:cn {c_phone_DE_ortsname_06645_tl} {Ulrichstein}
\tl_const:cn {c_phone_DE_ortsname_06646_tl} {Grebenau}
\tl_const:cn {c_phone_DE_ortsname_06647_tl} {Herbstein-Stockhausen}
\tl_const:cn {c_phone_DE_ortsname_06648_tl} {Bad~Salzschlirf}
\tl_const:cn {c_phone_DE_ortsname_06650_tl} {Hosenfeld}
\tl_const:cn {c_phone_DE_ortsname_06651_tl} {Rasdorf}
\tl_const:cn {c_phone_DE_ortsname_06652_tl} {H\"unfeld}
\tl_const:cn {c_phone_DE_ortsname_06653_tl} {Burghaun}
\tl_const:cn {c_phone_DE_ortsname_06654_tl} {Gersfeld~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_06655_tl} {Neuhof~Kreis~Fulda}
\tl_const:cn {c_phone_DE_ortsname_06656_tl} {Ebersburg}
\tl_const:cn {c_phone_DE_ortsname_06657_tl} {Hofbieber}
\tl_const:cn {c_phone_DE_ortsname_06658_tl} {Poppenhausen~Wasserkuppe}
\tl_const:cn {c_phone_DE_ortsname_06659_tl} {Eichenzell}
\tl_const:cn {c_phone_DE_ortsname_06660_tl} {Steinau-Marjo\ss}
\tl_const:cn {c_phone_DE_ortsname_06661_tl} {Schl\"uchtern}
\tl_const:cn {c_phone_DE_ortsname_06663_tl} {Steinau~an~der~Stra\ss e}
\tl_const:cn {c_phone_DE_ortsname_06664_tl} {Sinntal-Sterbfritz}
\tl_const:cn {c_phone_DE_ortsname_06665_tl} {Sinntal-Altengronau}
\tl_const:cn {c_phone_DE_ortsname_06666_tl} {Freiensteinau}
\tl_const:cn {c_phone_DE_ortsname_06667_tl} {Steinau-Ulmbach}
\tl_const:cn {c_phone_DE_ortsname_06668_tl} {Birstein-Lichenroth}
\tl_const:cn {c_phone_DE_ortsname_06669_tl} {Neuhof-Hauswurz}
\tl_const:cn {c_phone_DE_ortsname_06670_tl} {Ludwigsau~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06672_tl} {Eiterfeld}
\tl_const:cn {c_phone_DE_ortsname_06673_tl} {Haunetal}
\tl_const:cn {c_phone_DE_ortsname_06674_tl} {Friedewald~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06675_tl} {Breitenbach~am~Herzberg}
\tl_const:cn {c_phone_DE_ortsname_06676_tl} {Hohenroda~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06677_tl} {Neuenstein~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06678_tl} {Wildeck-H\"onebach}
\tl_const:cn {c_phone_DE_ortsname_06681_tl} {Hilders}
\tl_const:cn {c_phone_DE_ortsname_06682_tl} {Tann~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_06683_tl} {Ehrenberg~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_06684_tl} {Hofbieber-Schwarzbach}
\tl_const:cn {c_phone_DE_ortsname_06691_tl} {Schwalmstadt}
\tl_const:cn {c_phone_DE_ortsname_06692_tl} {Neustadt~Hessen}
\tl_const:cn {c_phone_DE_ortsname_06693_tl} {Neuental}
\tl_const:cn {c_phone_DE_ortsname_06694_tl} {Neukirchen~Kn\"ull}
\tl_const:cn {c_phone_DE_ortsname_06695_tl} {Jesberg}
\tl_const:cn {c_phone_DE_ortsname_06696_tl} {Gilserberg}
\tl_const:cn {c_phone_DE_ortsname_06697_tl} {Willingshausen}
\tl_const:cn {c_phone_DE_ortsname_06698_tl} {Schrecksbach}
\tl_const:cn {c_phone_DE_ortsname_06701_tl} {Sprendlingen~Rheinhessen}
\tl_const:cn {c_phone_DE_ortsname_06703_tl} {W\"ollstein~Rheinhessen}
\tl_const:cn {c_phone_DE_ortsname_06704_tl} {Langenlonsheim}
\tl_const:cn {c_phone_DE_ortsname_06706_tl} {Wallhausen~Nahe}
\tl_const:cn {c_phone_DE_ortsname_06707_tl} {Windesheim}
\tl_const:cn {c_phone_DE_ortsname_06708_tl} {Bad~M\"unster~am~Stein-Ebernburg}
\tl_const:cn {c_phone_DE_ortsname_06709_tl} {F\"urfeld~Kreis~Bad~Kreuznach}
\tl_const:cn {c_phone_DE_ortsname_0671_tl} {Bad~Kreuznach}
\tl_const:cn {c_phone_DE_ortsname_06721_tl} {Bingen~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_06722_tl} {R\"udesheim~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_06723_tl} {Oestrich-Winkel}
\tl_const:cn {c_phone_DE_ortsname_06724_tl} {Stromberg~Hunsr\"uck}
\tl_const:cn {c_phone_DE_ortsname_06725_tl} {Gau-Algesheim}
\tl_const:cn {c_phone_DE_ortsname_06726_tl} {Lorch~Rheingau}
\tl_const:cn {c_phone_DE_ortsname_06727_tl} {Gensingen}
\tl_const:cn {c_phone_DE_ortsname_06728_tl} {Ober-Hilbersheim}
\tl_const:cn {c_phone_DE_ortsname_06731_tl} {Alzey}
\tl_const:cn {c_phone_DE_ortsname_06732_tl} {W\"orrstadt}
\tl_const:cn {c_phone_DE_ortsname_06733_tl} {Gau-Odernheim}
\tl_const:cn {c_phone_DE_ortsname_06734_tl} {Flonheim}
\tl_const:cn {c_phone_DE_ortsname_06735_tl} {Eppelsheim}
\tl_const:cn {c_phone_DE_ortsname_06736_tl} {Bechenheim}
\tl_const:cn {c_phone_DE_ortsname_06737_tl} {K\"ongernheim}
\tl_const:cn {c_phone_DE_ortsname_06741_tl} {Sankt~Goar}
\tl_const:cn {c_phone_DE_ortsname_06742_tl} {Boppard}
\tl_const:cn {c_phone_DE_ortsname_06743_tl} {Bacharach}
\tl_const:cn {c_phone_DE_ortsname_06744_tl} {Oberwesel}
\tl_const:cn {c_phone_DE_ortsname_06745_tl} {Gondershausen}
\tl_const:cn {c_phone_DE_ortsname_06746_tl} {Pfalzfeld}
\tl_const:cn {c_phone_DE_ortsname_06747_tl} {Emmelshausen}
\tl_const:cn {c_phone_DE_ortsname_06751_tl} {Bad~Sobernheim}
\tl_const:cn {c_phone_DE_ortsname_06752_tl} {Kirn~Nahe}
\tl_const:cn {c_phone_DE_ortsname_06753_tl} {Meisenheim}
\tl_const:cn {c_phone_DE_ortsname_06754_tl} {Martinstein}
\tl_const:cn {c_phone_DE_ortsname_06755_tl} {Odernheim~am~Glan}
\tl_const:cn {c_phone_DE_ortsname_06756_tl} {Winterbach~Soonwald}
\tl_const:cn {c_phone_DE_ortsname_06757_tl} {Becherbach~bei~Kirn}
\tl_const:cn {c_phone_DE_ortsname_06758_tl} {Waldb\"ockelheim}
\tl_const:cn {c_phone_DE_ortsname_06761_tl} {Simmern~Hunsr\"uck}
\tl_const:cn {c_phone_DE_ortsname_06762_tl} {Kastellaun}
\tl_const:cn {c_phone_DE_ortsname_06763_tl} {Kirchberg~Hunsr\"uck}
\tl_const:cn {c_phone_DE_ortsname_06764_tl} {Rheinb\"ollen}
\tl_const:cn {c_phone_DE_ortsname_06765_tl} {Gem\"unden~Hunsr\"uck}
\tl_const:cn {c_phone_DE_ortsname_06766_tl} {Kisselbach}
\tl_const:cn {c_phone_DE_ortsname_06771_tl} {Sankt~Goarshausen}
\tl_const:cn {c_phone_DE_ortsname_06772_tl} {Nast\"atten}
\tl_const:cn {c_phone_DE_ortsname_06773_tl} {Kamp-Bornhofen}
\tl_const:cn {c_phone_DE_ortsname_06774_tl} {Kaub}
\tl_const:cn {c_phone_DE_ortsname_06775_tl} {Str\"uth~Taunus}
\tl_const:cn {c_phone_DE_ortsname_06776_tl} {Dachsenhausen}
\tl_const:cn {c_phone_DE_ortsname_06781_tl} {Idar-Oberstein}
\tl_const:cn {c_phone_DE_ortsname_06782_tl} {Birkenfeld~Nahe}
\tl_const:cn {c_phone_DE_ortsname_06783_tl} {Baumholder}
\tl_const:cn {c_phone_DE_ortsname_06784_tl} {Weierbach}
\tl_const:cn {c_phone_DE_ortsname_06785_tl} {Herrstein}
\tl_const:cn {c_phone_DE_ortsname_06786_tl} {Kempfeld}
\tl_const:cn {c_phone_DE_ortsname_06787_tl} {Niederbrombach}
\tl_const:cn {c_phone_DE_ortsname_06788_tl} {Sien}
\tl_const:cn {c_phone_DE_ortsname_06789_tl} {Heimbach~Nahe}
\tl_const:cn {c_phone_DE_ortsname_06802_tl} {V\"olklingen-Lauterbach}
\tl_const:cn {c_phone_DE_ortsname_06803_tl} {Mandelbachtal-Ommersheim}
\tl_const:cn {c_phone_DE_ortsname_06804_tl} {Mandelbachtal}
\tl_const:cn {c_phone_DE_ortsname_06805_tl} {Kleinblittersdorf}
\tl_const:cn {c_phone_DE_ortsname_06806_tl} {Heusweiler}
\tl_const:cn {c_phone_DE_ortsname_06809_tl} {Gro\ss rosseln}
\tl_const:cn {c_phone_DE_ortsname_0681_tl} {Saarbr\"ucken}
\tl_const:cn {c_phone_DE_ortsname_06821_tl} {Neunkirchen~Saar}
\tl_const:cn {c_phone_DE_ortsname_06824_tl} {Ottweiler}
\tl_const:cn {c_phone_DE_ortsname_06825_tl} {Illingen~Saar}
\tl_const:cn {c_phone_DE_ortsname_06826_tl} {Bexbach}
\tl_const:cn {c_phone_DE_ortsname_06827_tl} {Eppelborn}
\tl_const:cn {c_phone_DE_ortsname_06831_tl} {Saarlouis}
\tl_const:cn {c_phone_DE_ortsname_06832_tl} {Beckingen-Reimsbach}
\tl_const:cn {c_phone_DE_ortsname_06833_tl} {Rehlingen-Siersburg}
\tl_const:cn {c_phone_DE_ortsname_06834_tl} {Bous}
\tl_const:cn {c_phone_DE_ortsname_06835_tl} {Beckingen}
\tl_const:cn {c_phone_DE_ortsname_06836_tl} {\"Uberherrn}
\tl_const:cn {c_phone_DE_ortsname_06837_tl} {Wallerfangen}
\tl_const:cn {c_phone_DE_ortsname_06838_tl} {Saarwellingen}
\tl_const:cn {c_phone_DE_ortsname_06841_tl} {Homburg~Saar}
\tl_const:cn {c_phone_DE_ortsname_06842_tl} {Blieskastel}
\tl_const:cn {c_phone_DE_ortsname_06843_tl} {Gersheim}
\tl_const:cn {c_phone_DE_ortsname_06844_tl} {Blieskastel-Altheim}
\tl_const:cn {c_phone_DE_ortsname_06848_tl} {Homburg-Ein\"od}
\tl_const:cn {c_phone_DE_ortsname_06849_tl} {Kirkel}
\tl_const:cn {c_phone_DE_ortsname_06851_tl} {St.\ Wendel}
\tl_const:cn {c_phone_DE_ortsname_06852_tl} {Nohfelden}
\tl_const:cn {c_phone_DE_ortsname_06853_tl} {Marpingen}
\tl_const:cn {c_phone_DE_ortsname_06854_tl} {Oberthal~Saar}
\tl_const:cn {c_phone_DE_ortsname_06855_tl} {Freisen}
\tl_const:cn {c_phone_DE_ortsname_06856_tl} {St.\ Wendel-Niederkirchen}
\tl_const:cn {c_phone_DE_ortsname_06857_tl} {Namborn}
\tl_const:cn {c_phone_DE_ortsname_06858_tl} {Ottweiler-F\"urth}
\tl_const:cn {c_phone_DE_ortsname_06861_tl} {Merzig}
\tl_const:cn {c_phone_DE_ortsname_06864_tl} {Mettlach}
\tl_const:cn {c_phone_DE_ortsname_06865_tl} {Mettlach-Orscholz}
\tl_const:cn {c_phone_DE_ortsname_06866_tl} {Perl-Nennig}
\tl_const:cn {c_phone_DE_ortsname_06867_tl} {Perl}
\tl_const:cn {c_phone_DE_ortsname_06868_tl} {Mettlach-T\"unsdorf}
\tl_const:cn {c_phone_DE_ortsname_06869_tl} {Merzig-Silwingen}
\tl_const:cn {c_phone_DE_ortsname_06871_tl} {Wadern}
\tl_const:cn {c_phone_DE_ortsname_06872_tl} {Losheim~am~See}
\tl_const:cn {c_phone_DE_ortsname_06873_tl} {Nonnweiler}
\tl_const:cn {c_phone_DE_ortsname_06874_tl} {Wadern-Nunkirchen}
\tl_const:cn {c_phone_DE_ortsname_06875_tl} {Nonnweiler-Primstal}
\tl_const:cn {c_phone_DE_ortsname_06876_tl} {Weiskirchen~Saar}
\tl_const:cn {c_phone_DE_ortsname_06881_tl} {Lebach}
\tl_const:cn {c_phone_DE_ortsname_06887_tl} {Schmelz~Saar}
\tl_const:cn {c_phone_DE_ortsname_06888_tl} {Lebach-Steinbach}
\tl_const:cn {c_phone_DE_ortsname_06893_tl} {Saarbr\"ucken-Ensheim}
\tl_const:cn {c_phone_DE_ortsname_06894_tl} {St.\ Ingbert}
\tl_const:cn {c_phone_DE_ortsname_06897_tl} {Sulzbach~Saar}
\tl_const:cn {c_phone_DE_ortsname_06898_tl} {V\"olklingen}
\tl_const:cn {c_phone_DE_ortsname_069_tl} {Frankfurt~am~Main}
\tl_const:cn {c_phone_DE_ortsname_07021_tl} {Kirchheim~unter~Teck}
\tl_const:cn {c_phone_DE_ortsname_07022_tl} {N\"urtingen}
\tl_const:cn {c_phone_DE_ortsname_07023_tl} {Weilheim~an~der~Teck}
\tl_const:cn {c_phone_DE_ortsname_07024_tl} {Wendlingen~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07025_tl} {Neuffen}
\tl_const:cn {c_phone_DE_ortsname_07026_tl} {Lenningen}
\tl_const:cn {c_phone_DE_ortsname_07031_tl} {B\"oblingen}
\tl_const:cn {c_phone_DE_ortsname_07032_tl} {Herrenberg}
\tl_const:cn {c_phone_DE_ortsname_07033_tl} {Weil~der~Stadt}
\tl_const:cn {c_phone_DE_ortsname_07034_tl} {Ehningen}
\tl_const:cn {c_phone_DE_ortsname_07041_tl} {M\"uhlacker}
\tl_const:cn {c_phone_DE_ortsname_07042_tl} {Vaihingen~an~der~Enz}
\tl_const:cn {c_phone_DE_ortsname_07043_tl} {Maulbronn}
\tl_const:cn {c_phone_DE_ortsname_07044_tl} {M\"onsheim}
\tl_const:cn {c_phone_DE_ortsname_07045_tl} {Oberderdingen}
\tl_const:cn {c_phone_DE_ortsname_07046_tl} {Zaberfeld}
\tl_const:cn {c_phone_DE_ortsname_07051_tl} {Calw}
\tl_const:cn {c_phone_DE_ortsname_07052_tl} {Bad~Liebenzell}
\tl_const:cn {c_phone_DE_ortsname_07053_tl} {Bad~Teinach-Zavelstein}
\tl_const:cn {c_phone_DE_ortsname_07054_tl} {Wildberg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07055_tl} {Neuweiler~Kreis~Calw}
\tl_const:cn {c_phone_DE_ortsname_07056_tl} {Gechingen}
\tl_const:cn {c_phone_DE_ortsname_07062_tl} {Beilstein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07063_tl} {Bad~Wimpfen}
\tl_const:cn {c_phone_DE_ortsname_07066_tl} {Bad~Rappenau-Bonfeld}
\tl_const:cn {c_phone_DE_ortsname_07071_tl} {T\"ubingen}
\tl_const:cn {c_phone_DE_ortsname_07072_tl} {Gomaringen}
\tl_const:cn {c_phone_DE_ortsname_07073_tl} {Ammerbuch}
\tl_const:cn {c_phone_DE_ortsname_07081_tl} {Bad~Wildbad}
\tl_const:cn {c_phone_DE_ortsname_07082_tl} {Neuenb\"urg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07083_tl} {Bad~Herrenalb}
\tl_const:cn {c_phone_DE_ortsname_07084_tl} {Sch\"omberg~bei~Neuenb\"urg}
\tl_const:cn {c_phone_DE_ortsname_07085_tl} {Enzkl\"osterle}
\tl_const:cn {c_phone_DE_ortsname_0711_tl} {Stuttgart}
\tl_const:cn {c_phone_DE_ortsname_07121_tl} {Reutlingen}
\tl_const:cn {c_phone_DE_ortsname_07122_tl} {St.\ Johann~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07123_tl} {Metzingen~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07124_tl} {Trochtelfingen~Hohenzollern}
\tl_const:cn {c_phone_DE_ortsname_07125_tl} {Bad~Urach}
\tl_const:cn {c_phone_DE_ortsname_07126_tl} {Burladingen-Melchingen}
\tl_const:cn {c_phone_DE_ortsname_07127_tl} {Neckartenzlingen}
\tl_const:cn {c_phone_DE_ortsname_07128_tl} {Sonnenb\"uhl}
\tl_const:cn {c_phone_DE_ortsname_07129_tl} {Lichtenstein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07130_tl} {L\"owenstein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07131_tl} {Heilbronn~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07132_tl} {Neckarsulm}
\tl_const:cn {c_phone_DE_ortsname_07133_tl} {Lauffen~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07134_tl} {Weinsberg}
\tl_const:cn {c_phone_DE_ortsname_07135_tl} {Brackenheim}
\tl_const:cn {c_phone_DE_ortsname_07136_tl} {Bad~Friedrichshall}
\tl_const:cn {c_phone_DE_ortsname_07138_tl} {Schwaigern}
\tl_const:cn {c_phone_DE_ortsname_07139_tl} {Neuenstadt~am~Kocher}
\tl_const:cn {c_phone_DE_ortsname_07141_tl} {Ludwigsburg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07142_tl} {Bietigheim-Bissingen}
\tl_const:cn {c_phone_DE_ortsname_07143_tl} {Besigheim}
\tl_const:cn {c_phone_DE_ortsname_07144_tl} {Marbach~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07145_tl} {Markgr\"oningen}
\tl_const:cn {c_phone_DE_ortsname_07146_tl} {Remseck~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07147_tl} {Sachsenheim~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07148_tl} {Gro\ss bottwar}
\tl_const:cn {c_phone_DE_ortsname_07150_tl} {Korntal-M\"unchingen}
\tl_const:cn {c_phone_DE_ortsname_07151_tl} {Waiblingen}
\tl_const:cn {c_phone_DE_ortsname_07152_tl} {Leonberg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07153_tl} {Plochingen}
\tl_const:cn {c_phone_DE_ortsname_07154_tl} {Kornwestheim}
\tl_const:cn {c_phone_DE_ortsname_07156_tl} {Ditzingen}
\tl_const:cn {c_phone_DE_ortsname_07157_tl} {Waldenbuch}
\tl_const:cn {c_phone_DE_ortsname_07158_tl} {Neuhausen~auf~den~Fildern}
\tl_const:cn {c_phone_DE_ortsname_07159_tl} {Renningen}
\tl_const:cn {c_phone_DE_ortsname_07161_tl} {G\"oppingen}
\tl_const:cn {c_phone_DE_ortsname_07162_tl} {S\"u\ss en}
\tl_const:cn {c_phone_DE_ortsname_07163_tl} {Ebersbach~an~der~Fils}
\tl_const:cn {c_phone_DE_ortsname_07164_tl} {Boll~Kreis~G\"oppingen}
\tl_const:cn {c_phone_DE_ortsname_07165_tl} {G\"oppingen-Hohenstaufen}
\tl_const:cn {c_phone_DE_ortsname_07166_tl} {Adelberg}
\tl_const:cn {c_phone_DE_ortsname_07171_tl} {Schw\"abisch~Gm\"und}
\tl_const:cn {c_phone_DE_ortsname_07172_tl} {Lorch~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07173_tl} {Heubach}
\tl_const:cn {c_phone_DE_ortsname_07174_tl} {M\"ogglingen}
\tl_const:cn {c_phone_DE_ortsname_07175_tl} {Leinzell}
\tl_const:cn {c_phone_DE_ortsname_07176_tl} {Spraitbach}
\tl_const:cn {c_phone_DE_ortsname_07181_tl} {Schorndorf~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07182_tl} {Welzheim}
\tl_const:cn {c_phone_DE_ortsname_07183_tl} {Rudersberg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07184_tl} {Kaisersbach}
\tl_const:cn {c_phone_DE_ortsname_07191_tl} {Backnang}
\tl_const:cn {c_phone_DE_ortsname_07192_tl} {Murrhardt}
\tl_const:cn {c_phone_DE_ortsname_07193_tl} {Sulzbach~an~der~Murr}
\tl_const:cn {c_phone_DE_ortsname_07194_tl} {Spiegelberg}
\tl_const:cn {c_phone_DE_ortsname_07195_tl} {Winnenden}
\tl_const:cn {c_phone_DE_ortsname_07202_tl} {Karlsbad}
\tl_const:cn {c_phone_DE_ortsname_07203_tl} {Walzbachtal}
\tl_const:cn {c_phone_DE_ortsname_07204_tl} {Malsch-V\"olkersbach}
\tl_const:cn {c_phone_DE_ortsname_0721_tl} {Karlsruhe}
\tl_const:cn {c_phone_DE_ortsname_07220_tl} {Forbach-Hundsbach}
\tl_const:cn {c_phone_DE_ortsname_07221_tl} {Baden-Baden}
\tl_const:cn {c_phone_DE_ortsname_07222_tl} {Rastatt}
\tl_const:cn {c_phone_DE_ortsname_07223_tl} {B\"uhl~Baden}
\tl_const:cn {c_phone_DE_ortsname_07224_tl} {Gernsbach}
\tl_const:cn {c_phone_DE_ortsname_07225_tl} {Gaggenau}
\tl_const:cn {c_phone_DE_ortsname_07226_tl} {B\"uhl-Sand}
\tl_const:cn {c_phone_DE_ortsname_07227_tl} {Lichtenau~Baden}
\tl_const:cn {c_phone_DE_ortsname_07228_tl} {Forbach}
\tl_const:cn {c_phone_DE_ortsname_07229_tl} {Iffezheim}
\tl_const:cn {c_phone_DE_ortsname_07231_tl} {Pforzheim}
\tl_const:cn {c_phone_DE_ortsname_07232_tl} {K\"onigsbach-Stein}
\tl_const:cn {c_phone_DE_ortsname_07233_tl} {Niefern-\"Oschelbronn}
\tl_const:cn {c_phone_DE_ortsname_07234_tl} {Tiefenbronn}
\tl_const:cn {c_phone_DE_ortsname_07235_tl} {Unterreichenbach~Kreis~Calw}
\tl_const:cn {c_phone_DE_ortsname_07236_tl} {Keltern}
\tl_const:cn {c_phone_DE_ortsname_07237_tl} {Neulingen~Enzkreis}
\tl_const:cn {c_phone_DE_ortsname_07240_tl} {Pfinztal}
\tl_const:cn {c_phone_DE_ortsname_07242_tl} {Rheinstetten}
\tl_const:cn {c_phone_DE_ortsname_07243_tl} {Ettlingen}
\tl_const:cn {c_phone_DE_ortsname_07244_tl} {Weingarten~Baden}
\tl_const:cn {c_phone_DE_ortsname_07245_tl} {Durmersheim}
\tl_const:cn {c_phone_DE_ortsname_07246_tl} {Malsch~Kreis~Karlsruhe}
\tl_const:cn {c_phone_DE_ortsname_07247_tl} {Linkenheim-Hochstetten}
\tl_const:cn {c_phone_DE_ortsname_07248_tl} {Marxzell}
\tl_const:cn {c_phone_DE_ortsname_07249_tl} {Stutensee}
\tl_const:cn {c_phone_DE_ortsname_07250_tl} {Kraichtal}
\tl_const:cn {c_phone_DE_ortsname_07251_tl} {Bruchsal}
\tl_const:cn {c_phone_DE_ortsname_07252_tl} {Bretten}
\tl_const:cn {c_phone_DE_ortsname_07253_tl} {Bad~Sch\"onborn}
\tl_const:cn {c_phone_DE_ortsname_07254_tl} {Wagh\"ausel}
\tl_const:cn {c_phone_DE_ortsname_07255_tl} {Graben-Neudorf}
\tl_const:cn {c_phone_DE_ortsname_07256_tl} {Philippsburg}
\tl_const:cn {c_phone_DE_ortsname_07257_tl} {Bruchsal-Untergrombach}
\tl_const:cn {c_phone_DE_ortsname_07258_tl} {Oberderdingen-Flehingen}
\tl_const:cn {c_phone_DE_ortsname_07259_tl} {\"Ostringen-Odenheim}
\tl_const:cn {c_phone_DE_ortsname_07260_tl} {Sinsheim-Hilsbach}
\tl_const:cn {c_phone_DE_ortsname_07261_tl} {Sinsheim}
\tl_const:cn {c_phone_DE_ortsname_07262_tl} {Eppingen}
\tl_const:cn {c_phone_DE_ortsname_07263_tl} {Waibstadt}
\tl_const:cn {c_phone_DE_ortsname_07264_tl} {Bad~Rappenau}
\tl_const:cn {c_phone_DE_ortsname_07265_tl} {Angelbachtal}
\tl_const:cn {c_phone_DE_ortsname_07266_tl} {Kirchardt}
\tl_const:cn {c_phone_DE_ortsname_07267_tl} {Gemmingen}
\tl_const:cn {c_phone_DE_ortsname_07268_tl} {Bad~Rappenau-Obergimpern}
\tl_const:cn {c_phone_DE_ortsname_07269_tl} {Sulzfeld~Baden}
\tl_const:cn {c_phone_DE_ortsname_07271_tl} {W\"orth~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_07272_tl} {R\"ulzheim}
\tl_const:cn {c_phone_DE_ortsname_07273_tl} {Hagenbach~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_07274_tl} {Germersheim}
\tl_const:cn {c_phone_DE_ortsname_07275_tl} {Kandel}
\tl_const:cn {c_phone_DE_ortsname_07276_tl} {Herxheim~bei~Landau~Pfalz}
\tl_const:cn {c_phone_DE_ortsname_07277_tl} {W\"orth-B\"uchelberg}
\tl_const:cn {c_phone_DE_ortsname_07300_tl} {Roggenburg}
\tl_const:cn {c_phone_DE_ortsname_07302_tl} {Pfaffenhofen~an~der~Roth}
\tl_const:cn {c_phone_DE_ortsname_07303_tl} {Illertissen}
\tl_const:cn {c_phone_DE_ortsname_07304_tl} {Blaustein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07305_tl} {Erbach~Donau}
\tl_const:cn {c_phone_DE_ortsname_07306_tl} {V\"ohringen~Iller}
\tl_const:cn {c_phone_DE_ortsname_07307_tl} {Senden~Iller}
\tl_const:cn {c_phone_DE_ortsname_07308_tl} {Nersingen}
\tl_const:cn {c_phone_DE_ortsname_07309_tl} {Wei\ss enhorn}
\tl_const:cn {c_phone_DE_ortsname_0731_tl} {Ulm~Donau}
\tl_const:cn {c_phone_DE_ortsname_07321_tl} {Heidenheim~an~der~Brenz}
\tl_const:cn {c_phone_DE_ortsname_07322_tl} {Giengen~an~der~Brenz}
\tl_const:cn {c_phone_DE_ortsname_07323_tl} {Gerstetten}
\tl_const:cn {c_phone_DE_ortsname_07324_tl} {Herbrechtingen}
\tl_const:cn {c_phone_DE_ortsname_07325_tl} {Sontheim~an~der~Brenz}
\tl_const:cn {c_phone_DE_ortsname_07326_tl} {Neresheim}
\tl_const:cn {c_phone_DE_ortsname_07327_tl} {Dischingen}
\tl_const:cn {c_phone_DE_ortsname_07328_tl} {K\"onigsbronn}
\tl_const:cn {c_phone_DE_ortsname_07329_tl} {Steinheim~am~Albuch}
\tl_const:cn {c_phone_DE_ortsname_07331_tl} {Geislingen~an~der~Steige}
\tl_const:cn {c_phone_DE_ortsname_07332_tl} {Lauterstein}
\tl_const:cn {c_phone_DE_ortsname_07333_tl} {Laichingen}
\tl_const:cn {c_phone_DE_ortsname_07334_tl} {Deggingen}
\tl_const:cn {c_phone_DE_ortsname_07335_tl} {Wiesensteig}
\tl_const:cn {c_phone_DE_ortsname_07336_tl} {Lonsee}
\tl_const:cn {c_phone_DE_ortsname_07337_tl} {Nellingen~Alb}
\tl_const:cn {c_phone_DE_ortsname_07340_tl} {Neenstetten}
\tl_const:cn {c_phone_DE_ortsname_07343_tl} {Buch~bei~Illertissen}
\tl_const:cn {c_phone_DE_ortsname_07344_tl} {Blaubeuren}
\tl_const:cn {c_phone_DE_ortsname_07345_tl} {Langenau~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07346_tl} {Illerkirchberg}
\tl_const:cn {c_phone_DE_ortsname_07347_tl} {Dietenheim}
\tl_const:cn {c_phone_DE_ortsname_07348_tl} {Beimerstetten}
\tl_const:cn {c_phone_DE_ortsname_07351_tl} {Biberach~an~der~Ri\ss}
\tl_const:cn {c_phone_DE_ortsname_07352_tl} {Ochsenhausen}
\tl_const:cn {c_phone_DE_ortsname_07353_tl} {Schwendi}
\tl_const:cn {c_phone_DE_ortsname_07354_tl} {Erolzheim}
\tl_const:cn {c_phone_DE_ortsname_07355_tl} {Hochdorf~Ri\ss}
\tl_const:cn {c_phone_DE_ortsname_07356_tl} {Schemmerhofen}
\tl_const:cn {c_phone_DE_ortsname_07357_tl} {Attenweiler}
\tl_const:cn {c_phone_DE_ortsname_07358_tl} {Eberhardzell-F\"uramoos}
\tl_const:cn {c_phone_DE_ortsname_07361_tl} {Aalen}
\tl_const:cn {c_phone_DE_ortsname_07362_tl} {Bopfingen}
\tl_const:cn {c_phone_DE_ortsname_07363_tl} {Lauchheim}
\tl_const:cn {c_phone_DE_ortsname_07364_tl} {Oberkochen}
\tl_const:cn {c_phone_DE_ortsname_07365_tl} {Essingen~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07366_tl} {Abtsgm\"und}
\tl_const:cn {c_phone_DE_ortsname_07367_tl} {Aalen-Ebnat}
\tl_const:cn {c_phone_DE_ortsname_07371_tl} {Riedlingen~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07373_tl} {Zwiefalten}
\tl_const:cn {c_phone_DE_ortsname_07374_tl} {Uttenweiler}
\tl_const:cn {c_phone_DE_ortsname_07375_tl} {Obermarchtal}
\tl_const:cn {c_phone_DE_ortsname_07376_tl} {Langenenslingen}
\tl_const:cn {c_phone_DE_ortsname_07381_tl} {M\"unsingen}
\tl_const:cn {c_phone_DE_ortsname_07382_tl} {R\"omerstein}
\tl_const:cn {c_phone_DE_ortsname_07383_tl} {M\"unsingen-Buttenhausen}
\tl_const:cn {c_phone_DE_ortsname_07384_tl} {Schelklingen-H\"utten}
\tl_const:cn {c_phone_DE_ortsname_07385_tl} {Gomadingen}
\tl_const:cn {c_phone_DE_ortsname_07386_tl} {Hayingen}
\tl_const:cn {c_phone_DE_ortsname_07387_tl} {Hohenstein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07388_tl} {Pfronstetten}
\tl_const:cn {c_phone_DE_ortsname_07389_tl} {Heroldstatt}
\tl_const:cn {c_phone_DE_ortsname_07391_tl} {Ehingen~Donau}
\tl_const:cn {c_phone_DE_ortsname_07392_tl} {Laupheim}
\tl_const:cn {c_phone_DE_ortsname_07393_tl} {Munderkingen}
\tl_const:cn {c_phone_DE_ortsname_07394_tl} {Schelklingen}
\tl_const:cn {c_phone_DE_ortsname_07395_tl} {Ehingen-D\"achingen}
\tl_const:cn {c_phone_DE_ortsname_07402_tl} {Fluorn-Winzeln}
\tl_const:cn {c_phone_DE_ortsname_07403_tl} {Dunningen}
\tl_const:cn {c_phone_DE_ortsname_07404_tl} {Epfendorf}
\tl_const:cn {c_phone_DE_ortsname_0741_tl} {Rottweil}
\tl_const:cn {c_phone_DE_ortsname_07420_tl} {Dei\ss lingen}
\tl_const:cn {c_phone_DE_ortsname_07422_tl} {Schramberg}
\tl_const:cn {c_phone_DE_ortsname_07423_tl} {Oberndorf~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07424_tl} {Spaichingen}
\tl_const:cn {c_phone_DE_ortsname_07425_tl} {Trossingen}
\tl_const:cn {c_phone_DE_ortsname_07426_tl} {Gosheim}
\tl_const:cn {c_phone_DE_ortsname_07427_tl} {Sch\"omberg~bei~Balingen}
\tl_const:cn {c_phone_DE_ortsname_07428_tl} {Rosenfeld}
\tl_const:cn {c_phone_DE_ortsname_07429_tl} {Egesheim}
\tl_const:cn {c_phone_DE_ortsname_07431_tl} {Albstadt-Ebingen}
\tl_const:cn {c_phone_DE_ortsname_07432_tl} {Albstadt-Tailfingen}
\tl_const:cn {c_phone_DE_ortsname_07433_tl} {Balingen}
\tl_const:cn {c_phone_DE_ortsname_07434_tl} {Winterlingen}
\tl_const:cn {c_phone_DE_ortsname_07435_tl} {Albstadt-Laufen}
\tl_const:cn {c_phone_DE_ortsname_07436_tl} {Me\ss stetten-Oberdigisheim}
\tl_const:cn {c_phone_DE_ortsname_07440_tl} {Bad~Rippoldsau}
\tl_const:cn {c_phone_DE_ortsname_07441_tl} {Freudenstadt}
\tl_const:cn {c_phone_DE_ortsname_07442_tl} {Baiersbronn}
\tl_const:cn {c_phone_DE_ortsname_07443_tl} {Dornstetten}
\tl_const:cn {c_phone_DE_ortsname_07444_tl} {Alpirsbach}
\tl_const:cn {c_phone_DE_ortsname_07445_tl} {Pfalzgrafenweiler}
\tl_const:cn {c_phone_DE_ortsname_07446_tl} {Lo\ss burg}
\tl_const:cn {c_phone_DE_ortsname_07447_tl} {Baiersbronn-Schwarzenberg}
\tl_const:cn {c_phone_DE_ortsname_07448_tl} {Seewald}
\tl_const:cn {c_phone_DE_ortsname_07449_tl} {Baiersbronn-Obertal}
\tl_const:cn {c_phone_DE_ortsname_07451_tl} {Horb~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07452_tl} {Nagold}
\tl_const:cn {c_phone_DE_ortsname_07453_tl} {Altensteig~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07454_tl} {Sulz~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07455_tl} {Dornhan}
\tl_const:cn {c_phone_DE_ortsname_07456_tl} {Haiterbach}
\tl_const:cn {c_phone_DE_ortsname_07457_tl} {Rottenburg-Ergenzingen}
\tl_const:cn {c_phone_DE_ortsname_07458_tl} {Ebhausen}
\tl_const:cn {c_phone_DE_ortsname_07459_tl} {Nagold-Hochdorf}
\tl_const:cn {c_phone_DE_ortsname_07461_tl} {Tuttlingen}
\tl_const:cn {c_phone_DE_ortsname_07462_tl} {Immendingen}
\tl_const:cn {c_phone_DE_ortsname_07463_tl} {M\"uhlheim~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_07464_tl} {Talheim~Kreis~Tuttlingen}
\tl_const:cn {c_phone_DE_ortsname_07465_tl} {Emmingen-Liptingen}
\tl_const:cn {c_phone_DE_ortsname_07466_tl} {Beuron}
\tl_const:cn {c_phone_DE_ortsname_07467_tl} {Neuhausen~ob~Eck}
\tl_const:cn {c_phone_DE_ortsname_07471_tl} {Hechingen}
\tl_const:cn {c_phone_DE_ortsname_07472_tl} {Rottenburg~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07473_tl} {M\"ossingen}
\tl_const:cn {c_phone_DE_ortsname_07474_tl} {Haigerloch}
\tl_const:cn {c_phone_DE_ortsname_07475_tl} {Burladingen}
\tl_const:cn {c_phone_DE_ortsname_07476_tl} {Bisingen}
\tl_const:cn {c_phone_DE_ortsname_07477_tl} {Jungingen~bei~Hechingen}
\tl_const:cn {c_phone_DE_ortsname_07478_tl} {Hirrlingen}
\tl_const:cn {c_phone_DE_ortsname_07482_tl} {Horb-Dettingen}
\tl_const:cn {c_phone_DE_ortsname_07483_tl} {Horb-M\"uhringen}
\tl_const:cn {c_phone_DE_ortsname_07484_tl} {Simmersfeld}
\tl_const:cn {c_phone_DE_ortsname_07485_tl} {Empfingen}
\tl_const:cn {c_phone_DE_ortsname_07486_tl} {Horb-Altheim}
\tl_const:cn {c_phone_DE_ortsname_07502_tl} {Wolpertswende}
\tl_const:cn {c_phone_DE_ortsname_07503_tl} {Wilhelmsdorf~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07504_tl} {Horgenzell}
\tl_const:cn {c_phone_DE_ortsname_07505_tl} {Fronreute}
\tl_const:cn {c_phone_DE_ortsname_07506_tl} {Wangen-Leupolz}
\tl_const:cn {c_phone_DE_ortsname_0751_tl} {Ravensburg}
\tl_const:cn {c_phone_DE_ortsname_07520_tl} {Bodnegg}
\tl_const:cn {c_phone_DE_ortsname_07522_tl} {Wangen~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_07524_tl} {Bad~Waldsee}
\tl_const:cn {c_phone_DE_ortsname_07525_tl} {Aulendorf}
\tl_const:cn {c_phone_DE_ortsname_07527_tl} {Wolfegg}
\tl_const:cn {c_phone_DE_ortsname_07528_tl} {Neukirch~bei~Tettnang}
\tl_const:cn {c_phone_DE_ortsname_07529_tl} {Waldburg~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07531_tl} {Konstanz}
\tl_const:cn {c_phone_DE_ortsname_07532_tl} {Meersburg}
\tl_const:cn {c_phone_DE_ortsname_07533_tl} {Allensbach}
\tl_const:cn {c_phone_DE_ortsname_07534_tl} {Reichenau~Baden}
\tl_const:cn {c_phone_DE_ortsname_07541_tl} {Friedrichshafen}
\tl_const:cn {c_phone_DE_ortsname_07542_tl} {Tettnang}
\tl_const:cn {c_phone_DE_ortsname_07543_tl} {Kressbronn~am~Bodensee}
\tl_const:cn {c_phone_DE_ortsname_07544_tl} {Markdorf}
\tl_const:cn {c_phone_DE_ortsname_07545_tl} {Immenstaad~am~Bodensee}
\tl_const:cn {c_phone_DE_ortsname_07546_tl} {Oberteuringen}
\tl_const:cn {c_phone_DE_ortsname_07551_tl} {\"Uberlingen~Bodensee}
\tl_const:cn {c_phone_DE_ortsname_07552_tl} {Pfullendorf}
\tl_const:cn {c_phone_DE_ortsname_07553_tl} {Salem~Baden}
\tl_const:cn {c_phone_DE_ortsname_07554_tl} {Heiligenberg~Baden}
\tl_const:cn {c_phone_DE_ortsname_07555_tl} {Deggenhausertal}
\tl_const:cn {c_phone_DE_ortsname_07556_tl} {Uhldingen-M\"uhlhofen}
\tl_const:cn {c_phone_DE_ortsname_07557_tl} {Herdwangen-Sch\"onach}
\tl_const:cn {c_phone_DE_ortsname_07558_tl} {Illmensee}
\tl_const:cn {c_phone_DE_ortsname_07561_tl} {Leutkirch~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_07562_tl} {Isny~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_07563_tl} {Ki\ss legg}
\tl_const:cn {c_phone_DE_ortsname_07564_tl} {Bad~Wurzach}
\tl_const:cn {c_phone_DE_ortsname_07565_tl} {Aichstetten~Kreis~Ravensburg}
\tl_const:cn {c_phone_DE_ortsname_07566_tl} {Argenb\"uhl}
\tl_const:cn {c_phone_DE_ortsname_07567_tl} {Leutkirch-Friesenhofen}
\tl_const:cn {c_phone_DE_ortsname_07568_tl} {Bad~Wurzach-Hauerz}
\tl_const:cn {c_phone_DE_ortsname_07569_tl} {Isny-Eisenbach}
\tl_const:cn {c_phone_DE_ortsname_07570_tl} {Sigmaringen-Gutenstein}
\tl_const:cn {c_phone_DE_ortsname_07571_tl} {Sigmaringen}
\tl_const:cn {c_phone_DE_ortsname_07572_tl} {Mengen~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07573_tl} {Stetten~am~kalten~Markt}
\tl_const:cn {c_phone_DE_ortsname_07574_tl} {Gammertingen}
\tl_const:cn {c_phone_DE_ortsname_07575_tl} {Me\ss kirch}
\tl_const:cn {c_phone_DE_ortsname_07576_tl} {Krauchenwies}
\tl_const:cn {c_phone_DE_ortsname_07577_tl} {Veringenstadt}
\tl_const:cn {c_phone_DE_ortsname_07578_tl} {Wald~Hohenzollern}
\tl_const:cn {c_phone_DE_ortsname_07579_tl} {Schwenningen~Baden}
\tl_const:cn {c_phone_DE_ortsname_07581_tl} {Saulgau}
\tl_const:cn {c_phone_DE_ortsname_07582_tl} {Bad~Buchau}
\tl_const:cn {c_phone_DE_ortsname_07583_tl} {Bad~Schussenried}
\tl_const:cn {c_phone_DE_ortsname_07584_tl} {Altshausen}
\tl_const:cn {c_phone_DE_ortsname_07585_tl} {Ostrach}
\tl_const:cn {c_phone_DE_ortsname_07586_tl} {Herbertingen}
\tl_const:cn {c_phone_DE_ortsname_07587_tl} {Ho\ss kirch}
\tl_const:cn {c_phone_DE_ortsname_07602_tl} {Oberried~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_0761_tl} {Freiburg~im~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07620_tl} {Schopfheim-Gersbach}
\tl_const:cn {c_phone_DE_ortsname_07621_tl} {L\"orrach}
\tl_const:cn {c_phone_DE_ortsname_07622_tl} {Schopfheim}
\tl_const:cn {c_phone_DE_ortsname_07623_tl} {Rheinfelden~Baden}
\tl_const:cn {c_phone_DE_ortsname_07624_tl} {Grenzach-Wyhlen}
\tl_const:cn {c_phone_DE_ortsname_07625_tl} {Zell~im~Wiesental}
\tl_const:cn {c_phone_DE_ortsname_07626_tl} {Kandern}
\tl_const:cn {c_phone_DE_ortsname_07627_tl} {Steinen~Kreis~L\"orrach}
\tl_const:cn {c_phone_DE_ortsname_07628_tl} {Efringen-Kirchen}
\tl_const:cn {c_phone_DE_ortsname_07629_tl} {Tegernau~Baden}
\tl_const:cn {c_phone_DE_ortsname_07631_tl} {M\"ullheim~Baden}
\tl_const:cn {c_phone_DE_ortsname_07632_tl} {Badenweiler}
\tl_const:cn {c_phone_DE_ortsname_07633_tl} {Staufen~im~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07634_tl} {Sulzburg}
\tl_const:cn {c_phone_DE_ortsname_07635_tl} {Schliengen}
\tl_const:cn {c_phone_DE_ortsname_07636_tl} {M\"unstertal~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07641_tl} {Emmendingen}
\tl_const:cn {c_phone_DE_ortsname_07642_tl} {Endingen~Kaiserstuhl}
\tl_const:cn {c_phone_DE_ortsname_07643_tl} {Herbolzheim~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07644_tl} {Kenzingen}
\tl_const:cn {c_phone_DE_ortsname_07645_tl} {Freiamt}
\tl_const:cn {c_phone_DE_ortsname_07646_tl} {Weisweil~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07651_tl} {Titisee-Neustadt}
\tl_const:cn {c_phone_DE_ortsname_07652_tl} {Hinterzarten}
\tl_const:cn {c_phone_DE_ortsname_07653_tl} {Lenzkirch}
\tl_const:cn {c_phone_DE_ortsname_07654_tl} {L\"offingen}
\tl_const:cn {c_phone_DE_ortsname_07655_tl} {Feldberg-Altglash\"utten}
\tl_const:cn {c_phone_DE_ortsname_07656_tl} {Schluchsee}
\tl_const:cn {c_phone_DE_ortsname_07657_tl} {Eisenbach~Hochschwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07660_tl} {St.\ Peter~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07661_tl} {Kirchzarten}
\tl_const:cn {c_phone_DE_ortsname_07662_tl} {Vogtsburg~im~Kaiserstuhl}
\tl_const:cn {c_phone_DE_ortsname_07663_tl} {Eichstetten}
\tl_const:cn {c_phone_DE_ortsname_07664_tl} {Freiburg-Tiengen}
\tl_const:cn {c_phone_DE_ortsname_07665_tl} {March~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07666_tl} {Denzlingen}
\tl_const:cn {c_phone_DE_ortsname_07667_tl} {Breisach~am~Rhein}
\tl_const:cn {c_phone_DE_ortsname_07668_tl} {Ihringen}
\tl_const:cn {c_phone_DE_ortsname_07669_tl} {St.\ M\"argen}
\tl_const:cn {c_phone_DE_ortsname_07671_tl} {Todtnau}
\tl_const:cn {c_phone_DE_ortsname_07672_tl} {St.\ Blasien}
\tl_const:cn {c_phone_DE_ortsname_07673_tl} {Sch\"onau~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07674_tl} {Todtmoos}
\tl_const:cn {c_phone_DE_ortsname_07675_tl} {Bernau~Baden}
\tl_const:cn {c_phone_DE_ortsname_07676_tl} {Feldberg~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07681_tl} {Waldkirch~Breisgau}
\tl_const:cn {c_phone_DE_ortsname_07682_tl} {Elzach}
\tl_const:cn {c_phone_DE_ortsname_07683_tl} {Simonswald}
\tl_const:cn {c_phone_DE_ortsname_07684_tl} {Glottertal}
\tl_const:cn {c_phone_DE_ortsname_07685_tl} {Gutach-Bleibach}
\tl_const:cn {c_phone_DE_ortsname_07702_tl} {Blumberg~Baden}
\tl_const:cn {c_phone_DE_ortsname_07703_tl} {Bonndorf~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07704_tl} {Geisingen~Baden}
\tl_const:cn {c_phone_DE_ortsname_07705_tl} {Wolterdingen~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07706_tl} {Oberbaldingen}
\tl_const:cn {c_phone_DE_ortsname_07707_tl} {Br\"aunlingen}
\tl_const:cn {c_phone_DE_ortsname_07708_tl} {Geisingen-Leipferdingen}
\tl_const:cn {c_phone_DE_ortsname_07709_tl} {Wutach}
\tl_const:cn {c_phone_DE_ortsname_0771_tl} {Donaueschingen}
\tl_const:cn {c_phone_DE_ortsname_07720_tl} {Schwenningen~am~Neckar}
\tl_const:cn {c_phone_DE_ortsname_07721_tl} {Villingen~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07722_tl} {Triberg~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07723_tl} {Furtwangen~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07724_tl} {St.\ Georgen~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07725_tl} {K\"onigsfeld~im~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07726_tl} {Bad~D\"urrheim}
\tl_const:cn {c_phone_DE_ortsname_07727_tl} {V\"ohrenbach}
\tl_const:cn {c_phone_DE_ortsname_07728_tl} {Niedereschach}
\tl_const:cn {c_phone_DE_ortsname_07729_tl} {Tennenbronn}
\tl_const:cn {c_phone_DE_ortsname_07731_tl} {Singen~Hohentwiel}
\tl_const:cn {c_phone_DE_ortsname_07732_tl} {Radolfzell~am~Bodensee}
\tl_const:cn {c_phone_DE_ortsname_07733_tl} {Engen~Hegau}
\tl_const:cn {c_phone_DE_ortsname_07734_tl} {Gailingen}
\tl_const:cn {c_phone_DE_ortsname_07735_tl} {\"Ohningen}
\tl_const:cn {c_phone_DE_ortsname_07736_tl} {Tengen}
\tl_const:cn {c_phone_DE_ortsname_07738_tl} {Stei\ss lingen}
\tl_const:cn {c_phone_DE_ortsname_07739_tl} {Hilzingen}
\tl_const:cn {c_phone_DE_ortsname_07741_tl} {Tiengen~Hochrhein}
\tl_const:cn {c_phone_DE_ortsname_07742_tl} {Klettgau}
\tl_const:cn {c_phone_DE_ortsname_07743_tl} {\"Uhlingen-Birkendorf}
\tl_const:cn {c_phone_DE_ortsname_07744_tl} {St\"uhlingen}
\tl_const:cn {c_phone_DE_ortsname_07745_tl} {Jestetten}
\tl_const:cn {c_phone_DE_ortsname_07746_tl} {Wut\"oschingen}
\tl_const:cn {c_phone_DE_ortsname_07747_tl} {Berau}
\tl_const:cn {c_phone_DE_ortsname_07748_tl} {Grafenhausen~Hochschwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07751_tl} {Waldshut}
\tl_const:cn {c_phone_DE_ortsname_07753_tl} {Albbruck}
\tl_const:cn {c_phone_DE_ortsname_07754_tl} {G\"orwihl}
\tl_const:cn {c_phone_DE_ortsname_07755_tl} {Weilheim~Kreis~Waldshut}
\tl_const:cn {c_phone_DE_ortsname_07761_tl} {Bad~S\"ackingen}
\tl_const:cn {c_phone_DE_ortsname_07762_tl} {Wehr~Baden}
\tl_const:cn {c_phone_DE_ortsname_07763_tl} {Murg}
\tl_const:cn {c_phone_DE_ortsname_07764_tl} {Herrischried}
\tl_const:cn {c_phone_DE_ortsname_07765_tl} {Rickenbach~Hotzenwald}
\tl_const:cn {c_phone_DE_ortsname_07771_tl} {Stockach}
\tl_const:cn {c_phone_DE_ortsname_07773_tl} {Bodman-Ludwigshafen}
\tl_const:cn {c_phone_DE_ortsname_07774_tl} {Eigeltingen}
\tl_const:cn {c_phone_DE_ortsname_07775_tl} {M\"uhlingen}
\tl_const:cn {c_phone_DE_ortsname_07777_tl} {Sauldorf}
\tl_const:cn {c_phone_DE_ortsname_07802_tl} {Oberkirch~Baden}
\tl_const:cn {c_phone_DE_ortsname_07803_tl} {Gengenbach}
\tl_const:cn {c_phone_DE_ortsname_07804_tl} {Oppenau}
\tl_const:cn {c_phone_DE_ortsname_07805_tl} {Appenweier}
\tl_const:cn {c_phone_DE_ortsname_07806_tl} {Bad~Peterstal-Griesbach}
\tl_const:cn {c_phone_DE_ortsname_07807_tl} {Neuried~Ortenaukreis}
\tl_const:cn {c_phone_DE_ortsname_07808_tl} {Hohberg~bei~Offenburg}
\tl_const:cn {c_phone_DE_ortsname_0781_tl} {Offenburg}
\tl_const:cn {c_phone_DE_ortsname_07821_tl} {Lahr~Schwarzwald}
\tl_const:cn {c_phone_DE_ortsname_07822_tl} {Ettenheim}
\tl_const:cn {c_phone_DE_ortsname_07823_tl} {Seelbach~Schutter}
\tl_const:cn {c_phone_DE_ortsname_07824_tl} {Schwanau}
\tl_const:cn {c_phone_DE_ortsname_07825_tl} {Kippenheim}
\tl_const:cn {c_phone_DE_ortsname_07826_tl} {Schuttertal}
\tl_const:cn {c_phone_DE_ortsname_07831_tl} {Hausach}
\tl_const:cn {c_phone_DE_ortsname_07832_tl} {Haslach~im~Kinzigtal}
\tl_const:cn {c_phone_DE_ortsname_07833_tl} {Hornberg~Schwarzwaldbahn}
\tl_const:cn {c_phone_DE_ortsname_07834_tl} {Wolfach}
\tl_const:cn {c_phone_DE_ortsname_07835_tl} {Zell~am~Harmersbach}
\tl_const:cn {c_phone_DE_ortsname_07836_tl} {Schiltach}
\tl_const:cn {c_phone_DE_ortsname_07837_tl} {Oberharmersbach}
\tl_const:cn {c_phone_DE_ortsname_07838_tl} {Nordrach}
\tl_const:cn {c_phone_DE_ortsname_07839_tl} {Schapbach}
\tl_const:cn {c_phone_DE_ortsname_07841_tl} {Achern}
\tl_const:cn {c_phone_DE_ortsname_07842_tl} {Kappelrodeck}
\tl_const:cn {c_phone_DE_ortsname_07843_tl} {Renchen}
\tl_const:cn {c_phone_DE_ortsname_07844_tl} {Rheinau}
\tl_const:cn {c_phone_DE_ortsname_07851_tl} {Kehl}
\tl_const:cn {c_phone_DE_ortsname_07852_tl} {Willst\"att}
\tl_const:cn {c_phone_DE_ortsname_07853_tl} {Kehl-Bodersweier}
\tl_const:cn {c_phone_DE_ortsname_07854_tl} {Kehl-Goldscheuer}
\tl_const:cn {c_phone_DE_ortsname_07903_tl} {Mainhardt}
\tl_const:cn {c_phone_DE_ortsname_07904_tl} {Ilshofen}
\tl_const:cn {c_phone_DE_ortsname_07905_tl} {Langenburg}
\tl_const:cn {c_phone_DE_ortsname_07906_tl} {Braunsbach}
\tl_const:cn {c_phone_DE_ortsname_07907_tl} {Schw\"abisch~Hall-Sulzdorf}
\tl_const:cn {c_phone_DE_ortsname_0791_tl} {Schw\"abisch~Hall}
\tl_const:cn {c_phone_DE_ortsname_07930_tl} {Boxberg~Baden}
\tl_const:cn {c_phone_DE_ortsname_07931_tl} {Bad~Mergentheim}
\tl_const:cn {c_phone_DE_ortsname_07932_tl} {Niederstetten~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07933_tl} {Creglingen}
\tl_const:cn {c_phone_DE_ortsname_07934_tl} {Weikersheim}
\tl_const:cn {c_phone_DE_ortsname_07935_tl} {Schrozberg}
\tl_const:cn {c_phone_DE_ortsname_07936_tl} {Schrozberg-Bartenstein}
\tl_const:cn {c_phone_DE_ortsname_07937_tl} {D\"orzbach}
\tl_const:cn {c_phone_DE_ortsname_07938_tl} {Mulfingen~Jagst}
\tl_const:cn {c_phone_DE_ortsname_07939_tl} {Schrozberg-Spielbach}
\tl_const:cn {c_phone_DE_ortsname_07940_tl} {K\"unzelsau}
\tl_const:cn {c_phone_DE_ortsname_07941_tl} {\"Ohringen}
\tl_const:cn {c_phone_DE_ortsname_07942_tl} {Neuenstein~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07943_tl} {Sch\"ontal~Jagst}
\tl_const:cn {c_phone_DE_ortsname_07944_tl} {Kupferzell}
\tl_const:cn {c_phone_DE_ortsname_07945_tl} {W\"ustenrot}
\tl_const:cn {c_phone_DE_ortsname_07946_tl} {Bretzfeld}
\tl_const:cn {c_phone_DE_ortsname_07947_tl} {Forchtenberg}
\tl_const:cn {c_phone_DE_ortsname_07948_tl} {\"Ohringen-Ohrnberg}
\tl_const:cn {c_phone_DE_ortsname_07949_tl} {Pfedelbach-Untersteinbach}
\tl_const:cn {c_phone_DE_ortsname_07950_tl} {Schnelldorf}
\tl_const:cn {c_phone_DE_ortsname_07951_tl} {Crailsheim}
\tl_const:cn {c_phone_DE_ortsname_07952_tl} {Gerabronn}
\tl_const:cn {c_phone_DE_ortsname_07953_tl} {Blaufelden}
\tl_const:cn {c_phone_DE_ortsname_07954_tl} {Kirchberg~an~der~Jagst}
\tl_const:cn {c_phone_DE_ortsname_07955_tl} {Wallhausen~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_07957_tl} {Kre\ss berg}
\tl_const:cn {c_phone_DE_ortsname_07958_tl} {Rot~am~See-Brettheim}
\tl_const:cn {c_phone_DE_ortsname_07959_tl} {Frankenhardt}
\tl_const:cn {c_phone_DE_ortsname_07961_tl} {Ellwangen~Jagst}
\tl_const:cn {c_phone_DE_ortsname_07962_tl} {Fichtenau}
\tl_const:cn {c_phone_DE_ortsname_07963_tl} {Adelmannsfelden}
\tl_const:cn {c_phone_DE_ortsname_07964_tl} {St\"odtlen}
\tl_const:cn {c_phone_DE_ortsname_07965_tl} {Ellwangen-R\"ohlingen}
\tl_const:cn {c_phone_DE_ortsname_07966_tl} {Unterschneidheim}
\tl_const:cn {c_phone_DE_ortsname_07967_tl} {Jagstzell}
\tl_const:cn {c_phone_DE_ortsname_07971_tl} {Gaildorf}
\tl_const:cn {c_phone_DE_ortsname_07972_tl} {Gschwend~bei~Gaildorf}
\tl_const:cn {c_phone_DE_ortsname_07973_tl} {Obersontheim}
\tl_const:cn {c_phone_DE_ortsname_07974_tl} {B\"uhlerzell}
\tl_const:cn {c_phone_DE_ortsname_07975_tl} {Untergr\"oningen}
\tl_const:cn {c_phone_DE_ortsname_07976_tl} {Sulzbach-Laufen}
\tl_const:cn {c_phone_DE_ortsname_07977_tl} {Oberrot~bei~Gaildorf}
\tl_const:cn {c_phone_DE_ortsname_08020_tl} {Weyarn}
\tl_const:cn {c_phone_DE_ortsname_08021_tl} {Waakirchen}
\tl_const:cn {c_phone_DE_ortsname_08022_tl} {Tegernsee}
\tl_const:cn {c_phone_DE_ortsname_08023_tl} {Bayrischzell}
\tl_const:cn {c_phone_DE_ortsname_08024_tl} {Holzkirchen}
\tl_const:cn {c_phone_DE_ortsname_08025_tl} {Miesbach}
\tl_const:cn {c_phone_DE_ortsname_08026_tl} {Hausham}
\tl_const:cn {c_phone_DE_ortsname_08027_tl} {Dietramszell}
\tl_const:cn {c_phone_DE_ortsname_08028_tl} {Fischbachau}
\tl_const:cn {c_phone_DE_ortsname_08029_tl} {Kreuth~bei~Tegernsee}
\tl_const:cn {c_phone_DE_ortsname_08031_tl} {Rosenheim~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08032_tl} {Rohrdorf~Kreis~Rosenheim}
\tl_const:cn {c_phone_DE_ortsname_08033_tl} {Oberaudorf}
\tl_const:cn {c_phone_DE_ortsname_08034_tl} {Brannenburg}
\tl_const:cn {c_phone_DE_ortsname_08035_tl} {Raubling}
\tl_const:cn {c_phone_DE_ortsname_08036_tl} {Stephanskirchen~Simssee}
\tl_const:cn {c_phone_DE_ortsname_08038_tl} {Vogtareuth}
\tl_const:cn {c_phone_DE_ortsname_08039_tl} {Rott~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08041_tl} {Bad~T\"olz}
\tl_const:cn {c_phone_DE_ortsname_08042_tl} {Lenggries}
\tl_const:cn {c_phone_DE_ortsname_08043_tl} {Jachenau}
\tl_const:cn {c_phone_DE_ortsname_08045_tl} {Lenggries-Fall}
\tl_const:cn {c_phone_DE_ortsname_08046_tl} {Bad~Heilbrunn}
\tl_const:cn {c_phone_DE_ortsname_08051_tl} {Prien~am~Chiemsee}
\tl_const:cn {c_phone_DE_ortsname_08052_tl} {Aschau~im~Chiemgau}
\tl_const:cn {c_phone_DE_ortsname_08053_tl} {Bad~Endorf}
\tl_const:cn {c_phone_DE_ortsname_08054_tl} {Breitbrunn~am~Chiemsee}
\tl_const:cn {c_phone_DE_ortsname_08055_tl} {Halfing}
\tl_const:cn {c_phone_DE_ortsname_08056_tl} {Eggst\"att}
\tl_const:cn {c_phone_DE_ortsname_08057_tl} {Aschau-Sachrang}
\tl_const:cn {c_phone_DE_ortsname_08061_tl} {Bad~Aibling}
\tl_const:cn {c_phone_DE_ortsname_08062_tl} {Bruckm\"uhl~Mangfall}
\tl_const:cn {c_phone_DE_ortsname_08063_tl} {Feldkirchen-Westerham}
\tl_const:cn {c_phone_DE_ortsname_08064_tl} {Au~bei~Bad~Aibling}
\tl_const:cn {c_phone_DE_ortsname_08065_tl} {Tuntenhausen-Sch\"onau}
\tl_const:cn {c_phone_DE_ortsname_08066_tl} {Bad~Feilnbach}
\tl_const:cn {c_phone_DE_ortsname_08067_tl} {Tuntenhausen}
\tl_const:cn {c_phone_DE_ortsname_08071_tl} {Wasserburg~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08072_tl} {Haag~in~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08073_tl} {Gars~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08074_tl} {Schnaitsee}
\tl_const:cn {c_phone_DE_ortsname_08075_tl} {Amerang}
\tl_const:cn {c_phone_DE_ortsname_08076_tl} {Pfaffing}
\tl_const:cn {c_phone_DE_ortsname_08081_tl} {Dorfen~Stadt}
\tl_const:cn {c_phone_DE_ortsname_08082_tl} {Schwindegg}
\tl_const:cn {c_phone_DE_ortsname_08083_tl} {Isen}
\tl_const:cn {c_phone_DE_ortsname_08084_tl} {Taufkirchen~Vils}
\tl_const:cn {c_phone_DE_ortsname_08085_tl} {Sankt~Wolfgang}
\tl_const:cn {c_phone_DE_ortsname_08086_tl} {Buchbach~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08091_tl} {Kirchseeon}
\tl_const:cn {c_phone_DE_ortsname_08092_tl} {Grafing~bei~M\"unchen}
\tl_const:cn {c_phone_DE_ortsname_08093_tl} {Glonn~Kreis~Ebersberg}
\tl_const:cn {c_phone_DE_ortsname_08094_tl} {Steinh\"oring}
\tl_const:cn {c_phone_DE_ortsname_08095_tl} {Aying}
\tl_const:cn {c_phone_DE_ortsname_08102_tl} {H\"ohenkirchen-Siegertsbrunn}
\tl_const:cn {c_phone_DE_ortsname_08104_tl} {Sauerlach}
\tl_const:cn {c_phone_DE_ortsname_08105_tl} {Gilching}
\tl_const:cn {c_phone_DE_ortsname_08106_tl} {Vaterstetten}
\tl_const:cn {c_phone_DE_ortsname_0811_tl} {Hallbergmoos}
\tl_const:cn {c_phone_DE_ortsname_08121_tl} {Markt~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08122_tl} {Erding}
\tl_const:cn {c_phone_DE_ortsname_08123_tl} {Moosinning}
\tl_const:cn {c_phone_DE_ortsname_08124_tl} {Forstern~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08131_tl} {Dachau}
\tl_const:cn {c_phone_DE_ortsname_08133_tl} {Haimhausen~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08134_tl} {Odelzhausen}
\tl_const:cn {c_phone_DE_ortsname_08135_tl} {Sulzemoos}
\tl_const:cn {c_phone_DE_ortsname_08136_tl} {Markt~Indersdorf}
\tl_const:cn {c_phone_DE_ortsname_08137_tl} {Petershausen}
\tl_const:cn {c_phone_DE_ortsname_08138_tl} {Schwabhausen~bei~Dachau}
\tl_const:cn {c_phone_DE_ortsname_08139_tl} {R\"ohrmoos}
\tl_const:cn {c_phone_DE_ortsname_08141_tl} {F\"urstenfeldbruck}
\tl_const:cn {c_phone_DE_ortsname_08142_tl} {Olching}
\tl_const:cn {c_phone_DE_ortsname_08143_tl} {Inning~am~Ammersee}
\tl_const:cn {c_phone_DE_ortsname_08144_tl} {Grafrath}
\tl_const:cn {c_phone_DE_ortsname_08145_tl} {Mammendorf}
\tl_const:cn {c_phone_DE_ortsname_08146_tl} {Moorenweis}
\tl_const:cn {c_phone_DE_ortsname_08151_tl} {Starnberg}
\tl_const:cn {c_phone_DE_ortsname_08152_tl} {Herrsching~am~Ammersee}
\tl_const:cn {c_phone_DE_ortsname_08153_tl} {We\ss ling}
\tl_const:cn {c_phone_DE_ortsname_08157_tl} {Feldafing}
\tl_const:cn {c_phone_DE_ortsname_08158_tl} {Tutzing}
\tl_const:cn {c_phone_DE_ortsname_08161_tl} {Freising}
\tl_const:cn {c_phone_DE_ortsname_08165_tl} {Neufahrn~bei~Freising}
\tl_const:cn {c_phone_DE_ortsname_08166_tl} {Allershausen~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08167_tl} {Zolling}
\tl_const:cn {c_phone_DE_ortsname_08168_tl} {Attenkirchen}
\tl_const:cn {c_phone_DE_ortsname_08170_tl} {Stra\ss lach-Dingharting}
\tl_const:cn {c_phone_DE_ortsname_08171_tl} {Wolfratshausen}
\tl_const:cn {c_phone_DE_ortsname_08176_tl} {Egling~bei~Wolfratshausen}
\tl_const:cn {c_phone_DE_ortsname_08177_tl} {M\"unsing~Starnberger~See}
\tl_const:cn {c_phone_DE_ortsname_08178_tl} {Icking}
\tl_const:cn {c_phone_DE_ortsname_08179_tl} {Eurasburg~an~der~Loisach}
\tl_const:cn {c_phone_DE_ortsname_08191_tl} {Landsberg~am~Lech}
\tl_const:cn {c_phone_DE_ortsname_08192_tl} {Schondorf~am~Ammersee}
\tl_const:cn {c_phone_DE_ortsname_08193_tl} {Geltendorf}
\tl_const:cn {c_phone_DE_ortsname_08194_tl} {Vilgertshofen}
\tl_const:cn {c_phone_DE_ortsname_08195_tl} {Weil~Kreis~Landsberg~am~Lech}
\tl_const:cn {c_phone_DE_ortsname_08196_tl} {P\"urgen}
\tl_const:cn {c_phone_DE_ortsname_08202_tl} {Althegnenberg}
\tl_const:cn {c_phone_DE_ortsname_08203_tl} {Gro\ss aitingen}
\tl_const:cn {c_phone_DE_ortsname_08204_tl} {Mickhausen}
\tl_const:cn {c_phone_DE_ortsname_08205_tl} {Dasing}
\tl_const:cn {c_phone_DE_ortsname_08206_tl} {Egling~an~der~Paar}
\tl_const:cn {c_phone_DE_ortsname_08207_tl} {Affing}
\tl_const:cn {c_phone_DE_ortsname_08208_tl} {Eurasburg~bei~Augsburg}
\tl_const:cn {c_phone_DE_ortsname_0821_tl} {Augsburg}
\tl_const:cn {c_phone_DE_ortsname_08221_tl} {G\"unzburg}
\tl_const:cn {c_phone_DE_ortsname_08222_tl} {Burgau~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08223_tl} {Ichenhausen}
\tl_const:cn {c_phone_DE_ortsname_08224_tl} {Offingen~Donau}
\tl_const:cn {c_phone_DE_ortsname_08225_tl} {Jettingen-Scheppach}
\tl_const:cn {c_phone_DE_ortsname_08226_tl} {Bibertal}
\tl_const:cn {c_phone_DE_ortsname_08230_tl} {Gablingen}
\tl_const:cn {c_phone_DE_ortsname_08231_tl} {K\"onigsbrunn~bei~Augsburg}
\tl_const:cn {c_phone_DE_ortsname_08232_tl} {Schwabm\"unchen}
\tl_const:cn {c_phone_DE_ortsname_08233_tl} {Kissing}
\tl_const:cn {c_phone_DE_ortsname_08234_tl} {Bobingen}
\tl_const:cn {c_phone_DE_ortsname_08236_tl} {Fischach}
\tl_const:cn {c_phone_DE_ortsname_08237_tl} {Aindling}
\tl_const:cn {c_phone_DE_ortsname_08238_tl} {Gessertshausen}
\tl_const:cn {c_phone_DE_ortsname_08239_tl} {Langenneufnach}
\tl_const:cn {c_phone_DE_ortsname_08241_tl} {Buchloe}
\tl_const:cn {c_phone_DE_ortsname_08243_tl} {Fuchstal}
\tl_const:cn {c_phone_DE_ortsname_08245_tl} {T\"urkheim~Wertach}
\tl_const:cn {c_phone_DE_ortsname_08246_tl} {Waal}
\tl_const:cn {c_phone_DE_ortsname_08247_tl} {Bad~W\"orishofen}
\tl_const:cn {c_phone_DE_ortsname_08248_tl} {Lamerdingen}
\tl_const:cn {c_phone_DE_ortsname_08249_tl} {Ettringen~Wertach}
\tl_const:cn {c_phone_DE_ortsname_08250_tl} {Hilgertshausen-Tandern}
\tl_const:cn {c_phone_DE_ortsname_08251_tl} {Aichach}
\tl_const:cn {c_phone_DE_ortsname_08252_tl} {Schrobenhausen}
\tl_const:cn {c_phone_DE_ortsname_08253_tl} {P\"ottmes}
\tl_const:cn {c_phone_DE_ortsname_08254_tl} {Altom\"unster}
\tl_const:cn {c_phone_DE_ortsname_08257_tl} {Inchenhofen}
\tl_const:cn {c_phone_DE_ortsname_08258_tl} {Sielenbach}
\tl_const:cn {c_phone_DE_ortsname_08259_tl} {Schiltberg}
\tl_const:cn {c_phone_DE_ortsname_08261_tl} {Mindelheim}
\tl_const:cn {c_phone_DE_ortsname_08262_tl} {Mittelneufnach}
\tl_const:cn {c_phone_DE_ortsname_08263_tl} {Breitenbrunn~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08265_tl} {Pfaffenhausen~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08266_tl} {Kirchheim~in~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08267_tl} {Dirlewang}
\tl_const:cn {c_phone_DE_ortsname_08268_tl} {Tussenhausen}
\tl_const:cn {c_phone_DE_ortsname_08269_tl} {Unteregg~bei~Mindelheim}
\tl_const:cn {c_phone_DE_ortsname_08271_tl} {Meitingen}
\tl_const:cn {c_phone_DE_ortsname_08272_tl} {Wertingen}
\tl_const:cn {c_phone_DE_ortsname_08273_tl} {Nordendorf}
\tl_const:cn {c_phone_DE_ortsname_08274_tl} {Buttenwiesen}
\tl_const:cn {c_phone_DE_ortsname_08276_tl} {Baar~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08281_tl} {Thannhausen~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08282_tl} {Krumbach~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08283_tl} {Neuburg~an~der~Kammel}
\tl_const:cn {c_phone_DE_ortsname_08284_tl} {Ziemetshausen}
\tl_const:cn {c_phone_DE_ortsname_08285_tl} {Burtenbach}
\tl_const:cn {c_phone_DE_ortsname_08291_tl} {Zusmarshausen}
\tl_const:cn {c_phone_DE_ortsname_08292_tl} {Dinkelscherben}
\tl_const:cn {c_phone_DE_ortsname_08293_tl} {Welden~bei~Augsburg}
\tl_const:cn {c_phone_DE_ortsname_08294_tl} {Horgau}
\tl_const:cn {c_phone_DE_ortsname_08295_tl} {Altenm\"unster~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08296_tl} {Villenbach}
\tl_const:cn {c_phone_DE_ortsname_08302_tl} {G\"orisried}
\tl_const:cn {c_phone_DE_ortsname_08303_tl} {Waltenhofen}
\tl_const:cn {c_phone_DE_ortsname_08304_tl} {Wildpoldsried}
\tl_const:cn {c_phone_DE_ortsname_08306_tl} {Ronsberg}
\tl_const:cn {c_phone_DE_ortsname_0831_tl} {Kempten~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08320_tl} {Missen-Wilhams}
\tl_const:cn {c_phone_DE_ortsname_08321_tl} {Sonthofen}
\tl_const:cn {c_phone_DE_ortsname_08322_tl} {Oberstdorf}
\tl_const:cn {c_phone_DE_ortsname_08323_tl} {Immenstadt~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08324_tl} {Hindelang}
\tl_const:cn {c_phone_DE_ortsname_08325_tl} {Oberstaufen-Thalkirchdorf}
\tl_const:cn {c_phone_DE_ortsname_08326_tl} {Fischen~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08327_tl} {Rettenberg}
\tl_const:cn {c_phone_DE_ortsname_08328_tl} {Balderschwang}
\tl_const:cn {c_phone_DE_ortsname_08330_tl} {Legau}
\tl_const:cn {c_phone_DE_ortsname_08331_tl} {Memmingen}
\tl_const:cn {c_phone_DE_ortsname_08332_tl} {Ottobeuren}
\tl_const:cn {c_phone_DE_ortsname_08333_tl} {Babenhausen~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_08334_tl} {Bad~Gr\"onenbach}
\tl_const:cn {c_phone_DE_ortsname_08335_tl} {Fellheim}
\tl_const:cn {c_phone_DE_ortsname_08336_tl} {Erkheim}
\tl_const:cn {c_phone_DE_ortsname_08337_tl} {Altenstadt~Iller}
\tl_const:cn {c_phone_DE_ortsname_08338_tl} {B\"ohen}
\tl_const:cn {c_phone_DE_ortsname_08340_tl} {Baisweil}
\tl_const:cn {c_phone_DE_ortsname_08341_tl} {Kaufbeuren}
\tl_const:cn {c_phone_DE_ortsname_08342_tl} {Marktoberdorf}
\tl_const:cn {c_phone_DE_ortsname_08343_tl} {Aitrang}
\tl_const:cn {c_phone_DE_ortsname_08344_tl} {Westendorf~bei~Kaufbeuren}
\tl_const:cn {c_phone_DE_ortsname_08345_tl} {St\"ottwang}
\tl_const:cn {c_phone_DE_ortsname_08346_tl} {Pforzen}
\tl_const:cn {c_phone_DE_ortsname_08347_tl} {Friesenried}
\tl_const:cn {c_phone_DE_ortsname_08348_tl} {Bidingen}
\tl_const:cn {c_phone_DE_ortsname_08349_tl} {St\"otten~am~Auerberg}
\tl_const:cn {c_phone_DE_ortsname_08361_tl} {Nesselwang}
\tl_const:cn {c_phone_DE_ortsname_08362_tl} {F\"ussen}
\tl_const:cn {c_phone_DE_ortsname_08363_tl} {Pfronten}
\tl_const:cn {c_phone_DE_ortsname_08364_tl} {Seeg}
\tl_const:cn {c_phone_DE_ortsname_08365_tl} {Wertach}
\tl_const:cn {c_phone_DE_ortsname_08366_tl} {Oy-Mittelberg}
\tl_const:cn {c_phone_DE_ortsname_08367_tl} {Ro\ss haupten~Forggensee}
\tl_const:cn {c_phone_DE_ortsname_08368_tl} {Halblech}
\tl_const:cn {c_phone_DE_ortsname_08369_tl} {R\"uckholz}
\tl_const:cn {c_phone_DE_ortsname_08370_tl} {Wiggensbach}
\tl_const:cn {c_phone_DE_ortsname_08372_tl} {Oberg\"unzburg}
\tl_const:cn {c_phone_DE_ortsname_08373_tl} {Altusried}
\tl_const:cn {c_phone_DE_ortsname_08374_tl} {Dietmannsried}
\tl_const:cn {c_phone_DE_ortsname_08375_tl} {Weitnau}
\tl_const:cn {c_phone_DE_ortsname_08376_tl} {Sulzberg~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08377_tl} {Unterthingau}
\tl_const:cn {c_phone_DE_ortsname_08378_tl} {Buchenberg~bei~Kempten}
\tl_const:cn {c_phone_DE_ortsname_08379_tl} {Waltenhofen-Oberdorf}
\tl_const:cn {c_phone_DE_ortsname_08380_tl} {Achberg}
\tl_const:cn {c_phone_DE_ortsname_08381_tl} {Lindenberg~im~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08382_tl} {Lindau~Bodensee}
\tl_const:cn {c_phone_DE_ortsname_08383_tl} {Gr\"unenbach~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08384_tl} {R\"othenbach~Allg\"au}
\tl_const:cn {c_phone_DE_ortsname_08385_tl} {Hergatz}
\tl_const:cn {c_phone_DE_ortsname_08386_tl} {Oberstaufen}
\tl_const:cn {c_phone_DE_ortsname_08387_tl} {Weiler-Simmerberg}
\tl_const:cn {c_phone_DE_ortsname_08388_tl} {Hergensweiler}
\tl_const:cn {c_phone_DE_ortsname_08389_tl} {Wei\ss ensberg}
\tl_const:cn {c_phone_DE_ortsname_08392_tl} {Markt~Rettenbach}
\tl_const:cn {c_phone_DE_ortsname_08393_tl} {Holzg\"unz}
\tl_const:cn {c_phone_DE_ortsname_08394_tl} {Lautrach}
\tl_const:cn {c_phone_DE_ortsname_08395_tl} {Tannheim~W\"urttemberg}
\tl_const:cn {c_phone_DE_ortsname_08402_tl} {M\"unchsm\"unster}
\tl_const:cn {c_phone_DE_ortsname_08403_tl} {Pf\"orring}
\tl_const:cn {c_phone_DE_ortsname_08404_tl} {Oberdolling}
\tl_const:cn {c_phone_DE_ortsname_08405_tl} {Stammham~bei~Ingolstadt}
\tl_const:cn {c_phone_DE_ortsname_08406_tl} {B\"ohmfeld}
\tl_const:cn {c_phone_DE_ortsname_08407_tl} {Gro\ss mehring}
\tl_const:cn {c_phone_DE_ortsname_0841_tl} {Ingolstadt~Donau}
\tl_const:cn {c_phone_DE_ortsname_08421_tl} {Eichst\"att~Bayern}
\tl_const:cn {c_phone_DE_ortsname_08422_tl} {Dollnstein}
\tl_const:cn {c_phone_DE_ortsname_08423_tl} {Titting}
\tl_const:cn {c_phone_DE_ortsname_08424_tl} {Nassenfels}
\tl_const:cn {c_phone_DE_ortsname_08426_tl} {Walting~Kreis~Eichst\"att}
\tl_const:cn {c_phone_DE_ortsname_08427_tl} {Wellheim}
\tl_const:cn {c_phone_DE_ortsname_08431_tl} {Neuburg~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_08432_tl} {Burgheim}
\tl_const:cn {c_phone_DE_ortsname_08433_tl} {K\"onigsmoos}
\tl_const:cn {c_phone_DE_ortsname_08434_tl} {Rennertshofen}
\tl_const:cn {c_phone_DE_ortsname_08435_tl} {Ehekirchen}
\tl_const:cn {c_phone_DE_ortsname_08441_tl} {Pfaffenhofen~an~der~Ilm}
\tl_const:cn {c_phone_DE_ortsname_08442_tl} {Wolnzach}
\tl_const:cn {c_phone_DE_ortsname_08443_tl} {Hohenwart~Paar}
\tl_const:cn {c_phone_DE_ortsname_08444_tl} {Schweitenkirchen}
\tl_const:cn {c_phone_DE_ortsname_08445_tl} {Gerolsbach}
\tl_const:cn {c_phone_DE_ortsname_08446_tl} {P\"ornbach}
\tl_const:cn {c_phone_DE_ortsname_08450_tl} {Ingolstadt-Zuchering}
\tl_const:cn {c_phone_DE_ortsname_08452_tl} {Geisenfeld}
\tl_const:cn {c_phone_DE_ortsname_08453_tl} {Reichertshofen~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08454_tl} {Karlshuld}
\tl_const:cn {c_phone_DE_ortsname_08456_tl} {Lenting}
\tl_const:cn {c_phone_DE_ortsname_08457_tl} {Vohburg~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_08458_tl} {Gaimersheim}
\tl_const:cn {c_phone_DE_ortsname_08459_tl} {Manching}
\tl_const:cn {c_phone_DE_ortsname_08460_tl} {Berching-Holnstein}
\tl_const:cn {c_phone_DE_ortsname_08461_tl} {Beilngries}
\tl_const:cn {c_phone_DE_ortsname_08462_tl} {Berching}
\tl_const:cn {c_phone_DE_ortsname_08463_tl} {Greding}
\tl_const:cn {c_phone_DE_ortsname_08464_tl} {Dietfurt~an~der~Altm\"uhl}
\tl_const:cn {c_phone_DE_ortsname_08465_tl} {Kipfenberg}
\tl_const:cn {c_phone_DE_ortsname_08466_tl} {Denkendorf~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08467_tl} {Kinding}
\tl_const:cn {c_phone_DE_ortsname_08468_tl} {Altmannstein-Pondorf}
\tl_const:cn {c_phone_DE_ortsname_08469_tl} {Freystadt-Burggriesbach}
\tl_const:cn {c_phone_DE_ortsname_08501_tl} {Thyrnau}
\tl_const:cn {c_phone_DE_ortsname_08502_tl} {F\"urstenzell}
\tl_const:cn {c_phone_DE_ortsname_08503_tl} {Neuhaus~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08504_tl} {Tittling}
\tl_const:cn {c_phone_DE_ortsname_08505_tl} {Hutthurm}
\tl_const:cn {c_phone_DE_ortsname_08506_tl} {Bad~H\"ohenstadt}
\tl_const:cn {c_phone_DE_ortsname_08507_tl} {Neuburg~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08509_tl} {Ruderting}
\tl_const:cn {c_phone_DE_ortsname_0851_tl} {Passau}
\tl_const:cn {c_phone_DE_ortsname_08531_tl} {Pocking}
\tl_const:cn {c_phone_DE_ortsname_08532_tl} {Griesbach~im~Rottal}
\tl_const:cn {c_phone_DE_ortsname_08533_tl} {Rotthalm\"unster}
\tl_const:cn {c_phone_DE_ortsname_08534_tl} {Tettenweis}
\tl_const:cn {c_phone_DE_ortsname_08535_tl} {Haarbach}
\tl_const:cn {c_phone_DE_ortsname_08536_tl} {K\"o\ss larn}
\tl_const:cn {c_phone_DE_ortsname_08537_tl} {Bad~F\"ussing-Aigen}
\tl_const:cn {c_phone_DE_ortsname_08538_tl} {Pocking-Hartkirchen}
\tl_const:cn {c_phone_DE_ortsname_08541_tl} {Vilshofen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08542_tl} {Ortenburg}
\tl_const:cn {c_phone_DE_ortsname_08543_tl} {Aidenbach}
\tl_const:cn {c_phone_DE_ortsname_08544_tl} {Eging~am~See}
\tl_const:cn {c_phone_DE_ortsname_08545_tl} {Hofkirchen~Bayern}
\tl_const:cn {c_phone_DE_ortsname_08546_tl} {Windorf-Otterskirchen}
\tl_const:cn {c_phone_DE_ortsname_08547_tl} {Osterhofen-Gergweis}
\tl_const:cn {c_phone_DE_ortsname_08548_tl} {Vilshofen-Sandbach}
\tl_const:cn {c_phone_DE_ortsname_08549_tl} {Vilshofen-Pleinting}
\tl_const:cn {c_phone_DE_ortsname_08550_tl} {Philippsreut}
\tl_const:cn {c_phone_DE_ortsname_08551_tl} {Freyung}
\tl_const:cn {c_phone_DE_ortsname_08552_tl} {Grafenau~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08553_tl} {Spiegelau}
\tl_const:cn {c_phone_DE_ortsname_08554_tl} {Sch\"onberg~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08555_tl} {Perlesreut}
\tl_const:cn {c_phone_DE_ortsname_08556_tl} {Haidm\"uhle}
\tl_const:cn {c_phone_DE_ortsname_08557_tl} {Mauth}
\tl_const:cn {c_phone_DE_ortsname_08558_tl} {Hohenau~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08561_tl} {Pfarrkirchen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08562_tl} {Triftern}
\tl_const:cn {c_phone_DE_ortsname_08563_tl} {Bad~Birnbach~Rottal}
\tl_const:cn {c_phone_DE_ortsname_08564_tl} {Johanniskirchen}
\tl_const:cn {c_phone_DE_ortsname_08565_tl} {Dietersburg-Baumgarten}
\tl_const:cn {c_phone_DE_ortsname_08571_tl} {Simbach~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08572_tl} {Tann~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08573_tl} {Ering}
\tl_const:cn {c_phone_DE_ortsname_08574_tl} {Wittibreut}
\tl_const:cn {c_phone_DE_ortsname_08581_tl} {Waldkirchen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08582_tl} {R\"ohrnbach}
\tl_const:cn {c_phone_DE_ortsname_08583_tl} {Neureichenau}
\tl_const:cn {c_phone_DE_ortsname_08584_tl} {Breitenberg~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08585_tl} {Grainet}
\tl_const:cn {c_phone_DE_ortsname_08586_tl} {Hauzenberg}
\tl_const:cn {c_phone_DE_ortsname_08591_tl} {Obernzell}
\tl_const:cn {c_phone_DE_ortsname_08592_tl} {Wegscheid~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08593_tl} {Untergriesbach}
\tl_const:cn {c_phone_DE_ortsname_0861_tl} {Traunstein}
\tl_const:cn {c_phone_DE_ortsname_08621_tl} {Trostberg}
\tl_const:cn {c_phone_DE_ortsname_08622_tl} {Tacherting-~Peterskirchen}
\tl_const:cn {c_phone_DE_ortsname_08623_tl} {Kirchweidach}
\tl_const:cn {c_phone_DE_ortsname_08624_tl} {Obing}
\tl_const:cn {c_phone_DE_ortsname_08628_tl} {Kienberg~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08629_tl} {Palling}
\tl_const:cn {c_phone_DE_ortsname_08630_tl} {Oberneukirchen}
\tl_const:cn {c_phone_DE_ortsname_08631_tl} {M\"uhldorf~am~Inn}
\tl_const:cn {c_phone_DE_ortsname_08633_tl} {T\"u\ss ling}
\tl_const:cn {c_phone_DE_ortsname_08634_tl} {Garching~an~der~Alz}
\tl_const:cn {c_phone_DE_ortsname_08635_tl} {Pleiskirchen}
\tl_const:cn {c_phone_DE_ortsname_08636_tl} {Ampfing}
\tl_const:cn {c_phone_DE_ortsname_08637_tl} {Lohkirchen}
\tl_const:cn {c_phone_DE_ortsname_08638_tl} {Waldkraiburg}
\tl_const:cn {c_phone_DE_ortsname_08639_tl} {Neumarkt-Sankt~Veit}
\tl_const:cn {c_phone_DE_ortsname_08640_tl} {Reit~im~Winkl}
\tl_const:cn {c_phone_DE_ortsname_08641_tl} {Grassau~Kreis~Traunstein}
\tl_const:cn {c_phone_DE_ortsname_08642_tl} {\"Ubersee}
\tl_const:cn {c_phone_DE_ortsname_08649_tl} {Schleching}
\tl_const:cn {c_phone_DE_ortsname_08650_tl} {Marktschellenberg}
\tl_const:cn {c_phone_DE_ortsname_08651_tl} {Bad~Reichenhall}
\tl_const:cn {c_phone_DE_ortsname_08652_tl} {Berchtesgaden}
\tl_const:cn {c_phone_DE_ortsname_08654_tl} {Freilassing}
\tl_const:cn {c_phone_DE_ortsname_08656_tl} {Anger}
\tl_const:cn {c_phone_DE_ortsname_08657_tl} {Ramsau~bei~Berchtesgaden}
\tl_const:cn {c_phone_DE_ortsname_08661_tl} {Grabenst\"att~Chiemsee}
\tl_const:cn {c_phone_DE_ortsname_08662_tl} {Siegsdorf~Kreis~Traunstein}
\tl_const:cn {c_phone_DE_ortsname_08663_tl} {Ruhpolding}
\tl_const:cn {c_phone_DE_ortsname_08664_tl} {Chieming}
\tl_const:cn {c_phone_DE_ortsname_08665_tl} {Inzell}
\tl_const:cn {c_phone_DE_ortsname_08666_tl} {Teisendorf}
\tl_const:cn {c_phone_DE_ortsname_08667_tl} {Seeon-Seebruck}
\tl_const:cn {c_phone_DE_ortsname_08669_tl} {Traunreut}
\tl_const:cn {c_phone_DE_ortsname_08670_tl} {Reischach~Kreis~Alt\"otting}
\tl_const:cn {c_phone_DE_ortsname_08671_tl} {Alt\"otting}
\tl_const:cn {c_phone_DE_ortsname_08677_tl} {Burghausen~Salzach}
\tl_const:cn {c_phone_DE_ortsname_08678_tl} {Marktl}
\tl_const:cn {c_phone_DE_ortsname_08679_tl} {Burgkirchen~an~der~Alz}
\tl_const:cn {c_phone_DE_ortsname_08681_tl} {Waging~am~See}
\tl_const:cn {c_phone_DE_ortsname_08682_tl} {Laufen~Salzach}
\tl_const:cn {c_phone_DE_ortsname_08683_tl} {Tittmoning}
\tl_const:cn {c_phone_DE_ortsname_08684_tl} {Fridolfing}
\tl_const:cn {c_phone_DE_ortsname_08685_tl} {Kirchansch\"oring}
\tl_const:cn {c_phone_DE_ortsname_08686_tl} {Petting}
\tl_const:cn {c_phone_DE_ortsname_08687_tl} {Taching-Tengling}
\tl_const:cn {c_phone_DE_ortsname_08702_tl} {W\"orth~an~der~Isar}
\tl_const:cn {c_phone_DE_ortsname_08703_tl} {Essenbach}
\tl_const:cn {c_phone_DE_ortsname_08704_tl} {Altdorf-Pfettrach}
\tl_const:cn {c_phone_DE_ortsname_08705_tl} {Altfraunhofen}
\tl_const:cn {c_phone_DE_ortsname_08706_tl} {Vilsheim}
\tl_const:cn {c_phone_DE_ortsname_08707_tl} {Adlkofen}
\tl_const:cn {c_phone_DE_ortsname_08708_tl} {Weihmichl-Unterneuhausen}
\tl_const:cn {c_phone_DE_ortsname_08709_tl} {Eching~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_0871_tl} {Landshut}
\tl_const:cn {c_phone_DE_ortsname_08721_tl} {Eggenfelden}
\tl_const:cn {c_phone_DE_ortsname_08722_tl} {Gangkofen}
\tl_const:cn {c_phone_DE_ortsname_08723_tl} {Arnstorf}
\tl_const:cn {c_phone_DE_ortsname_08724_tl} {Massing}
\tl_const:cn {c_phone_DE_ortsname_08725_tl} {Wurmannsquick}
\tl_const:cn {c_phone_DE_ortsname_08726_tl} {Sch\"onau~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08727_tl} {Falkenberg~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08728_tl} {Geratskirchen}
\tl_const:cn {c_phone_DE_ortsname_08731_tl} {Dingolfing}
\tl_const:cn {c_phone_DE_ortsname_08732_tl} {Frontenhausen}
\tl_const:cn {c_phone_DE_ortsname_08733_tl} {Mengkofen}
\tl_const:cn {c_phone_DE_ortsname_08734_tl} {Reisbach~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08735_tl} {Gangkofen-Kollbach}
\tl_const:cn {c_phone_DE_ortsname_08741_tl} {Vilsbiburg}
\tl_const:cn {c_phone_DE_ortsname_08742_tl} {Velden~Vils}
\tl_const:cn {c_phone_DE_ortsname_08743_tl} {Geisenhausen}
\tl_const:cn {c_phone_DE_ortsname_08744_tl} {Gerzen}
\tl_const:cn {c_phone_DE_ortsname_08745_tl} {Bodenkirchen}
\tl_const:cn {c_phone_DE_ortsname_08751_tl} {Mainburg}
\tl_const:cn {c_phone_DE_ortsname_08752_tl} {Au~in~der~Hallertau}
\tl_const:cn {c_phone_DE_ortsname_08753_tl} {Elsendorf~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08754_tl} {Volkenschwand}
\tl_const:cn {c_phone_DE_ortsname_08756_tl} {Nandlstadt}
\tl_const:cn {c_phone_DE_ortsname_08761_tl} {Moosburg~an~der~Isar}
\tl_const:cn {c_phone_DE_ortsname_08762_tl} {Wartenberg~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08764_tl} {Mauern~Kreis~Freising}
\tl_const:cn {c_phone_DE_ortsname_08765_tl} {Bruckberg~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08766_tl} {Gammelsdorf}
\tl_const:cn {c_phone_DE_ortsname_08771_tl} {Ergoldsbach}
\tl_const:cn {c_phone_DE_ortsname_08772_tl} {Mallersdorf-Pfaffenberg}
\tl_const:cn {c_phone_DE_ortsname_08773_tl} {Neufahrn~in~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08774_tl} {Bayerbach~bei~Ergoldsbach}
\tl_const:cn {c_phone_DE_ortsname_08781_tl} {Rottenburg~an~der~Laaber}
\tl_const:cn {c_phone_DE_ortsname_08782_tl} {Pfeffenhausen}
\tl_const:cn {c_phone_DE_ortsname_08783_tl} {Rohr~in~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_08784_tl} {Hohenthann}
\tl_const:cn {c_phone_DE_ortsname_08785_tl} {Rottenburg-Oberroning}
\tl_const:cn {c_phone_DE_ortsname_08801_tl} {Seeshaupt}
\tl_const:cn {c_phone_DE_ortsname_08802_tl} {Huglfing}
\tl_const:cn {c_phone_DE_ortsname_08803_tl} {Pei\ss enberg}
\tl_const:cn {c_phone_DE_ortsname_08805_tl} {Hohenpei\ss enberg}
\tl_const:cn {c_phone_DE_ortsname_08806_tl} {Utting~am~Ammersee}
\tl_const:cn {c_phone_DE_ortsname_08807_tl} {Die\ss en~am~Ammersee}
\tl_const:cn {c_phone_DE_ortsname_08808_tl} {P\"ahl}
\tl_const:cn {c_phone_DE_ortsname_08809_tl} {Wessobrunn}
\tl_const:cn {c_phone_DE_ortsname_0881_tl} {Weilheim~in~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08821_tl} {Garmisch-Partenkirchen}
\tl_const:cn {c_phone_DE_ortsname_08822_tl} {Oberammergau}
\tl_const:cn {c_phone_DE_ortsname_08823_tl} {Mittenwald}
\tl_const:cn {c_phone_DE_ortsname_08824_tl} {Oberau~Loisach}
\tl_const:cn {c_phone_DE_ortsname_08825_tl} {Kr\"un}
\tl_const:cn {c_phone_DE_ortsname_08841_tl} {Murnau~am~Staffelsee}
\tl_const:cn {c_phone_DE_ortsname_08845_tl} {Bad~Kohlgrub}
\tl_const:cn {c_phone_DE_ortsname_08846_tl} {Uffing~am~Staffelsee}
\tl_const:cn {c_phone_DE_ortsname_08847_tl} {Obers\"ochering}
\tl_const:cn {c_phone_DE_ortsname_08851_tl} {Kochel~am~See}
\tl_const:cn {c_phone_DE_ortsname_08856_tl} {Penzberg}
\tl_const:cn {c_phone_DE_ortsname_08857_tl} {Benediktbeuern}
\tl_const:cn {c_phone_DE_ortsname_08858_tl} {Kochel-Walchensee}
\tl_const:cn {c_phone_DE_ortsname_08860_tl} {Bernbeuren}
\tl_const:cn {c_phone_DE_ortsname_08861_tl} {Schongau}
\tl_const:cn {c_phone_DE_ortsname_08862_tl} {Steingaden~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08867_tl} {Rottenbuch~Oberbayern}
\tl_const:cn {c_phone_DE_ortsname_08868_tl} {Schwabsoien}
\tl_const:cn {c_phone_DE_ortsname_08869_tl} {Kinsau}
\tl_const:cn {c_phone_DE_ortsname_089_tl} {M\"unchen}
\tl_const:cn {c_phone_DE_ortsname_0906_tl} {Donauw\"orth}
\tl_const:cn {c_phone_DE_ortsname_09070_tl} {Tapfheim}
\tl_const:cn {c_phone_DE_ortsname_09071_tl} {Dillingen~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_09072_tl} {Lauingen~Donau}
\tl_const:cn {c_phone_DE_ortsname_09073_tl} {Gundelfingen~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_09074_tl} {H\"ochst\"adt~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_09075_tl} {Gl\"ott}
\tl_const:cn {c_phone_DE_ortsname_09076_tl} {Wittislingen}
\tl_const:cn {c_phone_DE_ortsname_09077_tl} {Bachhagel}
\tl_const:cn {c_phone_DE_ortsname_09078_tl} {Mertingen}
\tl_const:cn {c_phone_DE_ortsname_09080_tl} {Harburg~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_09081_tl} {N\"ordlingen}
\tl_const:cn {c_phone_DE_ortsname_09082_tl} {Oettingen~in~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09083_tl} {M\"ottingen}
\tl_const:cn {c_phone_DE_ortsname_09084_tl} {Bissingen~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_09085_tl} {Alerheim}
\tl_const:cn {c_phone_DE_ortsname_09086_tl} {Fremdingen}
\tl_const:cn {c_phone_DE_ortsname_09087_tl} {Marktoffingen}
\tl_const:cn {c_phone_DE_ortsname_09088_tl} {M\"onchsdeggingen}
\tl_const:cn {c_phone_DE_ortsname_09089_tl} {Bissingen-Unterringingen}
\tl_const:cn {c_phone_DE_ortsname_09090_tl} {Rain~Lech}
\tl_const:cn {c_phone_DE_ortsname_09091_tl} {Monheim~Schwaben}
\tl_const:cn {c_phone_DE_ortsname_09092_tl} {Wemding}
\tl_const:cn {c_phone_DE_ortsname_09093_tl} {Polsingen}
\tl_const:cn {c_phone_DE_ortsname_09094_tl} {Tagmersheim}
\tl_const:cn {c_phone_DE_ortsname_09097_tl} {Marxheim}
\tl_const:cn {c_phone_DE_ortsname_09099_tl} {Kaisheim}
\tl_const:cn {c_phone_DE_ortsname_09101_tl} {Langenzenn}
\tl_const:cn {c_phone_DE_ortsname_09102_tl} {Wilhermsdorf}
\tl_const:cn {c_phone_DE_ortsname_09103_tl} {Cadolzburg}
\tl_const:cn {c_phone_DE_ortsname_09104_tl} {Emskirchen}
\tl_const:cn {c_phone_DE_ortsname_09105_tl} {Gro\ss habersdorf}
\tl_const:cn {c_phone_DE_ortsname_09106_tl} {Markt~Erlbach}
\tl_const:cn {c_phone_DE_ortsname_09107_tl} {Trautskirchen}
\tl_const:cn {c_phone_DE_ortsname_0911_tl} {N\"urnberg}
\tl_const:cn {c_phone_DE_ortsname_09120_tl} {Leinburg}
\tl_const:cn {c_phone_DE_ortsname_09122_tl} {Schwabach}
\tl_const:cn {c_phone_DE_ortsname_09123_tl} {Lauf~an~der~Pegnitz}
\tl_const:cn {c_phone_DE_ortsname_09126_tl} {Eckental}
\tl_const:cn {c_phone_DE_ortsname_09127_tl} {Ro\ss tal~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09128_tl} {Feucht}
\tl_const:cn {c_phone_DE_ortsname_09129_tl} {Wendelstein}
\tl_const:cn {c_phone_DE_ortsname_09131_tl} {Erlangen}
\tl_const:cn {c_phone_DE_ortsname_09132_tl} {Herzogenaurach}
\tl_const:cn {c_phone_DE_ortsname_09133_tl} {Baiersdorf~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09134_tl} {Neunkirchen~am~Brand}
\tl_const:cn {c_phone_DE_ortsname_09135_tl} {He\ss dorf~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09141_tl} {Wei\ss enburg~in~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09142_tl} {Treuchtlingen}
\tl_const:cn {c_phone_DE_ortsname_09143_tl} {Pappenheim~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09144_tl} {Pleinfeld}
\tl_const:cn {c_phone_DE_ortsname_09145_tl} {Solnhofen}
\tl_const:cn {c_phone_DE_ortsname_09146_tl} {Markt~Berolzheim}
\tl_const:cn {c_phone_DE_ortsname_09147_tl} {Nennslingen}
\tl_const:cn {c_phone_DE_ortsname_09148_tl} {Ettenstatt}
\tl_const:cn {c_phone_DE_ortsname_09149_tl} {Wei\ss enburg-Suffersheim}
\tl_const:cn {c_phone_DE_ortsname_09151_tl} {Hersbruck}
\tl_const:cn {c_phone_DE_ortsname_09152_tl} {Hartenstein~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09153_tl} {Schnaittach}
\tl_const:cn {c_phone_DE_ortsname_09154_tl} {Pommelsbrunn}
\tl_const:cn {c_phone_DE_ortsname_09155_tl} {Simmelsdorf}
\tl_const:cn {c_phone_DE_ortsname_09156_tl} {Neuhaus~an~der~Pegnitz}
\tl_const:cn {c_phone_DE_ortsname_09157_tl} {Alfeld~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09158_tl} {Offenhausen~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09161_tl} {Neustadt~an~der~Aisch}
\tl_const:cn {c_phone_DE_ortsname_09162_tl} {Scheinfeld}
\tl_const:cn {c_phone_DE_ortsname_09163_tl} {Dachsbach}
\tl_const:cn {c_phone_DE_ortsname_09164_tl} {Langenfeld~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09165_tl} {Sugenheim}
\tl_const:cn {c_phone_DE_ortsname_09166_tl} {M\"unchsteinach}
\tl_const:cn {c_phone_DE_ortsname_09167_tl} {Oberscheinfeld}
\tl_const:cn {c_phone_DE_ortsname_09170_tl} {Schwanstetten}
\tl_const:cn {c_phone_DE_ortsname_09171_tl} {Roth~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09172_tl} {Georgensgm\"und}
\tl_const:cn {c_phone_DE_ortsname_09173_tl} {Thalm\"assing}
\tl_const:cn {c_phone_DE_ortsname_09174_tl} {Hilpoltstein}
\tl_const:cn {c_phone_DE_ortsname_09175_tl} {Spalt}
\tl_const:cn {c_phone_DE_ortsname_09176_tl} {Allersberg}
\tl_const:cn {c_phone_DE_ortsname_09177_tl} {Heideck}
\tl_const:cn {c_phone_DE_ortsname_09178_tl} {Abenberg~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09179_tl} {Freystadt}
\tl_const:cn {c_phone_DE_ortsname_09180_tl} {Pyrbaum}
\tl_const:cn {c_phone_DE_ortsname_09181_tl} {Neumarkt~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09182_tl} {Velburg}
\tl_const:cn {c_phone_DE_ortsname_09183_tl} {Burgthann}
\tl_const:cn {c_phone_DE_ortsname_09184_tl} {Deining~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09185_tl} {M\"uhlhausen~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09186_tl} {Lauterhofen~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09187_tl} {Altdorf~bei~N\"urnberg}
\tl_const:cn {c_phone_DE_ortsname_09188_tl} {Postbauer-Heng}
\tl_const:cn {c_phone_DE_ortsname_09189_tl} {Berg~bei~Neumarkt~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09190_tl} {Heroldsbach}
\tl_const:cn {c_phone_DE_ortsname_09191_tl} {Forchheim~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09192_tl} {Gr\"afenberg}
\tl_const:cn {c_phone_DE_ortsname_09193_tl} {H\"ochstadt~an~der~Aisch}
\tl_const:cn {c_phone_DE_ortsname_09194_tl} {Ebermannstadt}
\tl_const:cn {c_phone_DE_ortsname_09195_tl} {Adelsdorf~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09196_tl} {Wiesenttal}
\tl_const:cn {c_phone_DE_ortsname_09197_tl} {Egloffstein}
\tl_const:cn {c_phone_DE_ortsname_09198_tl} {Heiligenstadt~in~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09199_tl} {Kunreuth}
\tl_const:cn {c_phone_DE_ortsname_09201_tl} {Gesees}
\tl_const:cn {c_phone_DE_ortsname_09202_tl} {Waischenfeld}
\tl_const:cn {c_phone_DE_ortsname_09203_tl} {Neudrossenfeld}
\tl_const:cn {c_phone_DE_ortsname_09204_tl} {Plankenfels}
\tl_const:cn {c_phone_DE_ortsname_09205_tl} {Vorbach}
\tl_const:cn {c_phone_DE_ortsname_09206_tl} {Mistelgau-Obernsees}
\tl_const:cn {c_phone_DE_ortsname_09207_tl} {K\"onigsfeld~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09208_tl} {Bindlach}
\tl_const:cn {c_phone_DE_ortsname_09209_tl} {Emtmannsberg}
\tl_const:cn {c_phone_DE_ortsname_0921_tl} {Bayreuth}
\tl_const:cn {c_phone_DE_ortsname_09220_tl} {Kasendorf-Azendorf}
\tl_const:cn {c_phone_DE_ortsname_09221_tl} {Kulmbach}
\tl_const:cn {c_phone_DE_ortsname_09222_tl} {Presseck}
\tl_const:cn {c_phone_DE_ortsname_09223_tl} {Rugendorf}
\tl_const:cn {c_phone_DE_ortsname_09225_tl} {Stadtsteinach}
\tl_const:cn {c_phone_DE_ortsname_09227_tl} {Neuenmarkt}
\tl_const:cn {c_phone_DE_ortsname_09228_tl} {Thurnau}
\tl_const:cn {c_phone_DE_ortsname_09229_tl} {Mainleus}
\tl_const:cn {c_phone_DE_ortsname_09231_tl} {Marktredwitz}
\tl_const:cn {c_phone_DE_ortsname_09232_tl} {Wunsiedel}
\tl_const:cn {c_phone_DE_ortsname_09233_tl} {Arzberg~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09234_tl} {Neusorg}
\tl_const:cn {c_phone_DE_ortsname_09235_tl} {Thierstein}
\tl_const:cn {c_phone_DE_ortsname_09236_tl} {Nagel}
\tl_const:cn {c_phone_DE_ortsname_09238_tl} {R\"oslau}
\tl_const:cn {c_phone_DE_ortsname_09241_tl} {Pegnitz}
\tl_const:cn {c_phone_DE_ortsname_09242_tl} {G\"o\ss weinstein}
\tl_const:cn {c_phone_DE_ortsname_09243_tl} {Pottenstein}
\tl_const:cn {c_phone_DE_ortsname_09244_tl} {Betzenstein}
\tl_const:cn {c_phone_DE_ortsname_09245_tl} {Obertrubach}
\tl_const:cn {c_phone_DE_ortsname_09246_tl} {Pegnitz-Trockau}
\tl_const:cn {c_phone_DE_ortsname_09251_tl} {M\"unchberg}
\tl_const:cn {c_phone_DE_ortsname_09252_tl} {Helmbrechts}
\tl_const:cn {c_phone_DE_ortsname_09253_tl} {Wei\ss enstadt}
\tl_const:cn {c_phone_DE_ortsname_09254_tl} {Gefrees}
\tl_const:cn {c_phone_DE_ortsname_09255_tl} {Marktleugast}
\tl_const:cn {c_phone_DE_ortsname_09256_tl} {Stammbach}
\tl_const:cn {c_phone_DE_ortsname_09257_tl} {Zell~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09260_tl} {Wilhelmsthal~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09261_tl} {Kronach}
\tl_const:cn {c_phone_DE_ortsname_09262_tl} {Wallenfels}
\tl_const:cn {c_phone_DE_ortsname_09263_tl} {Ludwigsstadt}
\tl_const:cn {c_phone_DE_ortsname_09264_tl} {K\"ups}
\tl_const:cn {c_phone_DE_ortsname_09265_tl} {Pressig}
\tl_const:cn {c_phone_DE_ortsname_09266_tl} {Mitwitz}
\tl_const:cn {c_phone_DE_ortsname_09267_tl} {Nordhalben}
\tl_const:cn {c_phone_DE_ortsname_09268_tl} {Teuschnitz}
\tl_const:cn {c_phone_DE_ortsname_09269_tl} {Tettau~Kreis~Kronach}
\tl_const:cn {c_phone_DE_ortsname_09270_tl} {Creu\ss en}
\tl_const:cn {c_phone_DE_ortsname_09271_tl} {Thurnau-Alladorf}
\tl_const:cn {c_phone_DE_ortsname_09272_tl} {Fichtelberg}
\tl_const:cn {c_phone_DE_ortsname_09273_tl} {Bad~Berneck~im~Fichtelgebirge}
\tl_const:cn {c_phone_DE_ortsname_09274_tl} {Hollfeld}
\tl_const:cn {c_phone_DE_ortsname_09275_tl} {Speichersdorf}
\tl_const:cn {c_phone_DE_ortsname_09276_tl} {Bischofsgr\"un}
\tl_const:cn {c_phone_DE_ortsname_09277_tl} {Warmensteinach}
\tl_const:cn {c_phone_DE_ortsname_09278_tl} {Weidenberg}
\tl_const:cn {c_phone_DE_ortsname_09279_tl} {Mistelgau}
\tl_const:cn {c_phone_DE_ortsname_09280_tl} {Selbitz~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09281_tl} {Hof~Saale}
\tl_const:cn {c_phone_DE_ortsname_09282_tl} {Naila}
\tl_const:cn {c_phone_DE_ortsname_09283_tl} {Rehau}
\tl_const:cn {c_phone_DE_ortsname_09284_tl} {Schwarzenbach~an~der~Saale}
\tl_const:cn {c_phone_DE_ortsname_09285_tl} {Kirchenlamitz}
\tl_const:cn {c_phone_DE_ortsname_09286_tl} {Oberkotzau}
\tl_const:cn {c_phone_DE_ortsname_09287_tl} {Selb}
\tl_const:cn {c_phone_DE_ortsname_09288_tl} {Bad~Steben}
\tl_const:cn {c_phone_DE_ortsname_09289_tl} {Schwarzenbach~am~Wald}
\tl_const:cn {c_phone_DE_ortsname_09292_tl} {Konradsreuth}
\tl_const:cn {c_phone_DE_ortsname_09293_tl} {Berg~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09294_tl} {Regnitzlosau}
\tl_const:cn {c_phone_DE_ortsname_09295_tl} {T\"open}
\tl_const:cn {c_phone_DE_ortsname_09302_tl} {Rottendorf~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09303_tl} {Eibelstadt}
\tl_const:cn {c_phone_DE_ortsname_09305_tl} {Estenfeld}
\tl_const:cn {c_phone_DE_ortsname_09306_tl} {Kist}
\tl_const:cn {c_phone_DE_ortsname_09307_tl} {Altertheim}
\tl_const:cn {c_phone_DE_ortsname_0931_tl} {W\"urzburg}
\tl_const:cn {c_phone_DE_ortsname_09321_tl} {Kitzingen}
\tl_const:cn {c_phone_DE_ortsname_09323_tl} {Iphofen}
\tl_const:cn {c_phone_DE_ortsname_09324_tl} {Dettelbach}
\tl_const:cn {c_phone_DE_ortsname_09325_tl} {Kleinlangheim}
\tl_const:cn {c_phone_DE_ortsname_09326_tl} {Markt~Einersheim}
\tl_const:cn {c_phone_DE_ortsname_09331_tl} {Ochsenfurt}
\tl_const:cn {c_phone_DE_ortsname_09332_tl} {Marktbreit}
\tl_const:cn {c_phone_DE_ortsname_09333_tl} {Sommerhausen}
\tl_const:cn {c_phone_DE_ortsname_09334_tl} {Giebelstadt}
\tl_const:cn {c_phone_DE_ortsname_09335_tl} {Aub~Kreis~W\"urzburg}
\tl_const:cn {c_phone_DE_ortsname_09336_tl} {B\"utthard}
\tl_const:cn {c_phone_DE_ortsname_09337_tl} {Gauk\"onigshofen}
\tl_const:cn {c_phone_DE_ortsname_09338_tl} {R\"ottingen~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09339_tl} {Ippesheim}
\tl_const:cn {c_phone_DE_ortsname_09340_tl} {K\"onigheim-Brehmen}
\tl_const:cn {c_phone_DE_ortsname_09341_tl} {Tauberbischofsheim}
\tl_const:cn {c_phone_DE_ortsname_09342_tl} {Wertheim}
\tl_const:cn {c_phone_DE_ortsname_09343_tl} {Lauda-K\"onigshofen}
\tl_const:cn {c_phone_DE_ortsname_09344_tl} {Gerchsheim}
\tl_const:cn {c_phone_DE_ortsname_09345_tl} {K\"ulsheim~Baden}
\tl_const:cn {c_phone_DE_ortsname_09346_tl} {Gr\"unsfeld}
\tl_const:cn {c_phone_DE_ortsname_09347_tl} {Wittighausen}
\tl_const:cn {c_phone_DE_ortsname_09348_tl} {Werbach-Gamburg}
\tl_const:cn {c_phone_DE_ortsname_09349_tl} {Werbach-Wenkheim}
\tl_const:cn {c_phone_DE_ortsname_09350_tl} {Eu\ss enheim-Hundsbach}
\tl_const:cn {c_phone_DE_ortsname_09351_tl} {Gem\"unden~am~Main}
\tl_const:cn {c_phone_DE_ortsname_09352_tl} {Lohr~am~Main}
\tl_const:cn {c_phone_DE_ortsname_09353_tl} {Karlstadt}
\tl_const:cn {c_phone_DE_ortsname_09354_tl} {Rieneck}
\tl_const:cn {c_phone_DE_ortsname_09355_tl} {Frammersbach}
\tl_const:cn {c_phone_DE_ortsname_09356_tl} {Burgsinn}
\tl_const:cn {c_phone_DE_ortsname_09357_tl} {Gr\"afendorf~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09358_tl} {G\"ossenheim}
\tl_const:cn {c_phone_DE_ortsname_09359_tl} {Karlstadt-Wiesenfeld}
\tl_const:cn {c_phone_DE_ortsname_09360_tl} {Th\"ungen}
\tl_const:cn {c_phone_DE_ortsname_09363_tl} {Arnstein~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09364_tl} {Zellingen}
\tl_const:cn {c_phone_DE_ortsname_09365_tl} {Rimpar}
\tl_const:cn {c_phone_DE_ortsname_09366_tl} {Geroldshausen~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09367_tl} {Unterpleichfeld}
\tl_const:cn {c_phone_DE_ortsname_09369_tl} {Uettingen}
\tl_const:cn {c_phone_DE_ortsname_09371_tl} {Miltenberg}
\tl_const:cn {c_phone_DE_ortsname_09372_tl} {Klingenberg~am~Main}
\tl_const:cn {c_phone_DE_ortsname_09373_tl} {Amorbach}
\tl_const:cn {c_phone_DE_ortsname_09374_tl} {Eschau}
\tl_const:cn {c_phone_DE_ortsname_09375_tl} {Freudenberg~Baden}
\tl_const:cn {c_phone_DE_ortsname_09376_tl} {Collenberg}
\tl_const:cn {c_phone_DE_ortsname_09377_tl} {Freudenberg-Boxtal}
\tl_const:cn {c_phone_DE_ortsname_09378_tl} {Eichenb\"uhl-Riedern}
\tl_const:cn {c_phone_DE_ortsname_09381_tl} {Volkach}
\tl_const:cn {c_phone_DE_ortsname_09382_tl} {Gerolzhofen}
\tl_const:cn {c_phone_DE_ortsname_09383_tl} {Wiesentheid}
\tl_const:cn {c_phone_DE_ortsname_09384_tl} {Schwanfeld}
\tl_const:cn {c_phone_DE_ortsname_09385_tl} {Kolitzheim}
\tl_const:cn {c_phone_DE_ortsname_09386_tl} {Prosselsheim}
\tl_const:cn {c_phone_DE_ortsname_09391_tl} {Marktheidenfeld}
\tl_const:cn {c_phone_DE_ortsname_09392_tl} {Faulbach~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09393_tl} {Rothenfels~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09394_tl} {Esselbach}
\tl_const:cn {c_phone_DE_ortsname_09395_tl} {Triefenstein}
\tl_const:cn {c_phone_DE_ortsname_09396_tl} {Urspringen~bei~Lohr}
\tl_const:cn {c_phone_DE_ortsname_09397_tl} {Wertheim-Dertingen}
\tl_const:cn {c_phone_DE_ortsname_09398_tl} {Birkenfeld~bei~W\"urzburg}
\tl_const:cn {c_phone_DE_ortsname_09401_tl} {Neutraubling}
\tl_const:cn {c_phone_DE_ortsname_09402_tl} {Regenstauf}
\tl_const:cn {c_phone_DE_ortsname_09403_tl} {Donaustauf}
\tl_const:cn {c_phone_DE_ortsname_09404_tl} {Nittendorf}
\tl_const:cn {c_phone_DE_ortsname_09405_tl} {Bad~Abbach}
\tl_const:cn {c_phone_DE_ortsname_09406_tl} {Mintraching}
\tl_const:cn {c_phone_DE_ortsname_09407_tl} {Wenzenbach}
\tl_const:cn {c_phone_DE_ortsname_09408_tl} {Altenthann}
\tl_const:cn {c_phone_DE_ortsname_09409_tl} {Pielenhofen}
\tl_const:cn {c_phone_DE_ortsname_0941_tl} {Regensburg}
\tl_const:cn {c_phone_DE_ortsname_09420_tl} {Feldkirchen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09421_tl} {Straubing}
\tl_const:cn {c_phone_DE_ortsname_09422_tl} {Bogen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09423_tl} {Geiselh\"oring}
\tl_const:cn {c_phone_DE_ortsname_09424_tl} {Stra\ss kirchen}
\tl_const:cn {c_phone_DE_ortsname_09426_tl} {Oberschneiding}
\tl_const:cn {c_phone_DE_ortsname_09427_tl} {Leiblfing}
\tl_const:cn {c_phone_DE_ortsname_09428_tl} {Kirchroth}
\tl_const:cn {c_phone_DE_ortsname_09429_tl} {Rain~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09431_tl} {Schwandorf}
\tl_const:cn {c_phone_DE_ortsname_09433_tl} {Nabburg}
\tl_const:cn {c_phone_DE_ortsname_09434_tl} {Bodenw\"ohr}
\tl_const:cn {c_phone_DE_ortsname_09435_tl} {Schwarzenfeld}
\tl_const:cn {c_phone_DE_ortsname_09436_tl} {Nittenau}
\tl_const:cn {c_phone_DE_ortsname_09438_tl} {Fensterbach}
\tl_const:cn {c_phone_DE_ortsname_09439_tl} {Neunburg-Kemnath}
\tl_const:cn {c_phone_DE_ortsname_09441_tl} {Kelheim}
\tl_const:cn {c_phone_DE_ortsname_09442_tl} {Riedenburg}
\tl_const:cn {c_phone_DE_ortsname_09443_tl} {Abensberg}
\tl_const:cn {c_phone_DE_ortsname_09444_tl} {Siegenburg}
\tl_const:cn {c_phone_DE_ortsname_09445_tl} {Neustadt~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_09446_tl} {Altmannstein}
\tl_const:cn {c_phone_DE_ortsname_09447_tl} {Essing}
\tl_const:cn {c_phone_DE_ortsname_09448_tl} {Hausen~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09451_tl} {Schierling}
\tl_const:cn {c_phone_DE_ortsname_09452_tl} {Langquaid}
\tl_const:cn {c_phone_DE_ortsname_09453_tl} {Thalmassing}
\tl_const:cn {c_phone_DE_ortsname_09454_tl} {Aufhausen~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09461_tl} {Roding}
\tl_const:cn {c_phone_DE_ortsname_09462_tl} {Falkenstein~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09463_tl} {Wald~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09464_tl} {Walderbach}
\tl_const:cn {c_phone_DE_ortsname_09465_tl} {Neukirchen-Balbini}
\tl_const:cn {c_phone_DE_ortsname_09466_tl} {Stamsried}
\tl_const:cn {c_phone_DE_ortsname_09467_tl} {Michelsneukirchen}
\tl_const:cn {c_phone_DE_ortsname_09468_tl} {Zell~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09469_tl} {Roding-Neub\"au}
\tl_const:cn {c_phone_DE_ortsname_09471_tl} {Burglengenfeld}
\tl_const:cn {c_phone_DE_ortsname_09472_tl} {Hohenfels~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09473_tl} {Kallm\"unz}
\tl_const:cn {c_phone_DE_ortsname_09474_tl} {Schmidm\"uhlen}
\tl_const:cn {c_phone_DE_ortsname_09480_tl} {S\"unching}
\tl_const:cn {c_phone_DE_ortsname_09481_tl} {Pfatter}
\tl_const:cn {c_phone_DE_ortsname_09482_tl} {W\"orth~an~der~Donau}
\tl_const:cn {c_phone_DE_ortsname_09484_tl} {Brennberg}
\tl_const:cn {c_phone_DE_ortsname_09491_tl} {Hemau}
\tl_const:cn {c_phone_DE_ortsname_09492_tl} {Parsberg}
\tl_const:cn {c_phone_DE_ortsname_09493_tl} {Beratzhausen}
\tl_const:cn {c_phone_DE_ortsname_09495_tl} {Breitenbrunn~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09497_tl} {Seubersdorf~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09498_tl} {Laaber}
\tl_const:cn {c_phone_DE_ortsname_09499_tl} {Painten}
\tl_const:cn {c_phone_DE_ortsname_09502_tl} {Frensdorf}
\tl_const:cn {c_phone_DE_ortsname_09503_tl} {Oberhaid~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09504_tl} {Stadelhofen}
\tl_const:cn {c_phone_DE_ortsname_09505_tl} {Litzendorf}
\tl_const:cn {c_phone_DE_ortsname_0951_tl} {Bamberg}
\tl_const:cn {c_phone_DE_ortsname_09521_tl} {Ha\ss furt}
\tl_const:cn {c_phone_DE_ortsname_09522_tl} {Eltmann}
\tl_const:cn {c_phone_DE_ortsname_09523_tl} {Hofheim~in~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09524_tl} {Zeil~am~Main}
\tl_const:cn {c_phone_DE_ortsname_09525_tl} {K\"onigsberg~in~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09526_tl} {Riedbach}
\tl_const:cn {c_phone_DE_ortsname_09527_tl} {Knetzgau}
\tl_const:cn {c_phone_DE_ortsname_09528_tl} {Donnersdorf}
\tl_const:cn {c_phone_DE_ortsname_09529_tl} {Oberaurach}
\tl_const:cn {c_phone_DE_ortsname_09531_tl} {Ebern}
\tl_const:cn {c_phone_DE_ortsname_09532_tl} {Maroldsweisach}
\tl_const:cn {c_phone_DE_ortsname_09533_tl} {Untermerzbach}
\tl_const:cn {c_phone_DE_ortsname_09534_tl} {Burgpreppach}
\tl_const:cn {c_phone_DE_ortsname_09535_tl} {Pfarrweisach}
\tl_const:cn {c_phone_DE_ortsname_09536_tl} {Kirchlauter}
\tl_const:cn {c_phone_DE_ortsname_09542_tl} {Sche\ss litz}
\tl_const:cn {c_phone_DE_ortsname_09543_tl} {Hirschaid}
\tl_const:cn {c_phone_DE_ortsname_09544_tl} {Baunach}
\tl_const:cn {c_phone_DE_ortsname_09545_tl} {Buttenheim}
\tl_const:cn {c_phone_DE_ortsname_09546_tl} {Burgebrach}
\tl_const:cn {c_phone_DE_ortsname_09547_tl} {Zapfendorf}
\tl_const:cn {c_phone_DE_ortsname_09548_tl} {M\"uhlhausen~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09549_tl} {Lisberg}
\tl_const:cn {c_phone_DE_ortsname_09551_tl} {Burgwindheim}
\tl_const:cn {c_phone_DE_ortsname_09552_tl} {Burghaslach}
\tl_const:cn {c_phone_DE_ortsname_09553_tl} {Ebrach~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09554_tl} {Untersteinbach~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09555_tl} {Schl\"usselfeld-Aschbach}
\tl_const:cn {c_phone_DE_ortsname_09556_tl} {Geiselwind}
\tl_const:cn {c_phone_DE_ortsname_09560_tl} {Grub~am~Forst}
\tl_const:cn {c_phone_DE_ortsname_09561_tl} {Coburg}
\tl_const:cn {c_phone_DE_ortsname_09562_tl} {Sonnefeld}
\tl_const:cn {c_phone_DE_ortsname_09563_tl} {R\"odental}
\tl_const:cn {c_phone_DE_ortsname_09564_tl} {Bad~Rodach}
\tl_const:cn {c_phone_DE_ortsname_09565_tl} {Untersiemau}
\tl_const:cn {c_phone_DE_ortsname_09566_tl} {Meeder}
\tl_const:cn {c_phone_DE_ortsname_09567_tl} {Se\ss lach-Gem\"unda}
\tl_const:cn {c_phone_DE_ortsname_09568_tl} {Neustadt~bei~Coburg}
\tl_const:cn {c_phone_DE_ortsname_09569_tl} {Se\ss lach}
\tl_const:cn {c_phone_DE_ortsname_09571_tl} {Lichtenfels~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09572_tl} {Burgkunstadt}
\tl_const:cn {c_phone_DE_ortsname_09573_tl} {Staffelstein~Oberfranken}
\tl_const:cn {c_phone_DE_ortsname_09574_tl} {Marktzeuln}
\tl_const:cn {c_phone_DE_ortsname_09575_tl} {Weismain}
\tl_const:cn {c_phone_DE_ortsname_09576_tl} {Lichtenfels-Isling}
\tl_const:cn {c_phone_DE_ortsname_09602_tl} {Neustadt~an~der~Waldnaab}
\tl_const:cn {c_phone_DE_ortsname_09603_tl} {Flo\ss}
\tl_const:cn {c_phone_DE_ortsname_09604_tl} {Wernberg-K\"oblitz}
\tl_const:cn {c_phone_DE_ortsname_09605_tl} {Weiherhammer}
\tl_const:cn {c_phone_DE_ortsname_09606_tl} {Pfreimd}
\tl_const:cn {c_phone_DE_ortsname_09607_tl} {Luhe-Wildenau}
\tl_const:cn {c_phone_DE_ortsname_09608_tl} {Kohlberg~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_0961_tl} {Weiden~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09621_tl} {Amberg~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09622_tl} {Hirschau~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09624_tl} {Ensdorf~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09625_tl} {Kastl~bei~Amberg}
\tl_const:cn {c_phone_DE_ortsname_09626_tl} {Hohenburg}
\tl_const:cn {c_phone_DE_ortsname_09627_tl} {Freudenberg~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09628_tl} {Ursensollen}
\tl_const:cn {c_phone_DE_ortsname_09631_tl} {Tirschenreuth}
\tl_const:cn {c_phone_DE_ortsname_09632_tl} {Waldsassen}
\tl_const:cn {c_phone_DE_ortsname_09633_tl} {Mitterteich}
\tl_const:cn {c_phone_DE_ortsname_09634_tl} {Wiesau}
\tl_const:cn {c_phone_DE_ortsname_09635_tl} {B\"arnau}
\tl_const:cn {c_phone_DE_ortsname_09636_tl} {Pl\"o\ss berg}
\tl_const:cn {c_phone_DE_ortsname_09637_tl} {Falkenberg~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09638_tl} {Neualbenreuth}
\tl_const:cn {c_phone_DE_ortsname_09639_tl} {M\"ahring}
\tl_const:cn {c_phone_DE_ortsname_09641_tl} {Grafenw\"ohr}
\tl_const:cn {c_phone_DE_ortsname_09642_tl} {Kemnath~Stadt}
\tl_const:cn {c_phone_DE_ortsname_09643_tl} {Auerbach~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09644_tl} {Pressath}
\tl_const:cn {c_phone_DE_ortsname_09645_tl} {Eschenbach~in~der~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09646_tl} {Freihung}
\tl_const:cn {c_phone_DE_ortsname_09647_tl} {Kirchenthumbach}
\tl_const:cn {c_phone_DE_ortsname_09648_tl} {Neustadt~am~Kulm}
\tl_const:cn {c_phone_DE_ortsname_09651_tl} {Vohenstrau\ss}
\tl_const:cn {c_phone_DE_ortsname_09652_tl} {Waidhaus}
\tl_const:cn {c_phone_DE_ortsname_09653_tl} {Eslarn}
\tl_const:cn {c_phone_DE_ortsname_09654_tl} {Pleystein}
\tl_const:cn {c_phone_DE_ortsname_09655_tl} {T\"annesberg}
\tl_const:cn {c_phone_DE_ortsname_09656_tl} {Moosbach~bei~Vohenstrau\ss}
\tl_const:cn {c_phone_DE_ortsname_09657_tl} {Waldthurn}
\tl_const:cn {c_phone_DE_ortsname_09658_tl} {Georgenberg}
\tl_const:cn {c_phone_DE_ortsname_09659_tl} {Leuchtenberg}
\tl_const:cn {c_phone_DE_ortsname_09661_tl} {Sulzbach-Rosenberg}
\tl_const:cn {c_phone_DE_ortsname_09662_tl} {Vilseck}
\tl_const:cn {c_phone_DE_ortsname_09663_tl} {Neukirchen~bei~Sulzbach-Rosenberg}
\tl_const:cn {c_phone_DE_ortsname_09664_tl} {Hahnbach}
\tl_const:cn {c_phone_DE_ortsname_09665_tl} {K\"onigstein~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09666_tl} {Illschwang}
\tl_const:cn {c_phone_DE_ortsname_09671_tl} {Oberviechtach}
\tl_const:cn {c_phone_DE_ortsname_09672_tl} {Neunburg~vorm~Wald}
\tl_const:cn {c_phone_DE_ortsname_09673_tl} {Tiefenbach~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09674_tl} {Sch\"onsee}
\tl_const:cn {c_phone_DE_ortsname_09675_tl} {Altendorf~bei~Nabburg}
\tl_const:cn {c_phone_DE_ortsname_09676_tl} {Winklarn}
\tl_const:cn {c_phone_DE_ortsname_09677_tl} {Oberviechtach-Pullenried}
\tl_const:cn {c_phone_DE_ortsname_09681_tl} {Windischeschenbach}
\tl_const:cn {c_phone_DE_ortsname_09682_tl} {Erbendorf}
\tl_const:cn {c_phone_DE_ortsname_09683_tl} {Friedenfels}
\tl_const:cn {c_phone_DE_ortsname_09701_tl} {Sandberg~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09704_tl} {Euerdorf}
\tl_const:cn {c_phone_DE_ortsname_09708_tl} {Bad~Bocklet}
\tl_const:cn {c_phone_DE_ortsname_0971_tl} {Bad~Kissingen}
\tl_const:cn {c_phone_DE_ortsname_09720_tl} {\"Uchtelhausen}
\tl_const:cn {c_phone_DE_ortsname_09721_tl} {Schweinfurt}
\tl_const:cn {c_phone_DE_ortsname_09722_tl} {Werneck}
\tl_const:cn {c_phone_DE_ortsname_09723_tl} {R\"othlein}
\tl_const:cn {c_phone_DE_ortsname_09724_tl} {Stadtlauringen}
\tl_const:cn {c_phone_DE_ortsname_09725_tl} {Poppenhausen~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09726_tl} {Euerbach}
\tl_const:cn {c_phone_DE_ortsname_09727_tl} {Schonungen-Marktsteinach}
\tl_const:cn {c_phone_DE_ortsname_09728_tl} {W\"ulfershausen~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09729_tl} {Grettstadt}
\tl_const:cn {c_phone_DE_ortsname_09732_tl} {Hammelburg}
\tl_const:cn {c_phone_DE_ortsname_09733_tl} {M\"unnerstadt}
\tl_const:cn {c_phone_DE_ortsname_09734_tl} {Burkardroth}
\tl_const:cn {c_phone_DE_ortsname_09735_tl} {Ma\ss bach}
\tl_const:cn {c_phone_DE_ortsname_09736_tl} {Oberthulba}
\tl_const:cn {c_phone_DE_ortsname_09737_tl} {Wartmannsroth}
\tl_const:cn {c_phone_DE_ortsname_09738_tl} {Rottershausen}
\tl_const:cn {c_phone_DE_ortsname_09741_tl} {Bad~Br\"uckenau}
\tl_const:cn {c_phone_DE_ortsname_09742_tl} {Kalbach~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_09744_tl} {Zeitlofs-Detter}
\tl_const:cn {c_phone_DE_ortsname_09745_tl} {Wildflecken}
\tl_const:cn {c_phone_DE_ortsname_09746_tl} {Zeitlofs}
\tl_const:cn {c_phone_DE_ortsname_09747_tl} {Geroda~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09748_tl} {Motten}
\tl_const:cn {c_phone_DE_ortsname_09749_tl} {Oberbach~Unterfranken}
\tl_const:cn {c_phone_DE_ortsname_09761_tl} {Bad~K\"onigshofen~im~Grabfeld}
\tl_const:cn {c_phone_DE_ortsname_09762_tl} {Saal~an~der~Saale}
\tl_const:cn {c_phone_DE_ortsname_09763_tl} {Sulzdorf~an~der~Lederhecke}
\tl_const:cn {c_phone_DE_ortsname_09764_tl} {H\"ochheim}
\tl_const:cn {c_phone_DE_ortsname_09765_tl} {Trappstadt}
\tl_const:cn {c_phone_DE_ortsname_09766_tl} {Gro\ss wenkheim}
\tl_const:cn {c_phone_DE_ortsname_09771_tl} {Bad~Neustadt~an~der~Saale}
\tl_const:cn {c_phone_DE_ortsname_09772_tl} {Bischofsheim~an~der~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_09773_tl} {Unsleben}
\tl_const:cn {c_phone_DE_ortsname_09774_tl} {Oberelsbach}
\tl_const:cn {c_phone_DE_ortsname_09775_tl} {Sch\"onau~an~der~Brend}
\tl_const:cn {c_phone_DE_ortsname_09776_tl} {Mellrichstadt}
\tl_const:cn {c_phone_DE_ortsname_09777_tl} {Ostheim~vor~der~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_09778_tl} {Fladungen}
\tl_const:cn {c_phone_DE_ortsname_09779_tl} {Nordheim~vor~der~Rh\"on}
\tl_const:cn {c_phone_DE_ortsname_09802_tl} {Ansbach-Katterbach}
\tl_const:cn {c_phone_DE_ortsname_09803_tl} {Colmberg}
\tl_const:cn {c_phone_DE_ortsname_09804_tl} {Aurach}
\tl_const:cn {c_phone_DE_ortsname_09805_tl} {Burgoberbach}
\tl_const:cn {c_phone_DE_ortsname_0981_tl} {Ansbach}
\tl_const:cn {c_phone_DE_ortsname_09820_tl} {Lehrberg}
\tl_const:cn {c_phone_DE_ortsname_09822_tl} {Bechhofen~an~der~Heide}
\tl_const:cn {c_phone_DE_ortsname_09823_tl} {Leutershausen}
\tl_const:cn {c_phone_DE_ortsname_09824_tl} {Dietenhofen}
\tl_const:cn {c_phone_DE_ortsname_09825_tl} {Herrieden}
\tl_const:cn {c_phone_DE_ortsname_09826_tl} {Weidenbach~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09827_tl} {Lichtenau~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09828_tl} {R\"ugland}
\tl_const:cn {c_phone_DE_ortsname_09829_tl} {Flachslanden}
\tl_const:cn {c_phone_DE_ortsname_09831_tl} {Gunzenhausen}
\tl_const:cn {c_phone_DE_ortsname_09832_tl} {Wassertr\"udingen}
\tl_const:cn {c_phone_DE_ortsname_09833_tl} {Heidenheim~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09834_tl} {Theilenhofen}
\tl_const:cn {c_phone_DE_ortsname_09835_tl} {Ehingen~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09836_tl} {Gunzenhausen-Cronheim}
\tl_const:cn {c_phone_DE_ortsname_09837_tl} {Haundorf}
\tl_const:cn {c_phone_DE_ortsname_09841_tl} {Bad~Windsheim}
\tl_const:cn {c_phone_DE_ortsname_09842_tl} {Uffenheim}
\tl_const:cn {c_phone_DE_ortsname_09843_tl} {Burgbernheim}
\tl_const:cn {c_phone_DE_ortsname_09844_tl} {Obernzenn}
\tl_const:cn {c_phone_DE_ortsname_09845_tl} {Oberdachstetten}
\tl_const:cn {c_phone_DE_ortsname_09846_tl} {Ipsheim}
\tl_const:cn {c_phone_DE_ortsname_09847_tl} {Ergersheim}
\tl_const:cn {c_phone_DE_ortsname_09848_tl} {Simmershofen}
\tl_const:cn {c_phone_DE_ortsname_09851_tl} {Dinkelsb\"uhl}
\tl_const:cn {c_phone_DE_ortsname_09852_tl} {Feuchtwangen}
\tl_const:cn {c_phone_DE_ortsname_09853_tl} {Wilburgstetten}
\tl_const:cn {c_phone_DE_ortsname_09854_tl} {Wittelshofen}
\tl_const:cn {c_phone_DE_ortsname_09855_tl} {Dentlein~am~Forst}
\tl_const:cn {c_phone_DE_ortsname_09856_tl} {D\"urrwangen}
\tl_const:cn {c_phone_DE_ortsname_09857_tl} {Schopf\/loch~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09861_tl} {Rothenburg~ob~der~Tauber}
\tl_const:cn {c_phone_DE_ortsname_09865_tl} {Adelshofen~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09867_tl} {Geslau}
\tl_const:cn {c_phone_DE_ortsname_09868_tl} {Schillingsf\"urst}
\tl_const:cn {c_phone_DE_ortsname_09869_tl} {Wettringen~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09871_tl} {Windsbach}
\tl_const:cn {c_phone_DE_ortsname_09872_tl} {Heilsbronn}
\tl_const:cn {c_phone_DE_ortsname_09873_tl} {Abenberg-Wassermungenau}
\tl_const:cn {c_phone_DE_ortsname_09874_tl} {Neuendettelsau}
\tl_const:cn {c_phone_DE_ortsname_09875_tl} {Wolframs-Eschenbach}
\tl_const:cn {c_phone_DE_ortsname_09876_tl} {Rohr~Mittelfranken}
\tl_const:cn {c_phone_DE_ortsname_09901_tl} {Hengersberg~Bayern}
\tl_const:cn {c_phone_DE_ortsname_09903_tl} {Sch\"ollnach}
\tl_const:cn {c_phone_DE_ortsname_09904_tl} {Lalling}
\tl_const:cn {c_phone_DE_ortsname_09905_tl} {Bernried~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09906_tl} {Mariaposching}
\tl_const:cn {c_phone_DE_ortsname_09907_tl} {Zenting}
\tl_const:cn {c_phone_DE_ortsname_09908_tl} {Sch\"ofweg}
\tl_const:cn {c_phone_DE_ortsname_0991_tl} {Deggendorf}
\tl_const:cn {c_phone_DE_ortsname_09920_tl} {Bischofsmais}
\tl_const:cn {c_phone_DE_ortsname_09921_tl} {Regen}
\tl_const:cn {c_phone_DE_ortsname_09922_tl} {Zwiesel}
\tl_const:cn {c_phone_DE_ortsname_09923_tl} {Teisnach}
\tl_const:cn {c_phone_DE_ortsname_09924_tl} {Bodenmais}
\tl_const:cn {c_phone_DE_ortsname_09925_tl} {Bayerisch~Eisenstein}
\tl_const:cn {c_phone_DE_ortsname_09926_tl} {Frauenau}
\tl_const:cn {c_phone_DE_ortsname_09927_tl} {Kirchberg~Wald}
\tl_const:cn {c_phone_DE_ortsname_09928_tl} {Kirchdorf~im~Wald}
\tl_const:cn {c_phone_DE_ortsname_09929_tl} {Ruhmannsfelden}
\tl_const:cn {c_phone_DE_ortsname_09931_tl} {Plattling}
\tl_const:cn {c_phone_DE_ortsname_09932_tl} {Osterhofen}
\tl_const:cn {c_phone_DE_ortsname_09933_tl} {Wallersdorf}
\tl_const:cn {c_phone_DE_ortsname_09935_tl} {Stephansposching}
\tl_const:cn {c_phone_DE_ortsname_09936_tl} {Wallerfing}
\tl_const:cn {c_phone_DE_ortsname_09937_tl} {Oberp\"oring}
\tl_const:cn {c_phone_DE_ortsname_09938_tl} {Moos~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09941_tl} {K\"otzting}
\tl_const:cn {c_phone_DE_ortsname_09942_tl} {Viechtach}
\tl_const:cn {c_phone_DE_ortsname_09943_tl} {Lam~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_09944_tl} {Miltach}
\tl_const:cn {c_phone_DE_ortsname_09945_tl} {Arnbruck}
\tl_const:cn {c_phone_DE_ortsname_09946_tl} {Hohenwarth~bei~K\"otzing}
\tl_const:cn {c_phone_DE_ortsname_09947_tl} {Neukirchen~beim~Heiligen~Blut}
\tl_const:cn {c_phone_DE_ortsname_09948_tl} {Eschlkam}
\tl_const:cn {c_phone_DE_ortsname_09951_tl} {Landau~an~der~Isar}
\tl_const:cn {c_phone_DE_ortsname_09952_tl} {Eichendorf}
\tl_const:cn {c_phone_DE_ortsname_09953_tl} {Pilsting}
\tl_const:cn {c_phone_DE_ortsname_09954_tl} {Simbach~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09955_tl} {Mamming}
\tl_const:cn {c_phone_DE_ortsname_09956_tl} {Eichendorf-Aufhausen}
\tl_const:cn {c_phone_DE_ortsname_09961_tl} {Mitterfels}
\tl_const:cn {c_phone_DE_ortsname_09962_tl} {Schwarzach~Niederbayern}
\tl_const:cn {c_phone_DE_ortsname_09963_tl} {Konzell}
\tl_const:cn {c_phone_DE_ortsname_09964_tl} {Stallwang}
\tl_const:cn {c_phone_DE_ortsname_09965_tl} {Sankt~Englmar}
\tl_const:cn {c_phone_DE_ortsname_09966_tl} {Wiesenfelden}
\tl_const:cn {c_phone_DE_ortsname_09971_tl} {Cham}
\tl_const:cn {c_phone_DE_ortsname_09972_tl} {Waldm\"unchen}
\tl_const:cn {c_phone_DE_ortsname_09973_tl} {Furth~im~Wald}
\tl_const:cn {c_phone_DE_ortsname_09974_tl} {Traitsching}
\tl_const:cn {c_phone_DE_ortsname_09975_tl} {Waldm\"unchen-Geigant}
\tl_const:cn {c_phone_DE_ortsname_09976_tl} {R\"otz}
\tl_const:cn {c_phone_DE_ortsname_09977_tl} {Arnschwang}
\tl_const:cn {c_phone_DE_ortsname_09978_tl} {Sch\"onthal~Oberpfalz}
\tl_const:cn {c_phone_DE_ortsname_01371_tl} {Massenverkehrsdienst~(14\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01372_tl} {Massenverkehrsdienst~(14\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01373_tl} {Massenverkehrsdienst~(14\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01374_tl} {Massenverkehrsdienst~(14\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01375_tl} {Massenverkehrsdienst~(14\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01376_tl} {Massenverkehrsdienst~(25\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01377_tl} {Massenverkehrsdienst~(1\nobreakspace Euro/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01378_tl} {Massenverkehrsdienst~(50\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01379_tl} {Massenverkehrsdienst~(50\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_015019_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015020_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01511_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01512_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01514_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01515_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01516_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01517_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015180_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015181_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015182_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015183_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015184_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015185_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015186_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015310_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01520_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01521_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01522_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01523_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01525_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01526_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01529_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015510_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015511_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015550_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015551_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015552_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015553_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015554_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015555_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015556_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015557_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015558_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015559_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015560_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015561_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015562_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015563_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015564_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015565_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015566_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015567_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015568_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015569_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015630_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015678_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015679_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015700_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015701_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015702_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015703_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015704_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015705_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015706_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01573_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01575_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01577_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01578_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01579_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_015888_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01590_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0160_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0162_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0163_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0164_tl} {Funkruf}
\tl_const:cn {c_phone_DE_ortsname_0168_tl} {Funkruf}
\tl_const:cn {c_phone_DE_ortsname_0169_tl} {Funkruf}
\tl_const:cn {c_phone_DE_ortsname_0170_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0171_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0172_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0173_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0174_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0175_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0176_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0177_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0178_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_0179_tl} {Mobilfunk}
\tl_const:cn {c_phone_DE_ortsname_01801_tl} {Service-Dienst~(3,9\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01802_tl} {Service-Dienst~(6\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01803_tl} {Service-Dienst~(9\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01804_tl} {Service-Dienst~(20\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01805_tl} {Service-Dienst~(14\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_01806_tl} {Service-Dienst~(20\,ct/Anruf)}
\tl_const:cn {c_phone_DE_ortsname_01807_tl} {Service-Dienst~(30\,s~frei,~danach~14\,ct/min)}
\tl_const:cn {c_phone_DE_ortsname_0181_tl} {Internationales~virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0182_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0183_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0184_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0185_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0186_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0187_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0188_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0189_tl} {Virtuelles~privates~Netz}
\tl_const:cn {c_phone_DE_ortsname_0191_tl} {Online-Dienst}
\tl_const:cn {c_phone_DE_ortsname_0192_tl} {Online-Dienst}
\tl_const:cn {c_phone_DE_ortsname_0193_tl} {Online-Dienst}
\tl_const:cn {c_phone_DE_ortsname_0194_tl} {Online-Dienst}
\tl_const:cn {c_phone_DE_ortsname_032_tl} {Nationale~Teilnehmerrufnummer}
\tl_const:cn {c_phone_DE_ortsname_0700_tl} {Pers\"onliche~Rufnummer}
\tl_const:cn {c_phone_DE_ortsname_0800_tl} {Entgeltfreier~Telefondienst}
\tl_const:cn {c_phone_DE_ortsname_09001_tl} {Premium-Dienst}
\tl_const:cn {c_phone_DE_ortsname_09003_tl} {Premium-Dienst}
\tl_const:cn {c_phone_DE_ortsname_09005_tl} {Premium-Dienst}

\tl_const:Nn \c_phone_DE_landesadjektiv_tl {German}
\bool_const:Nn \c_phone_DE_erlaubt_durchwahl_bool {\c_true_bool}

\clist_new:N \c_phone_DE_vorwahlen_clist
\clist_concat:NNN \c_phone_DE_vorwahlen_clist \c_phone_DE_ortsvorwahlen_clist \c_phone_DE_sondervorwahlen_clist

% Prüfe, ob eine Vorwahl als Heimatvorwahl zulässig ist.
% #1: Heimatvorwahl
\prg_new_protected_conditional:Npnn \phone_DE_heimatvorwahl_erlaubt:n #1 {T}
   {
      \clist_if_in:NnTF \c_phone_DE_ortsvorwahlen_clist {#1}
         {
            % Alle deutschen Ortsvorwahlen können Heimatvorwahl sein.
            \prg_return_true:
         }
         {
            \msg_warning:nnn {phonenumbers} {invalid home area code} {#1}
            \prg_return_false:
         }
   }

% Prüfe, ob eine Vorwahl eine Tarifkennung enthält.
% #1: Vorwahl
\prg_new_protected_conditional:Npnn \phone_DE_enthaelt_tarifkennung:n #1 {TF}
   {
      \bool_if:nTF { \int_compare_p:nNn { \str_count:n {#1} } = {5} }
         {
            % fünfstellige Vorwahl
            \str_set:Nx \l_tmpa_str { \str_range:nnn {#1} {1} {4} }

            \bool_lazy_or:nnTF { \str_if_eq_p:Vn \l_tmpa_str {0137} } { \str_if_eq_p:Vn \l_tmpa_str {0180} }
               {
                  \prg_return_true:
               }
               {
                  \prg_return_false:
               }
         }
         {
            % nicht fünfstellige Vorwahl
            \prg_return_false:
         }
   }

% #1: Vorwahl, #2: Soll die führende Null ausgegeben werden?
\cs_new_protected:Npn \phone_DE_ziffernvorwahl_schreiben:nN #1#2
   {
      \phone_DE_enthaelt_tarifkennung:nTF {#1}
         {
            % fünfstellige Vorwahl mit Tarifkennung: letzte Ziffer steht allein
            \bool_if:NTF #2
               {
                  \phone_von_vorne_gruppiert_schreiben:n {#1}
               }
               {
                  \phone_versetzt_gruppiert_schreiben:x { \str_tail:n {#1} }
               }
         }
         {
            % Vorwahl ohne Tarifkennung
            \bool_if:NTF #2
               {
                  \phone_von_hinten_gruppiert_schreiben:n {#1}
               }
               {
                  \phone_von_hinten_gruppiert_schreiben:x { \str_tail:n {#1} }
               }
         }
   }

% #1: Vorwahl, #2: Folgt eine Rufnummer?
\cs_new_protected:Npn \phone_DE_vorwahl_schreiben:nn #1 #2
   {
      \bool_lazy_or:nnTF { \str_if_eq_p:Vn \l_phone_auslandsvorwahltyp_str {off} } { \str_if_eq_p:Vn \l_phone_heimatland_str {DE} }
         {
            \clist_if_in:NnT \c_phone_DE_sondervorwahlen_clist {#1}
               {
                  \str_if_eq:VnT \l_phone_vorwahldarstellung_str {place}
                     {
                        \str_set:Nn \l_phone_vorwahldarstellung_str {number}
                     }
               }

            \bool_lazy_and:nnF { \str_if_eq_p:Vn \l_phone_heimatland_str {DE} } { \str_if_eq_p:Vn \l_phone_heimatvorwahl_str {#1} }
               {
                  \str_case:Vn \l_phone_vorwahldarstellung_str
                     {
                        {number}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnTF \l_phone_vorwahltrennung_str {brackets}
                                       {
                                          \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                          \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                       }
                                       {
                                          \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                          \tl_put_right:Nx \l_phone_ausgabetext_tl
                                             {
                                                \str_case:VnF \l_phone_vorwahltrennung_str
                                                   {
                                                      {space} {\c_space_tl}
                                                      {hyphen} {\c_phone_bindestrich_tl}
                                                   }
                                                   {
                                                      \c_phone_schraegstrich_tl
                                                   }
                                             }
                                       }
                                 }
                                 {
                                    \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                 }
                           }
                        {place}
                           {
                              \bool_if:nTF {#2}
                                 {
                                    \str_if_eq:VnT \l_phone_vorwahltrennung_str {brackets}
                                       {
                                          \tl_put_right:Nn \l_phone_ausgabetext_tl {(}
                                       }

                                    \tl_if_exist:cTF {c_phone_DE_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_DE_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }

                                    \tl_put_right:Nx \l_phone_ausgabetext_tl
                                       {
                                          \str_case:VnF \l_phone_vorwahltrennung_str
                                             {
                                                {brackets} {) \c_space_tl}
                                                {space} {\c_space_tl}
                                                {hyphen} {\c_phone_bindestrich_tl}
                                             }
                                             {
                                                \c_phone_schraegstrich_tl
                                             }
                                       }
                                 }
                                 {
                                    \tl_if_exist:cTF {c_phone_DE_ortsname_ #1 _tl}
                                       {
                                          \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_DE_ortsname_ #1 _tl}
                                       }
                                       {
                                          \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_true_bool
                                       }
                                 }
                           }
                        {place-and-number}
                           {
                              \tl_if_exist:cT {c_phone_DE_ortsname_ #1 _tl}
                                 {
                                    \tl_put_right:Nv \l_phone_ausgabetext_tl {c_phone_DE_ortsname_ #1 _tl}
                                    \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                 }

                              \str_if_eq:VnTF \l_phone_vorwahltrennung_str {brackets}
                                 {
                                    \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                    \bool_if:nT {#2}
                                       {
                                          \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
                                       }
                                 }
                                 {
                                    \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_true_bool

                                    \bool_if:nT {#2}
                                       {
                                          \tl_put_right:Nx \l_phone_ausgabetext_tl
                                             {
                                                \str_case:VnF \l_phone_vorwahltrennung_str
                                                   {
                                                      {space} {\c_space_tl}
                                                      {hyphen} {\c_phone_bindestrich_tl}
                                                   }
                                                   {
                                                      \c_phone_schraegstrich_tl
                                                   }
                                             }
                                       }
                                 }
                           }
                     }
               }
         }
         {
            \phone_gruppierte_auslandsvorwahl_schreiben:n {49}
            \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl

            \str_if_eq:VnTF \l_phone_auslandsvorwahltrennung_str {brackets}
               {
                  \phone_geklammerte_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }
               {
                  \phone_DE_ziffernvorwahl_schreiben:nN {#1} \c_false_bool
               }

            \bool_if:nT {#2}
               {
                  \tl_put_right:NV \l_phone_ausgabetext_tl \c_space_tl
               }
         }

      % Linktext schreiben, falls eine Rufnummer folgt
      \bool_if:nT {#2}
         {
            \str_put_right:Nx \l_phone_linktext_str {+49}
            \str_put_right:Nx \l_phone_linktext_str { \str_tail:n {#1} }
         }
   }

\cs_generate_variant:Nn \phone_DE_vorwahl_schreiben:nn {Vx}

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_DE_festnetzteilnehmerrufnummernlaenge_ueberpruefen:Nn #1#2
   {
      \int_set:Nn \l_tmpa_int { \str_count:N #1 }
      \int_add:Nn \l_tmpa_int { \str_count:n {#2} }
      \int_add:Nn \l_tmpa_int { \str_count:N \l_phone_bereinigte_durchwahl_str }

      \int_compare:nNnTF {\l_tmpa_int} > {13}
         {
            % Gesamtnummer hat mehr als 13 Stellen
            \msg_warning:nnnn {phonenumbers} {number too long} {landline} {13}
         }
         {
            \int_set:Nn \l_tmpa_int { \str_count:n {#2} }
            \int_add:Nn \l_tmpa_int { \str_count:N \l_phone_bereinigte_durchwahl_str }

            \int_compare:nNnTF {\l_tmpa_int} < {3}
               {
                  % Teilnehmerrufnummer hat weniger als 3 Stellen
                  \msg_warning:nnn {phonenumbers} {subscriber number too short} {3}
               }
               {
                  \bool_set_true:N \l_phone_teilnehmerrufnummer_gueltig_bool
               }
         }
   }

% #1: Nummer
\cs_new_protected:Npn \phone_DE_MABEZnummernlaenge_ueberpruefen:N #1
   {
      \int_set:Nn \l_tmpa_int { \str_count:N #1 }
      \int_add:Nn \l_tmpa_int { \str_count:N \l_phone_bereinigte_durchwahl_str }

      \int_compare:nNnTF {\l_tmpa_int} > {11}
         {
            % Gesamtnummer hat mehr als 11 Stellen
            \msg_warning:nnnn {phonenumbers} {number too long} {0137~(MABEZ)} {11}
         }
         {
            \int_compare:nNnTF {\l_tmpa_int} < {11}
               {
                  % Gesamtnummer hat weniger als 11 Stellen
                  \msg_warning:nnnn {phonenumbers} {number too short} {0137~(MABEZ)} {11}
               }
               {
                  \bool_set_true:N \l_phone_teilnehmerrufnummer_gueltig_bool
               }
         }
   }

% #1: Vorwahl, #2: Teilnehmerrufnummer
\cs_new_protected:Npn \phone_DE_teilnehmerrufnummer_schreiben:Nn #1 #2
   {
      % Überprüfen der Nummernlänge
      \str_if_empty:NTF #1
         {
            % Festnetznummer ohne Vorwahl
            \bool_if:NF \l_phone_eingabe_leer_bool
               {
                  \phone_DE_festnetzteilnehmerrufnummernlaenge_ueberpruefen:Nn #1 {#2}
               }
         }
         {
            \clist_if_in:NVTF \c_phone_DE_ortsvorwahlen_clist #1
               {
                  % Festnetznummer
                  \str_if_eq:xnTF { \str_head:n {#2} } {0}
                     {
                        \msg_warning:nnn {phonenumbers} {illegal start of subscriber number} {0}
                     }
                     {
                        \phone_DE_festnetzteilnehmerrufnummernlaenge_ueberpruefen:Nn #1 {#2}
                     }
               }
               {
                  % Mobilfunk-/Sondernummer
                  \str_set_eq:NN \l_tmpa_str #1
                  \str_put_right:Nn \l_tmpa_str {#2}

                  \str_if_eq:xnTF { \str_range:Nnn #1 {1} {5} } {09009}
                     {
                        \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {12} {12} {09009}
                     }
                     {
                        \str_case:xnF { \str_range:Nnn #1 {1} {4} }
                           {
                              {0137} { \phone_DE_MABEZnummernlaenge_ueberpruefen:N \l_tmpa_str }
                              {0160} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {12} {mobile~phone} }
                              {0162} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {12} {mobile~phone} }
                              {0163} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {12} {mobile~phone} }
                              {0164} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {14} {0164} } % Funkruf
                              {0168} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {15} {0168} } % Funkruf
                              {0169} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {15} {0169} } % Funkruf
                              {0180} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {11} {0180} }
                              {0181} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {8} {15} {0181} }
                              {0191} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {14} {0191} }
                              {0192} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {14} {0192} }
                              {0193} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {5} {14} {0193} }
                              {0194} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {7} {14} {0194} }
                              {0700} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {12} {12} {0700} }
                              {0800} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {14} {freephone} }
                              {0900} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {11} {premium~service} }
                           }
                           {
                              \str_case:xn {\str_range:Nnn #1 {1} {3}}
                                 {
                                    {015} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {12} {12} {mobile~phone} }
                                    {017} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {11} {12} {mobile~phone} }
                                    {018} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {12} {12} {018} }
                                    {032} { \phone_nummernlaenge_ueberpruefen:Vnnn \l_tmpa_str {12} {12} {032} }
                                 }
                           }
                     }

                  \str_if_empty:NF \l_phone_bereinigte_durchwahl_str
                     {
                        % Mobilfunk- und Sondernummern dürfen keine Durchwahl enthalten (ausgenommen MABEZ-Nummern)
                        \str_if_eq:xnF { \str_range:Nnn #1 {1} {4} } {0137}
                           {
                              \msg_warning:nn {phonenumbers} {odd extension}
                           }
                     }
               }

            \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
               {
                  % Für gültige Nummern mit Vorwahl Linktext schreiben:
                  \str_put_right:Nn \l_phone_linktext_str {#2}
                  \str_put_right:NV \l_phone_linktext_str \l_phone_bereinigte_durchwahl_str
               }
               {
                  % Für ungültige Nummern mit Vorwahl Linktext löschen:
                  \str_clear:N \l_phone_linktext_str
               }
         }

      \bool_if:NTF \l_phone_teilnehmerrufnummer_gueltig_bool
         {
            \phone_von_hinten_gruppiert_schreiben:n {#2}
         }
         {
            \str_put_right:Nn \l_phone_ausgabetext_tl {#2}
         }

      \str_if_empty:NF \l_phone_bereinigte_durchwahl_str
         {
            \tl_put_right:NV \l_phone_ausgabetext_tl \c_phone_bindestrich_tl
            \phone_von_hinten_gruppiert_schreiben:V \l_phone_bereinigte_durchwahl_str
         }
   }

\cs_generate_variant:Nn \phone_DE_teilnehmerrufnummer_schreiben:Nn {Nx,NV}

\cs_new_protected:Npn \phone_DE_nummer_schreiben:
   {
      \str_if_eq:xnTF { \str_head:N \l_phone_bereinigte_nummer_str } {0}
         {
            \phone_enthaelt_vorwahl:NTF \l_phone_bereinigte_nummer_str
               {
                  \int_set:Nn \l_phone_hauptnummernlaenge_int { \str_count:N \l_phone_bereinigte_nummer_str }
                  \int_set:Nn \l_phone_vorwahllaenge_int { \str_count:N \l_phone_vorwahl_str }

                  \phone_DE_vorwahl_schreiben:Vx \l_phone_vorwahl_str
                     {
                        \int_compare_p:nNn {\l_phone_vorwahllaenge_int} < {\l_phone_hauptnummernlaenge_int}
                     }

                  \int_compare:nNnTF {\l_phone_vorwahllaenge_int} = {\l_phone_hauptnummernlaenge_int}
                     {
                        \msg_warning:nn {phonenumbers} {missing subscriber number}
                     }
                     {
                        \phone_DE_teilnehmerrufnummer_schreiben:Nx \l_phone_vorwahl_str
                           {
                              \str_range:Nnn \l_phone_bereinigte_nummer_str { \l_phone_vorwahllaenge_int + 1 } {-1}
                           }
                     }
               }
               {
                  \msg_warning:nn {phonenumbers} {invalid area code}
                  \tl_put_right:NV \l_phone_ausgabetext_tl \l_phone_bereinigte_nummer_str
                  \tl_put_right:NV \l_phone_ausgabetext_tl \l_phone_bereinigte_durchwahl_str
               }
         }
         {
            \phone_DE_teilnehmerrufnummer_schreiben:NV \c_empty_tl \l_phone_bereinigte_nummer_str
         }
   }

\cs_new_protected:Npn \phone_DE_vorwahlliste_ausgeben:n #1
   {
      \begin{tabbing}
      \hspace {4,5em} \= \kill

      \bool_set_false:N \l_phone_zeilenumbruch_bool

      \clist_map_inline:cn {c_phone_DE_ #1 _clist}
         {
            \bool_if:NTF \l_phone_zeilenumbruch_bool
               {
                  \\
               }
               {
                  \bool_gset_true:N \l_phone_zeilenumbruch_bool
               }

            \phone_DE_ziffernvorwahl_schreiben:nN {##1} \c_true_bool
            \tl_use:N \l_phone_ausgabetext_tl
            \>
            \tl_if_exist:cT {c_phone_DE_ortsname_ ##1 _tl}
               {
                  \tl_use:c {c_phone_DE_ortsname_ ##1 _tl}
               }
         }
      \end{tabbing}
   }
